import { ServiceUpdateMessage, ServiceUpdateMessageCollectionResponse } from '../../../models/microsoft/graph/';
import { ArchiveRequestBuilder } from './archive/archiveRequestBuilder';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { FavoriteRequestBuilder } from './favorite/favoriteRequestBuilder';
import { MarkReadRequestBuilder } from './markRead/markReadRequestBuilder';
import { MarkUnreadRequestBuilder } from './markUnread/markUnreadRequestBuilder';
import { UnarchiveRequestBuilder } from './unarchive/unarchiveRequestBuilder';
import { UnfavoriteRequestBuilder } from './unfavorite/unfavoriteRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity.  */
export declare class MessagesRequestBuilder {
    get archive(): ArchiveRequestBuilder;
    get count(): CountRequestBuilder;
    get favorite(): FavoriteRequestBuilder;
    get markRead(): MarkReadRequestBuilder;
    get markUnread(): MarkUnreadRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get unarchive(): UnarchiveRequestBuilder;
    get unfavorite(): UnfavoriteRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new MessagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        count?: boolean;
        expand?: string[];
        filter?: string;
        orderby?: string[];
        search?: string;
        select?: string[];
        skip?: number;
        top?: number;
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Create new navigation property to messages for admin
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: ServiceUpdateMessage | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceUpdateMessageCollectionResponse
     */
    get(q?: {
        count?: boolean;
        expand?: string[];
        filter?: string;
        orderby?: string[];
        search?: string;
        select?: string[];
        skip?: number;
        top?: number;
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<ServiceUpdateMessageCollectionResponse | undefined>;
    /**
     * Create new navigation property to messages for admin
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceUpdateMessage
     */
    post(body: ServiceUpdateMessage | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<ServiceUpdateMessage | undefined>;
}
