"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MessagesRequestBuilder = void 0;
const createServiceUpdateMessageCollectionResponseFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/createServiceUpdateMessageCollectionResponseFromDiscriminatorValue");
const createServiceUpdateMessageFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/createServiceUpdateMessageFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const archiveRequestBuilder_1 = require("./archive/archiveRequestBuilder");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const favoriteRequestBuilder_1 = require("./favorite/favoriteRequestBuilder");
const markReadRequestBuilder_1 = require("./markRead/markReadRequestBuilder");
const markUnreadRequestBuilder_1 = require("./markUnread/markUnreadRequestBuilder");
const unarchiveRequestBuilder_1 = require("./unarchive/unarchiveRequestBuilder");
const unfavoriteRequestBuilder_1 = require("./unfavorite/unfavoriteRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the messages property of the microsoft.graph.serviceAnnouncement entity.  */
class MessagesRequestBuilder {
    /**
     * Instantiates a new MessagesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/admin/serviceAnnouncement/messages{?top,skip,search,filter,count,orderby,select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get archive() {
        return new archiveRequestBuilder_1.ArchiveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get favorite() {
        return new favoriteRequestBuilder_1.FavoriteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get markRead() {
        return new markReadRequestBuilder_1.MarkReadRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get markUnread() {
        return new markUnreadRequestBuilder_1.MarkUnreadRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get unarchive() {
        return new unarchiveRequestBuilder_1.UnarchiveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get unfavorite() {
        return new unfavoriteRequestBuilder_1.UnfavoriteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Create new navigation property to messages for admin
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPostRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.POST;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * A collection of service messages for tenant. This property is a contained navigation property, it is nullable and readonly.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceUpdateMessageCollectionResponse
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createServiceUpdateMessageCollectionResponseFromDiscriminatorValue_1.createServiceUpdateMessageCollectionResponseFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Create new navigation property to messages for admin
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ServiceUpdateMessage
     */
    post(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPostRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createServiceUpdateMessageFromDiscriminatorValue_1.createServiceUpdateMessageFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.MessagesRequestBuilder = MessagesRequestBuilder;
