import { Application } from '../../models/microsoft/graph/';
import { AddKeyRequestBuilder } from './addKey/addKeyRequestBuilder';
import { AddPasswordRequestBuilder } from './addPassword/addPasswordRequestBuilder';
import { CheckMemberGroupsRequestBuilder } from './checkMemberGroups/checkMemberGroupsRequestBuilder';
import { CheckMemberObjectsRequestBuilder } from './checkMemberObjects/checkMemberObjectsRequestBuilder';
import { CreatedOnBehalfOfRequestBuilder } from './createdOnBehalfOf/createdOnBehalfOfRequestBuilder';
import { ExtensionPropertiesRequestBuilder } from './extensionProperties/extensionPropertiesRequestBuilder';
import { ExtensionPropertyItemRequestBuilder } from './extensionProperties/item/extensionPropertyItemRequestBuilder';
import { GetMemberGroupsRequestBuilder } from './getMemberGroups/getMemberGroupsRequestBuilder';
import { GetMemberObjectsRequestBuilder } from './getMemberObjects/getMemberObjectsRequestBuilder';
import { HomeRealmDiscoveryPoliciesRequestBuilder } from './homeRealmDiscoveryPolicies/homeRealmDiscoveryPoliciesRequestBuilder';
import { HomeRealmDiscoveryPolicyItemRequestBuilder } from './homeRealmDiscoveryPolicies/item/homeRealmDiscoveryPolicyItemRequestBuilder';
import { LogoRequestBuilder } from './logo/logoRequestBuilder';
import { DirectoryObjectItemRequestBuilder } from './owners/item/directoryObjectItemRequestBuilder';
import { OwnersRequestBuilder } from './owners/ownersRequestBuilder';
import { RemoveKeyRequestBuilder } from './removeKey/removeKeyRequestBuilder';
import { RemovePasswordRequestBuilder } from './removePassword/removePasswordRequestBuilder';
import { RestoreRequestBuilder } from './restore/restoreRequestBuilder';
import { SetVerifiedPublisherRequestBuilder } from './setVerifiedPublisher/setVerifiedPublisherRequestBuilder';
import { TokenIssuancePolicyItemRequestBuilder } from './tokenIssuancePolicies/item/tokenIssuancePolicyItemRequestBuilder';
import { TokenIssuancePoliciesRequestBuilder } from './tokenIssuancePolicies/tokenIssuancePoliciesRequestBuilder';
import { TokenLifetimePolicyItemRequestBuilder } from './tokenLifetimePolicies/item/tokenLifetimePolicyItemRequestBuilder';
import { TokenLifetimePoliciesRequestBuilder } from './tokenLifetimePolicies/tokenLifetimePoliciesRequestBuilder';
import { UnsetVerifiedPublisherRequestBuilder } from './unsetVerifiedPublisher/unsetVerifiedPublisherRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of application entities.  */
export declare class ApplicationItemRequestBuilder {
    get addKey(): AddKeyRequestBuilder;
    get addPassword(): AddPasswordRequestBuilder;
    get checkMemberGroups(): CheckMemberGroupsRequestBuilder;
    get checkMemberObjects(): CheckMemberObjectsRequestBuilder;
    get createdOnBehalfOf(): CreatedOnBehalfOfRequestBuilder;
    get extensionProperties(): ExtensionPropertiesRequestBuilder;
    get getMemberGroups(): GetMemberGroupsRequestBuilder;
    get getMemberObjects(): GetMemberObjectsRequestBuilder;
    get homeRealmDiscoveryPolicies(): HomeRealmDiscoveryPoliciesRequestBuilder;
    get logo(): LogoRequestBuilder;
    get owners(): OwnersRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get removeKey(): RemoveKeyRequestBuilder;
    get removePassword(): RemovePasswordRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get restore(): RestoreRequestBuilder;
    get setVerifiedPublisher(): SetVerifiedPublisherRequestBuilder;
    get tokenIssuancePolicies(): TokenIssuancePoliciesRequestBuilder;
    get tokenLifetimePolicies(): TokenLifetimePoliciesRequestBuilder;
    get unsetVerifiedPublisher(): UnsetVerifiedPublisherRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new ApplicationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from applications
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entity from applications by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update entity in applications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Application | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete entity from applications
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.extensionProperties.item collection
     * @param id Unique identifier of the item
     * @returns a extensionPropertyItemRequestBuilder
     */
    extensionPropertiesById(id: string): ExtensionPropertyItemRequestBuilder;
    /**
     * Get entity from applications by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Application
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Application | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.homeRealmDiscoveryPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a homeRealmDiscoveryPolicyItemRequestBuilder
     */
    homeRealmDiscoveryPoliciesById(id: string): HomeRealmDiscoveryPolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.owners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    ownersById(id: string): DirectoryObjectItemRequestBuilder;
    /**
     * Update entity in applications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Application | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.tokenIssuancePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenIssuancePolicyItemRequestBuilder
     */
    tokenIssuancePoliciesById(id: string): TokenIssuancePolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.tokenLifetimePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenLifetimePolicyItemRequestBuilder
     */
    tokenLifetimePoliciesById(id: string): TokenLifetimePolicyItemRequestBuilder;
}
