"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ApplicationItemRequestBuilder = void 0;
const createApplicationFromDiscriminatorValue_1 = require("../../models/microsoft/graph/createApplicationFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const addKeyRequestBuilder_1 = require("./addKey/addKeyRequestBuilder");
const addPasswordRequestBuilder_1 = require("./addPassword/addPasswordRequestBuilder");
const checkMemberGroupsRequestBuilder_1 = require("./checkMemberGroups/checkMemberGroupsRequestBuilder");
const checkMemberObjectsRequestBuilder_1 = require("./checkMemberObjects/checkMemberObjectsRequestBuilder");
const createdOnBehalfOfRequestBuilder_1 = require("./createdOnBehalfOf/createdOnBehalfOfRequestBuilder");
const extensionPropertiesRequestBuilder_1 = require("./extensionProperties/extensionPropertiesRequestBuilder");
const extensionPropertyItemRequestBuilder_1 = require("./extensionProperties/item/extensionPropertyItemRequestBuilder");
const getMemberGroupsRequestBuilder_1 = require("./getMemberGroups/getMemberGroupsRequestBuilder");
const getMemberObjectsRequestBuilder_1 = require("./getMemberObjects/getMemberObjectsRequestBuilder");
const homeRealmDiscoveryPoliciesRequestBuilder_1 = require("./homeRealmDiscoveryPolicies/homeRealmDiscoveryPoliciesRequestBuilder");
const homeRealmDiscoveryPolicyItemRequestBuilder_1 = require("./homeRealmDiscoveryPolicies/item/homeRealmDiscoveryPolicyItemRequestBuilder");
const logoRequestBuilder_1 = require("./logo/logoRequestBuilder");
const directoryObjectItemRequestBuilder_1 = require("./owners/item/directoryObjectItemRequestBuilder");
const ownersRequestBuilder_1 = require("./owners/ownersRequestBuilder");
const removeKeyRequestBuilder_1 = require("./removeKey/removeKeyRequestBuilder");
const removePasswordRequestBuilder_1 = require("./removePassword/removePasswordRequestBuilder");
const restoreRequestBuilder_1 = require("./restore/restoreRequestBuilder");
const setVerifiedPublisherRequestBuilder_1 = require("./setVerifiedPublisher/setVerifiedPublisherRequestBuilder");
const tokenIssuancePolicyItemRequestBuilder_1 = require("./tokenIssuancePolicies/item/tokenIssuancePolicyItemRequestBuilder");
const tokenIssuancePoliciesRequestBuilder_1 = require("./tokenIssuancePolicies/tokenIssuancePoliciesRequestBuilder");
const tokenLifetimePolicyItemRequestBuilder_1 = require("./tokenLifetimePolicies/item/tokenLifetimePolicyItemRequestBuilder");
const tokenLifetimePoliciesRequestBuilder_1 = require("./tokenLifetimePolicies/tokenLifetimePoliciesRequestBuilder");
const unsetVerifiedPublisherRequestBuilder_1 = require("./unsetVerifiedPublisher/unsetVerifiedPublisherRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the collection of application entities.  */
class ApplicationItemRequestBuilder {
    /**
     * Instantiates a new ApplicationItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/applications/{application_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get addKey() {
        return new addKeyRequestBuilder_1.AddKeyRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get addPassword() {
        return new addPasswordRequestBuilder_1.AddPasswordRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get checkMemberGroups() {
        return new checkMemberGroupsRequestBuilder_1.CheckMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get checkMemberObjects() {
        return new checkMemberObjectsRequestBuilder_1.CheckMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get createdOnBehalfOf() {
        return new createdOnBehalfOfRequestBuilder_1.CreatedOnBehalfOfRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get extensionProperties() {
        return new extensionPropertiesRequestBuilder_1.ExtensionPropertiesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get getMemberGroups() {
        return new getMemberGroupsRequestBuilder_1.GetMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get getMemberObjects() {
        return new getMemberObjectsRequestBuilder_1.GetMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get homeRealmDiscoveryPolicies() {
        return new homeRealmDiscoveryPoliciesRequestBuilder_1.HomeRealmDiscoveryPoliciesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get logo() {
        return new logoRequestBuilder_1.LogoRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get owners() {
        return new ownersRequestBuilder_1.OwnersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get removeKey() {
        return new removeKeyRequestBuilder_1.RemoveKeyRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get removePassword() {
        return new removePasswordRequestBuilder_1.RemovePasswordRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get restore() {
        return new restoreRequestBuilder_1.RestoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get setVerifiedPublisher() {
        return new setVerifiedPublisherRequestBuilder_1.SetVerifiedPublisherRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get tokenIssuancePolicies() {
        return new tokenIssuancePoliciesRequestBuilder_1.TokenIssuancePoliciesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get tokenLifetimePolicies() {
        return new tokenLifetimePoliciesRequestBuilder_1.TokenLifetimePoliciesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get unsetVerifiedPublisher() {
        return new unsetVerifiedPublisherRequestBuilder_1.UnsetVerifiedPublisherRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete entity from applications
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Get entity from applications by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update entity in applications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete entity from applications
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.extensionProperties.item collection
     * @param id Unique identifier of the item
     * @returns a extensionPropertyItemRequestBuilder
     */
    extensionPropertiesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["extensionProperty_id"] = id;
        return new extensionPropertyItemRequestBuilder_1.ExtensionPropertyItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Get entity from applications by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Application
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createApplicationFromDiscriminatorValue_1.createApplicationFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.homeRealmDiscoveryPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a homeRealmDiscoveryPolicyItemRequestBuilder
     */
    homeRealmDiscoveryPoliciesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["homeRealmDiscoveryPolicy_id"] = id;
        return new homeRealmDiscoveryPolicyItemRequestBuilder_1.HomeRealmDiscoveryPolicyItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.owners.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    ownersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["directoryObject_id"] = id;
        return new directoryObjectItemRequestBuilder_1.DirectoryObjectItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update entity in applications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.tokenIssuancePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenIssuancePolicyItemRequestBuilder
     */
    tokenIssuancePoliciesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["tokenIssuancePolicy_id"] = id;
        return new tokenIssuancePolicyItemRequestBuilder_1.TokenIssuancePolicyItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.applications.item.tokenLifetimePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenLifetimePolicyItemRequestBuilder
     */
    tokenLifetimePoliciesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["tokenLifetimePolicy_id"] = id;
        return new tokenLifetimePolicyItemRequestBuilder_1.TokenLifetimePolicyItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.ApplicationItemRequestBuilder = ApplicationItemRequestBuilder;
