import { Call } from '../../../models/microsoft/graph/';
import { AnswerRequestBuilder } from './answer/answerRequestBuilder';
import { AudioRoutingGroupsRequestBuilder } from './audioRoutingGroups/audioRoutingGroupsRequestBuilder';
import { AudioRoutingGroupItemRequestBuilder } from './audioRoutingGroups/item/audioRoutingGroupItemRequestBuilder';
import { CancelMediaProcessingRequestBuilder } from './cancelMediaProcessing/cancelMediaProcessingRequestBuilder';
import { ChangeScreenSharingRoleRequestBuilder } from './changeScreenSharingRole/changeScreenSharingRoleRequestBuilder';
import { KeepAliveRequestBuilder } from './keepAlive/keepAliveRequestBuilder';
import { MuteRequestBuilder } from './mute/muteRequestBuilder';
import { CommsOperationItemRequestBuilder } from './operations/item/commsOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { ParticipantItemRequestBuilder } from './participants/item/participantItemRequestBuilder';
import { ParticipantsRequestBuilder } from './participants/participantsRequestBuilder';
import { PlayPromptRequestBuilder } from './playPrompt/playPromptRequestBuilder';
import { RecordResponseRequestBuilder } from './recordResponse/recordResponseRequestBuilder';
import { RedirectRequestBuilder } from './redirect/redirectRequestBuilder';
import { RejectRequestBuilder } from './reject/rejectRequestBuilder';
import { SubscribeToToneRequestBuilder } from './subscribeToTone/subscribeToToneRequestBuilder';
import { TransferRequestBuilder } from './transfer/transferRequestBuilder';
import { UnmuteRequestBuilder } from './unmute/unmuteRequestBuilder';
import { UpdateRecordingStatusRequestBuilder } from './updateRecordingStatus/updateRecordingStatusRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.  */
export declare class CallItemRequestBuilder {
    get answer(): AnswerRequestBuilder;
    get audioRoutingGroups(): AudioRoutingGroupsRequestBuilder;
    get cancelMediaProcessing(): CancelMediaProcessingRequestBuilder;
    get changeScreenSharingRole(): ChangeScreenSharingRoleRequestBuilder;
    get keepAlive(): KeepAliveRequestBuilder;
    get mute(): MuteRequestBuilder;
    get operations(): OperationsRequestBuilder;
    get participants(): ParticipantsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get playPrompt(): PlayPromptRequestBuilder;
    get recordResponse(): RecordResponseRequestBuilder;
    get redirect(): RedirectRequestBuilder;
    get reject(): RejectRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get subscribeToTone(): SubscribeToToneRequestBuilder;
    get transfer(): TransferRequestBuilder;
    get unmute(): UnmuteRequestBuilder;
    get updateRecordingStatus(): UpdateRecordingStatusRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.audioRoutingGroups.item collection
     * @param id Unique identifier of the item
     * @returns a audioRoutingGroupItemRequestBuilder
     */
    audioRoutingGroupsById(id: string): AudioRoutingGroupItemRequestBuilder;
    /**
     * Instantiates a new CallItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property calls for communications
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get calls from communications
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property calls in communications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Call | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property calls for communications
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get calls from communications
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Call
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Call | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a commsOperationItemRequestBuilder
     */
    operationsById(id: string): CommsOperationItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.participants.item collection
     * @param id Unique identifier of the item
     * @returns a participantItemRequestBuilder
     */
    participantsById(id: string): ParticipantItemRequestBuilder;
    /**
     * Update the navigation property calls in communications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Call | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
