"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CallItemRequestBuilder = void 0;
const createCallFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/createCallFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const answerRequestBuilder_1 = require("./answer/answerRequestBuilder");
const audioRoutingGroupsRequestBuilder_1 = require("./audioRoutingGroups/audioRoutingGroupsRequestBuilder");
const audioRoutingGroupItemRequestBuilder_1 = require("./audioRoutingGroups/item/audioRoutingGroupItemRequestBuilder");
const cancelMediaProcessingRequestBuilder_1 = require("./cancelMediaProcessing/cancelMediaProcessingRequestBuilder");
const changeScreenSharingRoleRequestBuilder_1 = require("./changeScreenSharingRole/changeScreenSharingRoleRequestBuilder");
const keepAliveRequestBuilder_1 = require("./keepAlive/keepAliveRequestBuilder");
const muteRequestBuilder_1 = require("./mute/muteRequestBuilder");
const commsOperationItemRequestBuilder_1 = require("./operations/item/commsOperationItemRequestBuilder");
const operationsRequestBuilder_1 = require("./operations/operationsRequestBuilder");
const participantItemRequestBuilder_1 = require("./participants/item/participantItemRequestBuilder");
const participantsRequestBuilder_1 = require("./participants/participantsRequestBuilder");
const playPromptRequestBuilder_1 = require("./playPrompt/playPromptRequestBuilder");
const recordResponseRequestBuilder_1 = require("./recordResponse/recordResponseRequestBuilder");
const redirectRequestBuilder_1 = require("./redirect/redirectRequestBuilder");
const rejectRequestBuilder_1 = require("./reject/rejectRequestBuilder");
const subscribeToToneRequestBuilder_1 = require("./subscribeToTone/subscribeToToneRequestBuilder");
const transferRequestBuilder_1 = require("./transfer/transferRequestBuilder");
const unmuteRequestBuilder_1 = require("./unmute/unmuteRequestBuilder");
const updateRecordingStatusRequestBuilder_1 = require("./updateRecordingStatus/updateRecordingStatusRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the calls property of the microsoft.graph.cloudCommunications entity.  */
class CallItemRequestBuilder {
    /**
     * Instantiates a new CallItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/communications/calls/{call_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get answer() {
        return new answerRequestBuilder_1.AnswerRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get audioRoutingGroups() {
        return new audioRoutingGroupsRequestBuilder_1.AudioRoutingGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get cancelMediaProcessing() {
        return new cancelMediaProcessingRequestBuilder_1.CancelMediaProcessingRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get changeScreenSharingRole() {
        return new changeScreenSharingRoleRequestBuilder_1.ChangeScreenSharingRoleRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get keepAlive() {
        return new keepAliveRequestBuilder_1.KeepAliveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get mute() {
        return new muteRequestBuilder_1.MuteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get operations() {
        return new operationsRequestBuilder_1.OperationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get participants() {
        return new participantsRequestBuilder_1.ParticipantsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get playPrompt() {
        return new playPromptRequestBuilder_1.PlayPromptRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get recordResponse() {
        return new recordResponseRequestBuilder_1.RecordResponseRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get redirect() {
        return new redirectRequestBuilder_1.RedirectRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get reject() {
        return new rejectRequestBuilder_1.RejectRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get subscribeToTone() {
        return new subscribeToToneRequestBuilder_1.SubscribeToToneRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get transfer() {
        return new transferRequestBuilder_1.TransferRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get unmute() {
        return new unmuteRequestBuilder_1.UnmuteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get updateRecordingStatus() {
        return new updateRecordingStatusRequestBuilder_1.UpdateRecordingStatusRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.audioRoutingGroups.item collection
     * @param id Unique identifier of the item
     * @returns a audioRoutingGroupItemRequestBuilder
     */
    audioRoutingGroupsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["audioRoutingGroup_id"] = id;
        return new audioRoutingGroupItemRequestBuilder_1.AudioRoutingGroupItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property calls for communications
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Get calls from communications
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property calls in communications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property calls for communications
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Get calls from communications
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Call
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createCallFromDiscriminatorValue_1.createCallFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a commsOperationItemRequestBuilder
     */
    operationsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["commsOperation_id"] = id;
        return new commsOperationItemRequestBuilder_1.CommsOperationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item.participants.item collection
     * @param id Unique identifier of the item
     * @returns a participantItemRequestBuilder
     */
    participantsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["participant_id"] = id;
        return new participantItemRequestBuilder_1.ParticipantItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property calls in communications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.CallItemRequestBuilder = CallItemRequestBuilder;
