import { CloudCommunications } from '../models/microsoft/graph/';
import { CallRecordsRequestBuilder } from './callRecords/callRecordsRequestBuilder';
import { CallRecordItemRequestBuilder } from './callRecords/item/callRecordItemRequestBuilder';
import { CallsRequestBuilder } from './calls/callsRequestBuilder';
import { CallItemRequestBuilder } from './calls/item/callItemRequestBuilder';
import { GetPresencesByUserIdRequestBuilder } from './getPresencesByUserId/getPresencesByUserIdRequestBuilder';
import { OnlineMeetingItemRequestBuilder } from './onlineMeetings/item/onlineMeetingItemRequestBuilder';
import { OnlineMeetingsRequestBuilder } from './onlineMeetings/onlineMeetingsRequestBuilder';
import { PresenceItemRequestBuilder } from './presences/item/presenceItemRequestBuilder';
import { PresencesRequestBuilder } from './presences/presencesRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the cloudCommunications singleton.  */
export declare class CommunicationsRequestBuilder {
    get callRecords(): CallRecordsRequestBuilder;
    get calls(): CallsRequestBuilder;
    get getPresencesByUserId(): GetPresencesByUserIdRequestBuilder;
    get onlineMeetings(): OnlineMeetingsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get presences(): PresencesRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.callRecords.item collection
     * @param id Unique identifier of the item
     * @returns a callRecordItemRequestBuilder
     */
    callRecordsById(id: string): CallRecordItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.calls.item collection
     * @param id Unique identifier of the item
     * @returns a callItemRequestBuilder
     */
    callsById(id: string): CallItemRequestBuilder;
    /**
     * Instantiates a new CommunicationsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get communications
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update communications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: CloudCommunications | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get communications
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of CloudCommunications
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<CloudCommunications | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.onlineMeetings.item collection
     * @param id Unique identifier of the item
     * @returns a onlineMeetingItemRequestBuilder
     */
    onlineMeetingsById(id: string): OnlineMeetingItemRequestBuilder;
    /**
     * Update communications
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: CloudCommunications | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.communications.presences.item collection
     * @param id Unique identifier of the item
     * @returns a presenceItemRequestBuilder
     */
    presencesById(id: string): PresenceItemRequestBuilder;
}
