import { ManagedEBook } from '../../../models/microsoft/graph/';
import { AssignRequestBuilder } from './assign/assignRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { ManagedEBookAssignmentItemRequestBuilder } from './assignments/item/managedEBookAssignmentItemRequestBuilder';
import { DeviceStatesRequestBuilder } from './deviceStates/deviceStatesRequestBuilder';
import { DeviceInstallStateItemRequestBuilder } from './deviceStates/item/deviceInstallStateItemRequestBuilder';
import { InstallSummaryRequestBuilder } from './installSummary/installSummaryRequestBuilder';
import { UserInstallStateSummaryItemRequestBuilder } from './userStateSummary/item/userInstallStateSummaryItemRequestBuilder';
import { UserStateSummaryRequestBuilder } from './userStateSummary/userStateSummaryRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity.  */
export declare class ManagedEBookItemRequestBuilder {
    get assign(): AssignRequestBuilder;
    get assignments(): AssignmentsRequestBuilder;
    get deviceStates(): DeviceStatesRequestBuilder;
    get installSummary(): InstallSummaryRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    get userStateSummary(): UserStateSummaryRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a managedEBookAssignmentItemRequestBuilder
     */
    assignmentsById(id: string): ManagedEBookAssignmentItemRequestBuilder;
    /**
     * Instantiates a new ManagedEBookItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The Managed eBook.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: ManagedEBook | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.deviceStates.item collection
     * @param id Unique identifier of the item
     * @returns a deviceInstallStateItemRequestBuilder
     */
    deviceStatesById(id: string): DeviceInstallStateItemRequestBuilder;
    /**
     * The Managed eBook.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ManagedEBook
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<ManagedEBook | undefined>;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: ManagedEBook | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.userStateSummary.item collection
     * @param id Unique identifier of the item
     * @returns a userInstallStateSummaryItemRequestBuilder
     */
    userStateSummaryById(id: string): UserInstallStateSummaryItemRequestBuilder;
}
