"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ManagedEBookItemRequestBuilder = void 0;
const createManagedEBookFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/createManagedEBookFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const assignRequestBuilder_1 = require("./assign/assignRequestBuilder");
const assignmentsRequestBuilder_1 = require("./assignments/assignmentsRequestBuilder");
const managedEBookAssignmentItemRequestBuilder_1 = require("./assignments/item/managedEBookAssignmentItemRequestBuilder");
const deviceStatesRequestBuilder_1 = require("./deviceStates/deviceStatesRequestBuilder");
const deviceInstallStateItemRequestBuilder_1 = require("./deviceStates/item/deviceInstallStateItemRequestBuilder");
const installSummaryRequestBuilder_1 = require("./installSummary/installSummaryRequestBuilder");
const userInstallStateSummaryItemRequestBuilder_1 = require("./userStateSummary/item/userInstallStateSummaryItemRequestBuilder");
const userStateSummaryRequestBuilder_1 = require("./userStateSummary/userStateSummaryRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the managedEBooks property of the microsoft.graph.deviceAppManagement entity.  */
class ManagedEBookItemRequestBuilder {
    /**
     * Instantiates a new ManagedEBookItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/deviceAppManagement/managedEBooks/{managedEBook_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get assign() {
        return new assignRequestBuilder_1.AssignRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get assignments() {
        return new assignmentsRequestBuilder_1.AssignmentsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get deviceStates() {
        return new deviceStatesRequestBuilder_1.DeviceStatesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get installSummary() {
        return new installSummaryRequestBuilder_1.InstallSummaryRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get userStateSummary() {
        return new userStateSummaryRequestBuilder_1.UserStateSummaryRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a managedEBookAssignmentItemRequestBuilder
     */
    assignmentsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["managedEBookAssignment_id"] = id;
        return new managedEBookAssignmentItemRequestBuilder_1.ManagedEBookAssignmentItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * The Managed eBook.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property managedEBooks for deviceAppManagement
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.deviceStates.item collection
     * @param id Unique identifier of the item
     * @returns a deviceInstallStateItemRequestBuilder
     */
    deviceStatesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["deviceInstallState_id"] = id;
        return new deviceInstallStateItemRequestBuilder_1.DeviceInstallStateItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * The Managed eBook.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ManagedEBook
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createManagedEBookFromDiscriminatorValue_1.createManagedEBookFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property managedEBooks in deviceAppManagement
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceAppManagement.managedEBooks.item.userStateSummary.item collection
     * @param id Unique identifier of the item
     * @returns a userInstallStateSummaryItemRequestBuilder
     */
    userStateSummaryById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["userInstallStateSummary_id"] = id;
        return new userInstallStateSummaryItemRequestBuilder_1.UserInstallStateSummaryItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.ManagedEBookItemRequestBuilder = ManagedEBookItemRequestBuilder;
