import { DeviceCompliancePolicy } from '../../../models/microsoft/graph/';
import { AssignRequestBuilder } from './assign/assignRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { DeviceCompliancePolicyAssignmentItemRequestBuilder } from './assignments/item/deviceCompliancePolicyAssignmentItemRequestBuilder';
import { DeviceSettingStateSummariesRequestBuilder } from './deviceSettingStateSummaries/deviceSettingStateSummariesRequestBuilder';
import { SettingStateDeviceSummaryItemRequestBuilder } from './deviceSettingStateSummaries/item/settingStateDeviceSummaryItemRequestBuilder';
import { DeviceStatusesRequestBuilder } from './deviceStatuses/deviceStatusesRequestBuilder';
import { DeviceComplianceDeviceStatusItemRequestBuilder } from './deviceStatuses/item/deviceComplianceDeviceStatusItemRequestBuilder';
import { DeviceStatusOverviewRequestBuilder } from './deviceStatusOverview/deviceStatusOverviewRequestBuilder';
import { ScheduleActionsForRulesRequestBuilder } from './scheduleActionsForRules/scheduleActionsForRulesRequestBuilder';
import { DeviceComplianceScheduledActionForRuleItemRequestBuilder } from './scheduledActionsForRule/item/deviceComplianceScheduledActionForRuleItemRequestBuilder';
import { ScheduledActionsForRuleRequestBuilder } from './scheduledActionsForRule/scheduledActionsForRuleRequestBuilder';
import { DeviceComplianceUserStatusItemRequestBuilder } from './userStatuses/item/deviceComplianceUserStatusItemRequestBuilder';
import { UserStatusesRequestBuilder } from './userStatuses/userStatusesRequestBuilder';
import { UserStatusOverviewRequestBuilder } from './userStatusOverview/userStatusOverviewRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the deviceCompliancePolicies property of the microsoft.graph.deviceManagement entity.  */
export declare class DeviceCompliancePolicyItemRequestBuilder {
    get assign(): AssignRequestBuilder;
    get assignments(): AssignmentsRequestBuilder;
    get deviceSettingStateSummaries(): DeviceSettingStateSummariesRequestBuilder;
    get deviceStatuses(): DeviceStatusesRequestBuilder;
    get deviceStatusOverview(): DeviceStatusOverviewRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get scheduleActionsForRules(): ScheduleActionsForRulesRequestBuilder;
    get scheduledActionsForRule(): ScheduledActionsForRuleRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    get userStatuses(): UserStatusesRequestBuilder;
    get userStatusOverview(): UserStatusOverviewRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a deviceCompliancePolicyAssignmentItemRequestBuilder
     */
    assignmentsById(id: string): DeviceCompliancePolicyAssignmentItemRequestBuilder;
    /**
     * Instantiates a new DeviceCompliancePolicyItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property deviceCompliancePolicies for deviceManagement
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The device compliance policies.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property deviceCompliancePolicies in deviceManagement
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: DeviceCompliancePolicy | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property deviceCompliancePolicies for deviceManagement
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.deviceSettingStateSummaries.item collection
     * @param id Unique identifier of the item
     * @returns a settingStateDeviceSummaryItemRequestBuilder
     */
    deviceSettingStateSummariesById(id: string): SettingStateDeviceSummaryItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.deviceStatuses.item collection
     * @param id Unique identifier of the item
     * @returns a deviceComplianceDeviceStatusItemRequestBuilder
     */
    deviceStatusesById(id: string): DeviceComplianceDeviceStatusItemRequestBuilder;
    /**
     * The device compliance policies.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DeviceCompliancePolicy
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<DeviceCompliancePolicy | undefined>;
    /**
     * Update the navigation property deviceCompliancePolicies in deviceManagement
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: DeviceCompliancePolicy | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.scheduledActionsForRule.item collection
     * @param id Unique identifier of the item
     * @returns a deviceComplianceScheduledActionForRuleItemRequestBuilder
     */
    scheduledActionsForRuleById(id: string): DeviceComplianceScheduledActionForRuleItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.deviceManagement.deviceCompliancePolicies.item.userStatuses.item collection
     * @param id Unique identifier of the item
     * @returns a deviceComplianceUserStatusItemRequestBuilder
     */
    userStatusesById(id: string): DeviceComplianceUserStatusItemRequestBuilder;
}
