import { Domain } from '../../models/microsoft/graph/';
import { DomainNameReferencesRequestBuilder } from './domainNameReferences/domainNameReferencesRequestBuilder';
import { DirectoryObjectItemRequestBuilder } from './domainNameReferences/item/directoryObjectItemRequestBuilder';
import { ForceDeleteRequestBuilder } from './forceDelete/forceDeleteRequestBuilder';
import { DomainDnsRecordItemRequestBuilder as if42c50e3e2ba9cccdeb447503ef296586e785bdceb37d68d3f26a20ec7a74730 } from './serviceConfigurationRecords/item/domainDnsRecordItemRequestBuilder';
import { ServiceConfigurationRecordsRequestBuilder } from './serviceConfigurationRecords/serviceConfigurationRecordsRequestBuilder';
import { DomainDnsRecordItemRequestBuilder as i34c2b049a11a56a0e845314c4913041442dc5d005e49ac8abe88e67f09a2a130 } from './verificationDnsRecords/item/domainDnsRecordItemRequestBuilder';
import { VerificationDnsRecordsRequestBuilder } from './verificationDnsRecords/verificationDnsRecordsRequestBuilder';
import { VerifyRequestBuilder } from './verify/verifyRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of domain entities.  */
export declare class DomainItemRequestBuilder {
    get domainNameReferences(): DomainNameReferencesRequestBuilder;
    get forceDelete(): ForceDeleteRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get serviceConfigurationRecords(): ServiceConfigurationRecordsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    get verificationDnsRecords(): VerificationDnsRecordsRequestBuilder;
    get verify(): VerifyRequestBuilder;
    /**
     * Instantiates a new DomainItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from domains
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entity from domains by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update entity in domains
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Domain | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete entity from domains
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.domainNameReferences.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    domainNameReferencesById(id: string): DirectoryObjectItemRequestBuilder;
    /**
     * Get entity from domains by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Domain
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Domain | undefined>;
    /**
     * Update entity in domains
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Domain | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.serviceConfigurationRecords.item collection
     * @param id Unique identifier of the item
     * @returns a domainDnsRecordItemRequestBuilder
     */
    serviceConfigurationRecordsById(id: string): if42c50e3e2ba9cccdeb447503ef296586e785bdceb37d68d3f26a20ec7a74730;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.verificationDnsRecords.item collection
     * @param id Unique identifier of the item
     * @returns a domainDnsRecordItemRequestBuilder
     */
    verificationDnsRecordsById(id: string): i34c2b049a11a56a0e845314c4913041442dc5d005e49ac8abe88e67f09a2a130;
}
