"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DomainItemRequestBuilder = void 0;
const createDomainFromDiscriminatorValue_1 = require("../../models/microsoft/graph/createDomainFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const domainNameReferencesRequestBuilder_1 = require("./domainNameReferences/domainNameReferencesRequestBuilder");
const directoryObjectItemRequestBuilder_1 = require("./domainNameReferences/item/directoryObjectItemRequestBuilder");
const forceDeleteRequestBuilder_1 = require("./forceDelete/forceDeleteRequestBuilder");
const domainDnsRecordItemRequestBuilder_1 = require("./serviceConfigurationRecords/item/domainDnsRecordItemRequestBuilder");
const serviceConfigurationRecordsRequestBuilder_1 = require("./serviceConfigurationRecords/serviceConfigurationRecordsRequestBuilder");
const domainDnsRecordItemRequestBuilder_2 = require("./verificationDnsRecords/item/domainDnsRecordItemRequestBuilder");
const verificationDnsRecordsRequestBuilder_1 = require("./verificationDnsRecords/verificationDnsRecordsRequestBuilder");
const verifyRequestBuilder_1 = require("./verify/verifyRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the collection of domain entities.  */
class DomainItemRequestBuilder {
    /**
     * Instantiates a new DomainItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/domains/{domain_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get domainNameReferences() {
        return new domainNameReferencesRequestBuilder_1.DomainNameReferencesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get forceDelete() {
        return new forceDeleteRequestBuilder_1.ForceDeleteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get serviceConfigurationRecords() {
        return new serviceConfigurationRecordsRequestBuilder_1.ServiceConfigurationRecordsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get verificationDnsRecords() {
        return new verificationDnsRecordsRequestBuilder_1.VerificationDnsRecordsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get verify() {
        return new verifyRequestBuilder_1.VerifyRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete entity from domains
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Get entity from domains by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update entity in domains
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete entity from domains
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.domainNameReferences.item collection
     * @param id Unique identifier of the item
     * @returns a directoryObjectItemRequestBuilder
     */
    domainNameReferencesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["directoryObject_id"] = id;
        return new directoryObjectItemRequestBuilder_1.DirectoryObjectItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Get entity from domains by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Domain
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createDomainFromDiscriminatorValue_1.createDomainFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update entity in domains
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.serviceConfigurationRecords.item collection
     * @param id Unique identifier of the item
     * @returns a domainDnsRecordItemRequestBuilder
     */
    serviceConfigurationRecordsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["domainDnsRecord_id"] = id;
        return new domainDnsRecordItemRequestBuilder_1.DomainDnsRecordItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.domains.item.verificationDnsRecords.item collection
     * @param id Unique identifier of the item
     * @returns a domainDnsRecordItemRequestBuilder
     */
    verificationDnsRecordsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["domainDnsRecord_id"] = id;
        return new domainDnsRecordItemRequestBuilder_2.DomainDnsRecordItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.DomainItemRequestBuilder = DomainItemRequestBuilder;
