import { Drive } from '../../models/microsoft/graph/';
import { BundlesRequestBuilder } from './bundles/bundlesRequestBuilder';
import { DriveItemItemRequestBuilder as iec6540cb1b85c361f7498e16b8ff950ff6195284a7c81ff665b7e1f6d0a6467f } from './bundles/item/driveItemItemRequestBuilder';
import { FollowingRequestBuilder } from './following/followingRequestBuilder';
import { DriveItemItemRequestBuilder as ia433b3c4b605213b36a6f31cdeafb12f94f5c69196f54ddda4db73ad976d1de5 } from './following/item/driveItemItemRequestBuilder';
import { DriveItemItemRequestBuilder as i002cedadeca1aa85247aeaa257298200371bfb79bc47ad91e1ee91fb9267685a } from './items/item/driveItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ListRequestBuilder } from './list/listRequestBuilder';
import { RecentRequestBuilder } from './recent/recentRequestBuilder';
import { RootRequestBuilder } from './root/rootRequestBuilder';
import { SearchWithQRequestBuilder } from './searchWithQ/searchWithQRequestBuilder';
import { SharedWithMeRequestBuilder } from './sharedWithMe/sharedWithMeRequestBuilder';
import { DriveItemItemRequestBuilder as i9eefba1d233a2d7ded037a6d83666626c509c52c7315f140eec8cae30add088b } from './special/item/driveItemItemRequestBuilder';
import { SpecialRequestBuilder } from './special/specialRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of drive entities.  */
export declare class DriveItemRequestBuilder {
    get bundles(): BundlesRequestBuilder;
    get following(): FollowingRequestBuilder;
    get items(): ItemsRequestBuilder;
    get list(): ListRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get root(): RootRequestBuilder;
    get special(): SpecialRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.bundles.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    bundlesById(id: string): iec6540cb1b85c361f7498e16b8ff950ff6195284a7c81ff665b7e1f6d0a6467f;
    /**
     * Instantiates a new DriveItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from drives
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entity from drives by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update entity in drives
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Drive | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete entity from drives
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.following.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    followingById(id: string): ia433b3c4b605213b36a6f31cdeafb12f94f5c69196f54ddda4db73ad976d1de5;
    /**
     * Get entity from drives by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Drive
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Drive | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    itemsById(id: string): i002cedadeca1aa85247aeaa257298200371bfb79bc47ad91e1ee91fb9267685a;
    /**
     * Update entity in drives
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Drive | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Provides operations to call the recent method.
     * @returns a recentRequestBuilder
     */
    recent(): RecentRequestBuilder;
    /**
     * Provides operations to call the search method.
     * @param q Usage: q='{q}'
     * @returns a searchWithQRequestBuilder
     */
    searchWithQ(q: string | undefined): SearchWithQRequestBuilder;
    /**
     * Provides operations to call the sharedWithMe method.
     * @returns a sharedWithMeRequestBuilder
     */
    sharedWithMe(): SharedWithMeRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.drives.item.special.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    specialById(id: string): i9eefba1d233a2d7ded037a6d83666626c509c52c7315f140eec8cae30add088b;
}
