"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EducationAssignmentItemRequestBuilder = void 0;
const createEducationAssignmentFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/createEducationAssignmentFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const categoriesRequestBuilder_1 = require("./categories/categoriesRequestBuilder");
const educationCategoryItemRequestBuilder_1 = require("./categories/item/educationCategoryItemRequestBuilder");
const publishRequestBuilder_1 = require("./publish/publishRequestBuilder");
const educationAssignmentResourceItemRequestBuilder_1 = require("./resources/item/educationAssignmentResourceItemRequestBuilder");
const resourcesRequestBuilder_1 = require("./resources/resourcesRequestBuilder");
const rubricRequestBuilder_1 = require("./rubric/rubricRequestBuilder");
const setUpResourcesFolderRequestBuilder_1 = require("./setUpResourcesFolder/setUpResourcesFolderRequestBuilder");
const educationSubmissionItemRequestBuilder_1 = require("./submissions/item/educationSubmissionItemRequestBuilder");
const submissionsRequestBuilder_1 = require("./submissions/submissionsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the assignments property of the microsoft.graph.educationUser entity.  */
class EducationAssignmentItemRequestBuilder {
    /**
     * Instantiates a new EducationAssignmentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/education/me/assignments/{educationAssignment_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get categories() {
        return new categoriesRequestBuilder_1.CategoriesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get publish() {
        return new publishRequestBuilder_1.PublishRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get resources() {
        return new resourcesRequestBuilder_1.ResourcesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get rubric() {
        return new rubricRequestBuilder_1.RubricRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get setUpResourcesFolder() {
        return new setUpResourcesFolderRequestBuilder_1.SetUpResourcesFolderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get submissions() {
        return new submissionsRequestBuilder_1.SubmissionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.me.assignments.item.categories.item collection
     * @param id Unique identifier of the item
     * @returns a educationCategoryItemRequestBuilder
     */
    categoriesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationCategory_id"] = id;
        return new educationCategoryItemRequestBuilder_1.EducationCategoryItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property assignments for education
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Assignments belonging to the user.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property assignments in education
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property assignments for education
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Assignments belonging to the user.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EducationAssignment
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createEducationAssignmentFromDiscriminatorValue_1.createEducationAssignmentFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property assignments in education
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.me.assignments.item.resources.item collection
     * @param id Unique identifier of the item
     * @returns a educationAssignmentResourceItemRequestBuilder
     */
    resourcesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationAssignmentResource_id"] = id;
        return new educationAssignmentResourceItemRequestBuilder_1.EducationAssignmentResourceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.me.assignments.item.submissions.item collection
     * @param id Unique identifier of the item
     * @returns a educationSubmissionItemRequestBuilder
     */
    submissionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["educationSubmission_id"] = id;
        return new educationSubmissionItemRequestBuilder_1.EducationSubmissionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.EducationAssignmentItemRequestBuilder = EducationAssignmentItemRequestBuilder;
