import { EducationAssignment } from '../../../../../models/microsoft/graph/';
import { CategoriesRequestBuilder } from './categories/categoriesRequestBuilder';
import { EducationCategoryItemRequestBuilder } from './categories/item/educationCategoryItemRequestBuilder';
import { PublishRequestBuilder } from './publish/publishRequestBuilder';
import { EducationAssignmentResourceItemRequestBuilder } from './resources/item/educationAssignmentResourceItemRequestBuilder';
import { ResourcesRequestBuilder } from './resources/resourcesRequestBuilder';
import { RubricRequestBuilder } from './rubric/rubricRequestBuilder';
import { SetUpResourcesFolderRequestBuilder } from './setUpResourcesFolder/setUpResourcesFolderRequestBuilder';
import { EducationSubmissionItemRequestBuilder } from './submissions/item/educationSubmissionItemRequestBuilder';
import { SubmissionsRequestBuilder } from './submissions/submissionsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the assignments property of the microsoft.graph.educationUser entity.  */
export declare class EducationAssignmentItemRequestBuilder {
    get categories(): CategoriesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get publish(): PublishRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get resources(): ResourcesRequestBuilder;
    get rubric(): RubricRequestBuilder;
    get setUpResourcesFolder(): SetUpResourcesFolderRequestBuilder;
    get submissions(): SubmissionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.users.item.assignments.item.categories.item collection
     * @param id Unique identifier of the item
     * @returns a educationCategoryItemRequestBuilder
     */
    categoriesById(id: string): EducationCategoryItemRequestBuilder;
    /**
     * Instantiates a new EducationAssignmentItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property assignments for education
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Assignments belonging to the user.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property assignments in education
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: EducationAssignment | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property assignments for education
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Assignments belonging to the user.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EducationAssignment
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<EducationAssignment | undefined>;
    /**
     * Update the navigation property assignments in education
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: EducationAssignment | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.users.item.assignments.item.resources.item collection
     * @param id Unique identifier of the item
     * @returns a educationAssignmentResourceItemRequestBuilder
     */
    resourcesById(id: string): EducationAssignmentResourceItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.education.users.item.assignments.item.submissions.item collection
     * @param id Unique identifier of the item
     * @returns a educationSubmissionItemRequestBuilder
     */
    submissionsById(id: string): EducationSubmissionItemRequestBuilder;
}
