import { OnenoteSection } from '../../../../../models/microsoft/graph/';
import { CopyToNotebookRequestBuilder } from './copyToNotebook/copyToNotebookRequestBuilder';
import { CopyToSectionGroupRequestBuilder } from './copyToSectionGroup/copyToSectionGroupRequestBuilder';
import { OnenotePageItemRequestBuilder } from './pages/item/onenotePageItemRequestBuilder';
import { PagesRequestBuilder } from './pages/pagesRequestBuilder';
import { ParentNotebookRequestBuilder } from './parentNotebook/parentNotebookRequestBuilder';
import { ParentSectionGroupRequestBuilder } from './parentSectionGroup/parentSectionGroupRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the sections property of the microsoft.graph.onenote entity.  */
export declare class OnenoteSectionItemRequestBuilder {
    get copyToNotebook(): CopyToNotebookRequestBuilder;
    get copyToSectionGroup(): CopyToSectionGroupRequestBuilder;
    get pages(): PagesRequestBuilder;
    get parentNotebook(): ParentNotebookRequestBuilder;
    get parentSectionGroup(): ParentSectionGroupRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new OnenoteSectionItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property sections for groups
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The sections in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property sections in groups
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: OnenoteSection | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property sections for groups
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The sections in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of OnenoteSection
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<OnenoteSection | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.onenote.sections.item.pages.item collection
     * @param id Unique identifier of the item
     * @returns a onenotePageItemRequestBuilder
     */
    pagesById(id: string): OnenotePageItemRequestBuilder;
    /**
     * Update the navigation property sections in groups
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: OnenoteSection | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
