"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SiteItemRequestBuilder = void 0;
const createSiteFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/createSiteFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const analyticsRequestBuilder_1 = require("./analytics/analyticsRequestBuilder");
const columnsRequestBuilder_1 = require("./columns/columnsRequestBuilder");
const columnDefinitionItemRequestBuilder_1 = require("./columns/item/columnDefinitionItemRequestBuilder");
const contentTypesRequestBuilder_1 = require("./contentTypes/contentTypesRequestBuilder");
const contentTypeItemRequestBuilder_1 = require("./contentTypes/item/contentTypeItemRequestBuilder");
const driveRequestBuilder_1 = require("./drive/driveRequestBuilder");
const drivesRequestBuilder_1 = require("./drives/drivesRequestBuilder");
const driveItemRequestBuilder_1 = require("./drives/item/driveItemRequestBuilder");
const externalColumnsRequestBuilder_1 = require("./externalColumns/externalColumnsRequestBuilder");
const columnDefinitionItemRequestBuilder_2 = require("./externalColumns/item/columnDefinitionItemRequestBuilder");
const baseItemItemRequestBuilder_1 = require("./items/item/baseItemItemRequestBuilder");
const itemsRequestBuilder_1 = require("./items/itemsRequestBuilder");
const listItemRequestBuilder_1 = require("./lists/item/listItemRequestBuilder");
const listsRequestBuilder_1 = require("./lists/listsRequestBuilder");
const onenoteRequestBuilder_1 = require("./onenote/onenoteRequestBuilder");
const permissionItemRequestBuilder_1 = require("./permissions/item/permissionItemRequestBuilder");
const permissionsRequestBuilder_1 = require("./permissions/permissionsRequestBuilder");
const siteItemRequestBuilder_1 = require("./sites/item/siteItemRequestBuilder");
const sitesRequestBuilder_1 = require("./sites/sitesRequestBuilder");
const termStoreRequestBuilder_1 = require("./termStore/termStoreRequestBuilder");
const storeItemRequestBuilder_1 = require("./termStores/item/storeItemRequestBuilder");
const termStoresRequestBuilder_1 = require("./termStores/termStoresRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the sites property of the microsoft.graph.group entity.  */
class SiteItemRequestBuilder {
    /**
     * Instantiates a new SiteItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/groups/{group_id}/sites/{site_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get analytics() {
        return new analyticsRequestBuilder_1.AnalyticsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get columns() {
        return new columnsRequestBuilder_1.ColumnsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get contentTypes() {
        return new contentTypesRequestBuilder_1.ContentTypesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get drive() {
        return new driveRequestBuilder_1.DriveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get drives() {
        return new drivesRequestBuilder_1.DrivesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get externalColumns() {
        return new externalColumnsRequestBuilder_1.ExternalColumnsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get items() {
        return new itemsRequestBuilder_1.ItemsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get lists() {
        return new listsRequestBuilder_1.ListsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get onenote() {
        return new onenoteRequestBuilder_1.OnenoteRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get permissions() {
        return new permissionsRequestBuilder_1.PermissionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get sites() {
        return new sitesRequestBuilder_1.SitesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get termStore() {
        return new termStoreRequestBuilder_1.TermStoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get termStores() {
        return new termStoresRequestBuilder_1.TermStoresRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.columns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["columnDefinition_id"] = id;
        return new columnDefinitionItemRequestBuilder_1.ColumnDefinitionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.contentTypes.item collection
     * @param id Unique identifier of the item
     * @returns a contentTypeItemRequestBuilder
     */
    contentTypesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["contentType_id"] = id;
        return new contentTypeItemRequestBuilder_1.ContentTypeItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property sites for groups
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * The list of SharePoint sites in this group. Access the default site with /sites/root.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property sites in groups
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property sites for groups
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.drives.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemRequestBuilder
     */
    drivesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["drive_id"] = id;
        return new driveItemRequestBuilder_1.DriveItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.externalColumns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    externalColumnsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["columnDefinition_id"] = id;
        return new columnDefinitionItemRequestBuilder_2.ColumnDefinitionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * The list of SharePoint sites in this group. Access the default site with /sites/root.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Site
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createSiteFromDiscriminatorValue_1.createSiteFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a baseItemItemRequestBuilder
     */
    itemsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["baseItem_id"] = id;
        return new baseItemItemRequestBuilder_1.BaseItemItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.lists.item collection
     * @param id Unique identifier of the item
     * @returns a listItemRequestBuilder
     */
    listsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["list_id"] = id;
        return new listItemRequestBuilder_1.ListItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property sites in groups
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.permissions.item collection
     * @param id Unique identifier of the item
     * @returns a permissionItemRequestBuilder
     */
    permissionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["permission_id"] = id;
        return new permissionItemRequestBuilder_1.PermissionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.sites.item collection
     * @param id Unique identifier of the item
     * @returns a siteItemRequestBuilder
     */
    sitesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["site_id1"] = id;
        return new siteItemRequestBuilder_1.SiteItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.sites.item.termStores.item collection
     * @param id Unique identifier of the item
     * @returns a storeItemRequestBuilder
     */
    termStoresById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["store_id"] = id;
        return new storeItemRequestBuilder_1.StoreItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.SiteItemRequestBuilder = SiteItemRequestBuilder;
