"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ScheduleRequestBuilder = void 0;
const createScheduleFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/createScheduleFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const offerShiftRequestItemRequestBuilder_1 = require("./offerShiftRequests/item/offerShiftRequestItemRequestBuilder");
const offerShiftRequestsRequestBuilder_1 = require("./offerShiftRequests/offerShiftRequestsRequestBuilder");
const openShiftChangeRequestItemRequestBuilder_1 = require("./openShiftChangeRequests/item/openShiftChangeRequestItemRequestBuilder");
const openShiftChangeRequestsRequestBuilder_1 = require("./openShiftChangeRequests/openShiftChangeRequestsRequestBuilder");
const openShiftItemRequestBuilder_1 = require("./openShifts/item/openShiftItemRequestBuilder");
const openShiftsRequestBuilder_1 = require("./openShifts/openShiftsRequestBuilder");
const schedulingGroupItemRequestBuilder_1 = require("./schedulingGroups/item/schedulingGroupItemRequestBuilder");
const schedulingGroupsRequestBuilder_1 = require("./schedulingGroups/schedulingGroupsRequestBuilder");
const shareRequestBuilder_1 = require("./share/shareRequestBuilder");
const shiftItemRequestBuilder_1 = require("./shifts/item/shiftItemRequestBuilder");
const shiftsRequestBuilder_1 = require("./shifts/shiftsRequestBuilder");
const swapShiftsChangeRequestItemRequestBuilder_1 = require("./swapShiftsChangeRequests/item/swapShiftsChangeRequestItemRequestBuilder");
const swapShiftsChangeRequestsRequestBuilder_1 = require("./swapShiftsChangeRequests/swapShiftsChangeRequestsRequestBuilder");
const timeOffReasonItemRequestBuilder_1 = require("./timeOffReasons/item/timeOffReasonItemRequestBuilder");
const timeOffReasonsRequestBuilder_1 = require("./timeOffReasons/timeOffReasonsRequestBuilder");
const timeOffRequestItemRequestBuilder_1 = require("./timeOffRequests/item/timeOffRequestItemRequestBuilder");
const timeOffRequestsRequestBuilder_1 = require("./timeOffRequests/timeOffRequestsRequestBuilder");
const timeOffItemRequestBuilder_1 = require("./timesOff/item/timeOffItemRequestBuilder");
const timesOffRequestBuilder_1 = require("./timesOff/timesOffRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the schedule property of the microsoft.graph.team entity.  */
class ScheduleRequestBuilder {
    /**
     * Instantiates a new ScheduleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/groups/{group_id}/team/schedule{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get offerShiftRequests() {
        return new offerShiftRequestsRequestBuilder_1.OfferShiftRequestsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get openShiftChangeRequests() {
        return new openShiftChangeRequestsRequestBuilder_1.OpenShiftChangeRequestsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get openShifts() {
        return new openShiftsRequestBuilder_1.OpenShiftsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get schedulingGroups() {
        return new schedulingGroupsRequestBuilder_1.SchedulingGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get share() {
        return new shareRequestBuilder_1.ShareRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get shifts() {
        return new shiftsRequestBuilder_1.ShiftsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get swapShiftsChangeRequests() {
        return new swapShiftsChangeRequestsRequestBuilder_1.SwapShiftsChangeRequestsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get timeOffReasons() {
        return new timeOffReasonsRequestBuilder_1.TimeOffReasonsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get timeOffRequests() {
        return new timeOffRequestsRequestBuilder_1.TimeOffRequestsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get timesOff() {
        return new timesOffRequestBuilder_1.TimesOffRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property schedule for groups
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * The schedule of shifts for this team.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property schedule in groups
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property schedule for groups
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * The schedule of shifts for this team.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Schedule
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createScheduleFromDiscriminatorValue_1.createScheduleFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.offerShiftRequests.item collection
     * @param id Unique identifier of the item
     * @returns a offerShiftRequestItemRequestBuilder
     */
    offerShiftRequestsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["offerShiftRequest_id"] = id;
        return new offerShiftRequestItemRequestBuilder_1.OfferShiftRequestItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.openShiftChangeRequests.item collection
     * @param id Unique identifier of the item
     * @returns a openShiftChangeRequestItemRequestBuilder
     */
    openShiftChangeRequestsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["openShiftChangeRequest_id"] = id;
        return new openShiftChangeRequestItemRequestBuilder_1.OpenShiftChangeRequestItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.openShifts.item collection
     * @param id Unique identifier of the item
     * @returns a openShiftItemRequestBuilder
     */
    openShiftsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["openShift_id"] = id;
        return new openShiftItemRequestBuilder_1.OpenShiftItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property schedule in groups
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.schedulingGroups.item collection
     * @param id Unique identifier of the item
     * @returns a schedulingGroupItemRequestBuilder
     */
    schedulingGroupsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["schedulingGroup_id"] = id;
        return new schedulingGroupItemRequestBuilder_1.SchedulingGroupItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.shifts.item collection
     * @param id Unique identifier of the item
     * @returns a shiftItemRequestBuilder
     */
    shiftsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["shift_id"] = id;
        return new shiftItemRequestBuilder_1.ShiftItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.swapShiftsChangeRequests.item collection
     * @param id Unique identifier of the item
     * @returns a swapShiftsChangeRequestItemRequestBuilder
     */
    swapShiftsChangeRequestsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["swapShiftsChangeRequest_id"] = id;
        return new swapShiftsChangeRequestItemRequestBuilder_1.SwapShiftsChangeRequestItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.timeOffReasons.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffReasonItemRequestBuilder
     */
    timeOffReasonsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["timeOffReason_id"] = id;
        return new timeOffReasonItemRequestBuilder_1.TimeOffReasonItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.timeOffRequests.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffRequestItemRequestBuilder
     */
    timeOffRequestsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["timeOffRequest_id"] = id;
        return new timeOffRequestItemRequestBuilder_1.TimeOffRequestItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.groups.item.team.schedule.timesOff.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffItemRequestBuilder
     */
    timesOffById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["timeOff_id"] = id;
        return new timeOffItemRequestBuilder_1.TimeOffItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.ScheduleRequestBuilder = ScheduleRequestBuilder;
