import { B2xIdentityUserFlow } from '../../../models/microsoft/graph/';
import { IdentityProvidersRequestBuilder } from './identityProviders/identityProvidersRequestBuilder';
import { IdentityProviderItemRequestBuilder } from './identityProviders/item/identityProviderItemRequestBuilder';
import { UserFlowLanguageConfigurationItemRequestBuilder } from './languages/item/userFlowLanguageConfigurationItemRequestBuilder';
import { LanguagesRequestBuilder } from './languages/languagesRequestBuilder';
import { IdentityUserFlowAttributeAssignmentItemRequestBuilder } from './userAttributeAssignments/item/identityUserFlowAttributeAssignmentItemRequestBuilder';
import { UserAttributeAssignmentsRequestBuilder } from './userAttributeAssignments/userAttributeAssignmentsRequestBuilder';
import { IdentityProviderBaseItemRequestBuilder } from './userFlowIdentityProviders/item/identityProviderBaseItemRequestBuilder';
import { UserFlowIdentityProvidersRequestBuilder } from './userFlowIdentityProviders/userFlowIdentityProvidersRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the b2xUserFlows property of the microsoft.graph.identityContainer entity.  */
export declare class B2xIdentityUserFlowItemRequestBuilder {
    get identityProviders(): IdentityProvidersRequestBuilder;
    get languages(): LanguagesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    get userAttributeAssignments(): UserAttributeAssignmentsRequestBuilder;
    get userFlowIdentityProviders(): UserFlowIdentityProvidersRequestBuilder;
    /**
     * Instantiates a new B2xIdentityUserFlowItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property b2xUserFlows for identity
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Represents entry point for B2X/self-service sign-up identity userflows.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property b2xUserFlows in identity
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: B2xIdentityUserFlow | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property b2xUserFlows for identity
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Represents entry point for B2X/self-service sign-up identity userflows.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of B2xIdentityUserFlow
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<B2xIdentityUserFlow | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.identityProviders.item collection
     * @param id Unique identifier of the item
     * @returns a identityProviderItemRequestBuilder
     */
    identityProvidersById(id: string): IdentityProviderItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.languages.item collection
     * @param id Unique identifier of the item
     * @returns a userFlowLanguageConfigurationItemRequestBuilder
     */
    languagesById(id: string): UserFlowLanguageConfigurationItemRequestBuilder;
    /**
     * Update the navigation property b2xUserFlows in identity
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: B2xIdentityUserFlow | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.userAttributeAssignments.item collection
     * @param id Unique identifier of the item
     * @returns a identityUserFlowAttributeAssignmentItemRequestBuilder
     */
    userAttributeAssignmentsById(id: string): IdentityUserFlowAttributeAssignmentItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identity.b2xUserFlows.item.userFlowIdentityProviders.item collection
     * @param id Unique identifier of the item
     * @returns a identityProviderBaseItemRequestBuilder
     */
    userFlowIdentityProvidersById(id: string): IdentityProviderBaseItemRequestBuilder;
}
