"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AccessReviewInstanceItemRequestBuilder = void 0;
const createAccessReviewInstanceFromDiscriminatorValue_1 = require("../../../../../../models/microsoft/graph/createAccessReviewInstanceFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const acceptRecommendationsRequestBuilder_1 = require("./acceptRecommendations/acceptRecommendationsRequestBuilder");
const applyDecisionsRequestBuilder_1 = require("./applyDecisions/applyDecisionsRequestBuilder");
const batchRecordDecisionsRequestBuilder_1 = require("./batchRecordDecisions/batchRecordDecisionsRequestBuilder");
const contactedReviewersRequestBuilder_1 = require("./contactedReviewers/contactedReviewersRequestBuilder");
const accessReviewReviewerItemRequestBuilder_1 = require("./contactedReviewers/item/accessReviewReviewerItemRequestBuilder");
const decisionsRequestBuilder_1 = require("./decisions/decisionsRequestBuilder");
const accessReviewInstanceDecisionItemItemRequestBuilder_1 = require("./decisions/item/accessReviewInstanceDecisionItemItemRequestBuilder");
const resetDecisionsRequestBuilder_1 = require("./resetDecisions/resetDecisionsRequestBuilder");
const sendReminderRequestBuilder_1 = require("./sendReminder/sendReminderRequestBuilder");
const stopRequestBuilder_1 = require("./stop/stopRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the instances property of the microsoft.graph.accessReviewScheduleDefinition entity.  */
class AccessReviewInstanceItemRequestBuilder {
    /**
     * Instantiates a new AccessReviewInstanceItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/identityGovernance/accessReviews/definitions/{accessReviewScheduleDefinition_id}/instances/{accessReviewInstance_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get acceptRecommendations() {
        return new acceptRecommendationsRequestBuilder_1.AcceptRecommendationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get applyDecisions() {
        return new applyDecisionsRequestBuilder_1.ApplyDecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get batchRecordDecisions() {
        return new batchRecordDecisionsRequestBuilder_1.BatchRecordDecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get contactedReviewers() {
        return new contactedReviewersRequestBuilder_1.ContactedReviewersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get decisions() {
        return new decisionsRequestBuilder_1.DecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get resetDecisions() {
        return new resetDecisionsRequestBuilder_1.ResetDecisionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get sendReminder() {
        return new sendReminderRequestBuilder_1.SendReminderRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get stop() {
        return new stopRequestBuilder_1.StopRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.accessReviews.definitions.item.instances.item.contactedReviewers.item collection
     * @param id Unique identifier of the item
     * @returns a accessReviewReviewerItemRequestBuilder
     */
    contactedReviewersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["accessReviewReviewer_id"] = id;
        return new accessReviewReviewerItemRequestBuilder_1.AccessReviewReviewerItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property instances for identityGovernance
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * If the accessReviewScheduleDefinition is a recurring access review, instances represent each recurrence. A review that does not recur will have exactly one instance. Instances also represent each unique resource under review in the accessReviewScheduleDefinition. If a review has multiple resources and multiple instances, each resource will have a unique instance for each recurrence.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property instances in identityGovernance
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.accessReviews.definitions.item.instances.item.decisions.item collection
     * @param id Unique identifier of the item
     * @returns a accessReviewInstanceDecisionItemItemRequestBuilder
     */
    decisionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["accessReviewInstanceDecisionItem_id"] = id;
        return new accessReviewInstanceDecisionItemItemRequestBuilder_1.AccessReviewInstanceDecisionItemItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property instances for identityGovernance
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * If the accessReviewScheduleDefinition is a recurring access review, instances represent each recurrence. A review that does not recur will have exactly one instance. Instances also represent each unique resource under review in the accessReviewScheduleDefinition. If a review has multiple resources and multiple instances, each resource will have a unique instance for each recurrence.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AccessReviewInstance
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createAccessReviewInstanceFromDiscriminatorValue_1.createAccessReviewInstanceFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property instances in identityGovernance
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.AccessReviewInstanceItemRequestBuilder = AccessReviewInstanceItemRequestBuilder;
