import { AccessPackageAssignmentRequest } from '../../../../models/microsoft/graph/';
import { AccessPackageRequestBuilder } from './accessPackage/accessPackageRequestBuilder';
import { AssignmentRequestBuilder } from './assignment/assignmentRequestBuilder';
import { CancelRequestBuilder } from './cancel/cancelRequestBuilder';
import { RequestorRequestBuilder } from './requestor/requestorRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the assignmentRequests property of the microsoft.graph.entitlementManagement entity.  */
export declare class AccessPackageAssignmentRequestItemRequestBuilder {
    get accessPackage(): AccessPackageRequestBuilder;
    get assignment(): AssignmentRequestBuilder;
    get cancel(): CancelRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get requestor(): RequestorRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new AccessPackageAssignmentRequestItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property assignmentRequests for identityGovernance
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Represents access package assignment requests created by or on behalf of a user.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property assignmentRequests in identityGovernance
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: AccessPackageAssignmentRequest | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property assignmentRequests for identityGovernance
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Represents access package assignment requests created by or on behalf of a user.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of AccessPackageAssignmentRequest
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<AccessPackageAssignmentRequest | undefined>;
    /**
     * Update the navigation property assignmentRequests in identityGovernance
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: AccessPackageAssignmentRequest | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
