import { EntitlementManagement } from '../../models/microsoft/graph/';
import { AccessPackageAssignmentApprovalsRequestBuilder } from './accessPackageAssignmentApprovals/accessPackageAssignmentApprovalsRequestBuilder';
import { ApprovalItemRequestBuilder } from './accessPackageAssignmentApprovals/item/approvalItemRequestBuilder';
import { AccessPackagesRequestBuilder } from './accessPackages/accessPackagesRequestBuilder';
import { AccessPackageItemRequestBuilder } from './accessPackages/item/accessPackageItemRequestBuilder';
import { AssignmentPoliciesRequestBuilder } from './assignmentPolicies/assignmentPoliciesRequestBuilder';
import { AccessPackageAssignmentPolicyItemRequestBuilder } from './assignmentPolicies/item/accessPackageAssignmentPolicyItemRequestBuilder';
import { AssignmentRequestsRequestBuilder } from './assignmentRequests/assignmentRequestsRequestBuilder';
import { AccessPackageAssignmentRequestItemRequestBuilder } from './assignmentRequests/item/accessPackageAssignmentRequestItemRequestBuilder';
import { AssignmentsRequestBuilder } from './assignments/assignmentsRequestBuilder';
import { AccessPackageAssignmentItemRequestBuilder } from './assignments/item/accessPackageAssignmentItemRequestBuilder';
import { CatalogsRequestBuilder } from './catalogs/catalogsRequestBuilder';
import { AccessPackageCatalogItemRequestBuilder } from './catalogs/item/accessPackageCatalogItemRequestBuilder';
import { ConnectedOrganizationsRequestBuilder } from './connectedOrganizations/connectedOrganizationsRequestBuilder';
import { ConnectedOrganizationItemRequestBuilder } from './connectedOrganizations/item/connectedOrganizationItemRequestBuilder';
import { SettingsRequestBuilder } from './settings/settingsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the entitlementManagement property of the microsoft.graph.identityGovernance entity.  */
export declare class EntitlementManagementRequestBuilder {
    get accessPackageAssignmentApprovals(): AccessPackageAssignmentApprovalsRequestBuilder;
    get accessPackages(): AccessPackagesRequestBuilder;
    get assignmentPolicies(): AssignmentPoliciesRequestBuilder;
    get assignmentRequests(): AssignmentRequestsRequestBuilder;
    get assignments(): AssignmentsRequestBuilder;
    get catalogs(): CatalogsRequestBuilder;
    get connectedOrganizations(): ConnectedOrganizationsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get settings(): SettingsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.entitlementManagement.accessPackageAssignmentApprovals.item collection
     * @param id Unique identifier of the item
     * @returns a approvalItemRequestBuilder
     */
    accessPackageAssignmentApprovalsById(id: string): ApprovalItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.entitlementManagement.accessPackages.item collection
     * @param id Unique identifier of the item
     * @returns a accessPackageItemRequestBuilder
     */
    accessPackagesById(id: string): AccessPackageItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.entitlementManagement.assignmentPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a accessPackageAssignmentPolicyItemRequestBuilder
     */
    assignmentPoliciesById(id: string): AccessPackageAssignmentPolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.entitlementManagement.assignmentRequests.item collection
     * @param id Unique identifier of the item
     * @returns a accessPackageAssignmentRequestItemRequestBuilder
     */
    assignmentRequestsById(id: string): AccessPackageAssignmentRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.entitlementManagement.assignments.item collection
     * @param id Unique identifier of the item
     * @returns a accessPackageAssignmentItemRequestBuilder
     */
    assignmentsById(id: string): AccessPackageAssignmentItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.entitlementManagement.catalogs.item collection
     * @param id Unique identifier of the item
     * @returns a accessPackageCatalogItemRequestBuilder
     */
    catalogsById(id: string): AccessPackageCatalogItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityGovernance.entitlementManagement.connectedOrganizations.item collection
     * @param id Unique identifier of the item
     * @returns a connectedOrganizationItemRequestBuilder
     */
    connectedOrganizationsById(id: string): ConnectedOrganizationItemRequestBuilder;
    /**
     * Instantiates a new EntitlementManagementRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property entitlementManagement for identityGovernance
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entitlementManagement from identityGovernance
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property entitlementManagement in identityGovernance
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: EntitlementManagement | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property entitlementManagement for identityGovernance
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get entitlementManagement from identityGovernance
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of EntitlementManagement
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<EntitlementManagement | undefined>;
    /**
     * Update the navigation property entitlementManagement in identityGovernance
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: EntitlementManagement | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
