import { IdentityProtectionRoot } from '../models/microsoft/graph/';
import { RiskDetectionItemRequestBuilder } from './riskDetections/item/riskDetectionItemRequestBuilder';
import { RiskDetectionsRequestBuilder } from './riskDetections/riskDetectionsRequestBuilder';
import { RiskyUserItemRequestBuilder } from './riskyUsers/item/riskyUserItemRequestBuilder';
import { RiskyUsersRequestBuilder } from './riskyUsers/riskyUsersRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the identityProtectionRoot singleton.  */
export declare class IdentityProtectionRequestBuilder {
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get riskDetections(): RiskDetectionsRequestBuilder;
    get riskyUsers(): RiskyUsersRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new IdentityProtectionRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get identityProtection
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update identityProtection
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: IdentityProtectionRoot | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get identityProtection
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of IdentityProtectionRoot
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<IdentityProtectionRoot | undefined>;
    /**
     * Update identityProtection
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: IdentityProtectionRoot | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityProtection.riskDetections.item collection
     * @param id Unique identifier of the item
     * @returns a riskDetectionItemRequestBuilder
     */
    riskDetectionsById(id: string): RiskDetectionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.identityProtection.riskyUsers.item collection
     * @param id Unique identifier of the item
     * @returns a riskyUserItemRequestBuilder
     */
    riskyUsersById(id: string): RiskyUserItemRequestBuilder;
}
