import { Calendar } from '../../models/microsoft/graph/';
import { AllowedCalendarSharingRolesWithUserRequestBuilder } from './allowedCalendarSharingRolesWithUser/allowedCalendarSharingRolesWithUserRequestBuilder';
import { CalendarPermissionsRequestBuilder } from './calendarPermissions/calendarPermissionsRequestBuilder';
import { CalendarPermissionItemRequestBuilder } from './calendarPermissions/item/calendarPermissionItemRequestBuilder';
import { CalendarViewRequestBuilder } from './calendarView/calendarViewRequestBuilder';
import { EventItemRequestBuilder as i3751a5be1bea96dd5e60e41a5e4edc2df1f5bfe3bd710bf537323db80acf3783 } from './calendarView/item/eventItemRequestBuilder';
import { EventsRequestBuilder } from './events/eventsRequestBuilder';
import { EventItemRequestBuilder as if7428d735a35c12d366df49aa16dcac9d697c6e91d40e8d91b0efade09d368ff } from './events/item/eventItemRequestBuilder';
import { GetScheduleRequestBuilder } from './getSchedule/getScheduleRequestBuilder';
import { MultiValueLegacyExtendedPropertyItemRequestBuilder } from './multiValueExtendedProperties/item/multiValueLegacyExtendedPropertyItemRequestBuilder';
import { MultiValueExtendedPropertiesRequestBuilder } from './multiValueExtendedProperties/multiValueExtendedPropertiesRequestBuilder';
import { SingleValueLegacyExtendedPropertyItemRequestBuilder } from './singleValueExtendedProperties/item/singleValueLegacyExtendedPropertyItemRequestBuilder';
import { SingleValueExtendedPropertiesRequestBuilder } from './singleValueExtendedProperties/singleValueExtendedPropertiesRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the calendar property of the microsoft.graph.user entity.  */
export declare class CalendarRequestBuilder {
    get calendarPermissions(): CalendarPermissionsRequestBuilder;
    get calendarView(): CalendarViewRequestBuilder;
    get events(): EventsRequestBuilder;
    get getSchedule(): GetScheduleRequestBuilder;
    get multiValueExtendedProperties(): MultiValueExtendedPropertiesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get singleValueExtendedProperties(): SingleValueExtendedPropertiesRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Provides operations to call the allowedCalendarSharingRoles method.
     * @param User Usage: User='{User}'
     * @returns a allowedCalendarSharingRolesWithUserRequestBuilder
     */
    allowedCalendarSharingRolesWithUser(user: string | undefined): AllowedCalendarSharingRolesWithUserRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.calendar.calendarPermissions.item collection
     * @param id Unique identifier of the item
     * @returns a calendarPermissionItemRequestBuilder
     */
    calendarPermissionsById(id: string): CalendarPermissionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.calendar.calendarView.item collection
     * @param id Unique identifier of the item
     * @returns a eventItemRequestBuilder
     */
    calendarViewById(id: string): i3751a5be1bea96dd5e60e41a5e4edc2df1f5bfe3bd710bf537323db80acf3783;
    /**
     * Instantiates a new CalendarRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property calendar for me
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The user's primary calendar. Read-only.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property calendar in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Calendar | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property calendar for me
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.calendar.events.item collection
     * @param id Unique identifier of the item
     * @returns a eventItemRequestBuilder
     */
    eventsById(id: string): if7428d735a35c12d366df49aa16dcac9d697c6e91d40e8d91b0efade09d368ff;
    /**
     * The user's primary calendar. Read-only.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Calendar
     */
    get(q?: {
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Calendar | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.calendar.multiValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a multiValueLegacyExtendedPropertyItemRequestBuilder
     */
    multiValueExtendedPropertiesById(id: string): MultiValueLegacyExtendedPropertyItemRequestBuilder;
    /**
     * Update the navigation property calendar in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Calendar | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.calendar.singleValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a singleValueLegacyExtendedPropertyItemRequestBuilder
     */
    singleValueExtendedPropertiesById(id: string): SingleValueLegacyExtendedPropertyItemRequestBuilder;
}
