import { DriveItem } from '../../../../../models/microsoft/graph/';
import { AnalyticsRequestBuilder } from './analytics/analyticsRequestBuilder';
import { ChildrenRequestBuilder } from './children/childrenRequestBuilder';
import { DriveItemItemRequestBuilder as ibcadf1d0083810cdedca61521fa5b3060646db184a878dab8d7d5226e61c37c2 } from './children/item/driveItemItemRequestBuilder';
import { ContentRequestBuilder } from './content/contentRequestBuilder';
import { ListItemRequestBuilder } from './listItem/listItemRequestBuilder';
import { PermissionItemRequestBuilder } from './permissions/item/permissionItemRequestBuilder';
import { PermissionsRequestBuilder } from './permissions/permissionsRequestBuilder';
import { SubscriptionItemRequestBuilder } from './subscriptions/item/subscriptionItemRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { ThumbnailSetItemRequestBuilder } from './thumbnails/item/thumbnailSetItemRequestBuilder';
import { ThumbnailsRequestBuilder } from './thumbnails/thumbnailsRequestBuilder';
import { DriveItemVersionItemRequestBuilder } from './versions/item/driveItemVersionItemRequestBuilder';
import { VersionsRequestBuilder } from './versions/versionsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the items property of the microsoft.graph.drive entity.  */
export declare class DriveItemItemRequestBuilder {
    get analytics(): AnalyticsRequestBuilder;
    get children(): ChildrenRequestBuilder;
    get content(): ContentRequestBuilder;
    get listItem(): ListItemRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get permissions(): PermissionsRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get subscriptions(): SubscriptionsRequestBuilder;
    get thumbnails(): ThumbnailsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    get versions(): VersionsRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.items.item.children.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    childrenById(id: string): ibcadf1d0083810cdedca61521fa5b3060646db184a878dab8d7d5226e61c37c2;
    /**
     * Instantiates a new DriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property items for me
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * All items contained in the drive. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property items in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: DriveItem | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property items for me
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * All items contained in the drive. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DriveItem
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<DriveItem | undefined>;
    /**
     * Update the navigation property items in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: DriveItem | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.items.item.permissions.item collection
     * @param id Unique identifier of the item
     * @returns a permissionItemRequestBuilder
     */
    permissionsById(id: string): PermissionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.items.item.subscriptions.item collection
     * @param id Unique identifier of the item
     * @returns a subscriptionItemRequestBuilder
     */
    subscriptionsById(id: string): SubscriptionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.items.item.thumbnails.item collection
     * @param id Unique identifier of the item
     * @returns a thumbnailSetItemRequestBuilder
     */
    thumbnailsById(id: string): ThumbnailSetItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.items.item.versions.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemVersionItemRequestBuilder
     */
    versionsById(id: string): DriveItemVersionItemRequestBuilder;
}
