import { List } from '../../../../models/microsoft/graph/';
import { ColumnsRequestBuilder } from './columns/columnsRequestBuilder';
import { ColumnDefinitionItemRequestBuilder } from './columns/item/columnDefinitionItemRequestBuilder';
import { ContentTypesRequestBuilder } from './contentTypes/contentTypesRequestBuilder';
import { ContentTypeItemRequestBuilder } from './contentTypes/item/contentTypeItemRequestBuilder';
import { DriveRequestBuilder } from './drive/driveRequestBuilder';
import { ListItemItemRequestBuilder } from './items/item/listItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { SubscriptionItemRequestBuilder } from './subscriptions/item/subscriptionItemRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the list property of the microsoft.graph.drive entity.  */
export declare class ListRequestBuilder {
    get columns(): ColumnsRequestBuilder;
    get contentTypes(): ContentTypesRequestBuilder;
    get drive(): DriveRequestBuilder;
    get items(): ItemsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get subscriptions(): SubscriptionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.list.columns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnsById(id: string): ColumnDefinitionItemRequestBuilder;
    /**
     * Instantiates a new ListRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.list.contentTypes.item collection
     * @param id Unique identifier of the item
     * @returns a contentTypeItemRequestBuilder
     */
    contentTypesById(id: string): ContentTypeItemRequestBuilder;
    /**
     * Delete navigation property list for me
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property list in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: List | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property list for me
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of List
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<List | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.list.items.item collection
     * @param id Unique identifier of the item
     * @returns a listItemItemRequestBuilder
     */
    itemsById(id: string): ListItemItemRequestBuilder;
    /**
     * Update the navigation property list in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: List | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.drives.item.list.subscriptions.item collection
     * @param id Unique identifier of the item
     * @returns a subscriptionItemRequestBuilder
     */
    subscriptionsById(id: string): SubscriptionItemRequestBuilder;
}
