import { Schedule } from '../../../../models/microsoft/graph/';
import { OfferShiftRequestItemRequestBuilder } from './offerShiftRequests/item/offerShiftRequestItemRequestBuilder';
import { OfferShiftRequestsRequestBuilder } from './offerShiftRequests/offerShiftRequestsRequestBuilder';
import { OpenShiftChangeRequestItemRequestBuilder } from './openShiftChangeRequests/item/openShiftChangeRequestItemRequestBuilder';
import { OpenShiftChangeRequestsRequestBuilder } from './openShiftChangeRequests/openShiftChangeRequestsRequestBuilder';
import { OpenShiftItemRequestBuilder } from './openShifts/item/openShiftItemRequestBuilder';
import { OpenShiftsRequestBuilder } from './openShifts/openShiftsRequestBuilder';
import { SchedulingGroupItemRequestBuilder } from './schedulingGroups/item/schedulingGroupItemRequestBuilder';
import { SchedulingGroupsRequestBuilder } from './schedulingGroups/schedulingGroupsRequestBuilder';
import { ShareRequestBuilder } from './share/shareRequestBuilder';
import { ShiftItemRequestBuilder } from './shifts/item/shiftItemRequestBuilder';
import { ShiftsRequestBuilder } from './shifts/shiftsRequestBuilder';
import { SwapShiftsChangeRequestItemRequestBuilder } from './swapShiftsChangeRequests/item/swapShiftsChangeRequestItemRequestBuilder';
import { SwapShiftsChangeRequestsRequestBuilder } from './swapShiftsChangeRequests/swapShiftsChangeRequestsRequestBuilder';
import { TimeOffReasonItemRequestBuilder } from './timeOffReasons/item/timeOffReasonItemRequestBuilder';
import { TimeOffReasonsRequestBuilder } from './timeOffReasons/timeOffReasonsRequestBuilder';
import { TimeOffRequestItemRequestBuilder } from './timeOffRequests/item/timeOffRequestItemRequestBuilder';
import { TimeOffRequestsRequestBuilder } from './timeOffRequests/timeOffRequestsRequestBuilder';
import { TimeOffItemRequestBuilder } from './timesOff/item/timeOffItemRequestBuilder';
import { TimesOffRequestBuilder } from './timesOff/timesOffRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the schedule property of the microsoft.graph.team entity.  */
export declare class ScheduleRequestBuilder {
    get offerShiftRequests(): OfferShiftRequestsRequestBuilder;
    get openShiftChangeRequests(): OpenShiftChangeRequestsRequestBuilder;
    get openShifts(): OpenShiftsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get schedulingGroups(): SchedulingGroupsRequestBuilder;
    get share(): ShareRequestBuilder;
    get shifts(): ShiftsRequestBuilder;
    get swapShiftsChangeRequests(): SwapShiftsChangeRequestsRequestBuilder;
    get timeOffReasons(): TimeOffReasonsRequestBuilder;
    get timeOffRequests(): TimeOffRequestsRequestBuilder;
    get timesOff(): TimesOffRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new ScheduleRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property schedule for me
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The schedule of shifts for this team.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property schedule in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Schedule | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property schedule for me
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The schedule of shifts for this team.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Schedule
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Schedule | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.offerShiftRequests.item collection
     * @param id Unique identifier of the item
     * @returns a offerShiftRequestItemRequestBuilder
     */
    offerShiftRequestsById(id: string): OfferShiftRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.openShiftChangeRequests.item collection
     * @param id Unique identifier of the item
     * @returns a openShiftChangeRequestItemRequestBuilder
     */
    openShiftChangeRequestsById(id: string): OpenShiftChangeRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.openShifts.item collection
     * @param id Unique identifier of the item
     * @returns a openShiftItemRequestBuilder
     */
    openShiftsById(id: string): OpenShiftItemRequestBuilder;
    /**
     * Update the navigation property schedule in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Schedule | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.schedulingGroups.item collection
     * @param id Unique identifier of the item
     * @returns a schedulingGroupItemRequestBuilder
     */
    schedulingGroupsById(id: string): SchedulingGroupItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.shifts.item collection
     * @param id Unique identifier of the item
     * @returns a shiftItemRequestBuilder
     */
    shiftsById(id: string): ShiftItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.swapShiftsChangeRequests.item collection
     * @param id Unique identifier of the item
     * @returns a swapShiftsChangeRequestItemRequestBuilder
     */
    swapShiftsChangeRequestsById(id: string): SwapShiftsChangeRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.timeOffReasons.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffReasonItemRequestBuilder
     */
    timeOffReasonsById(id: string): TimeOffReasonItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.timeOffRequests.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffRequestItemRequestBuilder
     */
    timeOffRequestsById(id: string): TimeOffRequestItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.schedule.timesOff.item collection
     * @param id Unique identifier of the item
     * @returns a timeOffItemRequestBuilder
     */
    timesOffById(id: string): TimeOffItemRequestBuilder;
}
