import { Team } from '../../../models/microsoft/graph/';
import { ChannelsRequestBuilder } from './channels/channelsRequestBuilder';
import { ChannelItemRequestBuilder } from './channels/item/channelItemRequestBuilder';
import { GroupRequestBuilder } from './group/groupRequestBuilder';
import { InstalledAppsRequestBuilder } from './installedApps/installedAppsRequestBuilder';
import { TeamsAppInstallationItemRequestBuilder } from './installedApps/item/teamsAppInstallationItemRequestBuilder';
import { ConversationMemberItemRequestBuilder } from './members/item/conversationMemberItemRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { TeamsAsyncOperationItemRequestBuilder } from './operations/item/teamsAsyncOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PrimaryChannelRequestBuilder } from './primaryChannel/primaryChannelRequestBuilder';
import { ScheduleRequestBuilder } from './schedule/scheduleRequestBuilder';
import { TemplateRequestBuilder } from './template/templateRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the joinedTeams property of the microsoft.graph.user entity.  */
export declare class TeamItemRequestBuilder {
    get channels(): ChannelsRequestBuilder;
    get group(): GroupRequestBuilder;
    get installedApps(): InstalledAppsRequestBuilder;
    get members(): MembersRequestBuilder;
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get primaryChannel(): PrimaryChannelRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get schedule(): ScheduleRequestBuilder;
    get template(): TemplateRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.channels.item collection
     * @param id Unique identifier of the item
     * @returns a channelItemRequestBuilder
     */
    channelsById(id: string): ChannelItemRequestBuilder;
    /**
     * Instantiates a new TeamItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property joinedTeams for me
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The Microsoft Teams teams that the user is a member of. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property joinedTeams in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Team | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property joinedTeams for me
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The Microsoft Teams teams that the user is a member of. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Team
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Team | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.installedApps.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAppInstallationItemRequestBuilder
     */
    installedAppsById(id: string): TeamsAppInstallationItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id: string): ConversationMemberItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.me.joinedTeams.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAsyncOperationItemRequestBuilder
     */
    operationsById(id: string): TeamsAsyncOperationItemRequestBuilder;
    /**
     * Update the navigation property joinedTeams in me
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Team | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
