import { AlertFeedback } from './alertFeedback';
import { AlertSeverity } from './alertSeverity';
import { AlertStatus } from './alertStatus';
import { AlertDetection, AlertHistoryState, AlertTrigger, CloudAppSecurityState, Entity, FileSecurityState, HostSecurityState, InvestigationSecurityState, MalwareState, MessageSecurityState, NetworkConnection, Process, RegistryKeyState, SecurityResource, SecurityVendorInformation, UriClickSecurityState, UserSecurityState, VulnerabilityState } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Alert extends Entity implements Parsable {
    /** Name or alias of the activity group (attacker) this alert is attributed to.  */
    private _activityGroupName?;
    private _alertDetections?;
    /** Name of the analyst the alert is assigned to for triage, investigation, or remediation (supports update).  */
    private _assignedTo?;
    /** Azure subscription ID, present if this alert is related to an Azure resource.  */
    private _azureSubscriptionId?;
    /** Azure Active Directory tenant ID. Required.  */
    private _azureTenantId?;
    /** Category of the alert (for example, credentialTheft, ransomware, etc.).  */
    private _category?;
    /** Time at which the alert was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z (supports update).  */
    private _closedDateTime?;
    /** Security-related stateful information generated by the provider about the cloud application/s related to this alert.  */
    private _cloudAppStates?;
    /** Customer-provided comments on alert (for customer alert management) (supports update).  */
    private _comments?;
    /** Confidence of the detection logic (percentage between 1-100).  */
    private _confidence?;
    /** Time at which the alert was created by the alert provider. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.  */
    private _createdDateTime?;
    /** Alert description.  */
    private _description?;
    /** Set of alerts related to this alert entity (each alert is pushed to the SIEM as a separate record).  */
    private _detectionIds?;
    /** Time at which the event(s) that served as the trigger(s) to generate the alert occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.  */
    private _eventDateTime?;
    /** Analyst feedback on the alert. Possible values are: unknown, truePositive, falsePositive, benignPositive. (supports update)  */
    private _feedback?;
    /** Security-related stateful information generated by the provider about the file(s) related to this alert.  */
    private _fileStates?;
    /** A collection of alertHistoryStates comprising an audit log of all updates made to an alert.  */
    private _historyStates?;
    /** Security-related stateful information generated by the provider about the host(s) related to this alert.  */
    private _hostStates?;
    /** IDs of incidents related to current alert.  */
    private _incidentIds?;
    private _investigationSecurityStates?;
    private _lastEventDateTime?;
    /** Time at which the alert entity was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.  */
    private _lastModifiedDateTime?;
    /** Threat Intelligence pertaining to malware related to this alert.  */
    private _malwareStates?;
    private _messageSecurityStates?;
    /** Security-related stateful information generated by the provider about the network connection(s) related to this alert.  */
    private _networkConnections?;
    /** Security-related stateful information generated by the provider about the process or processes related to this alert.  */
    private _processes?;
    /** Vendor/provider recommended action(s) to take as a result of the alert (for example, isolate machine, enforce2FA, reimage host).  */
    private _recommendedActions?;
    /** Security-related stateful information generated by the provider about the registry keys related to this alert.  */
    private _registryKeyStates?;
    /** Resources related to current alert. For example, for some alerts this can have the Azure Resource value.  */
    private _securityResources?;
    /** Alert severity - set by vendor/provider. Possible values are: unknown, informational, low, medium, high. Required.  */
    private _severity?;
    /** Hyperlinks (URIs) to the source material related to the alert, for example, provider's user interface for alerts or log search, etc.  */
    private _sourceMaterials?;
    /** Alert lifecycle status (stage). Possible values are: unknown, newAlert, inProgress, resolved. (supports update). Required.  */
    private _status?;
    /** User-definable labels that can be applied to an alert and can serve as filter conditions (for example 'HVA', 'SAW', etc.) (supports update).  */
    private _tags?;
    /** Alert title. Required.  */
    private _title?;
    /** Security-related information about the specific properties that triggered the alert (properties appearing in the alert). Alerts might contain information about multiple users, hosts, files, ip addresses. This field indicates which properties triggered the alert generation.  */
    private _triggers?;
    private _uriClickSecurityStates?;
    /** Security-related stateful information generated by the provider about the user accounts related to this alert.  */
    private _userStates?;
    /** Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=Windows Defender ATP; subProvider=AppLocker). Required.  */
    private _vendorInformation?;
    /** Threat intelligence pertaining to one or more vulnerabilities related to this alert.  */
    private _vulnerabilityStates?;
    /**
     * Gets the activityGroupName property value. Name or alias of the activity group (attacker) this alert is attributed to.
     * @returns a string
     */
    get activityGroupName(): string | undefined;
    /**
     * Sets the activityGroupName property value. Name or alias of the activity group (attacker) this alert is attributed to.
     * @param value Value to set for the activityGroupName property.
     */
    set activityGroupName(value: string | undefined);
    /**
     * Gets the alertDetections property value.
     * @returns a alertDetection
     */
    get alertDetections(): AlertDetection[] | undefined;
    /**
     * Sets the alertDetections property value.
     * @param value Value to set for the alertDetections property.
     */
    set alertDetections(value: AlertDetection[] | undefined);
    /**
     * Gets the assignedTo property value. Name of the analyst the alert is assigned to for triage, investigation, or remediation (supports update).
     * @returns a string
     */
    get assignedTo(): string | undefined;
    /**
     * Sets the assignedTo property value. Name of the analyst the alert is assigned to for triage, investigation, or remediation (supports update).
     * @param value Value to set for the assignedTo property.
     */
    set assignedTo(value: string | undefined);
    /**
     * Gets the azureSubscriptionId property value. Azure subscription ID, present if this alert is related to an Azure resource.
     * @returns a string
     */
    get azureSubscriptionId(): string | undefined;
    /**
     * Sets the azureSubscriptionId property value. Azure subscription ID, present if this alert is related to an Azure resource.
     * @param value Value to set for the azureSubscriptionId property.
     */
    set azureSubscriptionId(value: string | undefined);
    /**
     * Gets the azureTenantId property value. Azure Active Directory tenant ID. Required.
     * @returns a string
     */
    get azureTenantId(): string | undefined;
    /**
     * Sets the azureTenantId property value. Azure Active Directory tenant ID. Required.
     * @param value Value to set for the azureTenantId property.
     */
    set azureTenantId(value: string | undefined);
    /**
     * Gets the category property value. Category of the alert (for example, credentialTheft, ransomware, etc.).
     * @returns a string
     */
    get category(): string | undefined;
    /**
     * Sets the category property value. Category of the alert (for example, credentialTheft, ransomware, etc.).
     * @param value Value to set for the category property.
     */
    set category(value: string | undefined);
    /**
     * Gets the closedDateTime property value. Time at which the alert was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z (supports update).
     * @returns a Date
     */
    get closedDateTime(): Date | undefined;
    /**
     * Sets the closedDateTime property value. Time at which the alert was closed. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z (supports update).
     * @param value Value to set for the closedDateTime property.
     */
    set closedDateTime(value: Date | undefined);
    /**
     * Gets the cloudAppStates property value. Security-related stateful information generated by the provider about the cloud application/s related to this alert.
     * @returns a cloudAppSecurityState
     */
    get cloudAppStates(): CloudAppSecurityState[] | undefined;
    /**
     * Sets the cloudAppStates property value. Security-related stateful information generated by the provider about the cloud application/s related to this alert.
     * @param value Value to set for the cloudAppStates property.
     */
    set cloudAppStates(value: CloudAppSecurityState[] | undefined);
    /**
     * Gets the comments property value. Customer-provided comments on alert (for customer alert management) (supports update).
     * @returns a string
     */
    get comments(): string[] | undefined;
    /**
     * Sets the comments property value. Customer-provided comments on alert (for customer alert management) (supports update).
     * @param value Value to set for the comments property.
     */
    set comments(value: string[] | undefined);
    /**
     * Gets the confidence property value. Confidence of the detection logic (percentage between 1-100).
     * @returns a integer
     */
    get confidence(): number | undefined;
    /**
     * Sets the confidence property value. Confidence of the detection logic (percentage between 1-100).
     * @param value Value to set for the confidence property.
     */
    set confidence(value: number | undefined);
    /**
     * Instantiates a new alert and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Time at which the alert was created by the alert provider. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Time at which the alert was created by the alert provider. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the description property value. Alert description.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Alert description.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the detectionIds property value. Set of alerts related to this alert entity (each alert is pushed to the SIEM as a separate record).
     * @returns a string
     */
    get detectionIds(): string[] | undefined;
    /**
     * Sets the detectionIds property value. Set of alerts related to this alert entity (each alert is pushed to the SIEM as a separate record).
     * @param value Value to set for the detectionIds property.
     */
    set detectionIds(value: string[] | undefined);
    /**
     * Gets the eventDateTime property value. Time at which the event(s) that served as the trigger(s) to generate the alert occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
     * @returns a Date
     */
    get eventDateTime(): Date | undefined;
    /**
     * Sets the eventDateTime property value. Time at which the event(s) that served as the trigger(s) to generate the alert occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Required.
     * @param value Value to set for the eventDateTime property.
     */
    set eventDateTime(value: Date | undefined);
    /**
     * Gets the feedback property value. Analyst feedback on the alert. Possible values are: unknown, truePositive, falsePositive, benignPositive. (supports update)
     * @returns a alertFeedback
     */
    get feedback(): AlertFeedback | undefined;
    /**
     * Sets the feedback property value. Analyst feedback on the alert. Possible values are: unknown, truePositive, falsePositive, benignPositive. (supports update)
     * @param value Value to set for the feedback property.
     */
    set feedback(value: AlertFeedback | undefined);
    /**
     * Gets the fileStates property value. Security-related stateful information generated by the provider about the file(s) related to this alert.
     * @returns a fileSecurityState
     */
    get fileStates(): FileSecurityState[] | undefined;
    /**
     * Sets the fileStates property value. Security-related stateful information generated by the provider about the file(s) related to this alert.
     * @param value Value to set for the fileStates property.
     */
    set fileStates(value: FileSecurityState[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the historyStates property value. A collection of alertHistoryStates comprising an audit log of all updates made to an alert.
     * @returns a alertHistoryState
     */
    get historyStates(): AlertHistoryState[] | undefined;
    /**
     * Sets the historyStates property value. A collection of alertHistoryStates comprising an audit log of all updates made to an alert.
     * @param value Value to set for the historyStates property.
     */
    set historyStates(value: AlertHistoryState[] | undefined);
    /**
     * Gets the hostStates property value. Security-related stateful information generated by the provider about the host(s) related to this alert.
     * @returns a hostSecurityState
     */
    get hostStates(): HostSecurityState[] | undefined;
    /**
     * Sets the hostStates property value. Security-related stateful information generated by the provider about the host(s) related to this alert.
     * @param value Value to set for the hostStates property.
     */
    set hostStates(value: HostSecurityState[] | undefined);
    /**
     * Gets the incidentIds property value. IDs of incidents related to current alert.
     * @returns a string
     */
    get incidentIds(): string[] | undefined;
    /**
     * Sets the incidentIds property value. IDs of incidents related to current alert.
     * @param value Value to set for the incidentIds property.
     */
    set incidentIds(value: string[] | undefined);
    /**
     * Gets the investigationSecurityStates property value.
     * @returns a investigationSecurityState
     */
    get investigationSecurityStates(): InvestigationSecurityState[] | undefined;
    /**
     * Sets the investigationSecurityStates property value.
     * @param value Value to set for the investigationSecurityStates property.
     */
    set investigationSecurityStates(value: InvestigationSecurityState[] | undefined);
    /**
     * Gets the lastEventDateTime property value.
     * @returns a Date
     */
    get lastEventDateTime(): Date | undefined;
    /**
     * Sets the lastEventDateTime property value.
     * @param value Value to set for the lastEventDateTime property.
     */
    set lastEventDateTime(value: Date | undefined);
    /**
     * Gets the lastModifiedDateTime property value. Time at which the alert entity was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. Time at which the alert entity was last modified. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the malwareStates property value. Threat Intelligence pertaining to malware related to this alert.
     * @returns a malwareState
     */
    get malwareStates(): MalwareState[] | undefined;
    /**
     * Sets the malwareStates property value. Threat Intelligence pertaining to malware related to this alert.
     * @param value Value to set for the malwareStates property.
     */
    set malwareStates(value: MalwareState[] | undefined);
    /**
     * Gets the messageSecurityStates property value.
     * @returns a messageSecurityState
     */
    get messageSecurityStates(): MessageSecurityState[] | undefined;
    /**
     * Sets the messageSecurityStates property value.
     * @param value Value to set for the messageSecurityStates property.
     */
    set messageSecurityStates(value: MessageSecurityState[] | undefined);
    /**
     * Gets the networkConnections property value. Security-related stateful information generated by the provider about the network connection(s) related to this alert.
     * @returns a networkConnection
     */
    get networkConnections(): NetworkConnection[] | undefined;
    /**
     * Sets the networkConnections property value. Security-related stateful information generated by the provider about the network connection(s) related to this alert.
     * @param value Value to set for the networkConnections property.
     */
    set networkConnections(value: NetworkConnection[] | undefined);
    /**
     * Gets the processes property value. Security-related stateful information generated by the provider about the process or processes related to this alert.
     * @returns a process
     */
    get processes(): Process[] | undefined;
    /**
     * Sets the processes property value. Security-related stateful information generated by the provider about the process or processes related to this alert.
     * @param value Value to set for the processes property.
     */
    set processes(value: Process[] | undefined);
    /**
     * Gets the recommendedActions property value. Vendor/provider recommended action(s) to take as a result of the alert (for example, isolate machine, enforce2FA, reimage host).
     * @returns a string
     */
    get recommendedActions(): string[] | undefined;
    /**
     * Sets the recommendedActions property value. Vendor/provider recommended action(s) to take as a result of the alert (for example, isolate machine, enforce2FA, reimage host).
     * @param value Value to set for the recommendedActions property.
     */
    set recommendedActions(value: string[] | undefined);
    /**
     * Gets the registryKeyStates property value. Security-related stateful information generated by the provider about the registry keys related to this alert.
     * @returns a registryKeyState
     */
    get registryKeyStates(): RegistryKeyState[] | undefined;
    /**
     * Sets the registryKeyStates property value. Security-related stateful information generated by the provider about the registry keys related to this alert.
     * @param value Value to set for the registryKeyStates property.
     */
    set registryKeyStates(value: RegistryKeyState[] | undefined);
    /**
     * Gets the securityResources property value. Resources related to current alert. For example, for some alerts this can have the Azure Resource value.
     * @returns a securityResource
     */
    get securityResources(): SecurityResource[] | undefined;
    /**
     * Sets the securityResources property value. Resources related to current alert. For example, for some alerts this can have the Azure Resource value.
     * @param value Value to set for the securityResources property.
     */
    set securityResources(value: SecurityResource[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the severity property value. Alert severity - set by vendor/provider. Possible values are: unknown, informational, low, medium, high. Required.
     * @returns a alertSeverity
     */
    get severity(): AlertSeverity | undefined;
    /**
     * Sets the severity property value. Alert severity - set by vendor/provider. Possible values are: unknown, informational, low, medium, high. Required.
     * @param value Value to set for the severity property.
     */
    set severity(value: AlertSeverity | undefined);
    /**
     * Gets the sourceMaterials property value. Hyperlinks (URIs) to the source material related to the alert, for example, provider's user interface for alerts or log search, etc.
     * @returns a string
     */
    get sourceMaterials(): string[] | undefined;
    /**
     * Sets the sourceMaterials property value. Hyperlinks (URIs) to the source material related to the alert, for example, provider's user interface for alerts or log search, etc.
     * @param value Value to set for the sourceMaterials property.
     */
    set sourceMaterials(value: string[] | undefined);
    /**
     * Gets the status property value. Alert lifecycle status (stage). Possible values are: unknown, newAlert, inProgress, resolved. (supports update). Required.
     * @returns a alertStatus
     */
    get status(): AlertStatus | undefined;
    /**
     * Sets the status property value. Alert lifecycle status (stage). Possible values are: unknown, newAlert, inProgress, resolved. (supports update). Required.
     * @param value Value to set for the status property.
     */
    set status(value: AlertStatus | undefined);
    /**
     * Gets the tags property value. User-definable labels that can be applied to an alert and can serve as filter conditions (for example 'HVA', 'SAW', etc.) (supports update).
     * @returns a string
     */
    get tags(): string[] | undefined;
    /**
     * Sets the tags property value. User-definable labels that can be applied to an alert and can serve as filter conditions (for example 'HVA', 'SAW', etc.) (supports update).
     * @param value Value to set for the tags property.
     */
    set tags(value: string[] | undefined);
    /**
     * Gets the title property value. Alert title. Required.
     * @returns a string
     */
    get title(): string | undefined;
    /**
     * Sets the title property value. Alert title. Required.
     * @param value Value to set for the title property.
     */
    set title(value: string | undefined);
    /**
     * Gets the triggers property value. Security-related information about the specific properties that triggered the alert (properties appearing in the alert). Alerts might contain information about multiple users, hosts, files, ip addresses. This field indicates which properties triggered the alert generation.
     * @returns a alertTrigger
     */
    get triggers(): AlertTrigger[] | undefined;
    /**
     * Sets the triggers property value. Security-related information about the specific properties that triggered the alert (properties appearing in the alert). Alerts might contain information about multiple users, hosts, files, ip addresses. This field indicates which properties triggered the alert generation.
     * @param value Value to set for the triggers property.
     */
    set triggers(value: AlertTrigger[] | undefined);
    /**
     * Gets the uriClickSecurityStates property value.
     * @returns a uriClickSecurityState
     */
    get uriClickSecurityStates(): UriClickSecurityState[] | undefined;
    /**
     * Sets the uriClickSecurityStates property value.
     * @param value Value to set for the uriClickSecurityStates property.
     */
    set uriClickSecurityStates(value: UriClickSecurityState[] | undefined);
    /**
     * Gets the userStates property value. Security-related stateful information generated by the provider about the user accounts related to this alert.
     * @returns a userSecurityState
     */
    get userStates(): UserSecurityState[] | undefined;
    /**
     * Sets the userStates property value. Security-related stateful information generated by the provider about the user accounts related to this alert.
     * @param value Value to set for the userStates property.
     */
    set userStates(value: UserSecurityState[] | undefined);
    /**
     * Gets the vendorInformation property value. Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=Windows Defender ATP; subProvider=AppLocker). Required.
     * @returns a securityVendorInformation
     */
    get vendorInformation(): SecurityVendorInformation | undefined;
    /**
     * Sets the vendorInformation property value. Complex type containing details about the security product/service vendor, provider, and subprovider (for example, vendor=Microsoft; provider=Windows Defender ATP; subProvider=AppLocker). Required.
     * @param value Value to set for the vendorInformation property.
     */
    set vendorInformation(value: SecurityVendorInformation | undefined);
    /**
     * Gets the vulnerabilityStates property value. Threat intelligence pertaining to one or more vulnerabilities related to this alert.
     * @returns a vulnerabilityState
     */
    get vulnerabilityStates(): VulnerabilityState[] | undefined;
    /**
     * Sets the vulnerabilityStates property value. Threat intelligence pertaining to one or more vulnerabilities related to this alert.
     * @param value Value to set for the vulnerabilityStates property.
     */
    set vulnerabilityStates(value: VulnerabilityState[] | undefined);
}
