import { ManagedAppPolicyDeploymentSummary, ManagedMobileApp, TargetedManagedAppProtection } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class AndroidManagedAppProtection extends TargetedManagedAppProtection implements Parsable {
    /** List of apps to which the policy is deployed.  */
    private _apps?;
    /** Friendly name of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.  */
    private _customBrowserDisplayName?;
    /** Unique identifier of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.  */
    private _customBrowserPackageId?;
    /** Count of apps to which the current policy is deployed.  */
    private _deployedAppCount?;
    /** Navigation property to deployment summary of the configuration.  */
    private _deploymentSummary?;
    /** When this setting is enabled, app level encryption is disabled if device level encryption is enabled  */
    private _disableAppEncryptionIfDeviceEncryptionIsEnabled?;
    /** Indicates whether application data for managed apps should be encrypted  */
    private _encryptAppData?;
    /** Define the oldest required Android security patch level a user can have to gain secure access to the app.  */
    private _minimumRequiredPatchVersion?;
    /** Define the oldest recommended Android security patch level a user can have for secure access to the app.  */
    private _minimumWarningPatchVersion?;
    /** Indicates whether a managed user can take screen captures of managed apps  */
    private _screenCaptureBlocked?;
    /**
     * Gets the apps property value. List of apps to which the policy is deployed.
     * @returns a managedMobileApp
     */
    get apps(): ManagedMobileApp[] | undefined;
    /**
     * Sets the apps property value. List of apps to which the policy is deployed.
     * @param value Value to set for the apps property.
     */
    set apps(value: ManagedMobileApp[] | undefined);
    /**
     * Instantiates a new androidManagedAppProtection and sets the default values.
     */
    constructor();
    /**
     * Gets the customBrowserDisplayName property value. Friendly name of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
     * @returns a string
     */
    get customBrowserDisplayName(): string | undefined;
    /**
     * Sets the customBrowserDisplayName property value. Friendly name of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
     * @param value Value to set for the customBrowserDisplayName property.
     */
    set customBrowserDisplayName(value: string | undefined);
    /**
     * Gets the customBrowserPackageId property value. Unique identifier of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
     * @returns a string
     */
    get customBrowserPackageId(): string | undefined;
    /**
     * Sets the customBrowserPackageId property value. Unique identifier of the preferred custom browser to open weblink on Android. When this property is configured, ManagedBrowserToOpenLinksRequired should be true.
     * @param value Value to set for the customBrowserPackageId property.
     */
    set customBrowserPackageId(value: string | undefined);
    /**
     * Gets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @returns a integer
     */
    get deployedAppCount(): number | undefined;
    /**
     * Sets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @param value Value to set for the deployedAppCount property.
     */
    set deployedAppCount(value: number | undefined);
    /**
     * Gets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @returns a managedAppPolicyDeploymentSummary
     */
    get deploymentSummary(): ManagedAppPolicyDeploymentSummary | undefined;
    /**
     * Sets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @param value Value to set for the deploymentSummary property.
     */
    set deploymentSummary(value: ManagedAppPolicyDeploymentSummary | undefined);
    /**
     * Gets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled
     * @returns a boolean
     */
    get disableAppEncryptionIfDeviceEncryptionIsEnabled(): boolean | undefined;
    /**
     * Sets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled
     * @param value Value to set for the disableAppEncryptionIfDeviceEncryptionIsEnabled property.
     */
    set disableAppEncryptionIfDeviceEncryptionIsEnabled(value: boolean | undefined);
    /**
     * Gets the encryptAppData property value. Indicates whether application data for managed apps should be encrypted
     * @returns a boolean
     */
    get encryptAppData(): boolean | undefined;
    /**
     * Sets the encryptAppData property value. Indicates whether application data for managed apps should be encrypted
     * @param value Value to set for the encryptAppData property.
     */
    set encryptAppData(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app.
     * @returns a string
     */
    get minimumRequiredPatchVersion(): string | undefined;
    /**
     * Sets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app.
     * @param value Value to set for the minimumRequiredPatchVersion property.
     */
    set minimumRequiredPatchVersion(value: string | undefined);
    /**
     * Gets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app.
     * @returns a string
     */
    get minimumWarningPatchVersion(): string | undefined;
    /**
     * Sets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app.
     * @param value Value to set for the minimumWarningPatchVersion property.
     */
    set minimumWarningPatchVersion(value: string | undefined);
    /**
     * Gets the screenCaptureBlocked property value. Indicates whether a managed user can take screen captures of managed apps
     * @returns a boolean
     */
    get screenCaptureBlocked(): boolean | undefined;
    /**
     * Sets the screenCaptureBlocked property value. Indicates whether a managed user can take screen captures of managed apps
     * @param value Value to set for the screenCaptureBlocked property.
     */
    set screenCaptureBlocked(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
