"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.AppRoleAssignment = void 0;
const index_1 = require("./index");
class AppRoleAssignment extends index_1.DirectoryObject {
    /**
     * Instantiates a new appRoleAssignment and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the appRoleId property value. The identifier (id) for the app role which is assigned to the principal. This app role must be exposed in the appRoles property on the resource application's service principal (resourceId). If the resource application has not declared any app roles, a default app role ID of 00000000-0000-0000-0000-000000000000 can be specified to signal that the principal is assigned to the resource app without any specific app roles. Required on create.
     * @returns a string
     */
    get appRoleId() {
        return this._appRoleId;
    }
    ;
    /**
     * Sets the appRoleId property value. The identifier (id) for the app role which is assigned to the principal. This app role must be exposed in the appRoles property on the resource application's service principal (resourceId). If the resource application has not declared any app roles, a default app role ID of 00000000-0000-0000-0000-000000000000 can be specified to signal that the principal is assigned to the resource app without any specific app roles. Required on create.
     * @param value Value to set for the appRoleId property.
     */
    set appRoleId(value) {
        this._appRoleId = value;
    }
    ;
    ;
    /**
     * Gets the createdDateTime property value. The time when the app role assignment was created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. The time when the app role assignment was created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "appRoleId": (o, n) => { o.appRoleId = n.getStringValue(); }, "createdDateTime": (o, n) => { o.createdDateTime = n.getDateValue(); }, "principalDisplayName": (o, n) => { o.principalDisplayName = n.getStringValue(); }, "principalId": (o, n) => { o.principalId = n.getStringValue(); }, "principalType": (o, n) => { o.principalType = n.getStringValue(); }, "resourceDisplayName": (o, n) => { o.resourceDisplayName = n.getStringValue(); }, "resourceId": (o, n) => { o.resourceId = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the principalDisplayName property value. The display name of the user, group, or service principal that was granted the app role assignment. Read-only. Supports $filter (eq and startswith).
     * @returns a string
     */
    get principalDisplayName() {
        return this._principalDisplayName;
    }
    ;
    /**
     * Sets the principalDisplayName property value. The display name of the user, group, or service principal that was granted the app role assignment. Read-only. Supports $filter (eq and startswith).
     * @param value Value to set for the principalDisplayName property.
     */
    set principalDisplayName(value) {
        this._principalDisplayName = value;
    }
    ;
    /**
     * Gets the principalId property value. The unique identifier (id) for the user, group, or service principal being granted the app role. Required on create.
     * @returns a string
     */
    get principalId() {
        return this._principalId;
    }
    ;
    /**
     * Sets the principalId property value. The unique identifier (id) for the user, group, or service principal being granted the app role. Required on create.
     * @param value Value to set for the principalId property.
     */
    set principalId(value) {
        this._principalId = value;
    }
    ;
    /**
     * Gets the principalType property value. The type of the assigned principal. This can either be User, Group, or ServicePrincipal. Read-only.
     * @returns a string
     */
    get principalType() {
        return this._principalType;
    }
    ;
    /**
     * Sets the principalType property value. The type of the assigned principal. This can either be User, Group, or ServicePrincipal. Read-only.
     * @param value Value to set for the principalType property.
     */
    set principalType(value) {
        this._principalType = value;
    }
    ;
    /**
     * Gets the resourceDisplayName property value. The display name of the resource app's service principal to which the assignment is made.
     * @returns a string
     */
    get resourceDisplayName() {
        return this._resourceDisplayName;
    }
    ;
    /**
     * Sets the resourceDisplayName property value. The display name of the resource app's service principal to which the assignment is made.
     * @param value Value to set for the resourceDisplayName property.
     */
    set resourceDisplayName(value) {
        this._resourceDisplayName = value;
    }
    ;
    /**
     * Gets the resourceId property value. The unique identifier (id) for the resource service principal for which the assignment is made. Required on create. Supports $filter (eq only).
     * @returns a string
     */
    get resourceId() {
        return this._resourceId;
    }
    ;
    /**
     * Sets the resourceId property value. The unique identifier (id) for the resource service principal for which the assignment is made. Required on create. Supports $filter (eq only).
     * @param value Value to set for the resourceId property.
     */
    set resourceId(value) {
        this._resourceId = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("appRoleId", this.appRoleId);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeStringValue("principalDisplayName", this.principalDisplayName);
        writer.writeStringValue("principalId", this.principalId);
        writer.writeStringValue("principalType", this.principalType);
        writer.writeStringValue("resourceDisplayName", this.resourceDisplayName);
        writer.writeStringValue("resourceId", this.resourceId);
    }
    ;
}
exports.AppRoleAssignment = AppRoleAssignment;
