import { AddIn, ApiApplication, AppRole, DirectoryObject, ExtensionProperty, HomeRealmDiscoveryPolicy, InformationalUrl, KeyCredential, OptionalClaims, ParentalControlSettings, PasswordCredential, PublicClientApplication, RequiredResourceAccess, SpaApplication, TokenIssuancePolicy, TokenLifetimePolicy, VerifiedPublisher, WebApplication } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Application extends DirectoryObject implements Parsable {
    /** Defines custom behavior that a consuming service can use to call an app in specific contexts. For example, applications that can render file streams may set the addIns property for its 'FileHandler' functionality. This will let services like Office 365 call the application in the context of a document the user is working on.  */
    private _addIns?;
    /** Specifies settings for an application that implements a web API.  */
    private _api?;
    /** The unique identifier for the application that is assigned to an application by Azure AD. Not nullable. Read-only.  */
    private _appId?;
    /** Unique identifier of the applicationTemplate. Supports $filter (eq, not, ne).  */
    private _applicationTemplateId?;
    /** The collection of roles assigned to the application. With app role assignments, these roles can be assigned to users, groups, or service principals associated with other applications. Not nullable.  */
    private _appRoles?;
    /** The date and time the application was registered. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  Supports $filter (eq, ne, not, ge, le, in, and eq on null values) and $orderBy.  */
    private _createdDateTime?;
    /** Read-only.  */
    private _createdOnBehalfOf?;
    /** Free text field to provide a description of the application object to end users. The maximum allowed size is 1024 characters. Supports $filter (eq, ne, not, ge, le, startsWith) and $search.  */
    private _description?;
    /** Specifies whether Microsoft has disabled the registered application. Possible values are: null (default value), NotDisabled, and DisabledDueToViolationOfServicesAgreement (reasons may include suspicious, abusive, or malicious activity, or a violation of the Microsoft Services Agreement).  Supports $filter (eq, ne, not).  */
    private _disabledByMicrosoftStatus?;
    /** The display name for the application. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq on null values), $search, and $orderBy.  */
    private _displayName?;
    /** Read-only. Nullable.  */
    private _extensionProperties?;
    /** Configures the groups claim issued in a user or OAuth 2.0 access token that the application expects. To set this attribute, use one of the following valid string values: None, SecurityGroup (for security groups and Azure AD roles), All (this gets all of the security groups, distribution groups, and Azure AD directory roles that the signed-in user is a member of).  */
    private _groupMembershipClaims?;
    private _homeRealmDiscoveryPolicies?;
    /** Also known as App ID URI, this value is set when an application is used as a resource app. The identifierUris acts as the prefix for the scopes you'll reference in your API's code, and it must be globally unique. You can use the default value provided, which is in the form api://<application-client-id>, or specify a more readable URI like https://contoso.com/api. For more information on valid identifierUris patterns and best practices, see Azure AD application registration security best practices. Not nullable. Supports $filter (eq, ne, ge, le, startsWith).  */
    private _identifierUris?;
    /** Basic profile information of the application such as  app's marketing, support, terms of service and privacy statement URLs. The terms of service and privacy statement are surfaced to users through the user consent experience. For more info, see How to: Add Terms of service and privacy statement for registered Azure AD apps. Supports $filter (eq, ne, not, ge, le, and eq on null values).  */
    private _info?;
    /** Specifies whether this application supports device authentication without a user. The default is false.  */
    private _isDeviceOnlyAuthSupported?;
    /** Specifies the fallback application type as public client, such as an installed application running on a mobile device. The default value is false which means the fallback application type is confidential client such as a web app. There are certain scenarios where Azure AD cannot determine the client application type. For example, the ROPC flow where it is configured without specifying a redirect URI. In those cases Azure AD interprets the application type based on the value of this property.  */
    private _isFallbackPublicClient?;
    /** The collection of key credentials associated with the application. Not nullable. Supports $filter (eq, not, ge, le).  */
    private _keyCredentials?;
    /** The main logo for the application. Not nullable.  */
    private _logo?;
    /** Notes relevant for the management of the application.  */
    private _notes?;
    private _oauth2RequirePostResponse?;
    /** Application developers can configure optional claims in their Azure AD applications to specify the claims that are sent to their application by the Microsoft security token service. For more information, see How to: Provide optional claims to your app.  */
    private _optionalClaims?;
    /** Directory objects that are owners of the application. Read-only. Nullable. Supports $expand.  */
    private _owners?;
    /** Specifies parental control settings for an application.  */
    private _parentalControlSettings?;
    /** The collection of password credentials associated with the application. Not nullable.  */
    private _passwordCredentials?;
    /** Specifies settings for installed clients such as desktop or mobile devices.  */
    private _publicClient?;
    /** The verified publisher domain for the application. Read-only. For more information, see How to: Configure an application's publisher domain. Supports $filter (eq, ne, ge, le, startsWith).  */
    private _publisherDomain?;
    /** Specifies the resources that the application needs to access. This property also specifies the set of delegated permissions and application roles that it needs for each of those resources. This configuration of access to the required resources drives the consent experience. No more than 50 resource services (APIs) can be configured. Beginning mid-October 2021, the total number of required permissions must not exceed 400. Not nullable. Supports $filter (eq, not, ge, le).  */
    private _requiredResourceAccess?;
    /** Specifies the Microsoft accounts that are supported for the current application. The possible values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount (default), and PersonalMicrosoftAccount. See more in the table below. Supports $filter (eq, ne, not).  */
    private _signInAudience?;
    /** Specifies settings for a single-page application, including sign out URLs and redirect URIs for authorization codes and access tokens.  */
    private _spa?;
    /** Custom strings that can be used to categorize and identify the application. Not nullable. Supports $filter (eq, not, ge, le, startsWith).  */
    private _tags?;
    /** Specifies the keyId of a public key from the keyCredentials collection. When configured, Azure AD encrypts all the tokens it emits by using the key this property points to. The application code that receives the encrypted token must use the matching private key to decrypt the token before it can be used for the signed-in user.  */
    private _tokenEncryptionKeyId?;
    private _tokenIssuancePolicies?;
    /** The tokenLifetimePolicies assigned to this application. Supports $expand.  */
    private _tokenLifetimePolicies?;
    /** Specifies the verified publisher of the application. For more information about how publisher verification helps support application security, trustworthiness, and compliance, see Publisher verification.  */
    private _verifiedPublisher?;
    /** Specifies settings for a web application.  */
    private _web?;
    /**
     * Gets the addIns property value. Defines custom behavior that a consuming service can use to call an app in specific contexts. For example, applications that can render file streams may set the addIns property for its 'FileHandler' functionality. This will let services like Office 365 call the application in the context of a document the user is working on.
     * @returns a addIn
     */
    get addIns(): AddIn[] | undefined;
    /**
     * Sets the addIns property value. Defines custom behavior that a consuming service can use to call an app in specific contexts. For example, applications that can render file streams may set the addIns property for its 'FileHandler' functionality. This will let services like Office 365 call the application in the context of a document the user is working on.
     * @param value Value to set for the addIns property.
     */
    set addIns(value: AddIn[] | undefined);
    /**
     * Gets the api property value. Specifies settings for an application that implements a web API.
     * @returns a apiApplication
     */
    get api(): ApiApplication | undefined;
    /**
     * Sets the api property value. Specifies settings for an application that implements a web API.
     * @param value Value to set for the api property.
     */
    set api(value: ApiApplication | undefined);
    /**
     * Gets the appId property value. The unique identifier for the application that is assigned to an application by Azure AD. Not nullable. Read-only.
     * @returns a string
     */
    get appId(): string | undefined;
    /**
     * Sets the appId property value. The unique identifier for the application that is assigned to an application by Azure AD. Not nullable. Read-only.
     * @param value Value to set for the appId property.
     */
    set appId(value: string | undefined);
    /**
     * Gets the applicationTemplateId property value. Unique identifier of the applicationTemplate. Supports $filter (eq, not, ne).
     * @returns a string
     */
    get applicationTemplateId(): string | undefined;
    /**
     * Sets the applicationTemplateId property value. Unique identifier of the applicationTemplate. Supports $filter (eq, not, ne).
     * @param value Value to set for the applicationTemplateId property.
     */
    set applicationTemplateId(value: string | undefined);
    /**
     * Gets the appRoles property value. The collection of roles assigned to the application. With app role assignments, these roles can be assigned to users, groups, or service principals associated with other applications. Not nullable.
     * @returns a appRole
     */
    get appRoles(): AppRole[] | undefined;
    /**
     * Sets the appRoles property value. The collection of roles assigned to the application. With app role assignments, these roles can be assigned to users, groups, or service principals associated with other applications. Not nullable.
     * @param value Value to set for the appRoles property.
     */
    set appRoles(value: AppRole[] | undefined);
    /**
     * Instantiates a new application and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. The date and time the application was registered. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  Supports $filter (eq, ne, not, ge, le, in, and eq on null values) and $orderBy.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The date and time the application was registered. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  Supports $filter (eq, ne, not, ge, le, in, and eq on null values) and $orderBy.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the createdOnBehalfOf property value. Read-only.
     * @returns a directoryObject
     */
    get createdOnBehalfOf(): DirectoryObject | undefined;
    /**
     * Sets the createdOnBehalfOf property value. Read-only.
     * @param value Value to set for the createdOnBehalfOf property.
     */
    set createdOnBehalfOf(value: DirectoryObject | undefined);
    /**
     * Gets the description property value. Free text field to provide a description of the application object to end users. The maximum allowed size is 1024 characters. Supports $filter (eq, ne, not, ge, le, startsWith) and $search.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Free text field to provide a description of the application object to end users. The maximum allowed size is 1024 characters. Supports $filter (eq, ne, not, ge, le, startsWith) and $search.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the disabledByMicrosoftStatus property value. Specifies whether Microsoft has disabled the registered application. Possible values are: null (default value), NotDisabled, and DisabledDueToViolationOfServicesAgreement (reasons may include suspicious, abusive, or malicious activity, or a violation of the Microsoft Services Agreement).  Supports $filter (eq, ne, not).
     * @returns a string
     */
    get disabledByMicrosoftStatus(): string | undefined;
    /**
     * Sets the disabledByMicrosoftStatus property value. Specifies whether Microsoft has disabled the registered application. Possible values are: null (default value), NotDisabled, and DisabledDueToViolationOfServicesAgreement (reasons may include suspicious, abusive, or malicious activity, or a violation of the Microsoft Services Agreement).  Supports $filter (eq, ne, not).
     * @param value Value to set for the disabledByMicrosoftStatus property.
     */
    set disabledByMicrosoftStatus(value: string | undefined);
    /**
     * Gets the displayName property value. The display name for the application. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq on null values), $search, and $orderBy.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The display name for the application. Supports $filter (eq, ne, not, ge, le, in, startsWith, and eq on null values), $search, and $orderBy.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the extensionProperties property value. Read-only. Nullable.
     * @returns a extensionProperty
     */
    get extensionProperties(): ExtensionProperty[] | undefined;
    /**
     * Sets the extensionProperties property value. Read-only. Nullable.
     * @param value Value to set for the extensionProperties property.
     */
    set extensionProperties(value: ExtensionProperty[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the groupMembershipClaims property value. Configures the groups claim issued in a user or OAuth 2.0 access token that the application expects. To set this attribute, use one of the following valid string values: None, SecurityGroup (for security groups and Azure AD roles), All (this gets all of the security groups, distribution groups, and Azure AD directory roles that the signed-in user is a member of).
     * @returns a string
     */
    get groupMembershipClaims(): string | undefined;
    /**
     * Sets the groupMembershipClaims property value. Configures the groups claim issued in a user or OAuth 2.0 access token that the application expects. To set this attribute, use one of the following valid string values: None, SecurityGroup (for security groups and Azure AD roles), All (this gets all of the security groups, distribution groups, and Azure AD directory roles that the signed-in user is a member of).
     * @param value Value to set for the groupMembershipClaims property.
     */
    set groupMembershipClaims(value: string | undefined);
    /**
     * Gets the homeRealmDiscoveryPolicies property value.
     * @returns a homeRealmDiscoveryPolicy
     */
    get homeRealmDiscoveryPolicies(): HomeRealmDiscoveryPolicy[] | undefined;
    /**
     * Sets the homeRealmDiscoveryPolicies property value.
     * @param value Value to set for the homeRealmDiscoveryPolicies property.
     */
    set homeRealmDiscoveryPolicies(value: HomeRealmDiscoveryPolicy[] | undefined);
    /**
     * Gets the identifierUris property value. Also known as App ID URI, this value is set when an application is used as a resource app. The identifierUris acts as the prefix for the scopes you'll reference in your API's code, and it must be globally unique. You can use the default value provided, which is in the form api://<application-client-id>, or specify a more readable URI like https://contoso.com/api. For more information on valid identifierUris patterns and best practices, see Azure AD application registration security best practices. Not nullable. Supports $filter (eq, ne, ge, le, startsWith).
     * @returns a string
     */
    get identifierUris(): string[] | undefined;
    /**
     * Sets the identifierUris property value. Also known as App ID URI, this value is set when an application is used as a resource app. The identifierUris acts as the prefix for the scopes you'll reference in your API's code, and it must be globally unique. You can use the default value provided, which is in the form api://<application-client-id>, or specify a more readable URI like https://contoso.com/api. For more information on valid identifierUris patterns and best practices, see Azure AD application registration security best practices. Not nullable. Supports $filter (eq, ne, ge, le, startsWith).
     * @param value Value to set for the identifierUris property.
     */
    set identifierUris(value: string[] | undefined);
    /**
     * Gets the info property value. Basic profile information of the application such as  app's marketing, support, terms of service and privacy statement URLs. The terms of service and privacy statement are surfaced to users through the user consent experience. For more info, see How to: Add Terms of service and privacy statement for registered Azure AD apps. Supports $filter (eq, ne, not, ge, le, and eq on null values).
     * @returns a informationalUrl
     */
    get info(): InformationalUrl | undefined;
    /**
     * Sets the info property value. Basic profile information of the application such as  app's marketing, support, terms of service and privacy statement URLs. The terms of service and privacy statement are surfaced to users through the user consent experience. For more info, see How to: Add Terms of service and privacy statement for registered Azure AD apps. Supports $filter (eq, ne, not, ge, le, and eq on null values).
     * @param value Value to set for the info property.
     */
    set info(value: InformationalUrl | undefined);
    /**
     * Gets the isDeviceOnlyAuthSupported property value. Specifies whether this application supports device authentication without a user. The default is false.
     * @returns a boolean
     */
    get isDeviceOnlyAuthSupported(): boolean | undefined;
    /**
     * Sets the isDeviceOnlyAuthSupported property value. Specifies whether this application supports device authentication without a user. The default is false.
     * @param value Value to set for the isDeviceOnlyAuthSupported property.
     */
    set isDeviceOnlyAuthSupported(value: boolean | undefined);
    /**
     * Gets the isFallbackPublicClient property value. Specifies the fallback application type as public client, such as an installed application running on a mobile device. The default value is false which means the fallback application type is confidential client such as a web app. There are certain scenarios where Azure AD cannot determine the client application type. For example, the ROPC flow where it is configured without specifying a redirect URI. In those cases Azure AD interprets the application type based on the value of this property.
     * @returns a boolean
     */
    get isFallbackPublicClient(): boolean | undefined;
    /**
     * Sets the isFallbackPublicClient property value. Specifies the fallback application type as public client, such as an installed application running on a mobile device. The default value is false which means the fallback application type is confidential client such as a web app. There are certain scenarios where Azure AD cannot determine the client application type. For example, the ROPC flow where it is configured without specifying a redirect URI. In those cases Azure AD interprets the application type based on the value of this property.
     * @param value Value to set for the isFallbackPublicClient property.
     */
    set isFallbackPublicClient(value: boolean | undefined);
    /**
     * Gets the keyCredentials property value. The collection of key credentials associated with the application. Not nullable. Supports $filter (eq, not, ge, le).
     * @returns a keyCredential
     */
    get keyCredentials(): KeyCredential[] | undefined;
    /**
     * Sets the keyCredentials property value. The collection of key credentials associated with the application. Not nullable. Supports $filter (eq, not, ge, le).
     * @param value Value to set for the keyCredentials property.
     */
    set keyCredentials(value: KeyCredential[] | undefined);
    /**
     * Gets the logo property value. The main logo for the application. Not nullable.
     * @returns a binary
     */
    get logo(): string | undefined;
    /**
     * Sets the logo property value. The main logo for the application. Not nullable.
     * @param value Value to set for the logo property.
     */
    set logo(value: string | undefined);
    /**
     * Gets the notes property value. Notes relevant for the management of the application.
     * @returns a string
     */
    get notes(): string | undefined;
    /**
     * Sets the notes property value. Notes relevant for the management of the application.
     * @param value Value to set for the notes property.
     */
    set notes(value: string | undefined);
    /**
     * Gets the oauth2RequirePostResponse property value.
     * @returns a boolean
     */
    get oauth2RequirePostResponse(): boolean | undefined;
    /**
     * Sets the oauth2RequirePostResponse property value.
     * @param value Value to set for the oauth2RequirePostResponse property.
     */
    set oauth2RequirePostResponse(value: boolean | undefined);
    /**
     * Gets the optionalClaims property value. Application developers can configure optional claims in their Azure AD applications to specify the claims that are sent to their application by the Microsoft security token service. For more information, see How to: Provide optional claims to your app.
     * @returns a optionalClaims
     */
    get optionalClaims(): OptionalClaims | undefined;
    /**
     * Sets the optionalClaims property value. Application developers can configure optional claims in their Azure AD applications to specify the claims that are sent to their application by the Microsoft security token service. For more information, see How to: Provide optional claims to your app.
     * @param value Value to set for the optionalClaims property.
     */
    set optionalClaims(value: OptionalClaims | undefined);
    /**
     * Gets the owners property value. Directory objects that are owners of the application. Read-only. Nullable. Supports $expand.
     * @returns a directoryObject
     */
    get owners(): DirectoryObject[] | undefined;
    /**
     * Sets the owners property value. Directory objects that are owners of the application. Read-only. Nullable. Supports $expand.
     * @param value Value to set for the owners property.
     */
    set owners(value: DirectoryObject[] | undefined);
    /**
     * Gets the parentalControlSettings property value. Specifies parental control settings for an application.
     * @returns a parentalControlSettings
     */
    get parentalControlSettings(): ParentalControlSettings | undefined;
    /**
     * Sets the parentalControlSettings property value. Specifies parental control settings for an application.
     * @param value Value to set for the parentalControlSettings property.
     */
    set parentalControlSettings(value: ParentalControlSettings | undefined);
    /**
     * Gets the passwordCredentials property value. The collection of password credentials associated with the application. Not nullable.
     * @returns a passwordCredential
     */
    get passwordCredentials(): PasswordCredential[] | undefined;
    /**
     * Sets the passwordCredentials property value. The collection of password credentials associated with the application. Not nullable.
     * @param value Value to set for the passwordCredentials property.
     */
    set passwordCredentials(value: PasswordCredential[] | undefined);
    /**
     * Gets the publicClient property value. Specifies settings for installed clients such as desktop or mobile devices.
     * @returns a publicClientApplication
     */
    get publicClient(): PublicClientApplication | undefined;
    /**
     * Sets the publicClient property value. Specifies settings for installed clients such as desktop or mobile devices.
     * @param value Value to set for the publicClient property.
     */
    set publicClient(value: PublicClientApplication | undefined);
    /**
     * Gets the publisherDomain property value. The verified publisher domain for the application. Read-only. For more information, see How to: Configure an application's publisher domain. Supports $filter (eq, ne, ge, le, startsWith).
     * @returns a string
     */
    get publisherDomain(): string | undefined;
    /**
     * Sets the publisherDomain property value. The verified publisher domain for the application. Read-only. For more information, see How to: Configure an application's publisher domain. Supports $filter (eq, ne, ge, le, startsWith).
     * @param value Value to set for the publisherDomain property.
     */
    set publisherDomain(value: string | undefined);
    /**
     * Gets the requiredResourceAccess property value. Specifies the resources that the application needs to access. This property also specifies the set of delegated permissions and application roles that it needs for each of those resources. This configuration of access to the required resources drives the consent experience. No more than 50 resource services (APIs) can be configured. Beginning mid-October 2021, the total number of required permissions must not exceed 400. Not nullable. Supports $filter (eq, not, ge, le).
     * @returns a requiredResourceAccess
     */
    get requiredResourceAccess(): RequiredResourceAccess[] | undefined;
    /**
     * Sets the requiredResourceAccess property value. Specifies the resources that the application needs to access. This property also specifies the set of delegated permissions and application roles that it needs for each of those resources. This configuration of access to the required resources drives the consent experience. No more than 50 resource services (APIs) can be configured. Beginning mid-October 2021, the total number of required permissions must not exceed 400. Not nullable. Supports $filter (eq, not, ge, le).
     * @param value Value to set for the requiredResourceAccess property.
     */
    set requiredResourceAccess(value: RequiredResourceAccess[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the signInAudience property value. Specifies the Microsoft accounts that are supported for the current application. The possible values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount (default), and PersonalMicrosoftAccount. See more in the table below. Supports $filter (eq, ne, not).
     * @returns a string
     */
    get signInAudience(): string | undefined;
    /**
     * Sets the signInAudience property value. Specifies the Microsoft accounts that are supported for the current application. The possible values are: AzureADMyOrg, AzureADMultipleOrgs, AzureADandPersonalMicrosoftAccount (default), and PersonalMicrosoftAccount. See more in the table below. Supports $filter (eq, ne, not).
     * @param value Value to set for the signInAudience property.
     */
    set signInAudience(value: string | undefined);
    /**
     * Gets the spa property value. Specifies settings for a single-page application, including sign out URLs and redirect URIs for authorization codes and access tokens.
     * @returns a spaApplication
     */
    get spa(): SpaApplication | undefined;
    /**
     * Sets the spa property value. Specifies settings for a single-page application, including sign out URLs and redirect URIs for authorization codes and access tokens.
     * @param value Value to set for the spa property.
     */
    set spa(value: SpaApplication | undefined);
    /**
     * Gets the tags property value. Custom strings that can be used to categorize and identify the application. Not nullable. Supports $filter (eq, not, ge, le, startsWith).
     * @returns a string
     */
    get tags(): string[] | undefined;
    /**
     * Sets the tags property value. Custom strings that can be used to categorize and identify the application. Not nullable. Supports $filter (eq, not, ge, le, startsWith).
     * @param value Value to set for the tags property.
     */
    set tags(value: string[] | undefined);
    /**
     * Gets the tokenEncryptionKeyId property value. Specifies the keyId of a public key from the keyCredentials collection. When configured, Azure AD encrypts all the tokens it emits by using the key this property points to. The application code that receives the encrypted token must use the matching private key to decrypt the token before it can be used for the signed-in user.
     * @returns a string
     */
    get tokenEncryptionKeyId(): string | undefined;
    /**
     * Sets the tokenEncryptionKeyId property value. Specifies the keyId of a public key from the keyCredentials collection. When configured, Azure AD encrypts all the tokens it emits by using the key this property points to. The application code that receives the encrypted token must use the matching private key to decrypt the token before it can be used for the signed-in user.
     * @param value Value to set for the tokenEncryptionKeyId property.
     */
    set tokenEncryptionKeyId(value: string | undefined);
    /**
     * Gets the tokenIssuancePolicies property value.
     * @returns a tokenIssuancePolicy
     */
    get tokenIssuancePolicies(): TokenIssuancePolicy[] | undefined;
    /**
     * Sets the tokenIssuancePolicies property value.
     * @param value Value to set for the tokenIssuancePolicies property.
     */
    set tokenIssuancePolicies(value: TokenIssuancePolicy[] | undefined);
    /**
     * Gets the tokenLifetimePolicies property value. The tokenLifetimePolicies assigned to this application. Supports $expand.
     * @returns a tokenLifetimePolicy
     */
    get tokenLifetimePolicies(): TokenLifetimePolicy[] | undefined;
    /**
     * Sets the tokenLifetimePolicies property value. The tokenLifetimePolicies assigned to this application. Supports $expand.
     * @param value Value to set for the tokenLifetimePolicies property.
     */
    set tokenLifetimePolicies(value: TokenLifetimePolicy[] | undefined);
    /**
     * Gets the verifiedPublisher property value. Specifies the verified publisher of the application. For more information about how publisher verification helps support application security, trustworthiness, and compliance, see Publisher verification.
     * @returns a verifiedPublisher
     */
    get verifiedPublisher(): VerifiedPublisher | undefined;
    /**
     * Sets the verifiedPublisher property value. Specifies the verified publisher of the application. For more information about how publisher verification helps support application security, trustworthiness, and compliance, see Publisher verification.
     * @param value Value to set for the verifiedPublisher property.
     */
    set verifiedPublisher(value: VerifiedPublisher | undefined);
    /**
     * Gets the web property value. Specifies settings for a web application.
     * @returns a webApplication
     */
    get web(): WebApplication | undefined;
    /**
     * Sets the web property value. Specifies settings for a web application.
     * @param value Value to set for the web property.
     */
    set web(value: WebApplication | undefined);
}
