import { AllowInvitesFrom } from './allowInvitesFrom';
import { DefaultUserRolePermissions, PolicyBase } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class AuthorizationPolicy extends PolicyBase implements Parsable {
    /** Indicates whether users can sign up for email based subscriptions.  */
    private _allowedToSignUpEmailBasedSubscriptions?;
    /** Indicates whether the Self-Serve Password Reset feature can be used by users on the tenant.  */
    private _allowedToUseSSPR?;
    /** Indicates whether a user can join the tenant by email validation.  */
    private _allowEmailVerifiedUsersToJoinOrganization?;
    /** Indicates who can invite external users to the organization. Possible values are: none, adminsAndGuestInviters, adminsGuestInvitersAndAllMembers, everyone.  everyone is the default setting for all cloud environments except US Government. See more in the table below.  */
    private _allowInvitesFrom?;
    /** To disable the use of MSOL PowerShell set this property to true. This will also disable user-based access to the legacy service endpoint used by MSOL PowerShell. This does not affect Azure AD Connect or Microsoft Graph.  */
    private _blockMsolPowerShell?;
    private _defaultUserRolePermissions?;
    /** Represents role templateId for the role that should be granted to guest user. Currently following roles are supported:  User (a0b1b346-4d3e-4e8b-98f8-753987be4970), Guest User (10dae51f-b6af-4016-8d66-8c2a99b929b3), and Restricted Guest User (2af84b1e-32c8-42b7-82bc-daa82404023b).  */
    private _guestUserRoleId?;
    /**
     * Gets the allowedToSignUpEmailBasedSubscriptions property value. Indicates whether users can sign up for email based subscriptions.
     * @returns a boolean
     */
    get allowedToSignUpEmailBasedSubscriptions(): boolean | undefined;
    /**
     * Sets the allowedToSignUpEmailBasedSubscriptions property value. Indicates whether users can sign up for email based subscriptions.
     * @param value Value to set for the allowedToSignUpEmailBasedSubscriptions property.
     */
    set allowedToSignUpEmailBasedSubscriptions(value: boolean | undefined);
    /**
     * Gets the allowedToUseSSPR property value. Indicates whether the Self-Serve Password Reset feature can be used by users on the tenant.
     * @returns a boolean
     */
    get allowedToUseSSPR(): boolean | undefined;
    /**
     * Sets the allowedToUseSSPR property value. Indicates whether the Self-Serve Password Reset feature can be used by users on the tenant.
     * @param value Value to set for the allowedToUseSSPR property.
     */
    set allowedToUseSSPR(value: boolean | undefined);
    /**
     * Gets the allowEmailVerifiedUsersToJoinOrganization property value. Indicates whether a user can join the tenant by email validation.
     * @returns a boolean
     */
    get allowEmailVerifiedUsersToJoinOrganization(): boolean | undefined;
    /**
     * Sets the allowEmailVerifiedUsersToJoinOrganization property value. Indicates whether a user can join the tenant by email validation.
     * @param value Value to set for the allowEmailVerifiedUsersToJoinOrganization property.
     */
    set allowEmailVerifiedUsersToJoinOrganization(value: boolean | undefined);
    /**
     * Gets the allowInvitesFrom property value. Indicates who can invite external users to the organization. Possible values are: none, adminsAndGuestInviters, adminsGuestInvitersAndAllMembers, everyone.  everyone is the default setting for all cloud environments except US Government. See more in the table below.
     * @returns a allowInvitesFrom
     */
    get allowInvitesFrom(): AllowInvitesFrom | undefined;
    /**
     * Sets the allowInvitesFrom property value. Indicates who can invite external users to the organization. Possible values are: none, adminsAndGuestInviters, adminsGuestInvitersAndAllMembers, everyone.  everyone is the default setting for all cloud environments except US Government. See more in the table below.
     * @param value Value to set for the allowInvitesFrom property.
     */
    set allowInvitesFrom(value: AllowInvitesFrom | undefined);
    /**
     * Gets the blockMsolPowerShell property value. To disable the use of MSOL PowerShell set this property to true. This will also disable user-based access to the legacy service endpoint used by MSOL PowerShell. This does not affect Azure AD Connect or Microsoft Graph.
     * @returns a boolean
     */
    get blockMsolPowerShell(): boolean | undefined;
    /**
     * Sets the blockMsolPowerShell property value. To disable the use of MSOL PowerShell set this property to true. This will also disable user-based access to the legacy service endpoint used by MSOL PowerShell. This does not affect Azure AD Connect or Microsoft Graph.
     * @param value Value to set for the blockMsolPowerShell property.
     */
    set blockMsolPowerShell(value: boolean | undefined);
    /**
     * Instantiates a new authorizationPolicy and sets the default values.
     */
    constructor();
    /**
     * Gets the defaultUserRolePermissions property value.
     * @returns a defaultUserRolePermissions
     */
    get defaultUserRolePermissions(): DefaultUserRolePermissions | undefined;
    /**
     * Sets the defaultUserRolePermissions property value.
     * @param value Value to set for the defaultUserRolePermissions property.
     */
    set defaultUserRolePermissions(value: DefaultUserRolePermissions | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the guestUserRoleId property value. Represents role templateId for the role that should be granted to guest user. Currently following roles are supported:  User (a0b1b346-4d3e-4e8b-98f8-753987be4970), Guest User (10dae51f-b6af-4016-8d66-8c2a99b929b3), and Restricted Guest User (2af84b1e-32c8-42b7-82bc-daa82404023b).
     * @returns a string
     */
    get guestUserRoleId(): string | undefined;
    /**
     * Sets the guestUserRoleId property value. Represents role templateId for the role that should be granted to guest user. Currently following roles are supported:  User (a0b1b346-4d3e-4e8b-98f8-753987be4970), Guest User (10dae51f-b6af-4016-8d66-8c2a99b929b3), and Restricted Guest User (2af84b1e-32c8-42b7-82bc-daa82404023b).
     * @param value Value to set for the guestUserRoleId property.
     */
    set guestUserRoleId(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
