import { IdentityProvider, IdentityProviderBase, IdentityUserFlow, IdentityUserFlowAttributeAssignment, UserFlowApiConnectorConfiguration, UserFlowLanguageConfiguration } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class B2xIdentityUserFlow extends IdentityUserFlow implements Parsable {
    /** Configuration for enabling an API connector for use as part of the self-service sign-up user flow. You can only obtain the value of this object using Get userFlowApiConnectorConfiguration.  */
    private _apiConnectorConfiguration?;
    /** The identity providers included in the user flow.  */
    private _identityProviders?;
    /** The languages supported for customization within the user flow. Language customization is enabled by default in self-service sign-up user flow. You cannot create custom languages in self-service sign-up user flows.  */
    private _languages?;
    /** The user attribute assignments included in the user flow.  */
    private _userAttributeAssignments?;
    private _userFlowIdentityProviders?;
    /**
     * Gets the apiConnectorConfiguration property value. Configuration for enabling an API connector for use as part of the self-service sign-up user flow. You can only obtain the value of this object using Get userFlowApiConnectorConfiguration.
     * @returns a userFlowApiConnectorConfiguration
     */
    get apiConnectorConfiguration(): UserFlowApiConnectorConfiguration | undefined;
    /**
     * Sets the apiConnectorConfiguration property value. Configuration for enabling an API connector for use as part of the self-service sign-up user flow. You can only obtain the value of this object using Get userFlowApiConnectorConfiguration.
     * @param value Value to set for the apiConnectorConfiguration property.
     */
    set apiConnectorConfiguration(value: UserFlowApiConnectorConfiguration | undefined);
    /**
     * Instantiates a new b2xIdentityUserFlow and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the identityProviders property value. The identity providers included in the user flow.
     * @returns a identityProvider
     */
    get identityProviders(): IdentityProvider[] | undefined;
    /**
     * Sets the identityProviders property value. The identity providers included in the user flow.
     * @param value Value to set for the identityProviders property.
     */
    set identityProviders(value: IdentityProvider[] | undefined);
    /**
     * Gets the languages property value. The languages supported for customization within the user flow. Language customization is enabled by default in self-service sign-up user flow. You cannot create custom languages in self-service sign-up user flows.
     * @returns a userFlowLanguageConfiguration
     */
    get languages(): UserFlowLanguageConfiguration[] | undefined;
    /**
     * Sets the languages property value. The languages supported for customization within the user flow. Language customization is enabled by default in self-service sign-up user flow. You cannot create custom languages in self-service sign-up user flows.
     * @param value Value to set for the languages property.
     */
    set languages(value: UserFlowLanguageConfiguration[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the userAttributeAssignments property value. The user attribute assignments included in the user flow.
     * @returns a identityUserFlowAttributeAssignment
     */
    get userAttributeAssignments(): IdentityUserFlowAttributeAssignment[] | undefined;
    /**
     * Sets the userAttributeAssignments property value. The user attribute assignments included in the user flow.
     * @param value Value to set for the userAttributeAssignments property.
     */
    set userAttributeAssignments(value: IdentityUserFlowAttributeAssignment[] | undefined);
    /**
     * Gets the userFlowIdentityProviders property value.
     * @returns a identityProviderBase
     */
    get userFlowIdentityProviders(): IdentityProviderBase[] | undefined;
    /**
     * Sets the userFlowIdentityProviders property value.
     * @param value Value to set for the userFlowIdentityProviders property.
     */
    set userFlowIdentityProviders(value: IdentityProviderBase[] | undefined);
}
