import { Entity, IdentitySet, ItemReference, User } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the drive singleton.  */
export declare class BaseItem extends Entity implements Parsable {
    /** Identity of the user, device, or application which created the item. Read-only.  */
    private _createdBy?;
    /** Identity of the user who created the item. Read-only.  */
    private _createdByUser?;
    /** Date and time of item creation. Read-only.  */
    private _createdDateTime?;
    /** Provides a user-visible description of the item. Optional.  */
    private _description?;
    /** ETag for the item. Read-only.  */
    private _eTag?;
    /** Identity of the user, device, and application which last modified the item. Read-only.  */
    private _lastModifiedBy?;
    /** Identity of the user who last modified the item. Read-only.  */
    private _lastModifiedByUser?;
    /** Date and time the item was last modified. Read-only.  */
    private _lastModifiedDateTime?;
    /** The name of the item. Read-write.  */
    private _name?;
    /** Parent information, if the item has a parent. Read-write.  */
    private _parentReference?;
    /** URL that displays the resource in the browser. Read-only.  */
    private _webUrl?;
    /**
     * Instantiates a new baseItem and sets the default values.
     */
    constructor();
    /**
     * Gets the createdBy property value. Identity of the user, device, or application which created the item. Read-only.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. Identity of the user, device, or application which created the item. Read-only.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the createdByUser property value. Identity of the user who created the item. Read-only.
     * @returns a user
     */
    get createdByUser(): User | undefined;
    /**
     * Sets the createdByUser property value. Identity of the user who created the item. Read-only.
     * @param value Value to set for the createdByUser property.
     */
    set createdByUser(value: User | undefined);
    /**
     * Gets the createdDateTime property value. Date and time of item creation. Read-only.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Date and time of item creation. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the description property value. Provides a user-visible description of the item. Optional.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Provides a user-visible description of the item. Optional.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the eTag property value. ETag for the item. Read-only.
     * @returns a string
     */
    get eTag(): string | undefined;
    /**
     * Sets the eTag property value. ETag for the item. Read-only.
     * @param value Value to set for the eTag property.
     */
    set eTag(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
     * @returns a identitySet
     */
    get lastModifiedBy(): IdentitySet | undefined;
    /**
     * Sets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
     * @param value Value to set for the lastModifiedBy property.
     */
    set lastModifiedBy(value: IdentitySet | undefined);
    /**
     * Gets the lastModifiedByUser property value. Identity of the user who last modified the item. Read-only.
     * @returns a user
     */
    get lastModifiedByUser(): User | undefined;
    /**
     * Sets the lastModifiedByUser property value. Identity of the user who last modified the item. Read-only.
     * @param value Value to set for the lastModifiedByUser property.
     */
    set lastModifiedByUser(value: User | undefined);
    /**
     * Gets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the name property value. The name of the item. Read-write.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The name of the item. Read-write.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the parentReference property value. Parent information, if the item has a parent. Read-write.
     * @returns a itemReference
     */
    get parentReference(): ItemReference | undefined;
    /**
     * Sets the parentReference property value. Parent information, if the item has a parent. Read-write.
     * @param value Value to set for the parentReference property.
     */
    set parentReference(value: ItemReference | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the webUrl property value. URL that displays the resource in the browser. Read-only.
     * @returns a string
     */
    get webUrl(): string | undefined;
    /**
     * Sets the webUrl property value. URL that displays the resource in the browser. Read-only.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value: string | undefined);
}
