"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.BaseItem = void 0;
const createIdentitySetFromDiscriminatorValue_1 = require("./createIdentitySetFromDiscriminatorValue");
const createItemReferenceFromDiscriminatorValue_1 = require("./createItemReferenceFromDiscriminatorValue");
const createUserFromDiscriminatorValue_1 = require("./createUserFromDiscriminatorValue");
const index_1 = require("./index");
/** Provides operations to manage the drive singleton.  */
class BaseItem extends index_1.Entity {
    /**
     * Instantiates a new baseItem and sets the default values.
     */
    constructor() {
        super();
    }
    ;
    /**
     * Gets the createdBy property value. Identity of the user, device, or application which created the item. Read-only.
     * @returns a identitySet
     */
    get createdBy() {
        return this._createdBy;
    }
    ;
    /**
     * Sets the createdBy property value. Identity of the user, device, or application which created the item. Read-only.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value) {
        this._createdBy = value;
    }
    ;
    /**
     * Gets the createdByUser property value. Identity of the user who created the item. Read-only.
     * @returns a user
     */
    get createdByUser() {
        return this._createdByUser;
    }
    ;
    /**
     * Sets the createdByUser property value. Identity of the user who created the item. Read-only.
     * @param value Value to set for the createdByUser property.
     */
    set createdByUser(value) {
        this._createdByUser = value;
    }
    ;
    /**
     * Gets the createdDateTime property value. Date and time of item creation. Read-only.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. Date and time of item creation. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the description property value. Provides a user-visible description of the item. Optional.
     * @returns a string
     */
    get description() {
        return this._description;
    }
    ;
    /**
     * Sets the description property value. Provides a user-visible description of the item. Optional.
     * @param value Value to set for the description property.
     */
    set description(value) {
        this._description = value;
    }
    ;
    /**
     * Gets the eTag property value. ETag for the item. Read-only.
     * @returns a string
     */
    get eTag() {
        return this._eTag;
    }
    ;
    /**
     * Sets the eTag property value. ETag for the item. Read-only.
     * @param value Value to set for the eTag property.
     */
    set eTag(value) {
        this._eTag = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "createdBy": (o, n) => { o.createdBy = n.getObjectValue(createIdentitySetFromDiscriminatorValue_1.createIdentitySetFromDiscriminatorValue); }, "createdByUser": (o, n) => { o.createdByUser = n.getObjectValue(createUserFromDiscriminatorValue_1.createUserFromDiscriminatorValue); }, "createdDateTime": (o, n) => { o.createdDateTime = n.getDateValue(); }, "description": (o, n) => { o.description = n.getStringValue(); }, "eTag": (o, n) => { o.eTag = n.getStringValue(); }, "lastModifiedBy": (o, n) => { o.lastModifiedBy = n.getObjectValue(createIdentitySetFromDiscriminatorValue_1.createIdentitySetFromDiscriminatorValue); }, "lastModifiedByUser": (o, n) => { o.lastModifiedByUser = n.getObjectValue(createUserFromDiscriminatorValue_1.createUserFromDiscriminatorValue); }, "lastModifiedDateTime": (o, n) => { o.lastModifiedDateTime = n.getDateValue(); }, "name": (o, n) => { o.name = n.getStringValue(); }, "parentReference": (o, n) => { o.parentReference = n.getObjectValue(createItemReferenceFromDiscriminatorValue_1.createItemReferenceFromDiscriminatorValue); }, "webUrl": (o, n) => { o.webUrl = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
     * @returns a identitySet
     */
    get lastModifiedBy() {
        return this._lastModifiedBy;
    }
    ;
    /**
     * Sets the lastModifiedBy property value. Identity of the user, device, and application which last modified the item. Read-only.
     * @param value Value to set for the lastModifiedBy property.
     */
    set lastModifiedBy(value) {
        this._lastModifiedBy = value;
    }
    ;
    /**
     * Gets the lastModifiedByUser property value. Identity of the user who last modified the item. Read-only.
     * @returns a user
     */
    get lastModifiedByUser() {
        return this._lastModifiedByUser;
    }
    ;
    /**
     * Sets the lastModifiedByUser property value. Identity of the user who last modified the item. Read-only.
     * @param value Value to set for the lastModifiedByUser property.
     */
    set lastModifiedByUser(value) {
        this._lastModifiedByUser = value;
    }
    ;
    /**
     * Gets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
     * @returns a Date
     */
    get lastModifiedDateTime() {
        return this._lastModifiedDateTime;
    }
    ;
    /**
     * Sets the lastModifiedDateTime property value. Date and time the item was last modified. Read-only.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value) {
        this._lastModifiedDateTime = value;
    }
    ;
    /**
     * Gets the name property value. The name of the item. Read-write.
     * @returns a string
     */
    get name() {
        return this._name;
    }
    ;
    /**
     * Sets the name property value. The name of the item. Read-write.
     * @param value Value to set for the name property.
     */
    set name(value) {
        this._name = value;
    }
    ;
    /**
     * Gets the parentReference property value. Parent information, if the item has a parent. Read-write.
     * @returns a itemReference
     */
    get parentReference() {
        return this._parentReference;
    }
    ;
    /**
     * Sets the parentReference property value. Parent information, if the item has a parent. Read-write.
     * @param value Value to set for the parentReference property.
     */
    set parentReference(value) {
        this._parentReference = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeObjectValue("createdBy", this.createdBy);
        writer.writeObjectValue("createdByUser", this.createdByUser);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeStringValue("description", this.description);
        writer.writeStringValue("eTag", this.eTag);
        writer.writeObjectValue("lastModifiedBy", this.lastModifiedBy);
        writer.writeObjectValue("lastModifiedByUser", this.lastModifiedByUser);
        writer.writeDateValue("lastModifiedDateTime", this.lastModifiedDateTime);
        writer.writeStringValue("name", this.name);
        writer.writeObjectValue("parentReference", this.parentReference);
        writer.writeStringValue("webUrl", this.webUrl);
    }
    ;
    /**
     * Gets the webUrl property value. URL that displays the resource in the browser. Read-only.
     * @returns a string
     */
    get webUrl() {
        return this._webUrl;
    }
    ;
    /**
     * Sets the webUrl property value. URL that displays the resource in the browser. Read-only.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value) {
        this._webUrl = value;
    }
    ;
}
exports.BaseItem = BaseItem;
