import { BookingPriceType } from './bookingPriceType';
import { BookingQuestionAssignment, BookingReminder, BookingSchedulingPolicy, Entity, Location } from './index';
import { Duration, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class BookingService extends Entity implements Parsable {
    /** Additional information that is sent to the customer when an appointment is confirmed.  */
    private _additionalInformation?;
    /** Contains the set of custom questions associated with a particular service.  */
    private _customQuestions?;
    /** The default length of the service, represented in numbers of days, hours, minutes, and seconds. For example, P11D23H59M59.999999999999S.  */
    private _defaultDuration?;
    /** The default physical location for the service.  */
    private _defaultLocation?;
    /** The default monetary price for the service.  */
    private _defaultPrice?;
    /** The default way the service is charged. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue.  */
    private _defaultPriceType?;
    /** The default set of reminders for an appointment of this service. The value of this property is available only when reading this bookingService by its ID.  */
    private _defaultReminders?;
    /** A text description for the service.  */
    private _description?;
    /** A service name.  */
    private _displayName?;
    /** True means this service is not available to customers for booking.  */
    private _isHiddenFromCustomers?;
    /** True indicates that the appointments for the service will be held online. Default value is false.  */
    private _isLocationOnline?;
    /** The maximum number of customers allowed in a service. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation.  */
    private _maximumAttendeesCount?;
    /** Additional information about this service.  */
    private _notes?;
    /** The time to buffer after an appointment for this service ends, and before the next customer appointment can be booked.  */
    private _postBuffer?;
    /** The time to buffer before an appointment for this service can start.  */
    private _preBuffer?;
    /** The set of policies that determine how appointments for this type of service should be created and managed.  */
    private _schedulingPolicy?;
    /** True indicates SMS notifications can be sent to the customers for the appointment of the service. Default value is false.  */
    private _smsNotificationsEnabled?;
    /** Represents those staff members who provide this service.  */
    private _staffMemberIds?;
    /** The URL a customer uses to access the service.  */
    private _webUrl?;
    /**
     * Gets the additionalInformation property value. Additional information that is sent to the customer when an appointment is confirmed.
     * @returns a string
     */
    get additionalInformation(): string | undefined;
    /**
     * Sets the additionalInformation property value. Additional information that is sent to the customer when an appointment is confirmed.
     * @param value Value to set for the additionalInformation property.
     */
    set additionalInformation(value: string | undefined);
    /**
     * Instantiates a new bookingService and sets the default values.
     */
    constructor();
    /**
     * Gets the customQuestions property value. Contains the set of custom questions associated with a particular service.
     * @returns a bookingQuestionAssignment
     */
    get customQuestions(): BookingQuestionAssignment[] | undefined;
    /**
     * Sets the customQuestions property value. Contains the set of custom questions associated with a particular service.
     * @param value Value to set for the customQuestions property.
     */
    set customQuestions(value: BookingQuestionAssignment[] | undefined);
    /**
     * Gets the defaultDuration property value. The default length of the service, represented in numbers of days, hours, minutes, and seconds. For example, P11D23H59M59.999999999999S.
     * @returns a Duration
     */
    get defaultDuration(): Duration | undefined;
    /**
     * Sets the defaultDuration property value. The default length of the service, represented in numbers of days, hours, minutes, and seconds. For example, P11D23H59M59.999999999999S.
     * @param value Value to set for the defaultDuration property.
     */
    set defaultDuration(value: Duration | undefined);
    /**
     * Gets the defaultLocation property value. The default physical location for the service.
     * @returns a location
     */
    get defaultLocation(): Location | undefined;
    /**
     * Sets the defaultLocation property value. The default physical location for the service.
     * @param value Value to set for the defaultLocation property.
     */
    set defaultLocation(value: Location | undefined);
    /**
     * Gets the defaultPrice property value. The default monetary price for the service.
     * @returns a double
     */
    get defaultPrice(): number | undefined;
    /**
     * Sets the defaultPrice property value. The default monetary price for the service.
     * @param value Value to set for the defaultPrice property.
     */
    set defaultPrice(value: number | undefined);
    /**
     * Gets the defaultPriceType property value. The default way the service is charged. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue.
     * @returns a bookingPriceType
     */
    get defaultPriceType(): BookingPriceType | undefined;
    /**
     * Sets the defaultPriceType property value. The default way the service is charged. Possible values are: undefined, fixedPrice, startingAt, hourly, free, priceVaries, callUs, notSet, unknownFutureValue.
     * @param value Value to set for the defaultPriceType property.
     */
    set defaultPriceType(value: BookingPriceType | undefined);
    /**
     * Gets the defaultReminders property value. The default set of reminders for an appointment of this service. The value of this property is available only when reading this bookingService by its ID.
     * @returns a bookingReminder
     */
    get defaultReminders(): BookingReminder[] | undefined;
    /**
     * Sets the defaultReminders property value. The default set of reminders for an appointment of this service. The value of this property is available only when reading this bookingService by its ID.
     * @param value Value to set for the defaultReminders property.
     */
    set defaultReminders(value: BookingReminder[] | undefined);
    /**
     * Gets the description property value. A text description for the service.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. A text description for the service.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. A service name.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. A service name.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isHiddenFromCustomers property value. True means this service is not available to customers for booking.
     * @returns a boolean
     */
    get isHiddenFromCustomers(): boolean | undefined;
    /**
     * Sets the isHiddenFromCustomers property value. True means this service is not available to customers for booking.
     * @param value Value to set for the isHiddenFromCustomers property.
     */
    set isHiddenFromCustomers(value: boolean | undefined);
    /**
     * Gets the isLocationOnline property value. True indicates that the appointments for the service will be held online. Default value is false.
     * @returns a boolean
     */
    get isLocationOnline(): boolean | undefined;
    /**
     * Sets the isLocationOnline property value. True indicates that the appointments for the service will be held online. Default value is false.
     * @param value Value to set for the isLocationOnline property.
     */
    set isLocationOnline(value: boolean | undefined);
    /**
     * Gets the maximumAttendeesCount property value. The maximum number of customers allowed in a service. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation.
     * @returns a integer
     */
    get maximumAttendeesCount(): number | undefined;
    /**
     * Sets the maximumAttendeesCount property value. The maximum number of customers allowed in a service. If maximumAttendeesCount of the service is greater than 1, pass valid customer IDs while creating or updating an appointment. To create a customer, use the Create bookingCustomer operation.
     * @param value Value to set for the maximumAttendeesCount property.
     */
    set maximumAttendeesCount(value: number | undefined);
    /**
     * Gets the notes property value. Additional information about this service.
     * @returns a string
     */
    get notes(): string | undefined;
    /**
     * Sets the notes property value. Additional information about this service.
     * @param value Value to set for the notes property.
     */
    set notes(value: string | undefined);
    /**
     * Gets the postBuffer property value. The time to buffer after an appointment for this service ends, and before the next customer appointment can be booked.
     * @returns a Duration
     */
    get postBuffer(): Duration | undefined;
    /**
     * Sets the postBuffer property value. The time to buffer after an appointment for this service ends, and before the next customer appointment can be booked.
     * @param value Value to set for the postBuffer property.
     */
    set postBuffer(value: Duration | undefined);
    /**
     * Gets the preBuffer property value. The time to buffer before an appointment for this service can start.
     * @returns a Duration
     */
    get preBuffer(): Duration | undefined;
    /**
     * Sets the preBuffer property value. The time to buffer before an appointment for this service can start.
     * @param value Value to set for the preBuffer property.
     */
    set preBuffer(value: Duration | undefined);
    /**
     * Gets the schedulingPolicy property value. The set of policies that determine how appointments for this type of service should be created and managed.
     * @returns a bookingSchedulingPolicy
     */
    get schedulingPolicy(): BookingSchedulingPolicy | undefined;
    /**
     * Sets the schedulingPolicy property value. The set of policies that determine how appointments for this type of service should be created and managed.
     * @param value Value to set for the schedulingPolicy property.
     */
    set schedulingPolicy(value: BookingSchedulingPolicy | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the smsNotificationsEnabled property value. True indicates SMS notifications can be sent to the customers for the appointment of the service. Default value is false.
     * @returns a boolean
     */
    get smsNotificationsEnabled(): boolean | undefined;
    /**
     * Sets the smsNotificationsEnabled property value. True indicates SMS notifications can be sent to the customers for the appointment of the service. Default value is false.
     * @param value Value to set for the smsNotificationsEnabled property.
     */
    set smsNotificationsEnabled(value: boolean | undefined);
    /**
     * Gets the staffMemberIds property value. Represents those staff members who provide this service.
     * @returns a string
     */
    get staffMemberIds(): string[] | undefined;
    /**
     * Sets the staffMemberIds property value. Represents those staff members who provide this service.
     * @param value Value to set for the staffMemberIds property.
     */
    set staffMemberIds(value: string[] | undefined);
    /**
     * Gets the webUrl property value. The URL a customer uses to access the service.
     * @returns a string
     */
    get webUrl(): string | undefined;
    /**
     * Sets the webUrl property value. The URL a customer uses to access the service.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value: string | undefined);
}
