import { CalendarColor } from './calendarColor';
import { CalendarPermission, EmailAddress, Entity, Event, MultiValueLegacyExtendedProperty, SingleValueLegacyExtendedProperty } from './index';
import { OnlineMeetingProviderType } from './onlineMeetingProviderType';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Calendar extends Entity implements Parsable {
    /** Represent the online meeting service providers that can be used to create online meetings in this calendar. Possible values are: unknown, skypeForBusiness, skypeForConsumer, teamsForBusiness.  */
    private _allowedOnlineMeetingProviders?;
    /** The permissions of the users with whom the calendar is shared.  */
    private _calendarPermissions?;
    /** The calendar view for the calendar. Navigation property. Read-only.  */
    private _calendarView?;
    /** true if the user can write to the calendar, false otherwise. This property is true for the user who created the calendar. This property is also true for a user who has been shared a calendar and granted write access.  */
    private _canEdit?;
    /** true if the user has the permission to share the calendar, false otherwise. Only the user who created the calendar can share it.  */
    private _canShare?;
    /** true if the user can read calendar items that have been marked private, false otherwise.  */
    private _canViewPrivateItems?;
    /** Identifies the version of the calendar object. Every time the calendar is changed, changeKey changes as well. This allows Exchange to apply changes to the correct version of the object. Read-only.  */
    private _changeKey?;
    /** Specifies the color theme to distinguish the calendar from other calendars in a UI. The property values are: auto, lightBlue, lightGreen, lightOrange, lightGray, lightYellow, lightTeal, lightPink, lightBrown, lightRed, maxColor.  */
    private _color?;
    /** The default online meeting provider for meetings sent from this calendar. Possible values are: unknown, skypeForBusiness, skypeForConsumer, teamsForBusiness.  */
    private _defaultOnlineMeetingProvider?;
    /** The events in the calendar. Navigation property. Read-only.  */
    private _events?;
    /** The calendar color, expressed in a hex color code of three hexadecimal values, each ranging from 00 to FF and representing the red, green, or blue components of the color in the RGB color space. If the user has never explicitly set a color for the calendar, this property is empty. Read-only.  */
    private _hexColor?;
    /** true if this is the default calendar where new events are created by default, false otherwise.  */
    private _isDefaultCalendar?;
    /** Indicates whether this user calendar can be deleted from the user mailbox.  */
    private _isRemovable?;
    /** Indicates whether this user calendar supports tracking of meeting responses. Only meeting invites sent from users' primary calendars support tracking of meeting responses.  */
    private _isTallyingResponses?;
    /** The collection of multi-value extended properties defined for the calendar. Read-only. Nullable.  */
    private _multiValueExtendedProperties?;
    /** The calendar name.  */
    private _name?;
    /** If set, this represents the user who created or added the calendar. For a calendar that the user created or added, the owner property is set to the user. For a calendar shared with the user, the owner property is set to the person who shared that calendar with the user.  */
    private _owner?;
    /** The collection of single-value extended properties defined for the calendar. Read-only. Nullable.  */
    private _singleValueExtendedProperties?;
    /**
     * Gets the allowedOnlineMeetingProviders property value. Represent the online meeting service providers that can be used to create online meetings in this calendar. Possible values are: unknown, skypeForBusiness, skypeForConsumer, teamsForBusiness.
     * @returns a onlineMeetingProviderType
     */
    get allowedOnlineMeetingProviders(): OnlineMeetingProviderType[] | undefined;
    /**
     * Sets the allowedOnlineMeetingProviders property value. Represent the online meeting service providers that can be used to create online meetings in this calendar. Possible values are: unknown, skypeForBusiness, skypeForConsumer, teamsForBusiness.
     * @param value Value to set for the allowedOnlineMeetingProviders property.
     */
    set allowedOnlineMeetingProviders(value: OnlineMeetingProviderType[] | undefined);
    /**
     * Gets the calendarPermissions property value. The permissions of the users with whom the calendar is shared.
     * @returns a calendarPermission
     */
    get calendarPermissions(): CalendarPermission[] | undefined;
    /**
     * Sets the calendarPermissions property value. The permissions of the users with whom the calendar is shared.
     * @param value Value to set for the calendarPermissions property.
     */
    set calendarPermissions(value: CalendarPermission[] | undefined);
    /**
     * Gets the calendarView property value. The calendar view for the calendar. Navigation property. Read-only.
     * @returns a event
     */
    get calendarView(): Event[] | undefined;
    /**
     * Sets the calendarView property value. The calendar view for the calendar. Navigation property. Read-only.
     * @param value Value to set for the calendarView property.
     */
    set calendarView(value: Event[] | undefined);
    /**
     * Gets the canEdit property value. true if the user can write to the calendar, false otherwise. This property is true for the user who created the calendar. This property is also true for a user who has been shared a calendar and granted write access.
     * @returns a boolean
     */
    get canEdit(): boolean | undefined;
    /**
     * Sets the canEdit property value. true if the user can write to the calendar, false otherwise. This property is true for the user who created the calendar. This property is also true for a user who has been shared a calendar and granted write access.
     * @param value Value to set for the canEdit property.
     */
    set canEdit(value: boolean | undefined);
    /**
     * Gets the canShare property value. true if the user has the permission to share the calendar, false otherwise. Only the user who created the calendar can share it.
     * @returns a boolean
     */
    get canShare(): boolean | undefined;
    /**
     * Sets the canShare property value. true if the user has the permission to share the calendar, false otherwise. Only the user who created the calendar can share it.
     * @param value Value to set for the canShare property.
     */
    set canShare(value: boolean | undefined);
    /**
     * Gets the canViewPrivateItems property value. true if the user can read calendar items that have been marked private, false otherwise.
     * @returns a boolean
     */
    get canViewPrivateItems(): boolean | undefined;
    /**
     * Sets the canViewPrivateItems property value. true if the user can read calendar items that have been marked private, false otherwise.
     * @param value Value to set for the canViewPrivateItems property.
     */
    set canViewPrivateItems(value: boolean | undefined);
    /**
     * Gets the changeKey property value. Identifies the version of the calendar object. Every time the calendar is changed, changeKey changes as well. This allows Exchange to apply changes to the correct version of the object. Read-only.
     * @returns a string
     */
    get changeKey(): string | undefined;
    /**
     * Sets the changeKey property value. Identifies the version of the calendar object. Every time the calendar is changed, changeKey changes as well. This allows Exchange to apply changes to the correct version of the object. Read-only.
     * @param value Value to set for the changeKey property.
     */
    set changeKey(value: string | undefined);
    /**
     * Gets the color property value. Specifies the color theme to distinguish the calendar from other calendars in a UI. The property values are: auto, lightBlue, lightGreen, lightOrange, lightGray, lightYellow, lightTeal, lightPink, lightBrown, lightRed, maxColor.
     * @returns a calendarColor
     */
    get color(): CalendarColor | undefined;
    /**
     * Sets the color property value. Specifies the color theme to distinguish the calendar from other calendars in a UI. The property values are: auto, lightBlue, lightGreen, lightOrange, lightGray, lightYellow, lightTeal, lightPink, lightBrown, lightRed, maxColor.
     * @param value Value to set for the color property.
     */
    set color(value: CalendarColor | undefined);
    /**
     * Instantiates a new calendar and sets the default values.
     */
    constructor();
    /**
     * Gets the defaultOnlineMeetingProvider property value. The default online meeting provider for meetings sent from this calendar. Possible values are: unknown, skypeForBusiness, skypeForConsumer, teamsForBusiness.
     * @returns a onlineMeetingProviderType
     */
    get defaultOnlineMeetingProvider(): OnlineMeetingProviderType | undefined;
    /**
     * Sets the defaultOnlineMeetingProvider property value. The default online meeting provider for meetings sent from this calendar. Possible values are: unknown, skypeForBusiness, skypeForConsumer, teamsForBusiness.
     * @param value Value to set for the defaultOnlineMeetingProvider property.
     */
    set defaultOnlineMeetingProvider(value: OnlineMeetingProviderType | undefined);
    /**
     * Gets the events property value. The events in the calendar. Navigation property. Read-only.
     * @returns a event
     */
    get events(): Event[] | undefined;
    /**
     * Sets the events property value. The events in the calendar. Navigation property. Read-only.
     * @param value Value to set for the events property.
     */
    set events(value: Event[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hexColor property value. The calendar color, expressed in a hex color code of three hexadecimal values, each ranging from 00 to FF and representing the red, green, or blue components of the color in the RGB color space. If the user has never explicitly set a color for the calendar, this property is empty. Read-only.
     * @returns a string
     */
    get hexColor(): string | undefined;
    /**
     * Sets the hexColor property value. The calendar color, expressed in a hex color code of three hexadecimal values, each ranging from 00 to FF and representing the red, green, or blue components of the color in the RGB color space. If the user has never explicitly set a color for the calendar, this property is empty. Read-only.
     * @param value Value to set for the hexColor property.
     */
    set hexColor(value: string | undefined);
    /**
     * Gets the isDefaultCalendar property value. true if this is the default calendar where new events are created by default, false otherwise.
     * @returns a boolean
     */
    get isDefaultCalendar(): boolean | undefined;
    /**
     * Sets the isDefaultCalendar property value. true if this is the default calendar where new events are created by default, false otherwise.
     * @param value Value to set for the isDefaultCalendar property.
     */
    set isDefaultCalendar(value: boolean | undefined);
    /**
     * Gets the isRemovable property value. Indicates whether this user calendar can be deleted from the user mailbox.
     * @returns a boolean
     */
    get isRemovable(): boolean | undefined;
    /**
     * Sets the isRemovable property value. Indicates whether this user calendar can be deleted from the user mailbox.
     * @param value Value to set for the isRemovable property.
     */
    set isRemovable(value: boolean | undefined);
    /**
     * Gets the isTallyingResponses property value. Indicates whether this user calendar supports tracking of meeting responses. Only meeting invites sent from users' primary calendars support tracking of meeting responses.
     * @returns a boolean
     */
    get isTallyingResponses(): boolean | undefined;
    /**
     * Sets the isTallyingResponses property value. Indicates whether this user calendar supports tracking of meeting responses. Only meeting invites sent from users' primary calendars support tracking of meeting responses.
     * @param value Value to set for the isTallyingResponses property.
     */
    set isTallyingResponses(value: boolean | undefined);
    /**
     * Gets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the calendar. Read-only. Nullable.
     * @returns a multiValueLegacyExtendedProperty
     */
    get multiValueExtendedProperties(): MultiValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the calendar. Read-only. Nullable.
     * @param value Value to set for the multiValueExtendedProperties property.
     */
    set multiValueExtendedProperties(value: MultiValueLegacyExtendedProperty[] | undefined);
    /**
     * Gets the name property value. The calendar name.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The calendar name.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the owner property value. If set, this represents the user who created or added the calendar. For a calendar that the user created or added, the owner property is set to the user. For a calendar shared with the user, the owner property is set to the person who shared that calendar with the user.
     * @returns a emailAddress
     */
    get owner(): EmailAddress | undefined;
    /**
     * Sets the owner property value. If set, this represents the user who created or added the calendar. For a calendar that the user created or added, the owner property is set to the user. For a calendar shared with the user, the owner property is set to the person who shared that calendar with the user.
     * @param value Value to set for the owner property.
     */
    set owner(value: EmailAddress | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the calendar. Read-only. Nullable.
     * @returns a singleValueLegacyExtendedProperty
     */
    get singleValueExtendedProperties(): SingleValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the calendar. Read-only. Nullable.
     * @param value Value to set for the singleValueExtendedProperties property.
     */
    set singleValueExtendedProperties(value: SingleValueLegacyExtendedProperty[] | undefined);
}
