import { NetworkConnectionType } from './networkConnectionType';
import { WifiBand } from './wifiBand';
import { WifiRadioType } from './wifiRadioType';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class NetworkInfo implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.  */
    private _additionalData;
    /** Fraction of the call that the media endpoint detected the available bandwidth or bandwidth policy was low enough to cause poor quality of the audio sent.  */
    private _bandwidthLowEventRatio?;
    /** The wireless LAN basic service set identifier of the media endpoint used to connect to the network.  */
    private _basicServiceSetIdentifier?;
    /** Type of network used by the media endpoint. Possible values are: unknown, wired, wifi, mobile, tunnel, unknownFutureValue.  */
    private _connectionType?;
    /** Fraction of the call that the media endpoint detected the network delay was significant enough to impact the ability to have real-time two-way communication.  */
    private _delayEventRatio?;
    /** DNS suffix associated with the network adapter of the media endpoint.  */
    private _dnsSuffix?;
    /** IP address of the media endpoint.  */
    private _ipAddress?;
    /** Link speed in bits per second reported by the network adapter used by the media endpoint.  */
    private _linkSpeed?;
    /** The media access control (MAC) address of the media endpoint's network device.  */
    private _macAddress?;
    /** Network port number used by media endpoint.  */
    private _port?;
    /** Fraction of the call that the media endpoint detected the network was causing poor quality of the audio received.  */
    private _receivedQualityEventRatio?;
    /** IP address of the media endpoint as seen by the media relay server. This is typically the public internet IP address associated to the endpoint.  */
    private _reflexiveIPAddress?;
    /** IP address of the media relay server allocated by the media endpoint.  */
    private _relayIPAddress?;
    /** Network port number allocated on the media relay server by the media endpoint.  */
    private _relayPort?;
    /** Fraction of the call that the media endpoint detected the network was causing poor quality of the audio sent.  */
    private _sentQualityEventRatio?;
    /** Subnet used for media stream by the media endpoint.  */
    private _subnet?;
    /** WiFi band used by the media endpoint. Possible values are: unknown, frequency24GHz, frequency50GHz, frequency60GHz, unknownFutureValue.  */
    private _wifiBand?;
    /** Estimated remaining battery charge in percentage reported by the media endpoint.  */
    private _wifiBatteryCharge?;
    /** WiFi channel used by the media endpoint.  */
    private _wifiChannel?;
    /** Name of the Microsoft WiFi driver used by the media endpoint. Value may be localized based on the language used by endpoint.  */
    private _wifiMicrosoftDriver?;
    /** Version of the Microsoft WiFi driver used by the media endpoint.  */
    private _wifiMicrosoftDriverVersion?;
    /** Type of WiFi radio used by the media endpoint. Possible values are: unknown, wifi80211a, wifi80211b, wifi80211g, wifi80211n, wifi80211ac, wifi80211ax, unknownFutureValue.  */
    private _wifiRadioType?;
    /** WiFi signal strength in percentage reported by the media endpoint.  */
    private _wifiSignalStrength?;
    /** Name of the WiFi driver used by the media endpoint. Value may be localized based on the language used by endpoint.  */
    private _wifiVendorDriver?;
    /** Version of the WiFi driver used by the media endpoint.  */
    private _wifiVendorDriverVersion?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the bandwidthLowEventRatio property value. Fraction of the call that the media endpoint detected the available bandwidth or bandwidth policy was low enough to cause poor quality of the audio sent.
     * @returns a float
     */
    get bandwidthLowEventRatio(): number | undefined;
    /**
     * Sets the bandwidthLowEventRatio property value. Fraction of the call that the media endpoint detected the available bandwidth or bandwidth policy was low enough to cause poor quality of the audio sent.
     * @param value Value to set for the bandwidthLowEventRatio property.
     */
    set bandwidthLowEventRatio(value: number | undefined);
    /**
     * Gets the basicServiceSetIdentifier property value. The wireless LAN basic service set identifier of the media endpoint used to connect to the network.
     * @returns a string
     */
    get basicServiceSetIdentifier(): string | undefined;
    /**
     * Sets the basicServiceSetIdentifier property value. The wireless LAN basic service set identifier of the media endpoint used to connect to the network.
     * @param value Value to set for the basicServiceSetIdentifier property.
     */
    set basicServiceSetIdentifier(value: string | undefined);
    /**
     * Gets the connectionType property value. Type of network used by the media endpoint. Possible values are: unknown, wired, wifi, mobile, tunnel, unknownFutureValue.
     * @returns a networkConnectionType
     */
    get connectionType(): NetworkConnectionType | undefined;
    /**
     * Sets the connectionType property value. Type of network used by the media endpoint. Possible values are: unknown, wired, wifi, mobile, tunnel, unknownFutureValue.
     * @param value Value to set for the connectionType property.
     */
    set connectionType(value: NetworkConnectionType | undefined);
    /**
     * Instantiates a new networkInfo and sets the default values.
     */
    constructor();
    /**
     * Gets the delayEventRatio property value. Fraction of the call that the media endpoint detected the network delay was significant enough to impact the ability to have real-time two-way communication.
     * @returns a float
     */
    get delayEventRatio(): number | undefined;
    /**
     * Sets the delayEventRatio property value. Fraction of the call that the media endpoint detected the network delay was significant enough to impact the ability to have real-time two-way communication.
     * @param value Value to set for the delayEventRatio property.
     */
    set delayEventRatio(value: number | undefined);
    /**
     * Gets the dnsSuffix property value. DNS suffix associated with the network adapter of the media endpoint.
     * @returns a string
     */
    get dnsSuffix(): string | undefined;
    /**
     * Sets the dnsSuffix property value. DNS suffix associated with the network adapter of the media endpoint.
     * @param value Value to set for the dnsSuffix property.
     */
    set dnsSuffix(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the ipAddress property value. IP address of the media endpoint.
     * @returns a string
     */
    get ipAddress(): string | undefined;
    /**
     * Sets the ipAddress property value. IP address of the media endpoint.
     * @param value Value to set for the ipAddress property.
     */
    set ipAddress(value: string | undefined);
    /**
     * Gets the linkSpeed property value. Link speed in bits per second reported by the network adapter used by the media endpoint.
     * @returns a int64
     */
    get linkSpeed(): number | undefined;
    /**
     * Sets the linkSpeed property value. Link speed in bits per second reported by the network adapter used by the media endpoint.
     * @param value Value to set for the linkSpeed property.
     */
    set linkSpeed(value: number | undefined);
    /**
     * Gets the macAddress property value. The media access control (MAC) address of the media endpoint's network device.
     * @returns a string
     */
    get macAddress(): string | undefined;
    /**
     * Sets the macAddress property value. The media access control (MAC) address of the media endpoint's network device.
     * @param value Value to set for the macAddress property.
     */
    set macAddress(value: string | undefined);
    /**
     * Gets the port property value. Network port number used by media endpoint.
     * @returns a integer
     */
    get port(): number | undefined;
    /**
     * Sets the port property value. Network port number used by media endpoint.
     * @param value Value to set for the port property.
     */
    set port(value: number | undefined);
    /**
     * Gets the receivedQualityEventRatio property value. Fraction of the call that the media endpoint detected the network was causing poor quality of the audio received.
     * @returns a float
     */
    get receivedQualityEventRatio(): number | undefined;
    /**
     * Sets the receivedQualityEventRatio property value. Fraction of the call that the media endpoint detected the network was causing poor quality of the audio received.
     * @param value Value to set for the receivedQualityEventRatio property.
     */
    set receivedQualityEventRatio(value: number | undefined);
    /**
     * Gets the reflexiveIPAddress property value. IP address of the media endpoint as seen by the media relay server. This is typically the public internet IP address associated to the endpoint.
     * @returns a string
     */
    get reflexiveIPAddress(): string | undefined;
    /**
     * Sets the reflexiveIPAddress property value. IP address of the media endpoint as seen by the media relay server. This is typically the public internet IP address associated to the endpoint.
     * @param value Value to set for the reflexiveIPAddress property.
     */
    set reflexiveIPAddress(value: string | undefined);
    /**
     * Gets the relayIPAddress property value. IP address of the media relay server allocated by the media endpoint.
     * @returns a string
     */
    get relayIPAddress(): string | undefined;
    /**
     * Sets the relayIPAddress property value. IP address of the media relay server allocated by the media endpoint.
     * @param value Value to set for the relayIPAddress property.
     */
    set relayIPAddress(value: string | undefined);
    /**
     * Gets the relayPort property value. Network port number allocated on the media relay server by the media endpoint.
     * @returns a integer
     */
    get relayPort(): number | undefined;
    /**
     * Sets the relayPort property value. Network port number allocated on the media relay server by the media endpoint.
     * @param value Value to set for the relayPort property.
     */
    set relayPort(value: number | undefined);
    /**
     * Gets the sentQualityEventRatio property value. Fraction of the call that the media endpoint detected the network was causing poor quality of the audio sent.
     * @returns a float
     */
    get sentQualityEventRatio(): number | undefined;
    /**
     * Sets the sentQualityEventRatio property value. Fraction of the call that the media endpoint detected the network was causing poor quality of the audio sent.
     * @param value Value to set for the sentQualityEventRatio property.
     */
    set sentQualityEventRatio(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the subnet property value. Subnet used for media stream by the media endpoint.
     * @returns a string
     */
    get subnet(): string | undefined;
    /**
     * Sets the subnet property value. Subnet used for media stream by the media endpoint.
     * @param value Value to set for the subnet property.
     */
    set subnet(value: string | undefined);
    /**
     * Gets the wifiBand property value. WiFi band used by the media endpoint. Possible values are: unknown, frequency24GHz, frequency50GHz, frequency60GHz, unknownFutureValue.
     * @returns a wifiBand
     */
    get wifiBand(): WifiBand | undefined;
    /**
     * Sets the wifiBand property value. WiFi band used by the media endpoint. Possible values are: unknown, frequency24GHz, frequency50GHz, frequency60GHz, unknownFutureValue.
     * @param value Value to set for the wifiBand property.
     */
    set wifiBand(value: WifiBand | undefined);
    /**
     * Gets the wifiBatteryCharge property value. Estimated remaining battery charge in percentage reported by the media endpoint.
     * @returns a integer
     */
    get wifiBatteryCharge(): number | undefined;
    /**
     * Sets the wifiBatteryCharge property value. Estimated remaining battery charge in percentage reported by the media endpoint.
     * @param value Value to set for the wifiBatteryCharge property.
     */
    set wifiBatteryCharge(value: number | undefined);
    /**
     * Gets the wifiChannel property value. WiFi channel used by the media endpoint.
     * @returns a integer
     */
    get wifiChannel(): number | undefined;
    /**
     * Sets the wifiChannel property value. WiFi channel used by the media endpoint.
     * @param value Value to set for the wifiChannel property.
     */
    set wifiChannel(value: number | undefined);
    /**
     * Gets the wifiMicrosoftDriver property value. Name of the Microsoft WiFi driver used by the media endpoint. Value may be localized based on the language used by endpoint.
     * @returns a string
     */
    get wifiMicrosoftDriver(): string | undefined;
    /**
     * Sets the wifiMicrosoftDriver property value. Name of the Microsoft WiFi driver used by the media endpoint. Value may be localized based on the language used by endpoint.
     * @param value Value to set for the wifiMicrosoftDriver property.
     */
    set wifiMicrosoftDriver(value: string | undefined);
    /**
     * Gets the wifiMicrosoftDriverVersion property value. Version of the Microsoft WiFi driver used by the media endpoint.
     * @returns a string
     */
    get wifiMicrosoftDriverVersion(): string | undefined;
    /**
     * Sets the wifiMicrosoftDriverVersion property value. Version of the Microsoft WiFi driver used by the media endpoint.
     * @param value Value to set for the wifiMicrosoftDriverVersion property.
     */
    set wifiMicrosoftDriverVersion(value: string | undefined);
    /**
     * Gets the wifiRadioType property value. Type of WiFi radio used by the media endpoint. Possible values are: unknown, wifi80211a, wifi80211b, wifi80211g, wifi80211n, wifi80211ac, wifi80211ax, unknownFutureValue.
     * @returns a wifiRadioType
     */
    get wifiRadioType(): WifiRadioType | undefined;
    /**
     * Sets the wifiRadioType property value. Type of WiFi radio used by the media endpoint. Possible values are: unknown, wifi80211a, wifi80211b, wifi80211g, wifi80211n, wifi80211ac, wifi80211ax, unknownFutureValue.
     * @param value Value to set for the wifiRadioType property.
     */
    set wifiRadioType(value: WifiRadioType | undefined);
    /**
     * Gets the wifiSignalStrength property value. WiFi signal strength in percentage reported by the media endpoint.
     * @returns a integer
     */
    get wifiSignalStrength(): number | undefined;
    /**
     * Sets the wifiSignalStrength property value. WiFi signal strength in percentage reported by the media endpoint.
     * @param value Value to set for the wifiSignalStrength property.
     */
    set wifiSignalStrength(value: number | undefined);
    /**
     * Gets the wifiVendorDriver property value. Name of the WiFi driver used by the media endpoint. Value may be localized based on the language used by endpoint.
     * @returns a string
     */
    get wifiVendorDriver(): string | undefined;
    /**
     * Sets the wifiVendorDriver property value. Name of the WiFi driver used by the media endpoint. Value may be localized based on the language used by endpoint.
     * @param value Value to set for the wifiVendorDriver property.
     */
    set wifiVendorDriver(value: string | undefined);
    /**
     * Gets the wifiVendorDriverVersion property value. Version of the WiFi driver used by the media endpoint.
     * @returns a string
     */
    get wifiVendorDriverVersion(): string | undefined;
    /**
     * Sets the wifiVendorDriverVersion property value. Version of the WiFi driver used by the media endpoint.
     * @param value Value to set for the wifiVendorDriverVersion property.
     */
    set wifiVendorDriverVersion(value: string | undefined);
}
