"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Session = void 0;
const __1 = require("../");
const createEndpointFromDiscriminatorValue_1 = require("./createEndpointFromDiscriminatorValue");
const createFailureInfoFromDiscriminatorValue_1 = require("./createFailureInfoFromDiscriminatorValue");
const createSegmentFromDiscriminatorValue_1 = require("./createSegmentFromDiscriminatorValue");
const modality_1 = require("./modality");
class Session extends __1.Entity {
    /**
     * Instantiates a new session and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the callee property value. Endpoint that answered the session.
     * @returns a endpoint
     */
    get callee() {
        return this._callee;
    }
    ;
    /**
     * Sets the callee property value. Endpoint that answered the session.
     * @param value Value to set for the callee property.
     */
    set callee(value) {
        this._callee = value;
    }
    ;
    /**
     * Gets the caller property value. Endpoint that initiated the session.
     * @returns a endpoint
     */
    get caller() {
        return this._caller;
    }
    ;
    /**
     * Sets the caller property value. Endpoint that initiated the session.
     * @param value Value to set for the caller property.
     */
    set caller(value) {
        this._caller = value;
    }
    ;
    ;
    /**
     * Gets the endDateTime property value. UTC time when the last user left the session. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get endDateTime() {
        return this._endDateTime;
    }
    ;
    /**
     * Sets the endDateTime property value. UTC time when the last user left the session. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value) {
        this._endDateTime = value;
    }
    ;
    /**
     * Gets the failureInfo property value. Failure information associated with the session if the session failed.
     * @returns a failureInfo
     */
    get failureInfo() {
        return this._failureInfo;
    }
    ;
    /**
     * Sets the failureInfo property value. Failure information associated with the session if the session failed.
     * @param value Value to set for the failureInfo property.
     */
    set failureInfo(value) {
        this._failureInfo = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "callee": (o, n) => { o.callee = n.getObjectValue(createEndpointFromDiscriminatorValue_1.createEndpointFromDiscriminatorValue); }, "caller": (o, n) => { o.caller = n.getObjectValue(createEndpointFromDiscriminatorValue_1.createEndpointFromDiscriminatorValue); }, "endDateTime": (o, n) => { o.endDateTime = n.getDateValue(); }, "failureInfo": (o, n) => { o.failureInfo = n.getObjectValue(createFailureInfoFromDiscriminatorValue_1.createFailureInfoFromDiscriminatorValue); }, "modalities": (o, n) => { o.modalities = n.getEnumValues(modality_1.Modality); }, "segments": (o, n) => { o.segments = n.getCollectionOfObjectValues(createSegmentFromDiscriminatorValue_1.createSegmentFromDiscriminatorValue); }, "startDateTime": (o, n) => { o.startDateTime = n.getDateValue(); } });
    }
    ;
    /**
     * Gets the modalities property value. List of modalities present in the session. Possible values are: unknown, audio, video, videoBasedScreenSharing, data, screenSharing, unknownFutureValue.
     * @returns a modality
     */
    get modalities() {
        return this._modalities;
    }
    ;
    /**
     * Sets the modalities property value. List of modalities present in the session. Possible values are: unknown, audio, video, videoBasedScreenSharing, data, screenSharing, unknownFutureValue.
     * @param value Value to set for the modalities property.
     */
    set modalities(value) {
        this._modalities = value;
    }
    ;
    /**
     * Gets the segments property value. The list of segments involved in the session. Read-only. Nullable.
     * @returns a segment
     */
    get segments() {
        return this._segments;
    }
    ;
    /**
     * Sets the segments property value. The list of segments involved in the session. Read-only. Nullable.
     * @param value Value to set for the segments property.
     */
    set segments(value) {
        this._segments = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeObjectValue("callee", this.callee);
        writer.writeObjectValue("caller", this.caller);
        writer.writeDateValue("endDateTime", this.endDateTime);
        writer.writeObjectValue("failureInfo", this.failureInfo);
        this.modalities && writer.writeEnumValue("modalities", ...this.modalities);
        writer.writeCollectionOfObjectValues("segments", this.segments);
        writer.writeDateValue("startDateTime", this.startDateTime);
    }
    ;
    /**
     * Gets the startDateTime property value. UTC time when the first user joined the session. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get startDateTime() {
        return this._startDateTime;
    }
    ;
    /**
     * Sets the startDateTime property value. UTC time when the first user joined the session. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value) {
        this._startDateTime = value;
    }
    ;
}
exports.Session = Session;
