"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Chat = void 0;
const chatType_1 = require("./chatType");
const createChatMessageFromDiscriminatorValue_1 = require("./createChatMessageFromDiscriminatorValue");
const createConversationMemberFromDiscriminatorValue_1 = require("./createConversationMemberFromDiscriminatorValue");
const createTeamsAppInstallationFromDiscriminatorValue_1 = require("./createTeamsAppInstallationFromDiscriminatorValue");
const createTeamsTabFromDiscriminatorValue_1 = require("./createTeamsTabFromDiscriminatorValue");
const createTeamworkOnlineMeetingInfoFromDiscriminatorValue_1 = require("./createTeamworkOnlineMeetingInfoFromDiscriminatorValue");
const index_1 = require("./index");
class Chat extends index_1.Entity {
    /**
     * Instantiates a new chat and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the chatType property value. Specifies the type of chat. Possible values are: group, oneOnOne, meeting, unknownFutureValue.
     * @returns a chatType
     */
    get chatType() {
        return this._chatType;
    }
    ;
    /**
     * Sets the chatType property value. Specifies the type of chat. Possible values are: group, oneOnOne, meeting, unknownFutureValue.
     * @param value Value to set for the chatType property.
     */
    set chatType(value) {
        this._chatType = value;
    }
    ;
    ;
    /**
     * Gets the createdDateTime property value. Date and time at which the chat was created. Read-only.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. Date and time at which the chat was created. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "chatType": (o, n) => { o.chatType = n.getEnumValue(chatType_1.ChatType); }, "createdDateTime": (o, n) => { o.createdDateTime = n.getDateValue(); }, "installedApps": (o, n) => { o.installedApps = n.getCollectionOfObjectValues(createTeamsAppInstallationFromDiscriminatorValue_1.createTeamsAppInstallationFromDiscriminatorValue); }, "lastUpdatedDateTime": (o, n) => { o.lastUpdatedDateTime = n.getDateValue(); }, "members": (o, n) => { o.members = n.getCollectionOfObjectValues(createConversationMemberFromDiscriminatorValue_1.createConversationMemberFromDiscriminatorValue); }, "messages": (o, n) => { o.messages = n.getCollectionOfObjectValues(createChatMessageFromDiscriminatorValue_1.createChatMessageFromDiscriminatorValue); }, "onlineMeetingInfo": (o, n) => { o.onlineMeetingInfo = n.getObjectValue(createTeamworkOnlineMeetingInfoFromDiscriminatorValue_1.createTeamworkOnlineMeetingInfoFromDiscriminatorValue); }, "tabs": (o, n) => { o.tabs = n.getCollectionOfObjectValues(createTeamsTabFromDiscriminatorValue_1.createTeamsTabFromDiscriminatorValue); }, "tenantId": (o, n) => { o.tenantId = n.getStringValue(); }, "topic": (o, n) => { o.topic = n.getStringValue(); }, "webUrl": (o, n) => { o.webUrl = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the installedApps property value. A collection of all the apps in the chat. Nullable.
     * @returns a teamsAppInstallation
     */
    get installedApps() {
        return this._installedApps;
    }
    ;
    /**
     * Sets the installedApps property value. A collection of all the apps in the chat. Nullable.
     * @param value Value to set for the installedApps property.
     */
    set installedApps(value) {
        this._installedApps = value;
    }
    ;
    /**
     * Gets the lastUpdatedDateTime property value. Date and time at which the chat was renamed or list of members were last changed. Read-only.
     * @returns a Date
     */
    get lastUpdatedDateTime() {
        return this._lastUpdatedDateTime;
    }
    ;
    /**
     * Sets the lastUpdatedDateTime property value. Date and time at which the chat was renamed or list of members were last changed. Read-only.
     * @param value Value to set for the lastUpdatedDateTime property.
     */
    set lastUpdatedDateTime(value) {
        this._lastUpdatedDateTime = value;
    }
    ;
    /**
     * Gets the members property value. A collection of all the members in the chat. Nullable.
     * @returns a conversationMember
     */
    get members() {
        return this._members;
    }
    ;
    /**
     * Sets the members property value. A collection of all the members in the chat. Nullable.
     * @param value Value to set for the members property.
     */
    set members(value) {
        this._members = value;
    }
    ;
    /**
     * Gets the messages property value. A collection of all the messages in the chat. Nullable.
     * @returns a chatMessage
     */
    get messages() {
        return this._messages;
    }
    ;
    /**
     * Sets the messages property value. A collection of all the messages in the chat. Nullable.
     * @param value Value to set for the messages property.
     */
    set messages(value) {
        this._messages = value;
    }
    ;
    /**
     * Gets the onlineMeetingInfo property value. Represents details about an online meeting. If the chat isn't associated with an online meeting, the property is empty. Read-only.
     * @returns a teamworkOnlineMeetingInfo
     */
    get onlineMeetingInfo() {
        return this._onlineMeetingInfo;
    }
    ;
    /**
     * Sets the onlineMeetingInfo property value. Represents details about an online meeting. If the chat isn't associated with an online meeting, the property is empty. Read-only.
     * @param value Value to set for the onlineMeetingInfo property.
     */
    set onlineMeetingInfo(value) {
        this._onlineMeetingInfo = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeEnumValue("chatType", this.chatType);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeCollectionOfObjectValues("installedApps", this.installedApps);
        writer.writeDateValue("lastUpdatedDateTime", this.lastUpdatedDateTime);
        writer.writeCollectionOfObjectValues("members", this.members);
        writer.writeCollectionOfObjectValues("messages", this.messages);
        writer.writeObjectValue("onlineMeetingInfo", this.onlineMeetingInfo);
        writer.writeCollectionOfObjectValues("tabs", this.tabs);
        writer.writeStringValue("tenantId", this.tenantId);
        writer.writeStringValue("topic", this.topic);
        writer.writeStringValue("webUrl", this.webUrl);
    }
    ;
    /**
     * Gets the tabs property value. A collection of all the tabs in the chat. Nullable.
     * @returns a teamsTab
     */
    get tabs() {
        return this._tabs;
    }
    ;
    /**
     * Sets the tabs property value. A collection of all the tabs in the chat. Nullable.
     * @param value Value to set for the tabs property.
     */
    set tabs(value) {
        this._tabs = value;
    }
    ;
    /**
     * Gets the tenantId property value. The identifier of the tenant in which the chat was created. Read-only.
     * @returns a string
     */
    get tenantId() {
        return this._tenantId;
    }
    ;
    /**
     * Sets the tenantId property value. The identifier of the tenant in which the chat was created. Read-only.
     * @param value Value to set for the tenantId property.
     */
    set tenantId(value) {
        this._tenantId = value;
    }
    ;
    /**
     * Gets the topic property value. (Optional) Subject or topic for the chat. Only available for group chats.
     * @returns a string
     */
    get topic() {
        return this._topic;
    }
    ;
    /**
     * Sets the topic property value. (Optional) Subject or topic for the chat. Only available for group chats.
     * @param value Value to set for the topic property.
     */
    set topic(value) {
        this._topic = value;
    }
    ;
    /**
     * Gets the webUrl property value. The URL for the chat in Microsoft Teams. The URL should be treated as an opaque blob, and not parsed. Read-only.
     * @returns a string
     */
    get webUrl() {
        return this._webUrl;
    }
    ;
    /**
     * Sets the webUrl property value. The URL for the chat in Microsoft Teams. The URL should be treated as an opaque blob, and not parsed. Read-only.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value) {
        this._webUrl = value;
    }
    ;
}
exports.Chat = Chat;
