import { ChatMessageImportance } from './chatMessageImportance';
import { ChatMessageType } from './chatMessageType';
import { ChannelIdentity, ChatMessageAttachment, ChatMessageFromIdentitySet, ChatMessageHostedContent, ChatMessageMention, ChatMessagePolicyViolation, ChatMessageReaction, Entity, EventMessageDetail, ItemBody } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ChatMessage extends Entity implements Parsable {
    /** References to attached objects like files, tabs, meetings etc.  */
    private _attachments?;
    private _body?;
    /** If the message was sent in a channel, represents identity of the channel.  */
    private _channelIdentity?;
    /** If the message was sent in a chat, represents the identity of the chat.  */
    private _chatId?;
    /** Timestamp of when the chat message was created.  */
    private _createdDateTime?;
    /** Read only. Timestamp at which the chat message was deleted, or null if not deleted.  */
    private _deletedDateTime?;
    /** Read-only. Version number of the chat message.  */
    private _etag?;
    /** Read-only. If present, represents details of an event that happened in a chat, a channel, or a team, for example, adding new members. For event messages, the messageType property will be set to systemEventMessage.  */
    private _eventDetail?;
    /** Details of the sender of the chat message. Can only be set during migration.  */
    private _from?;
    /** Content in a message hosted by Microsoft Teams - for example, images or code snippets.  */
    private _hostedContents?;
    /** The importance of the chat message. The possible values are: normal, high, urgent.  */
    private _importance?;
    /** Read only. Timestamp when edits to the chat message were made. Triggers an 'Edited' flag in the Teams UI. If no edits are made the value is null.  */
    private _lastEditedDateTime?;
    /** Read only. Timestamp when the chat message is created (initial setting) or modified, including when a reaction is added or removed.  */
    private _lastModifiedDateTime?;
    /** Locale of the chat message set by the client. Always set to en-us.  */
    private _locale?;
    /** List of entities mentioned in the chat message. Supported entities are: user, bot, team, and channel.  */
    private _mentions?;
    /** The type of chat message. The possible values are: message, chatEvent, typing, unknownFutureValue, systemEventMessage. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: systemEventMessage.  */
    private _messageType?;
    /** Defines the properties of a policy violation set by a data loss prevention (DLP) application.  */
    private _policyViolation?;
    /** Reactions for this chat message (for example, Like).  */
    private _reactions?;
    /** Replies for a specified message.  */
    private _replies?;
    /** Read-only. ID of the parent chat message or root chat message of the thread. (Only applies to chat messages in channels, not chats.)  */
    private _replyToId?;
    /** The subject of the chat message, in plaintext.  */
    private _subject?;
    /** Summary text of the chat message that could be used for push notifications and summary views or fall back views. Only applies to channel chat messages, not chat messages in a chat.  */
    private _summary?;
    /** Read-only. Link to the message in Microsoft Teams.  */
    private _webUrl?;
    /**
     * Gets the attachments property value. References to attached objects like files, tabs, meetings etc.
     * @returns a chatMessageAttachment
     */
    get attachments(): ChatMessageAttachment[] | undefined;
    /**
     * Sets the attachments property value. References to attached objects like files, tabs, meetings etc.
     * @param value Value to set for the attachments property.
     */
    set attachments(value: ChatMessageAttachment[] | undefined);
    /**
     * Gets the body property value.
     * @returns a itemBody
     */
    get body(): ItemBody | undefined;
    /**
     * Sets the body property value.
     * @param value Value to set for the body property.
     */
    set body(value: ItemBody | undefined);
    /**
     * Gets the channelIdentity property value. If the message was sent in a channel, represents identity of the channel.
     * @returns a channelIdentity
     */
    get channelIdentity(): ChannelIdentity | undefined;
    /**
     * Sets the channelIdentity property value. If the message was sent in a channel, represents identity of the channel.
     * @param value Value to set for the channelIdentity property.
     */
    set channelIdentity(value: ChannelIdentity | undefined);
    /**
     * Gets the chatId property value. If the message was sent in a chat, represents the identity of the chat.
     * @returns a string
     */
    get chatId(): string | undefined;
    /**
     * Sets the chatId property value. If the message was sent in a chat, represents the identity of the chat.
     * @param value Value to set for the chatId property.
     */
    set chatId(value: string | undefined);
    /**
     * Instantiates a new chatMessage and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Timestamp of when the chat message was created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Timestamp of when the chat message was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the deletedDateTime property value. Read only. Timestamp at which the chat message was deleted, or null if not deleted.
     * @returns a Date
     */
    get deletedDateTime(): Date | undefined;
    /**
     * Sets the deletedDateTime property value. Read only. Timestamp at which the chat message was deleted, or null if not deleted.
     * @param value Value to set for the deletedDateTime property.
     */
    set deletedDateTime(value: Date | undefined);
    /**
     * Gets the etag property value. Read-only. Version number of the chat message.
     * @returns a string
     */
    get etag(): string | undefined;
    /**
     * Sets the etag property value. Read-only. Version number of the chat message.
     * @param value Value to set for the etag property.
     */
    set etag(value: string | undefined);
    /**
     * Gets the eventDetail property value. Read-only. If present, represents details of an event that happened in a chat, a channel, or a team, for example, adding new members. For event messages, the messageType property will be set to systemEventMessage.
     * @returns a eventMessageDetail
     */
    get eventDetail(): EventMessageDetail | undefined;
    /**
     * Sets the eventDetail property value. Read-only. If present, represents details of an event that happened in a chat, a channel, or a team, for example, adding new members. For event messages, the messageType property will be set to systemEventMessage.
     * @param value Value to set for the eventDetail property.
     */
    set eventDetail(value: EventMessageDetail | undefined);
    /**
     * Gets the from property value. Details of the sender of the chat message. Can only be set during migration.
     * @returns a chatMessageFromIdentitySet
     */
    get from(): ChatMessageFromIdentitySet | undefined;
    /**
     * Sets the from property value. Details of the sender of the chat message. Can only be set during migration.
     * @param value Value to set for the from property.
     */
    set from(value: ChatMessageFromIdentitySet | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hostedContents property value. Content in a message hosted by Microsoft Teams - for example, images or code snippets.
     * @returns a chatMessageHostedContent
     */
    get hostedContents(): ChatMessageHostedContent[] | undefined;
    /**
     * Sets the hostedContents property value. Content in a message hosted by Microsoft Teams - for example, images or code snippets.
     * @param value Value to set for the hostedContents property.
     */
    set hostedContents(value: ChatMessageHostedContent[] | undefined);
    /**
     * Gets the importance property value. The importance of the chat message. The possible values are: normal, high, urgent.
     * @returns a chatMessageImportance
     */
    get importance(): ChatMessageImportance | undefined;
    /**
     * Sets the importance property value. The importance of the chat message. The possible values are: normal, high, urgent.
     * @param value Value to set for the importance property.
     */
    set importance(value: ChatMessageImportance | undefined);
    /**
     * Gets the lastEditedDateTime property value. Read only. Timestamp when edits to the chat message were made. Triggers an 'Edited' flag in the Teams UI. If no edits are made the value is null.
     * @returns a Date
     */
    get lastEditedDateTime(): Date | undefined;
    /**
     * Sets the lastEditedDateTime property value. Read only. Timestamp when edits to the chat message were made. Triggers an 'Edited' flag in the Teams UI. If no edits are made the value is null.
     * @param value Value to set for the lastEditedDateTime property.
     */
    set lastEditedDateTime(value: Date | undefined);
    /**
     * Gets the lastModifiedDateTime property value. Read only. Timestamp when the chat message is created (initial setting) or modified, including when a reaction is added or removed.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. Read only. Timestamp when the chat message is created (initial setting) or modified, including when a reaction is added or removed.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the locale property value. Locale of the chat message set by the client. Always set to en-us.
     * @returns a string
     */
    get locale(): string | undefined;
    /**
     * Sets the locale property value. Locale of the chat message set by the client. Always set to en-us.
     * @param value Value to set for the locale property.
     */
    set locale(value: string | undefined);
    /**
     * Gets the mentions property value. List of entities mentioned in the chat message. Supported entities are: user, bot, team, and channel.
     * @returns a chatMessageMention
     */
    get mentions(): ChatMessageMention[] | undefined;
    /**
     * Sets the mentions property value. List of entities mentioned in the chat message. Supported entities are: user, bot, team, and channel.
     * @param value Value to set for the mentions property.
     */
    set mentions(value: ChatMessageMention[] | undefined);
    /**
     * Gets the messageType property value. The type of chat message. The possible values are: message, chatEvent, typing, unknownFutureValue, systemEventMessage. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: systemEventMessage.
     * @returns a chatMessageType
     */
    get messageType(): ChatMessageType | undefined;
    /**
     * Sets the messageType property value. The type of chat message. The possible values are: message, chatEvent, typing, unknownFutureValue, systemEventMessage. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: systemEventMessage.
     * @param value Value to set for the messageType property.
     */
    set messageType(value: ChatMessageType | undefined);
    /**
     * Gets the policyViolation property value. Defines the properties of a policy violation set by a data loss prevention (DLP) application.
     * @returns a chatMessagePolicyViolation
     */
    get policyViolation(): ChatMessagePolicyViolation | undefined;
    /**
     * Sets the policyViolation property value. Defines the properties of a policy violation set by a data loss prevention (DLP) application.
     * @param value Value to set for the policyViolation property.
     */
    set policyViolation(value: ChatMessagePolicyViolation | undefined);
    /**
     * Gets the reactions property value. Reactions for this chat message (for example, Like).
     * @returns a chatMessageReaction
     */
    get reactions(): ChatMessageReaction[] | undefined;
    /**
     * Sets the reactions property value. Reactions for this chat message (for example, Like).
     * @param value Value to set for the reactions property.
     */
    set reactions(value: ChatMessageReaction[] | undefined);
    /**
     * Gets the replies property value. Replies for a specified message.
     * @returns a chatMessage
     */
    get replies(): ChatMessage[] | undefined;
    /**
     * Sets the replies property value. Replies for a specified message.
     * @param value Value to set for the replies property.
     */
    set replies(value: ChatMessage[] | undefined);
    /**
     * Gets the replyToId property value. Read-only. ID of the parent chat message or root chat message of the thread. (Only applies to chat messages in channels, not chats.)
     * @returns a string
     */
    get replyToId(): string | undefined;
    /**
     * Sets the replyToId property value. Read-only. ID of the parent chat message or root chat message of the thread. (Only applies to chat messages in channels, not chats.)
     * @param value Value to set for the replyToId property.
     */
    set replyToId(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the subject property value. The subject of the chat message, in plaintext.
     * @returns a string
     */
    get subject(): string | undefined;
    /**
     * Sets the subject property value. The subject of the chat message, in plaintext.
     * @param value Value to set for the subject property.
     */
    set subject(value: string | undefined);
    /**
     * Gets the summary property value. Summary text of the chat message that could be used for push notifications and summary views or fall back views. Only applies to channel chat messages, not chat messages in a chat.
     * @returns a string
     */
    get summary(): string | undefined;
    /**
     * Sets the summary property value. Summary text of the chat message that could be used for push notifications and summary views or fall back views. Only applies to channel chat messages, not chat messages in a chat.
     * @param value Value to set for the summary property.
     */
    set summary(value: string | undefined);
    /**
     * Gets the webUrl property value. Read-only. Link to the message in Microsoft Teams.
     * @returns a string
     */
    get webUrl(): string | undefined;
    /**
     * Sets the webUrl property value. Read-only. Link to the message in Microsoft Teams.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value: string | undefined);
}
