"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ChatMessage = void 0;
const chatMessageImportance_1 = require("./chatMessageImportance");
const chatMessageType_1 = require("./chatMessageType");
const createChannelIdentityFromDiscriminatorValue_1 = require("./createChannelIdentityFromDiscriminatorValue");
const createChatMessageAttachmentFromDiscriminatorValue_1 = require("./createChatMessageAttachmentFromDiscriminatorValue");
const createChatMessageFromDiscriminatorValue_1 = require("./createChatMessageFromDiscriminatorValue");
const createChatMessageFromIdentitySetFromDiscriminatorValue_1 = require("./createChatMessageFromIdentitySetFromDiscriminatorValue");
const createChatMessageHostedContentFromDiscriminatorValue_1 = require("./createChatMessageHostedContentFromDiscriminatorValue");
const createChatMessageMentionFromDiscriminatorValue_1 = require("./createChatMessageMentionFromDiscriminatorValue");
const createChatMessagePolicyViolationFromDiscriminatorValue_1 = require("./createChatMessagePolicyViolationFromDiscriminatorValue");
const createChatMessageReactionFromDiscriminatorValue_1 = require("./createChatMessageReactionFromDiscriminatorValue");
const createEventMessageDetailFromDiscriminatorValue_1 = require("./createEventMessageDetailFromDiscriminatorValue");
const createItemBodyFromDiscriminatorValue_1 = require("./createItemBodyFromDiscriminatorValue");
const index_1 = require("./index");
class ChatMessage extends index_1.Entity {
    /**
     * Instantiates a new chatMessage and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the attachments property value. References to attached objects like files, tabs, meetings etc.
     * @returns a chatMessageAttachment
     */
    get attachments() {
        return this._attachments;
    }
    ;
    /**
     * Sets the attachments property value. References to attached objects like files, tabs, meetings etc.
     * @param value Value to set for the attachments property.
     */
    set attachments(value) {
        this._attachments = value;
    }
    ;
    /**
     * Gets the body property value.
     * @returns a itemBody
     */
    get body() {
        return this._body;
    }
    ;
    /**
     * Sets the body property value.
     * @param value Value to set for the body property.
     */
    set body(value) {
        this._body = value;
    }
    ;
    /**
     * Gets the channelIdentity property value. If the message was sent in a channel, represents identity of the channel.
     * @returns a channelIdentity
     */
    get channelIdentity() {
        return this._channelIdentity;
    }
    ;
    /**
     * Sets the channelIdentity property value. If the message was sent in a channel, represents identity of the channel.
     * @param value Value to set for the channelIdentity property.
     */
    set channelIdentity(value) {
        this._channelIdentity = value;
    }
    ;
    /**
     * Gets the chatId property value. If the message was sent in a chat, represents the identity of the chat.
     * @returns a string
     */
    get chatId() {
        return this._chatId;
    }
    ;
    /**
     * Sets the chatId property value. If the message was sent in a chat, represents the identity of the chat.
     * @param value Value to set for the chatId property.
     */
    set chatId(value) {
        this._chatId = value;
    }
    ;
    ;
    /**
     * Gets the createdDateTime property value. Timestamp of when the chat message was created.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. Timestamp of when the chat message was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the deletedDateTime property value. Read only. Timestamp at which the chat message was deleted, or null if not deleted.
     * @returns a Date
     */
    get deletedDateTime() {
        return this._deletedDateTime;
    }
    ;
    /**
     * Sets the deletedDateTime property value. Read only. Timestamp at which the chat message was deleted, or null if not deleted.
     * @param value Value to set for the deletedDateTime property.
     */
    set deletedDateTime(value) {
        this._deletedDateTime = value;
    }
    ;
    /**
     * Gets the etag property value. Read-only. Version number of the chat message.
     * @returns a string
     */
    get etag() {
        return this._etag;
    }
    ;
    /**
     * Sets the etag property value. Read-only. Version number of the chat message.
     * @param value Value to set for the etag property.
     */
    set etag(value) {
        this._etag = value;
    }
    ;
    /**
     * Gets the eventDetail property value. Read-only. If present, represents details of an event that happened in a chat, a channel, or a team, for example, adding new members. For event messages, the messageType property will be set to systemEventMessage.
     * @returns a eventMessageDetail
     */
    get eventDetail() {
        return this._eventDetail;
    }
    ;
    /**
     * Sets the eventDetail property value. Read-only. If present, represents details of an event that happened in a chat, a channel, or a team, for example, adding new members. For event messages, the messageType property will be set to systemEventMessage.
     * @param value Value to set for the eventDetail property.
     */
    set eventDetail(value) {
        this._eventDetail = value;
    }
    ;
    /**
     * Gets the from property value. Details of the sender of the chat message. Can only be set during migration.
     * @returns a chatMessageFromIdentitySet
     */
    get from() {
        return this._from;
    }
    ;
    /**
     * Sets the from property value. Details of the sender of the chat message. Can only be set during migration.
     * @param value Value to set for the from property.
     */
    set from(value) {
        this._from = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "attachments": (o, n) => { o.attachments = n.getCollectionOfObjectValues(createChatMessageAttachmentFromDiscriminatorValue_1.createChatMessageAttachmentFromDiscriminatorValue); }, "body": (o, n) => { o.body = n.getObjectValue(createItemBodyFromDiscriminatorValue_1.createItemBodyFromDiscriminatorValue); }, "channelIdentity": (o, n) => { o.channelIdentity = n.getObjectValue(createChannelIdentityFromDiscriminatorValue_1.createChannelIdentityFromDiscriminatorValue); }, "chatId": (o, n) => { o.chatId = n.getStringValue(); }, "createdDateTime": (o, n) => { o.createdDateTime = n.getDateValue(); }, "deletedDateTime": (o, n) => { o.deletedDateTime = n.getDateValue(); }, "etag": (o, n) => { o.etag = n.getStringValue(); }, "eventDetail": (o, n) => { o.eventDetail = n.getObjectValue(createEventMessageDetailFromDiscriminatorValue_1.createEventMessageDetailFromDiscriminatorValue); }, "from": (o, n) => { o.from = n.getObjectValue(createChatMessageFromIdentitySetFromDiscriminatorValue_1.createChatMessageFromIdentitySetFromDiscriminatorValue); }, "hostedContents": (o, n) => { o.hostedContents = n.getCollectionOfObjectValues(createChatMessageHostedContentFromDiscriminatorValue_1.createChatMessageHostedContentFromDiscriminatorValue); }, "importance": (o, n) => { o.importance = n.getEnumValue(chatMessageImportance_1.ChatMessageImportance); }, "lastEditedDateTime": (o, n) => { o.lastEditedDateTime = n.getDateValue(); }, "lastModifiedDateTime": (o, n) => { o.lastModifiedDateTime = n.getDateValue(); }, "locale": (o, n) => { o.locale = n.getStringValue(); }, "mentions": (o, n) => { o.mentions = n.getCollectionOfObjectValues(createChatMessageMentionFromDiscriminatorValue_1.createChatMessageMentionFromDiscriminatorValue); }, "messageType": (o, n) => { o.messageType = n.getEnumValue(chatMessageType_1.ChatMessageType); }, "policyViolation": (o, n) => { o.policyViolation = n.getObjectValue(createChatMessagePolicyViolationFromDiscriminatorValue_1.createChatMessagePolicyViolationFromDiscriminatorValue); }, "reactions": (o, n) => { o.reactions = n.getCollectionOfObjectValues(createChatMessageReactionFromDiscriminatorValue_1.createChatMessageReactionFromDiscriminatorValue); }, "replies": (o, n) => { o.replies = n.getCollectionOfObjectValues(createChatMessageFromDiscriminatorValue_1.createChatMessageFromDiscriminatorValue); }, "replyToId": (o, n) => { o.replyToId = n.getStringValue(); }, "subject": (o, n) => { o.subject = n.getStringValue(); }, "summary": (o, n) => { o.summary = n.getStringValue(); }, "webUrl": (o, n) => { o.webUrl = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the hostedContents property value. Content in a message hosted by Microsoft Teams - for example, images or code snippets.
     * @returns a chatMessageHostedContent
     */
    get hostedContents() {
        return this._hostedContents;
    }
    ;
    /**
     * Sets the hostedContents property value. Content in a message hosted by Microsoft Teams - for example, images or code snippets.
     * @param value Value to set for the hostedContents property.
     */
    set hostedContents(value) {
        this._hostedContents = value;
    }
    ;
    /**
     * Gets the importance property value. The importance of the chat message. The possible values are: normal, high, urgent.
     * @returns a chatMessageImportance
     */
    get importance() {
        return this._importance;
    }
    ;
    /**
     * Sets the importance property value. The importance of the chat message. The possible values are: normal, high, urgent.
     * @param value Value to set for the importance property.
     */
    set importance(value) {
        this._importance = value;
    }
    ;
    /**
     * Gets the lastEditedDateTime property value. Read only. Timestamp when edits to the chat message were made. Triggers an 'Edited' flag in the Teams UI. If no edits are made the value is null.
     * @returns a Date
     */
    get lastEditedDateTime() {
        return this._lastEditedDateTime;
    }
    ;
    /**
     * Sets the lastEditedDateTime property value. Read only. Timestamp when edits to the chat message were made. Triggers an 'Edited' flag in the Teams UI. If no edits are made the value is null.
     * @param value Value to set for the lastEditedDateTime property.
     */
    set lastEditedDateTime(value) {
        this._lastEditedDateTime = value;
    }
    ;
    /**
     * Gets the lastModifiedDateTime property value. Read only. Timestamp when the chat message is created (initial setting) or modified, including when a reaction is added or removed.
     * @returns a Date
     */
    get lastModifiedDateTime() {
        return this._lastModifiedDateTime;
    }
    ;
    /**
     * Sets the lastModifiedDateTime property value. Read only. Timestamp when the chat message is created (initial setting) or modified, including when a reaction is added or removed.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value) {
        this._lastModifiedDateTime = value;
    }
    ;
    /**
     * Gets the locale property value. Locale of the chat message set by the client. Always set to en-us.
     * @returns a string
     */
    get locale() {
        return this._locale;
    }
    ;
    /**
     * Sets the locale property value. Locale of the chat message set by the client. Always set to en-us.
     * @param value Value to set for the locale property.
     */
    set locale(value) {
        this._locale = value;
    }
    ;
    /**
     * Gets the mentions property value. List of entities mentioned in the chat message. Supported entities are: user, bot, team, and channel.
     * @returns a chatMessageMention
     */
    get mentions() {
        return this._mentions;
    }
    ;
    /**
     * Sets the mentions property value. List of entities mentioned in the chat message. Supported entities are: user, bot, team, and channel.
     * @param value Value to set for the mentions property.
     */
    set mentions(value) {
        this._mentions = value;
    }
    ;
    /**
     * Gets the messageType property value. The type of chat message. The possible values are: message, chatEvent, typing, unknownFutureValue, systemEventMessage. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: systemEventMessage.
     * @returns a chatMessageType
     */
    get messageType() {
        return this._messageType;
    }
    ;
    /**
     * Sets the messageType property value. The type of chat message. The possible values are: message, chatEvent, typing, unknownFutureValue, systemEventMessage. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value in this evolvable enum: systemEventMessage.
     * @param value Value to set for the messageType property.
     */
    set messageType(value) {
        this._messageType = value;
    }
    ;
    /**
     * Gets the policyViolation property value. Defines the properties of a policy violation set by a data loss prevention (DLP) application.
     * @returns a chatMessagePolicyViolation
     */
    get policyViolation() {
        return this._policyViolation;
    }
    ;
    /**
     * Sets the policyViolation property value. Defines the properties of a policy violation set by a data loss prevention (DLP) application.
     * @param value Value to set for the policyViolation property.
     */
    set policyViolation(value) {
        this._policyViolation = value;
    }
    ;
    /**
     * Gets the reactions property value. Reactions for this chat message (for example, Like).
     * @returns a chatMessageReaction
     */
    get reactions() {
        return this._reactions;
    }
    ;
    /**
     * Sets the reactions property value. Reactions for this chat message (for example, Like).
     * @param value Value to set for the reactions property.
     */
    set reactions(value) {
        this._reactions = value;
    }
    ;
    /**
     * Gets the replies property value. Replies for a specified message.
     * @returns a chatMessage
     */
    get replies() {
        return this._replies;
    }
    ;
    /**
     * Sets the replies property value. Replies for a specified message.
     * @param value Value to set for the replies property.
     */
    set replies(value) {
        this._replies = value;
    }
    ;
    /**
     * Gets the replyToId property value. Read-only. ID of the parent chat message or root chat message of the thread. (Only applies to chat messages in channels, not chats.)
     * @returns a string
     */
    get replyToId() {
        return this._replyToId;
    }
    ;
    /**
     * Sets the replyToId property value. Read-only. ID of the parent chat message or root chat message of the thread. (Only applies to chat messages in channels, not chats.)
     * @param value Value to set for the replyToId property.
     */
    set replyToId(value) {
        this._replyToId = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeCollectionOfObjectValues("attachments", this.attachments);
        writer.writeObjectValue("body", this.body);
        writer.writeObjectValue("channelIdentity", this.channelIdentity);
        writer.writeStringValue("chatId", this.chatId);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeDateValue("deletedDateTime", this.deletedDateTime);
        writer.writeStringValue("etag", this.etag);
        writer.writeObjectValue("eventDetail", this.eventDetail);
        writer.writeObjectValue("from", this.from);
        writer.writeCollectionOfObjectValues("hostedContents", this.hostedContents);
        writer.writeEnumValue("importance", this.importance);
        writer.writeDateValue("lastEditedDateTime", this.lastEditedDateTime);
        writer.writeDateValue("lastModifiedDateTime", this.lastModifiedDateTime);
        writer.writeStringValue("locale", this.locale);
        writer.writeCollectionOfObjectValues("mentions", this.mentions);
        writer.writeEnumValue("messageType", this.messageType);
        writer.writeObjectValue("policyViolation", this.policyViolation);
        writer.writeCollectionOfObjectValues("reactions", this.reactions);
        writer.writeCollectionOfObjectValues("replies", this.replies);
        writer.writeStringValue("replyToId", this.replyToId);
        writer.writeStringValue("subject", this.subject);
        writer.writeStringValue("summary", this.summary);
        writer.writeStringValue("webUrl", this.webUrl);
    }
    ;
    /**
     * Gets the subject property value. The subject of the chat message, in plaintext.
     * @returns a string
     */
    get subject() {
        return this._subject;
    }
    ;
    /**
     * Sets the subject property value. The subject of the chat message, in plaintext.
     * @param value Value to set for the subject property.
     */
    set subject(value) {
        this._subject = value;
    }
    ;
    /**
     * Gets the summary property value. Summary text of the chat message that could be used for push notifications and summary views or fall back views. Only applies to channel chat messages, not chat messages in a chat.
     * @returns a string
     */
    get summary() {
        return this._summary;
    }
    ;
    /**
     * Sets the summary property value. Summary text of the chat message that could be used for push notifications and summary views or fall back views. Only applies to channel chat messages, not chat messages in a chat.
     * @param value Value to set for the summary property.
     */
    set summary(value) {
        this._summary = value;
    }
    ;
    /**
     * Gets the webUrl property value. Read-only. Link to the message in Microsoft Teams.
     * @returns a string
     */
    get webUrl() {
        return this._webUrl;
    }
    ;
    /**
     * Sets the webUrl property value. Read-only. Link to the message in Microsoft Teams.
     * @param value Value to set for the webUrl property.
     */
    set webUrl(value) {
        this._webUrl = value;
    }
    ;
}
exports.ChatMessage = ChatMessage;
