import { ColumnTypes } from './columnTypes';
import { BooleanColumn, CalculatedColumn, ChoiceColumn, ColumnValidation, ContentApprovalStatusColumn, ContentTypeInfo, CurrencyColumn, DateTimeColumn, DefaultColumnValue, Entity, GeolocationColumn, HyperlinkOrPictureColumn, LookupColumn, NumberColumn, PersonOrGroupColumn, TermColumn, TextColumn, ThumbnailColumn } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ColumnDefinition extends Entity implements Parsable {
    /** This column stores boolean values.  */
    private _boolean?;
    /** This column's data is calculated based on other columns.  */
    private _calculated?;
    /** This column stores data from a list of choices.  */
    private _choice?;
    /** For site columns, the name of the group this column belongs to. Helps organize related columns.  */
    private _columnGroup?;
    /** This column stores content approval status.  */
    private _contentApprovalStatus?;
    /** This column stores currency values.  */
    private _currency?;
    /** This column stores DateTime values.  */
    private _dateTime?;
    /** The default value for this column.  */
    private _defaultValue?;
    /** The user-facing description of the column.  */
    private _description?;
    /** The user-facing name of the column.  */
    private _displayName?;
    /** If true, no two list items may have the same value for this column.  */
    private _enforceUniqueValues?;
    /** This column stores a geolocation.  */
    private _geolocation?;
    /** Specifies whether the column is displayed in the user interface.  */
    private _hidden?;
    /** This column stores hyperlink or picture values.  */
    private _hyperlinkOrPicture?;
    /** Specifies whether the column values can be used for sorting and searching.  */
    private _indexed?;
    /** Indicates whether this column can be deleted.  */
    private _isDeletable?;
    /** Indicates whether values in the column can be reordered. Read-only.  */
    private _isReorderable?;
    /** Specifies whether the column can be changed.  */
    private _isSealed?;
    /** This column's data is looked up from another source in the site.  */
    private _lookup?;
    /** The API-facing name of the column as it appears in the [fields][] on a [listItem][]. For the user-facing name, see displayName.  */
    private _name?;
    /** This column stores number values.  */
    private _number?;
    /** This column stores Person or Group values.  */
    private _personOrGroup?;
    /** If 'true', changes to this column will be propagated to lists that implement the column.  */
    private _propagateChanges?;
    /** Specifies whether the column values can be modified.  */
    private _readOnly?;
    /** Specifies whether the column value isn't optional.  */
    private _required?;
    /** The source column for the content type column.  */
    private _sourceColumn?;
    /** ContentType from which this column is inherited from. Present only in contentTypes columns response. Read-only.  */
    private _sourceContentType?;
    /** This column stores taxonomy terms.  */
    private _term?;
    /** This column stores text values.  */
    private _text?;
    /** This column stores thumbnail values.  */
    private _thumbnail?;
    /** For site columns, the type of column. Read-only.  */
    private _type?;
    /** This column stores validation formula and message for the column.  */
    private _validation?;
    /**
     * Gets the boolean property value. This column stores boolean values.
     * @returns a booleanColumn
     */
    get boolean(): BooleanColumn | undefined;
    /**
     * Sets the boolean property value. This column stores boolean values.
     * @param value Value to set for the boolean property.
     */
    set boolean(value: BooleanColumn | undefined);
    /**
     * Gets the calculated property value. This column's data is calculated based on other columns.
     * @returns a calculatedColumn
     */
    get calculated(): CalculatedColumn | undefined;
    /**
     * Sets the calculated property value. This column's data is calculated based on other columns.
     * @param value Value to set for the calculated property.
     */
    set calculated(value: CalculatedColumn | undefined);
    /**
     * Gets the choice property value. This column stores data from a list of choices.
     * @returns a choiceColumn
     */
    get choice(): ChoiceColumn | undefined;
    /**
     * Sets the choice property value. This column stores data from a list of choices.
     * @param value Value to set for the choice property.
     */
    set choice(value: ChoiceColumn | undefined);
    /**
     * Gets the columnGroup property value. For site columns, the name of the group this column belongs to. Helps organize related columns.
     * @returns a string
     */
    get columnGroup(): string | undefined;
    /**
     * Sets the columnGroup property value. For site columns, the name of the group this column belongs to. Helps organize related columns.
     * @param value Value to set for the columnGroup property.
     */
    set columnGroup(value: string | undefined);
    /**
     * Instantiates a new columnDefinition and sets the default values.
     */
    constructor();
    /**
     * Gets the contentApprovalStatus property value. This column stores content approval status.
     * @returns a contentApprovalStatusColumn
     */
    get contentApprovalStatus(): ContentApprovalStatusColumn | undefined;
    /**
     * Sets the contentApprovalStatus property value. This column stores content approval status.
     * @param value Value to set for the contentApprovalStatus property.
     */
    set contentApprovalStatus(value: ContentApprovalStatusColumn | undefined);
    /**
     * Gets the currency property value. This column stores currency values.
     * @returns a currencyColumn
     */
    get currency(): CurrencyColumn | undefined;
    /**
     * Sets the currency property value. This column stores currency values.
     * @param value Value to set for the currency property.
     */
    set currency(value: CurrencyColumn | undefined);
    /**
     * Gets the dateTime property value. This column stores DateTime values.
     * @returns a dateTimeColumn
     */
    get dateTime(): DateTimeColumn | undefined;
    /**
     * Sets the dateTime property value. This column stores DateTime values.
     * @param value Value to set for the dateTime property.
     */
    set dateTime(value: DateTimeColumn | undefined);
    /**
     * Gets the defaultValue property value. The default value for this column.
     * @returns a defaultColumnValue
     */
    get defaultValue(): DefaultColumnValue | undefined;
    /**
     * Sets the defaultValue property value. The default value for this column.
     * @param value Value to set for the defaultValue property.
     */
    set defaultValue(value: DefaultColumnValue | undefined);
    /**
     * Gets the description property value. The user-facing description of the column.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. The user-facing description of the column.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. The user-facing name of the column.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The user-facing name of the column.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the enforceUniqueValues property value. If true, no two list items may have the same value for this column.
     * @returns a boolean
     */
    get enforceUniqueValues(): boolean | undefined;
    /**
     * Sets the enforceUniqueValues property value. If true, no two list items may have the same value for this column.
     * @param value Value to set for the enforceUniqueValues property.
     */
    set enforceUniqueValues(value: boolean | undefined);
    /**
     * Gets the geolocation property value. This column stores a geolocation.
     * @returns a geolocationColumn
     */
    get geolocation(): GeolocationColumn | undefined;
    /**
     * Sets the geolocation property value. This column stores a geolocation.
     * @param value Value to set for the geolocation property.
     */
    set geolocation(value: GeolocationColumn | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hidden property value. Specifies whether the column is displayed in the user interface.
     * @returns a boolean
     */
    get hidden(): boolean | undefined;
    /**
     * Sets the hidden property value. Specifies whether the column is displayed in the user interface.
     * @param value Value to set for the hidden property.
     */
    set hidden(value: boolean | undefined);
    /**
     * Gets the hyperlinkOrPicture property value. This column stores hyperlink or picture values.
     * @returns a hyperlinkOrPictureColumn
     */
    get hyperlinkOrPicture(): HyperlinkOrPictureColumn | undefined;
    /**
     * Sets the hyperlinkOrPicture property value. This column stores hyperlink or picture values.
     * @param value Value to set for the hyperlinkOrPicture property.
     */
    set hyperlinkOrPicture(value: HyperlinkOrPictureColumn | undefined);
    /**
     * Gets the indexed property value. Specifies whether the column values can be used for sorting and searching.
     * @returns a boolean
     */
    get indexed(): boolean | undefined;
    /**
     * Sets the indexed property value. Specifies whether the column values can be used for sorting and searching.
     * @param value Value to set for the indexed property.
     */
    set indexed(value: boolean | undefined);
    /**
     * Gets the isDeletable property value. Indicates whether this column can be deleted.
     * @returns a boolean
     */
    get isDeletable(): boolean | undefined;
    /**
     * Sets the isDeletable property value. Indicates whether this column can be deleted.
     * @param value Value to set for the isDeletable property.
     */
    set isDeletable(value: boolean | undefined);
    /**
     * Gets the isReorderable property value. Indicates whether values in the column can be reordered. Read-only.
     * @returns a boolean
     */
    get isReorderable(): boolean | undefined;
    /**
     * Sets the isReorderable property value. Indicates whether values in the column can be reordered. Read-only.
     * @param value Value to set for the isReorderable property.
     */
    set isReorderable(value: boolean | undefined);
    /**
     * Gets the isSealed property value. Specifies whether the column can be changed.
     * @returns a boolean
     */
    get isSealed(): boolean | undefined;
    /**
     * Sets the isSealed property value. Specifies whether the column can be changed.
     * @param value Value to set for the isSealed property.
     */
    set isSealed(value: boolean | undefined);
    /**
     * Gets the lookup property value. This column's data is looked up from another source in the site.
     * @returns a lookupColumn
     */
    get lookup(): LookupColumn | undefined;
    /**
     * Sets the lookup property value. This column's data is looked up from another source in the site.
     * @param value Value to set for the lookup property.
     */
    set lookup(value: LookupColumn | undefined);
    /**
     * Gets the name property value. The API-facing name of the column as it appears in the [fields][] on a [listItem][]. For the user-facing name, see displayName.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The API-facing name of the column as it appears in the [fields][] on a [listItem][]. For the user-facing name, see displayName.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the number property value. This column stores number values.
     * @returns a numberColumn
     */
    get number(): NumberColumn | undefined;
    /**
     * Sets the number property value. This column stores number values.
     * @param value Value to set for the number property.
     */
    set number(value: NumberColumn | undefined);
    /**
     * Gets the personOrGroup property value. This column stores Person or Group values.
     * @returns a personOrGroupColumn
     */
    get personOrGroup(): PersonOrGroupColumn | undefined;
    /**
     * Sets the personOrGroup property value. This column stores Person or Group values.
     * @param value Value to set for the personOrGroup property.
     */
    set personOrGroup(value: PersonOrGroupColumn | undefined);
    /**
     * Gets the propagateChanges property value. If 'true', changes to this column will be propagated to lists that implement the column.
     * @returns a boolean
     */
    get propagateChanges(): boolean | undefined;
    /**
     * Sets the propagateChanges property value. If 'true', changes to this column will be propagated to lists that implement the column.
     * @param value Value to set for the propagateChanges property.
     */
    set propagateChanges(value: boolean | undefined);
    /**
     * Gets the readOnly property value. Specifies whether the column values can be modified.
     * @returns a boolean
     */
    get readOnly(): boolean | undefined;
    /**
     * Sets the readOnly property value. Specifies whether the column values can be modified.
     * @param value Value to set for the readOnly property.
     */
    set readOnly(value: boolean | undefined);
    /**
     * Gets the required property value. Specifies whether the column value isn't optional.
     * @returns a boolean
     */
    get required(): boolean | undefined;
    /**
     * Sets the required property value. Specifies whether the column value isn't optional.
     * @param value Value to set for the required property.
     */
    set required(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the sourceColumn property value. The source column for the content type column.
     * @returns a columnDefinition
     */
    get sourceColumn(): ColumnDefinition | undefined;
    /**
     * Sets the sourceColumn property value. The source column for the content type column.
     * @param value Value to set for the sourceColumn property.
     */
    set sourceColumn(value: ColumnDefinition | undefined);
    /**
     * Gets the sourceContentType property value. ContentType from which this column is inherited from. Present only in contentTypes columns response. Read-only.
     * @returns a contentTypeInfo
     */
    get sourceContentType(): ContentTypeInfo | undefined;
    /**
     * Sets the sourceContentType property value. ContentType from which this column is inherited from. Present only in contentTypes columns response. Read-only.
     * @param value Value to set for the sourceContentType property.
     */
    set sourceContentType(value: ContentTypeInfo | undefined);
    /**
     * Gets the term property value. This column stores taxonomy terms.
     * @returns a termColumn
     */
    get term(): TermColumn | undefined;
    /**
     * Sets the term property value. This column stores taxonomy terms.
     * @param value Value to set for the term property.
     */
    set term(value: TermColumn | undefined);
    /**
     * Gets the text property value. This column stores text values.
     * @returns a textColumn
     */
    get text(): TextColumn | undefined;
    /**
     * Sets the text property value. This column stores text values.
     * @param value Value to set for the text property.
     */
    set text(value: TextColumn | undefined);
    /**
     * Gets the thumbnail property value. This column stores thumbnail values.
     * @returns a thumbnailColumn
     */
    get thumbnail(): ThumbnailColumn | undefined;
    /**
     * Sets the thumbnail property value. This column stores thumbnail values.
     * @param value Value to set for the thumbnail property.
     */
    set thumbnail(value: ThumbnailColumn | undefined);
    /**
     * Gets the type property value. For site columns, the type of column. Read-only.
     * @returns a columnTypes
     */
    get type(): ColumnTypes | undefined;
    /**
     * Sets the type property value. For site columns, the type of column. Read-only.
     * @param value Value to set for the type property.
     */
    set type(value: ColumnTypes | undefined);
    /**
     * Gets the validation property value. This column stores validation formula and message for the column.
     * @returns a columnValidation
     */
    get validation(): ColumnValidation | undefined;
    /**
     * Sets the validation property value. This column stores validation formula and message for the column.
     * @param value Value to set for the validation property.
     */
    set validation(value: ColumnValidation | undefined);
}
