import { ConditionalAccessClientApp } from './conditionalAccessClientApp';
import { ConditionalAccessApplications, ConditionalAccessClientApplications, ConditionalAccessDevices, ConditionalAccessLocations, ConditionalAccessPlatforms, ConditionalAccessUsers } from './index';
import { RiskLevel } from './riskLevel';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ConditionalAccessConditionSet implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.  */
    private _additionalData;
    /** Applications and user actions included in and excluded from the policy. Required.  */
    private _applications?;
    /** Client applications (service principals and workload identities) included in and excluded from the policy. Either users or clientApplications is required.  */
    private _clientApplications?;
    /** Client application types included in the policy. Possible values are: all, browser, mobileAppsAndDesktopClients, exchangeActiveSync, easSupported, other. Required.  */
    private _clientAppTypes?;
    /** Devices in the policy.  */
    private _devices?;
    /** Locations included in and excluded from the policy.  */
    private _locations?;
    /** Platforms included in and excluded from the policy.  */
    private _platforms?;
    /** Sign-in risk levels included in the policy. Possible values are: low, medium, high, hidden, none, unknownFutureValue. Required.  */
    private _signInRiskLevels?;
    /** User risk levels included in the policy. Possible values are: low, medium, high, hidden, none, unknownFutureValue. Required.  */
    private _userRiskLevels?;
    /** Users, groups, and roles included in and excluded from the policy. Required.  */
    private _users?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the applications property value. Applications and user actions included in and excluded from the policy. Required.
     * @returns a conditionalAccessApplications
     */
    get applications(): ConditionalAccessApplications | undefined;
    /**
     * Sets the applications property value. Applications and user actions included in and excluded from the policy. Required.
     * @param value Value to set for the applications property.
     */
    set applications(value: ConditionalAccessApplications | undefined);
    /**
     * Gets the clientApplications property value. Client applications (service principals and workload identities) included in and excluded from the policy. Either users or clientApplications is required.
     * @returns a conditionalAccessClientApplications
     */
    get clientApplications(): ConditionalAccessClientApplications | undefined;
    /**
     * Sets the clientApplications property value. Client applications (service principals and workload identities) included in and excluded from the policy. Either users or clientApplications is required.
     * @param value Value to set for the clientApplications property.
     */
    set clientApplications(value: ConditionalAccessClientApplications | undefined);
    /**
     * Gets the clientAppTypes property value. Client application types included in the policy. Possible values are: all, browser, mobileAppsAndDesktopClients, exchangeActiveSync, easSupported, other. Required.
     * @returns a conditionalAccessClientApp
     */
    get clientAppTypes(): ConditionalAccessClientApp[] | undefined;
    /**
     * Sets the clientAppTypes property value. Client application types included in the policy. Possible values are: all, browser, mobileAppsAndDesktopClients, exchangeActiveSync, easSupported, other. Required.
     * @param value Value to set for the clientAppTypes property.
     */
    set clientAppTypes(value: ConditionalAccessClientApp[] | undefined);
    /**
     * Instantiates a new conditionalAccessConditionSet and sets the default values.
     */
    constructor();
    /**
     * Gets the devices property value. Devices in the policy.
     * @returns a conditionalAccessDevices
     */
    get devices(): ConditionalAccessDevices | undefined;
    /**
     * Sets the devices property value. Devices in the policy.
     * @param value Value to set for the devices property.
     */
    set devices(value: ConditionalAccessDevices | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the locations property value. Locations included in and excluded from the policy.
     * @returns a conditionalAccessLocations
     */
    get locations(): ConditionalAccessLocations | undefined;
    /**
     * Sets the locations property value. Locations included in and excluded from the policy.
     * @param value Value to set for the locations property.
     */
    set locations(value: ConditionalAccessLocations | undefined);
    /**
     * Gets the platforms property value. Platforms included in and excluded from the policy.
     * @returns a conditionalAccessPlatforms
     */
    get platforms(): ConditionalAccessPlatforms | undefined;
    /**
     * Sets the platforms property value. Platforms included in and excluded from the policy.
     * @param value Value to set for the platforms property.
     */
    set platforms(value: ConditionalAccessPlatforms | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the signInRiskLevels property value. Sign-in risk levels included in the policy. Possible values are: low, medium, high, hidden, none, unknownFutureValue. Required.
     * @returns a riskLevel
     */
    get signInRiskLevels(): RiskLevel[] | undefined;
    /**
     * Sets the signInRiskLevels property value. Sign-in risk levels included in the policy. Possible values are: low, medium, high, hidden, none, unknownFutureValue. Required.
     * @param value Value to set for the signInRiskLevels property.
     */
    set signInRiskLevels(value: RiskLevel[] | undefined);
    /**
     * Gets the userRiskLevels property value. User risk levels included in the policy. Possible values are: low, medium, high, hidden, none, unknownFutureValue. Required.
     * @returns a riskLevel
     */
    get userRiskLevels(): RiskLevel[] | undefined;
    /**
     * Sets the userRiskLevels property value. User risk levels included in the policy. Possible values are: low, medium, high, hidden, none, unknownFutureValue. Required.
     * @param value Value to set for the userRiskLevels property.
     */
    set userRiskLevels(value: RiskLevel[] | undefined);
    /**
     * Gets the users property value. Users, groups, and roles included in and excluded from the policy. Required.
     * @returns a conditionalAccessUsers
     */
    get users(): ConditionalAccessUsers | undefined;
    /**
     * Sets the users property value. Users, groups, and roles included in and excluded from the policy. Required.
     * @param value Value to set for the users property.
     */
    set users(value: ConditionalAccessUsers | undefined);
}
