import { DataPolicyOperationStatus } from './dataPolicyOperationStatus';
import { Entity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class DataPolicyOperation extends Entity implements Parsable {
    /** Represents when the request for this data policy operation was completed, in UTC time, using the ISO 8601 format. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Null until the operation completes.  */
    private _completedDateTime?;
    /** Specifies the progress of an operation.  */
    private _progress?;
    /** Possible values are: notStarted, running, complete, failed, unknownFutureValue.  */
    private _status?;
    /** The URL location to where data is being exported for export requests.  */
    private _storageLocation?;
    /** Represents when the request for this data operation was submitted, in UTC time, using the ISO 8601 format. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z  */
    private _submittedDateTime?;
    /** The id for the user on whom the operation is performed.  */
    private _userId?;
    /**
     * Gets the completedDateTime property value. Represents when the request for this data policy operation was completed, in UTC time, using the ISO 8601 format. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Null until the operation completes.
     * @returns a Date
     */
    get completedDateTime(): Date | undefined;
    /**
     * Sets the completedDateTime property value. Represents when the request for this data policy operation was completed, in UTC time, using the ISO 8601 format. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Null until the operation completes.
     * @param value Value to set for the completedDateTime property.
     */
    set completedDateTime(value: Date | undefined);
    /**
     * Instantiates a new dataPolicyOperation and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the progress property value. Specifies the progress of an operation.
     * @returns a double
     */
    get progress(): number | undefined;
    /**
     * Sets the progress property value. Specifies the progress of an operation.
     * @param value Value to set for the progress property.
     */
    set progress(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. Possible values are: notStarted, running, complete, failed, unknownFutureValue.
     * @returns a dataPolicyOperationStatus
     */
    get status(): DataPolicyOperationStatus | undefined;
    /**
     * Sets the status property value. Possible values are: notStarted, running, complete, failed, unknownFutureValue.
     * @param value Value to set for the status property.
     */
    set status(value: DataPolicyOperationStatus | undefined);
    /**
     * Gets the storageLocation property value. The URL location to where data is being exported for export requests.
     * @returns a string
     */
    get storageLocation(): string | undefined;
    /**
     * Sets the storageLocation property value. The URL location to where data is being exported for export requests.
     * @param value Value to set for the storageLocation property.
     */
    set storageLocation(value: string | undefined);
    /**
     * Gets the submittedDateTime property value. Represents when the request for this data operation was submitted, in UTC time, using the ISO 8601 format. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get submittedDateTime(): Date | undefined;
    /**
     * Sets the submittedDateTime property value. Represents when the request for this data operation was submitted, in UTC time, using the ISO 8601 format. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the submittedDateTime property.
     */
    set submittedDateTime(value: Date | undefined);
    /**
     * Gets the userId property value. The id for the user on whom the operation is performed.
     * @returns a string
     */
    get userId(): string | undefined;
    /**
     * Sets the userId property value. The id for the user on whom the operation is performed.
     * @param value Value to set for the userId property.
     */
    set userId(value: string | undefined);
}
