import { KeyValuePair, ManagedAppPolicyDeploymentSummary, ManagedAppProtection, ManagedMobileApp } from './index';
import { ManagedAppDataEncryptionType } from './managedAppDataEncryptionType';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class DefaultManagedAppProtection extends ManagedAppProtection implements Parsable {
    /** Type of encryption which should be used for data in a managed app. (iOS Only). Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.  */
    private _appDataEncryptionType?;
    /** List of apps to which the policy is deployed.  */
    private _apps?;
    /** A set of string key and string value pairs to be sent to the affected users, unalterned by this service  */
    private _customSettings?;
    /** Count of apps to which the current policy is deployed.  */
    private _deployedAppCount?;
    /** Navigation property to deployment summary of the configuration.  */
    private _deploymentSummary?;
    /** When this setting is enabled, app level encryption is disabled if device level encryption is enabled. (Android only)  */
    private _disableAppEncryptionIfDeviceEncryptionIsEnabled?;
    /** Indicates whether managed-app data should be encrypted. (Android only)  */
    private _encryptAppData?;
    /** Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True. (iOS Only)  */
    private _faceIdBlocked?;
    /** Define the oldest required Android security patch level a user can have to gain secure access to the app. (Android only)  */
    private _minimumRequiredPatchVersion?;
    /** Versions less than the specified version will block the managed app from accessing company data. (iOS Only)  */
    private _minimumRequiredSdkVersion?;
    /** Define the oldest recommended Android security patch level a user can have for secure access to the app. (Android only)  */
    private _minimumWarningPatchVersion?;
    /** Indicates whether screen capture is blocked. (Android only)  */
    private _screenCaptureBlocked?;
    /**
     * Gets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. (iOS Only). Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @returns a managedAppDataEncryptionType
     */
    get appDataEncryptionType(): ManagedAppDataEncryptionType | undefined;
    /**
     * Sets the appDataEncryptionType property value. Type of encryption which should be used for data in a managed app. (iOS Only). Possible values are: useDeviceSettings, afterDeviceRestart, whenDeviceLockedExceptOpenFiles, whenDeviceLocked.
     * @param value Value to set for the appDataEncryptionType property.
     */
    set appDataEncryptionType(value: ManagedAppDataEncryptionType | undefined);
    /**
     * Gets the apps property value. List of apps to which the policy is deployed.
     * @returns a managedMobileApp
     */
    get apps(): ManagedMobileApp[] | undefined;
    /**
     * Sets the apps property value. List of apps to which the policy is deployed.
     * @param value Value to set for the apps property.
     */
    set apps(value: ManagedMobileApp[] | undefined);
    /**
     * Instantiates a new defaultManagedAppProtection and sets the default values.
     */
    constructor();
    /**
     * Gets the customSettings property value. A set of string key and string value pairs to be sent to the affected users, unalterned by this service
     * @returns a keyValuePair
     */
    get customSettings(): KeyValuePair[] | undefined;
    /**
     * Sets the customSettings property value. A set of string key and string value pairs to be sent to the affected users, unalterned by this service
     * @param value Value to set for the customSettings property.
     */
    set customSettings(value: KeyValuePair[] | undefined);
    /**
     * Gets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @returns a integer
     */
    get deployedAppCount(): number | undefined;
    /**
     * Sets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @param value Value to set for the deployedAppCount property.
     */
    set deployedAppCount(value: number | undefined);
    /**
     * Gets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @returns a managedAppPolicyDeploymentSummary
     */
    get deploymentSummary(): ManagedAppPolicyDeploymentSummary | undefined;
    /**
     * Sets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @param value Value to set for the deploymentSummary property.
     */
    set deploymentSummary(value: ManagedAppPolicyDeploymentSummary | undefined);
    /**
     * Gets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled. (Android only)
     * @returns a boolean
     */
    get disableAppEncryptionIfDeviceEncryptionIsEnabled(): boolean | undefined;
    /**
     * Sets the disableAppEncryptionIfDeviceEncryptionIsEnabled property value. When this setting is enabled, app level encryption is disabled if device level encryption is enabled. (Android only)
     * @param value Value to set for the disableAppEncryptionIfDeviceEncryptionIsEnabled property.
     */
    set disableAppEncryptionIfDeviceEncryptionIsEnabled(value: boolean | undefined);
    /**
     * Gets the encryptAppData property value. Indicates whether managed-app data should be encrypted. (Android only)
     * @returns a boolean
     */
    get encryptAppData(): boolean | undefined;
    /**
     * Sets the encryptAppData property value. Indicates whether managed-app data should be encrypted. (Android only)
     * @param value Value to set for the encryptAppData property.
     */
    set encryptAppData(value: boolean | undefined);
    /**
     * Gets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True. (iOS Only)
     * @returns a boolean
     */
    get faceIdBlocked(): boolean | undefined;
    /**
     * Sets the faceIdBlocked property value. Indicates whether use of the FaceID is allowed in place of a pin if PinRequired is set to True. (iOS Only)
     * @param value Value to set for the faceIdBlocked property.
     */
    set faceIdBlocked(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app. (Android only)
     * @returns a string
     */
    get minimumRequiredPatchVersion(): string | undefined;
    /**
     * Sets the minimumRequiredPatchVersion property value. Define the oldest required Android security patch level a user can have to gain secure access to the app. (Android only)
     * @param value Value to set for the minimumRequiredPatchVersion property.
     */
    set minimumRequiredPatchVersion(value: string | undefined);
    /**
     * Gets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data. (iOS Only)
     * @returns a string
     */
    get minimumRequiredSdkVersion(): string | undefined;
    /**
     * Sets the minimumRequiredSdkVersion property value. Versions less than the specified version will block the managed app from accessing company data. (iOS Only)
     * @param value Value to set for the minimumRequiredSdkVersion property.
     */
    set minimumRequiredSdkVersion(value: string | undefined);
    /**
     * Gets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app. (Android only)
     * @returns a string
     */
    get minimumWarningPatchVersion(): string | undefined;
    /**
     * Sets the minimumWarningPatchVersion property value. Define the oldest recommended Android security patch level a user can have for secure access to the app. (Android only)
     * @param value Value to set for the minimumWarningPatchVersion property.
     */
    set minimumWarningPatchVersion(value: string | undefined);
    /**
     * Gets the screenCaptureBlocked property value. Indicates whether screen capture is blocked. (Android only)
     * @returns a boolean
     */
    get screenCaptureBlocked(): boolean | undefined;
    /**
     * Sets the screenCaptureBlocked property value. Indicates whether screen capture is blocked. (Android only)
     * @param value Value to set for the screenCaptureBlocked property.
     */
    set screenCaptureBlocked(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
