import { AndroidManagedAppProtection, DefaultManagedAppProtection, Entity, IosManagedAppProtection, ManagedAppPolicy, ManagedAppRegistration, ManagedAppStatus, ManagedDeviceMobileAppConfiguration, ManagedEBook, MdmWindowsInformationProtectionPolicy, MobileApp, MobileAppCategory, TargetedManagedAppConfiguration, VppToken, WindowsInformationProtectionPolicy } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Singleton entity that acts as a container for all device app management functionality.  */
export declare class DeviceAppManagement extends Entity implements Parsable {
    /** Android managed app policies.  */
    private _androidManagedAppProtections?;
    /** Default managed app policies.  */
    private _defaultManagedAppProtections?;
    /** iOS managed app policies.  */
    private _iosManagedAppProtections?;
    /** Whether the account is enabled for syncing applications from the Microsoft Store for Business.  */
    private _isEnabledForMicrosoftStoreForBusiness?;
    /** Managed app policies.  */
    private _managedAppPolicies?;
    /** The managed app registrations.  */
    private _managedAppRegistrations?;
    /** The managed app statuses.  */
    private _managedAppStatuses?;
    /** The Managed eBook.  */
    private _managedEBooks?;
    /** Windows information protection for apps running on devices which are MDM enrolled.  */
    private _mdmWindowsInformationProtectionPolicies?;
    /** The locale information used to sync applications from the Microsoft Store for Business. Cultures that are specific to a country/region. The names of these cultures follow RFC 4646 (Windows Vista and later). The format is -<country/regioncode2>, where  is a lowercase two-letter code derived from ISO 639-1 and <country/regioncode2> is an uppercase two-letter code derived from ISO 3166. For example, en-US for English (United States) is a specific culture.  */
    private _microsoftStoreForBusinessLanguage?;
    /** The last time an application sync from the Microsoft Store for Business was completed.  */
    private _microsoftStoreForBusinessLastCompletedApplicationSyncTime?;
    /** The last time the apps from the Microsoft Store for Business were synced successfully for the account.  */
    private _microsoftStoreForBusinessLastSuccessfulSyncDateTime?;
    /** The mobile app categories.  */
    private _mobileAppCategories?;
    /** The Managed Device Mobile Application Configurations.  */
    private _mobileAppConfigurations?;
    /** The mobile apps.  */
    private _mobileApps?;
    /** Targeted managed app configurations.  */
    private _targetedManagedAppConfigurations?;
    /** List of Vpp tokens for this organization.  */
    private _vppTokens?;
    /** Windows information protection for apps running on devices which are not MDM enrolled.  */
    private _windowsInformationProtectionPolicies?;
    /**
     * Gets the androidManagedAppProtections property value. Android managed app policies.
     * @returns a androidManagedAppProtection
     */
    get androidManagedAppProtections(): AndroidManagedAppProtection[] | undefined;
    /**
     * Sets the androidManagedAppProtections property value. Android managed app policies.
     * @param value Value to set for the androidManagedAppProtections property.
     */
    set androidManagedAppProtections(value: AndroidManagedAppProtection[] | undefined);
    /**
     * Instantiates a new deviceAppManagement and sets the default values.
     */
    constructor();
    /**
     * Gets the defaultManagedAppProtections property value. Default managed app policies.
     * @returns a defaultManagedAppProtection
     */
    get defaultManagedAppProtections(): DefaultManagedAppProtection[] | undefined;
    /**
     * Sets the defaultManagedAppProtections property value. Default managed app policies.
     * @param value Value to set for the defaultManagedAppProtections property.
     */
    set defaultManagedAppProtections(value: DefaultManagedAppProtection[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the iosManagedAppProtections property value. iOS managed app policies.
     * @returns a iosManagedAppProtection
     */
    get iosManagedAppProtections(): IosManagedAppProtection[] | undefined;
    /**
     * Sets the iosManagedAppProtections property value. iOS managed app policies.
     * @param value Value to set for the iosManagedAppProtections property.
     */
    set iosManagedAppProtections(value: IosManagedAppProtection[] | undefined);
    /**
     * Gets the isEnabledForMicrosoftStoreForBusiness property value. Whether the account is enabled for syncing applications from the Microsoft Store for Business.
     * @returns a boolean
     */
    get isEnabledForMicrosoftStoreForBusiness(): boolean | undefined;
    /**
     * Sets the isEnabledForMicrosoftStoreForBusiness property value. Whether the account is enabled for syncing applications from the Microsoft Store for Business.
     * @param value Value to set for the isEnabledForMicrosoftStoreForBusiness property.
     */
    set isEnabledForMicrosoftStoreForBusiness(value: boolean | undefined);
    /**
     * Gets the managedAppPolicies property value. Managed app policies.
     * @returns a managedAppPolicy
     */
    get managedAppPolicies(): ManagedAppPolicy[] | undefined;
    /**
     * Sets the managedAppPolicies property value. Managed app policies.
     * @param value Value to set for the managedAppPolicies property.
     */
    set managedAppPolicies(value: ManagedAppPolicy[] | undefined);
    /**
     * Gets the managedAppRegistrations property value. The managed app registrations.
     * @returns a managedAppRegistration
     */
    get managedAppRegistrations(): ManagedAppRegistration[] | undefined;
    /**
     * Sets the managedAppRegistrations property value. The managed app registrations.
     * @param value Value to set for the managedAppRegistrations property.
     */
    set managedAppRegistrations(value: ManagedAppRegistration[] | undefined);
    /**
     * Gets the managedAppStatuses property value. The managed app statuses.
     * @returns a managedAppStatus
     */
    get managedAppStatuses(): ManagedAppStatus[] | undefined;
    /**
     * Sets the managedAppStatuses property value. The managed app statuses.
     * @param value Value to set for the managedAppStatuses property.
     */
    set managedAppStatuses(value: ManagedAppStatus[] | undefined);
    /**
     * Gets the managedEBooks property value. The Managed eBook.
     * @returns a managedEBook
     */
    get managedEBooks(): ManagedEBook[] | undefined;
    /**
     * Sets the managedEBooks property value. The Managed eBook.
     * @param value Value to set for the managedEBooks property.
     */
    set managedEBooks(value: ManagedEBook[] | undefined);
    /**
     * Gets the mdmWindowsInformationProtectionPolicies property value. Windows information protection for apps running on devices which are MDM enrolled.
     * @returns a mdmWindowsInformationProtectionPolicy
     */
    get mdmWindowsInformationProtectionPolicies(): MdmWindowsInformationProtectionPolicy[] | undefined;
    /**
     * Sets the mdmWindowsInformationProtectionPolicies property value. Windows information protection for apps running on devices which are MDM enrolled.
     * @param value Value to set for the mdmWindowsInformationProtectionPolicies property.
     */
    set mdmWindowsInformationProtectionPolicies(value: MdmWindowsInformationProtectionPolicy[] | undefined);
    /**
     * Gets the microsoftStoreForBusinessLanguage property value. The locale information used to sync applications from the Microsoft Store for Business. Cultures that are specific to a country/region. The names of these cultures follow RFC 4646 (Windows Vista and later). The format is -<country/regioncode2>, where  is a lowercase two-letter code derived from ISO 639-1 and <country/regioncode2> is an uppercase two-letter code derived from ISO 3166. For example, en-US for English (United States) is a specific culture.
     * @returns a string
     */
    get microsoftStoreForBusinessLanguage(): string | undefined;
    /**
     * Sets the microsoftStoreForBusinessLanguage property value. The locale information used to sync applications from the Microsoft Store for Business. Cultures that are specific to a country/region. The names of these cultures follow RFC 4646 (Windows Vista and later). The format is -<country/regioncode2>, where  is a lowercase two-letter code derived from ISO 639-1 and <country/regioncode2> is an uppercase two-letter code derived from ISO 3166. For example, en-US for English (United States) is a specific culture.
     * @param value Value to set for the microsoftStoreForBusinessLanguage property.
     */
    set microsoftStoreForBusinessLanguage(value: string | undefined);
    /**
     * Gets the microsoftStoreForBusinessLastCompletedApplicationSyncTime property value. The last time an application sync from the Microsoft Store for Business was completed.
     * @returns a Date
     */
    get microsoftStoreForBusinessLastCompletedApplicationSyncTime(): Date | undefined;
    /**
     * Sets the microsoftStoreForBusinessLastCompletedApplicationSyncTime property value. The last time an application sync from the Microsoft Store for Business was completed.
     * @param value Value to set for the microsoftStoreForBusinessLastCompletedApplicationSyncTime property.
     */
    set microsoftStoreForBusinessLastCompletedApplicationSyncTime(value: Date | undefined);
    /**
     * Gets the microsoftStoreForBusinessLastSuccessfulSyncDateTime property value. The last time the apps from the Microsoft Store for Business were synced successfully for the account.
     * @returns a Date
     */
    get microsoftStoreForBusinessLastSuccessfulSyncDateTime(): Date | undefined;
    /**
     * Sets the microsoftStoreForBusinessLastSuccessfulSyncDateTime property value. The last time the apps from the Microsoft Store for Business were synced successfully for the account.
     * @param value Value to set for the microsoftStoreForBusinessLastSuccessfulSyncDateTime property.
     */
    set microsoftStoreForBusinessLastSuccessfulSyncDateTime(value: Date | undefined);
    /**
     * Gets the mobileAppCategories property value. The mobile app categories.
     * @returns a mobileAppCategory
     */
    get mobileAppCategories(): MobileAppCategory[] | undefined;
    /**
     * Sets the mobileAppCategories property value. The mobile app categories.
     * @param value Value to set for the mobileAppCategories property.
     */
    set mobileAppCategories(value: MobileAppCategory[] | undefined);
    /**
     * Gets the mobileAppConfigurations property value. The Managed Device Mobile Application Configurations.
     * @returns a managedDeviceMobileAppConfiguration
     */
    get mobileAppConfigurations(): ManagedDeviceMobileAppConfiguration[] | undefined;
    /**
     * Sets the mobileAppConfigurations property value. The Managed Device Mobile Application Configurations.
     * @param value Value to set for the mobileAppConfigurations property.
     */
    set mobileAppConfigurations(value: ManagedDeviceMobileAppConfiguration[] | undefined);
    /**
     * Gets the mobileApps property value. The mobile apps.
     * @returns a mobileApp
     */
    get mobileApps(): MobileApp[] | undefined;
    /**
     * Sets the mobileApps property value. The mobile apps.
     * @param value Value to set for the mobileApps property.
     */
    set mobileApps(value: MobileApp[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the targetedManagedAppConfigurations property value. Targeted managed app configurations.
     * @returns a targetedManagedAppConfiguration
     */
    get targetedManagedAppConfigurations(): TargetedManagedAppConfiguration[] | undefined;
    /**
     * Sets the targetedManagedAppConfigurations property value. Targeted managed app configurations.
     * @param value Value to set for the targetedManagedAppConfigurations property.
     */
    set targetedManagedAppConfigurations(value: TargetedManagedAppConfiguration[] | undefined);
    /**
     * Gets the vppTokens property value. List of Vpp tokens for this organization.
     * @returns a vppToken
     */
    get vppTokens(): VppToken[] | undefined;
    /**
     * Sets the vppTokens property value. List of Vpp tokens for this organization.
     * @param value Value to set for the vppTokens property.
     */
    set vppTokens(value: VppToken[] | undefined);
    /**
     * Gets the windowsInformationProtectionPolicies property value. Windows information protection for apps running on devices which are not MDM enrolled.
     * @returns a windowsInformationProtectionPolicy
     */
    get windowsInformationProtectionPolicies(): WindowsInformationProtectionPolicy[] | undefined;
    /**
     * Sets the windowsInformationProtectionPolicies property value. Windows information protection for apps running on devices which are not MDM enrolled.
     * @param value Value to set for the windowsInformationProtectionPolicies property.
     */
    set windowsInformationProtectionPolicies(value: WindowsInformationProtectionPolicy[] | undefined);
}
