import { ComplianceStatus } from './complianceStatus';
import { SettingSource } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Device Configuration Setting State for a given device.  */
export declare class DeviceConfigurationSettingState implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.  */
    private _additionalData;
    /** Current value of setting on device  */
    private _currentValue?;
    /** Error code for the setting  */
    private _errorCode?;
    /** Error description  */
    private _errorDescription?;
    /** Name of setting instance that is being reported.  */
    private _instanceDisplayName?;
    /** The setting that is being reported  */
    private _setting?;
    /** Localized/user friendly setting name that is being reported  */
    private _settingName?;
    /** Contributing policies  */
    private _sources?;
    /** The compliance state of the setting. Possible values are: unknown, notApplicable, compliant, remediated, nonCompliant, error, conflict, notAssigned.  */
    private _state?;
    /** UserEmail  */
    private _userEmail?;
    /** UserId  */
    private _userId?;
    /** UserName  */
    private _userName?;
    /** UserPrincipalName.  */
    private _userPrincipalName?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Instantiates a new deviceConfigurationSettingState and sets the default values.
     */
    constructor();
    /**
     * Gets the currentValue property value. Current value of setting on device
     * @returns a string
     */
    get currentValue(): string | undefined;
    /**
     * Sets the currentValue property value. Current value of setting on device
     * @param value Value to set for the currentValue property.
     */
    set currentValue(value: string | undefined);
    /**
     * Gets the errorCode property value. Error code for the setting
     * @returns a int64
     */
    get errorCode(): number | undefined;
    /**
     * Sets the errorCode property value. Error code for the setting
     * @param value Value to set for the errorCode property.
     */
    set errorCode(value: number | undefined);
    /**
     * Gets the errorDescription property value. Error description
     * @returns a string
     */
    get errorDescription(): string | undefined;
    /**
     * Sets the errorDescription property value. Error description
     * @param value Value to set for the errorDescription property.
     */
    set errorDescription(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the instanceDisplayName property value. Name of setting instance that is being reported.
     * @returns a string
     */
    get instanceDisplayName(): string | undefined;
    /**
     * Sets the instanceDisplayName property value. Name of setting instance that is being reported.
     * @param value Value to set for the instanceDisplayName property.
     */
    set instanceDisplayName(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the setting property value. The setting that is being reported
     * @returns a string
     */
    get setting(): string | undefined;
    /**
     * Sets the setting property value. The setting that is being reported
     * @param value Value to set for the setting property.
     */
    set setting(value: string | undefined);
    /**
     * Gets the settingName property value. Localized/user friendly setting name that is being reported
     * @returns a string
     */
    get settingName(): string | undefined;
    /**
     * Sets the settingName property value. Localized/user friendly setting name that is being reported
     * @param value Value to set for the settingName property.
     */
    set settingName(value: string | undefined);
    /**
     * Gets the sources property value. Contributing policies
     * @returns a settingSource
     */
    get sources(): SettingSource[] | undefined;
    /**
     * Sets the sources property value. Contributing policies
     * @param value Value to set for the sources property.
     */
    set sources(value: SettingSource[] | undefined);
    /**
     * Gets the state property value. The compliance state of the setting. Possible values are: unknown, notApplicable, compliant, remediated, nonCompliant, error, conflict, notAssigned.
     * @returns a complianceStatus
     */
    get state(): ComplianceStatus | undefined;
    /**
     * Sets the state property value. The compliance state of the setting. Possible values are: unknown, notApplicable, compliant, remediated, nonCompliant, error, conflict, notAssigned.
     * @param value Value to set for the state property.
     */
    set state(value: ComplianceStatus | undefined);
    /**
     * Gets the userEmail property value. UserEmail
     * @returns a string
     */
    get userEmail(): string | undefined;
    /**
     * Sets the userEmail property value. UserEmail
     * @param value Value to set for the userEmail property.
     */
    set userEmail(value: string | undefined);
    /**
     * Gets the userId property value. UserId
     * @returns a string
     */
    get userId(): string | undefined;
    /**
     * Sets the userId property value. UserId
     * @param value Value to set for the userId property.
     */
    set userId(value: string | undefined);
    /**
     * Gets the userName property value. UserName
     * @returns a string
     */
    get userName(): string | undefined;
    /**
     * Sets the userName property value. UserName
     * @param value Value to set for the userName property.
     */
    set userName(value: string | undefined);
    /**
     * Gets the userPrincipalName property value. UserPrincipalName.
     * @returns a string
     */
    get userPrincipalName(): string | undefined;
    /**
     * Sets the userPrincipalName property value. UserPrincipalName.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value: string | undefined);
}
