import { DeviceManagementExchangeConnectorStatus } from './deviceManagementExchangeConnectorStatus';
import { DeviceManagementExchangeConnectorType } from './deviceManagementExchangeConnectorType';
import { Entity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class DeviceManagementExchangeConnector extends Entity implements Parsable {
    /** The name of the server hosting the Exchange Connector.  */
    private _connectorServerName?;
    /** An alias assigned to the Exchange server  */
    private _exchangeAlias?;
    /** The type of Exchange Connector Configured. Possible values are: onPremises, hosted, serviceToService, dedicated.  */
    private _exchangeConnectorType?;
    /** Exchange Organization to the Exchange server  */
    private _exchangeOrganization?;
    /** Last sync time for the Exchange Connector  */
    private _lastSyncDateTime?;
    /** Email address used to configure the Service To Service Exchange Connector.  */
    private _primarySmtpAddress?;
    /** The name of the Exchange server.  */
    private _serverName?;
    /** Exchange Connector Status. Possible values are: none, connectionPending, connected, disconnected.  */
    private _status?;
    /** The version of the ExchangeConnectorAgent  */
    private _version?;
    /**
     * Gets the connectorServerName property value. The name of the server hosting the Exchange Connector.
     * @returns a string
     */
    get connectorServerName(): string | undefined;
    /**
     * Sets the connectorServerName property value. The name of the server hosting the Exchange Connector.
     * @param value Value to set for the connectorServerName property.
     */
    set connectorServerName(value: string | undefined);
    /**
     * Instantiates a new deviceManagementExchangeConnector and sets the default values.
     */
    constructor();
    /**
     * Gets the exchangeAlias property value. An alias assigned to the Exchange server
     * @returns a string
     */
    get exchangeAlias(): string | undefined;
    /**
     * Sets the exchangeAlias property value. An alias assigned to the Exchange server
     * @param value Value to set for the exchangeAlias property.
     */
    set exchangeAlias(value: string | undefined);
    /**
     * Gets the exchangeConnectorType property value. The type of Exchange Connector Configured. Possible values are: onPremises, hosted, serviceToService, dedicated.
     * @returns a deviceManagementExchangeConnectorType
     */
    get exchangeConnectorType(): DeviceManagementExchangeConnectorType | undefined;
    /**
     * Sets the exchangeConnectorType property value. The type of Exchange Connector Configured. Possible values are: onPremises, hosted, serviceToService, dedicated.
     * @param value Value to set for the exchangeConnectorType property.
     */
    set exchangeConnectorType(value: DeviceManagementExchangeConnectorType | undefined);
    /**
     * Gets the exchangeOrganization property value. Exchange Organization to the Exchange server
     * @returns a string
     */
    get exchangeOrganization(): string | undefined;
    /**
     * Sets the exchangeOrganization property value. Exchange Organization to the Exchange server
     * @param value Value to set for the exchangeOrganization property.
     */
    set exchangeOrganization(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the lastSyncDateTime property value. Last sync time for the Exchange Connector
     * @returns a Date
     */
    get lastSyncDateTime(): Date | undefined;
    /**
     * Sets the lastSyncDateTime property value. Last sync time for the Exchange Connector
     * @param value Value to set for the lastSyncDateTime property.
     */
    set lastSyncDateTime(value: Date | undefined);
    /**
     * Gets the primarySmtpAddress property value. Email address used to configure the Service To Service Exchange Connector.
     * @returns a string
     */
    get primarySmtpAddress(): string | undefined;
    /**
     * Sets the primarySmtpAddress property value. Email address used to configure the Service To Service Exchange Connector.
     * @param value Value to set for the primarySmtpAddress property.
     */
    set primarySmtpAddress(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the serverName property value. The name of the Exchange server.
     * @returns a string
     */
    get serverName(): string | undefined;
    /**
     * Sets the serverName property value. The name of the Exchange server.
     * @param value Value to set for the serverName property.
     */
    set serverName(value: string | undefined);
    /**
     * Gets the status property value. Exchange Connector Status. Possible values are: none, connectionPending, connected, disconnected.
     * @returns a deviceManagementExchangeConnectorStatus
     */
    get status(): DeviceManagementExchangeConnectorStatus | undefined;
    /**
     * Sets the status property value. Exchange Connector Status. Possible values are: none, connectionPending, connected, disconnected.
     * @param value Value to set for the status property.
     */
    set status(value: DeviceManagementExchangeConnectorStatus | undefined);
    /**
     * Gets the version property value. The version of the ExchangeConnectorAgent
     * @returns a string
     */
    get version(): string | undefined;
    /**
     * Sets the version property value. The version of the ExchangeConnectorAgent
     * @param value Value to set for the version property.
     */
    set version(value: string | undefined);
}
