import { DeviceManagementExportJobLocalizationType } from './deviceManagementExportJobLocalizationType';
import { DeviceManagementReportFileFormat } from './deviceManagementReportFileFormat';
import { DeviceManagementReportStatus } from './deviceManagementReportStatus';
import { Entity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class DeviceManagementExportJob extends Entity implements Parsable {
    /** Time that the exported report expires  */
    private _expirationDateTime?;
    /** Filters applied on the report  */
    private _filter?;
    /** Format of the exported report. Possible values are: csv, pdf.  */
    private _format?;
    /** Configures how the requested export job is localized. Possible values are: localizedValuesAsAdditionalColumn, replaceLocalizableValues.  */
    private _localizationType?;
    /** Name of the report  */
    private _reportName?;
    /** Time that the exported report was requested  */
    private _requestDateTime?;
    /** Columns selected from the report  */
    private _select?;
    /** A snapshot is an identifiable subset of the dataset represented by the ReportName. A sessionId or CachedReportConfiguration id can be used here. If a sessionId is specified, Filter, Select, and OrderBy are applied to the data represented by the sessionId. Filter, Select, and OrderBy cannot be specified together with a CachedReportConfiguration id.  */
    private _snapshotId?;
    /** Status of the export job. Possible values are: unknown, notStarted, inProgress, completed, failed.  */
    private _status?;
    /** Temporary location of the exported report  */
    private _url?;
    /**
     * Instantiates a new deviceManagementExportJob and sets the default values.
     */
    constructor();
    /**
     * Gets the expirationDateTime property value. Time that the exported report expires
     * @returns a Date
     */
    get expirationDateTime(): Date | undefined;
    /**
     * Sets the expirationDateTime property value. Time that the exported report expires
     * @param value Value to set for the expirationDateTime property.
     */
    set expirationDateTime(value: Date | undefined);
    /**
     * Gets the filter property value. Filters applied on the report
     * @returns a string
     */
    get filter(): string | undefined;
    /**
     * Sets the filter property value. Filters applied on the report
     * @param value Value to set for the filter property.
     */
    set filter(value: string | undefined);
    /**
     * Gets the format property value. Format of the exported report. Possible values are: csv, pdf.
     * @returns a deviceManagementReportFileFormat
     */
    get format(): DeviceManagementReportFileFormat | undefined;
    /**
     * Sets the format property value. Format of the exported report. Possible values are: csv, pdf.
     * @param value Value to set for the format property.
     */
    set format(value: DeviceManagementReportFileFormat | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the localizationType property value. Configures how the requested export job is localized. Possible values are: localizedValuesAsAdditionalColumn, replaceLocalizableValues.
     * @returns a deviceManagementExportJobLocalizationType
     */
    get localizationType(): DeviceManagementExportJobLocalizationType | undefined;
    /**
     * Sets the localizationType property value. Configures how the requested export job is localized. Possible values are: localizedValuesAsAdditionalColumn, replaceLocalizableValues.
     * @param value Value to set for the localizationType property.
     */
    set localizationType(value: DeviceManagementExportJobLocalizationType | undefined);
    /**
     * Gets the reportName property value. Name of the report
     * @returns a string
     */
    get reportName(): string | undefined;
    /**
     * Sets the reportName property value. Name of the report
     * @param value Value to set for the reportName property.
     */
    set reportName(value: string | undefined);
    /**
     * Gets the requestDateTime property value. Time that the exported report was requested
     * @returns a Date
     */
    get requestDateTime(): Date | undefined;
    /**
     * Sets the requestDateTime property value. Time that the exported report was requested
     * @param value Value to set for the requestDateTime property.
     */
    set requestDateTime(value: Date | undefined);
    /**
     * Gets the select property value. Columns selected from the report
     * @returns a string
     */
    get select(): string[] | undefined;
    /**
     * Sets the select property value. Columns selected from the report
     * @param value Value to set for the select property.
     */
    set select(value: string[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the snapshotId property value. A snapshot is an identifiable subset of the dataset represented by the ReportName. A sessionId or CachedReportConfiguration id can be used here. If a sessionId is specified, Filter, Select, and OrderBy are applied to the data represented by the sessionId. Filter, Select, and OrderBy cannot be specified together with a CachedReportConfiguration id.
     * @returns a string
     */
    get snapshotId(): string | undefined;
    /**
     * Sets the snapshotId property value. A snapshot is an identifiable subset of the dataset represented by the ReportName. A sessionId or CachedReportConfiguration id can be used here. If a sessionId is specified, Filter, Select, and OrderBy are applied to the data represented by the sessionId. Filter, Select, and OrderBy cannot be specified together with a CachedReportConfiguration id.
     * @param value Value to set for the snapshotId property.
     */
    set snapshotId(value: string | undefined);
    /**
     * Gets the status property value. Status of the export job. Possible values are: unknown, notStarted, inProgress, completed, failed.
     * @returns a deviceManagementReportStatus
     */
    get status(): DeviceManagementReportStatus | undefined;
    /**
     * Sets the status property value. Status of the export job. Possible values are: unknown, notStarted, inProgress, completed, failed.
     * @param value Value to set for the status property.
     */
    set status(value: DeviceManagementReportStatus | undefined);
    /**
     * Gets the url property value. Temporary location of the exported report
     * @returns a string
     */
    get url(): string | undefined;
    /**
     * Sets the url property value. Temporary location of the exported report
     * @param value Value to set for the url property.
     */
    set url(value: string | undefined);
}
