import { DirectoryObject, DomainDnsRecord, DomainState, Entity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Domain extends Entity implements Parsable {
    /** Indicates the configured authentication type for the domain. The value is either Managed or Federated. Managed indicates a cloud managed domain where Azure AD performs user authentication. Federated indicates authentication is federated with an identity provider such as the tenant's on-premises Active Directory via Active Directory Federation Services. This property is read-only and is not nullable.  */
    private _authenticationType?;
    /** This property is always null except when the verify action is used. When the verify action is used, a domain entity is returned in the response. The availabilityStatus property of the domain entity in the response is either AvailableImmediately or EmailVerifiedDomainTakeoverScheduled.  */
    private _availabilityStatus?;
    /** Read-only, Nullable  */
    private _domainNameReferences?;
    /** The value of the property is false if the DNS record management of the domain has been delegated to Microsoft 365. Otherwise, the value is true. Not nullable  */
    private _isAdminManaged?;
    /** true if this is the default domain that is used for user creation. There is only one default domain per company. Not nullable  */
    private _isDefault?;
    /** true if this is the initial domain created by Microsoft Online Services (companyname.onmicrosoft.com). There is only one initial domain per company. Not nullable  */
    private _isInitial?;
    /** true if the domain is a verified root domain. Otherwise, false if the domain is a subdomain or unverified. Not nullable  */
    private _isRoot?;
    /** true if the domain has completed domain ownership verification. Not nullable  */
    private _isVerified?;
    private _manufacturer?;
    private _model?;
    /** Specifies the number of days before a user receives notification that their password will expire. If the property is not set, a default value of 14 days will be used.  */
    private _passwordNotificationWindowInDays?;
    /** Specifies the length of time that a password is valid before it must be changed. If the property is not set, a default value of 90 days will be used.  */
    private _passwordValidityPeriodInDays?;
    /** DNS records the customer adds to the DNS zone file of the domain before the domain can be used by Microsoft Online services. Read-only, Nullable  */
    private _serviceConfigurationRecords?;
    /** Status of asynchronous operations scheduled for the domain.  */
    private _state?;
    /** The capabilities assigned to the domain. Can include 0, 1 or more of following values: Email, Sharepoint, EmailInternalRelayOnly, OfficeCommunicationsOnline, SharePointDefaultDomain, FullRedelegation, SharePointPublic, OrgIdAuthentication, Yammer, Intune. The values which you can add/remove using Graph API include: Email, OfficeCommunicationsOnline, Yammer. Not nullable  */
    private _supportedServices?;
    /** DNS records that the customer adds to the DNS zone file of the domain before the customer can complete domain ownership verification with Azure AD. Read-only, Nullable  */
    private _verificationDnsRecords?;
    /**
     * Gets the authenticationType property value. Indicates the configured authentication type for the domain. The value is either Managed or Federated. Managed indicates a cloud managed domain where Azure AD performs user authentication. Federated indicates authentication is federated with an identity provider such as the tenant's on-premises Active Directory via Active Directory Federation Services. This property is read-only and is not nullable.
     * @returns a string
     */
    get authenticationType(): string | undefined;
    /**
     * Sets the authenticationType property value. Indicates the configured authentication type for the domain. The value is either Managed or Federated. Managed indicates a cloud managed domain where Azure AD performs user authentication. Federated indicates authentication is federated with an identity provider such as the tenant's on-premises Active Directory via Active Directory Federation Services. This property is read-only and is not nullable.
     * @param value Value to set for the authenticationType property.
     */
    set authenticationType(value: string | undefined);
    /**
     * Gets the availabilityStatus property value. This property is always null except when the verify action is used. When the verify action is used, a domain entity is returned in the response. The availabilityStatus property of the domain entity in the response is either AvailableImmediately or EmailVerifiedDomainTakeoverScheduled.
     * @returns a string
     */
    get availabilityStatus(): string | undefined;
    /**
     * Sets the availabilityStatus property value. This property is always null except when the verify action is used. When the verify action is used, a domain entity is returned in the response. The availabilityStatus property of the domain entity in the response is either AvailableImmediately or EmailVerifiedDomainTakeoverScheduled.
     * @param value Value to set for the availabilityStatus property.
     */
    set availabilityStatus(value: string | undefined);
    /**
     * Instantiates a new domain and sets the default values.
     */
    constructor();
    /**
     * Gets the domainNameReferences property value. Read-only, Nullable
     * @returns a directoryObject
     */
    get domainNameReferences(): DirectoryObject[] | undefined;
    /**
     * Sets the domainNameReferences property value. Read-only, Nullable
     * @param value Value to set for the domainNameReferences property.
     */
    set domainNameReferences(value: DirectoryObject[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isAdminManaged property value. The value of the property is false if the DNS record management of the domain has been delegated to Microsoft 365. Otherwise, the value is true. Not nullable
     * @returns a boolean
     */
    get isAdminManaged(): boolean | undefined;
    /**
     * Sets the isAdminManaged property value. The value of the property is false if the DNS record management of the domain has been delegated to Microsoft 365. Otherwise, the value is true. Not nullable
     * @param value Value to set for the isAdminManaged property.
     */
    set isAdminManaged(value: boolean | undefined);
    /**
     * Gets the isDefault property value. true if this is the default domain that is used for user creation. There is only one default domain per company. Not nullable
     * @returns a boolean
     */
    get isDefault(): boolean | undefined;
    /**
     * Sets the isDefault property value. true if this is the default domain that is used for user creation. There is only one default domain per company. Not nullable
     * @param value Value to set for the isDefault property.
     */
    set isDefault(value: boolean | undefined);
    /**
     * Gets the isInitial property value. true if this is the initial domain created by Microsoft Online Services (companyname.onmicrosoft.com). There is only one initial domain per company. Not nullable
     * @returns a boolean
     */
    get isInitial(): boolean | undefined;
    /**
     * Sets the isInitial property value. true if this is the initial domain created by Microsoft Online Services (companyname.onmicrosoft.com). There is only one initial domain per company. Not nullable
     * @param value Value to set for the isInitial property.
     */
    set isInitial(value: boolean | undefined);
    /**
     * Gets the isRoot property value. true if the domain is a verified root domain. Otherwise, false if the domain is a subdomain or unverified. Not nullable
     * @returns a boolean
     */
    get isRoot(): boolean | undefined;
    /**
     * Sets the isRoot property value. true if the domain is a verified root domain. Otherwise, false if the domain is a subdomain or unverified. Not nullable
     * @param value Value to set for the isRoot property.
     */
    set isRoot(value: boolean | undefined);
    /**
     * Gets the isVerified property value. true if the domain has completed domain ownership verification. Not nullable
     * @returns a boolean
     */
    get isVerified(): boolean | undefined;
    /**
     * Sets the isVerified property value. true if the domain has completed domain ownership verification. Not nullable
     * @param value Value to set for the isVerified property.
     */
    set isVerified(value: boolean | undefined);
    /**
     * Gets the manufacturer property value.
     * @returns a string
     */
    get manufacturer(): string | undefined;
    /**
     * Sets the manufacturer property value.
     * @param value Value to set for the manufacturer property.
     */
    set manufacturer(value: string | undefined);
    /**
     * Gets the model property value.
     * @returns a string
     */
    get model(): string | undefined;
    /**
     * Sets the model property value.
     * @param value Value to set for the model property.
     */
    set model(value: string | undefined);
    /**
     * Gets the passwordNotificationWindowInDays property value. Specifies the number of days before a user receives notification that their password will expire. If the property is not set, a default value of 14 days will be used.
     * @returns a integer
     */
    get passwordNotificationWindowInDays(): number | undefined;
    /**
     * Sets the passwordNotificationWindowInDays property value. Specifies the number of days before a user receives notification that their password will expire. If the property is not set, a default value of 14 days will be used.
     * @param value Value to set for the passwordNotificationWindowInDays property.
     */
    set passwordNotificationWindowInDays(value: number | undefined);
    /**
     * Gets the passwordValidityPeriodInDays property value. Specifies the length of time that a password is valid before it must be changed. If the property is not set, a default value of 90 days will be used.
     * @returns a integer
     */
    get passwordValidityPeriodInDays(): number | undefined;
    /**
     * Sets the passwordValidityPeriodInDays property value. Specifies the length of time that a password is valid before it must be changed. If the property is not set, a default value of 90 days will be used.
     * @param value Value to set for the passwordValidityPeriodInDays property.
     */
    set passwordValidityPeriodInDays(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the serviceConfigurationRecords property value. DNS records the customer adds to the DNS zone file of the domain before the domain can be used by Microsoft Online services. Read-only, Nullable
     * @returns a domainDnsRecord
     */
    get serviceConfigurationRecords(): DomainDnsRecord[] | undefined;
    /**
     * Sets the serviceConfigurationRecords property value. DNS records the customer adds to the DNS zone file of the domain before the domain can be used by Microsoft Online services. Read-only, Nullable
     * @param value Value to set for the serviceConfigurationRecords property.
     */
    set serviceConfigurationRecords(value: DomainDnsRecord[] | undefined);
    /**
     * Gets the state property value. Status of asynchronous operations scheduled for the domain.
     * @returns a domainState
     */
    get state(): DomainState | undefined;
    /**
     * Sets the state property value. Status of asynchronous operations scheduled for the domain.
     * @param value Value to set for the state property.
     */
    set state(value: DomainState | undefined);
    /**
     * Gets the supportedServices property value. The capabilities assigned to the domain. Can include 0, 1 or more of following values: Email, Sharepoint, EmailInternalRelayOnly, OfficeCommunicationsOnline, SharePointDefaultDomain, FullRedelegation, SharePointPublic, OrgIdAuthentication, Yammer, Intune. The values which you can add/remove using Graph API include: Email, OfficeCommunicationsOnline, Yammer. Not nullable
     * @returns a string
     */
    get supportedServices(): string[] | undefined;
    /**
     * Sets the supportedServices property value. The capabilities assigned to the domain. Can include 0, 1 or more of following values: Email, Sharepoint, EmailInternalRelayOnly, OfficeCommunicationsOnline, SharePointDefaultDomain, FullRedelegation, SharePointPublic, OrgIdAuthentication, Yammer, Intune. The values which you can add/remove using Graph API include: Email, OfficeCommunicationsOnline, Yammer. Not nullable
     * @param value Value to set for the supportedServices property.
     */
    set supportedServices(value: string[] | undefined);
    /**
     * Gets the verificationDnsRecords property value. DNS records that the customer adds to the DNS zone file of the domain before the customer can complete domain ownership verification with Azure AD. Read-only, Nullable
     * @returns a domainDnsRecord
     */
    get verificationDnsRecords(): DomainDnsRecord[] | undefined;
    /**
     * Sets the verificationDnsRecords property value. DNS records that the customer adds to the DNS zone file of the domain before the customer can complete domain ownership verification with Azure AD. Read-only, Nullable
     * @param value Value to set for the verificationDnsRecords property.
     */
    set verificationDnsRecords(value: DomainDnsRecord[] | undefined);
}
