"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Domain = void 0;
const createDirectoryObjectFromDiscriminatorValue_1 = require("./createDirectoryObjectFromDiscriminatorValue");
const createDomainDnsRecordFromDiscriminatorValue_1 = require("./createDomainDnsRecordFromDiscriminatorValue");
const createDomainStateFromDiscriminatorValue_1 = require("./createDomainStateFromDiscriminatorValue");
const index_1 = require("./index");
class Domain extends index_1.Entity {
    /**
     * Instantiates a new domain and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the authenticationType property value. Indicates the configured authentication type for the domain. The value is either Managed or Federated. Managed indicates a cloud managed domain where Azure AD performs user authentication. Federated indicates authentication is federated with an identity provider such as the tenant's on-premises Active Directory via Active Directory Federation Services. This property is read-only and is not nullable.
     * @returns a string
     */
    get authenticationType() {
        return this._authenticationType;
    }
    ;
    /**
     * Sets the authenticationType property value. Indicates the configured authentication type for the domain. The value is either Managed or Federated. Managed indicates a cloud managed domain where Azure AD performs user authentication. Federated indicates authentication is federated with an identity provider such as the tenant's on-premises Active Directory via Active Directory Federation Services. This property is read-only and is not nullable.
     * @param value Value to set for the authenticationType property.
     */
    set authenticationType(value) {
        this._authenticationType = value;
    }
    ;
    /**
     * Gets the availabilityStatus property value. This property is always null except when the verify action is used. When the verify action is used, a domain entity is returned in the response. The availabilityStatus property of the domain entity in the response is either AvailableImmediately or EmailVerifiedDomainTakeoverScheduled.
     * @returns a string
     */
    get availabilityStatus() {
        return this._availabilityStatus;
    }
    ;
    /**
     * Sets the availabilityStatus property value. This property is always null except when the verify action is used. When the verify action is used, a domain entity is returned in the response. The availabilityStatus property of the domain entity in the response is either AvailableImmediately or EmailVerifiedDomainTakeoverScheduled.
     * @param value Value to set for the availabilityStatus property.
     */
    set availabilityStatus(value) {
        this._availabilityStatus = value;
    }
    ;
    ;
    /**
     * Gets the domainNameReferences property value. Read-only, Nullable
     * @returns a directoryObject
     */
    get domainNameReferences() {
        return this._domainNameReferences;
    }
    ;
    /**
     * Sets the domainNameReferences property value. Read-only, Nullable
     * @param value Value to set for the domainNameReferences property.
     */
    set domainNameReferences(value) {
        this._domainNameReferences = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "authenticationType": (o, n) => { o.authenticationType = n.getStringValue(); }, "availabilityStatus": (o, n) => { o.availabilityStatus = n.getStringValue(); }, "domainNameReferences": (o, n) => { o.domainNameReferences = n.getCollectionOfObjectValues(createDirectoryObjectFromDiscriminatorValue_1.createDirectoryObjectFromDiscriminatorValue); }, "isAdminManaged": (o, n) => { o.isAdminManaged = n.getBooleanValue(); }, "isDefault": (o, n) => { o.isDefault = n.getBooleanValue(); }, "isInitial": (o, n) => { o.isInitial = n.getBooleanValue(); }, "isRoot": (o, n) => { o.isRoot = n.getBooleanValue(); }, "isVerified": (o, n) => { o.isVerified = n.getBooleanValue(); }, "manufacturer": (o, n) => { o.manufacturer = n.getStringValue(); }, "model": (o, n) => { o.model = n.getStringValue(); }, "passwordNotificationWindowInDays": (o, n) => { o.passwordNotificationWindowInDays = n.getNumberValue(); }, "passwordValidityPeriodInDays": (o, n) => { o.passwordValidityPeriodInDays = n.getNumberValue(); }, "serviceConfigurationRecords": (o, n) => { o.serviceConfigurationRecords = n.getCollectionOfObjectValues(createDomainDnsRecordFromDiscriminatorValue_1.createDomainDnsRecordFromDiscriminatorValue); }, "state": (o, n) => { o.state = n.getObjectValue(createDomainStateFromDiscriminatorValue_1.createDomainStateFromDiscriminatorValue); }, "supportedServices": (o, n) => { o.supportedServices = n.getCollectionOfPrimitiveValues(); }, "verificationDnsRecords": (o, n) => { o.verificationDnsRecords = n.getCollectionOfObjectValues(createDomainDnsRecordFromDiscriminatorValue_1.createDomainDnsRecordFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the isAdminManaged property value. The value of the property is false if the DNS record management of the domain has been delegated to Microsoft 365. Otherwise, the value is true. Not nullable
     * @returns a boolean
     */
    get isAdminManaged() {
        return this._isAdminManaged;
    }
    ;
    /**
     * Sets the isAdminManaged property value. The value of the property is false if the DNS record management of the domain has been delegated to Microsoft 365. Otherwise, the value is true. Not nullable
     * @param value Value to set for the isAdminManaged property.
     */
    set isAdminManaged(value) {
        this._isAdminManaged = value;
    }
    ;
    /**
     * Gets the isDefault property value. true if this is the default domain that is used for user creation. There is only one default domain per company. Not nullable
     * @returns a boolean
     */
    get isDefault() {
        return this._isDefault;
    }
    ;
    /**
     * Sets the isDefault property value. true if this is the default domain that is used for user creation. There is only one default domain per company. Not nullable
     * @param value Value to set for the isDefault property.
     */
    set isDefault(value) {
        this._isDefault = value;
    }
    ;
    /**
     * Gets the isInitial property value. true if this is the initial domain created by Microsoft Online Services (companyname.onmicrosoft.com). There is only one initial domain per company. Not nullable
     * @returns a boolean
     */
    get isInitial() {
        return this._isInitial;
    }
    ;
    /**
     * Sets the isInitial property value. true if this is the initial domain created by Microsoft Online Services (companyname.onmicrosoft.com). There is only one initial domain per company. Not nullable
     * @param value Value to set for the isInitial property.
     */
    set isInitial(value) {
        this._isInitial = value;
    }
    ;
    /**
     * Gets the isRoot property value. true if the domain is a verified root domain. Otherwise, false if the domain is a subdomain or unverified. Not nullable
     * @returns a boolean
     */
    get isRoot() {
        return this._isRoot;
    }
    ;
    /**
     * Sets the isRoot property value. true if the domain is a verified root domain. Otherwise, false if the domain is a subdomain or unverified. Not nullable
     * @param value Value to set for the isRoot property.
     */
    set isRoot(value) {
        this._isRoot = value;
    }
    ;
    /**
     * Gets the isVerified property value. true if the domain has completed domain ownership verification. Not nullable
     * @returns a boolean
     */
    get isVerified() {
        return this._isVerified;
    }
    ;
    /**
     * Sets the isVerified property value. true if the domain has completed domain ownership verification. Not nullable
     * @param value Value to set for the isVerified property.
     */
    set isVerified(value) {
        this._isVerified = value;
    }
    ;
    /**
     * Gets the manufacturer property value.
     * @returns a string
     */
    get manufacturer() {
        return this._manufacturer;
    }
    ;
    /**
     * Sets the manufacturer property value.
     * @param value Value to set for the manufacturer property.
     */
    set manufacturer(value) {
        this._manufacturer = value;
    }
    ;
    /**
     * Gets the model property value.
     * @returns a string
     */
    get model() {
        return this._model;
    }
    ;
    /**
     * Sets the model property value.
     * @param value Value to set for the model property.
     */
    set model(value) {
        this._model = value;
    }
    ;
    /**
     * Gets the passwordNotificationWindowInDays property value. Specifies the number of days before a user receives notification that their password will expire. If the property is not set, a default value of 14 days will be used.
     * @returns a integer
     */
    get passwordNotificationWindowInDays() {
        return this._passwordNotificationWindowInDays;
    }
    ;
    /**
     * Sets the passwordNotificationWindowInDays property value. Specifies the number of days before a user receives notification that their password will expire. If the property is not set, a default value of 14 days will be used.
     * @param value Value to set for the passwordNotificationWindowInDays property.
     */
    set passwordNotificationWindowInDays(value) {
        this._passwordNotificationWindowInDays = value;
    }
    ;
    /**
     * Gets the passwordValidityPeriodInDays property value. Specifies the length of time that a password is valid before it must be changed. If the property is not set, a default value of 90 days will be used.
     * @returns a integer
     */
    get passwordValidityPeriodInDays() {
        return this._passwordValidityPeriodInDays;
    }
    ;
    /**
     * Sets the passwordValidityPeriodInDays property value. Specifies the length of time that a password is valid before it must be changed. If the property is not set, a default value of 90 days will be used.
     * @param value Value to set for the passwordValidityPeriodInDays property.
     */
    set passwordValidityPeriodInDays(value) {
        this._passwordValidityPeriodInDays = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("authenticationType", this.authenticationType);
        writer.writeStringValue("availabilityStatus", this.availabilityStatus);
        writer.writeCollectionOfObjectValues("domainNameReferences", this.domainNameReferences);
        writer.writeBooleanValue("isAdminManaged", this.isAdminManaged);
        writer.writeBooleanValue("isDefault", this.isDefault);
        writer.writeBooleanValue("isInitial", this.isInitial);
        writer.writeBooleanValue("isRoot", this.isRoot);
        writer.writeBooleanValue("isVerified", this.isVerified);
        writer.writeStringValue("manufacturer", this.manufacturer);
        writer.writeStringValue("model", this.model);
        writer.writeNumberValue("passwordNotificationWindowInDays", this.passwordNotificationWindowInDays);
        writer.writeNumberValue("passwordValidityPeriodInDays", this.passwordValidityPeriodInDays);
        writer.writeCollectionOfObjectValues("serviceConfigurationRecords", this.serviceConfigurationRecords);
        writer.writeObjectValue("state", this.state);
        writer.writeCollectionOfPrimitiveValues("supportedServices", this.supportedServices);
        writer.writeCollectionOfObjectValues("verificationDnsRecords", this.verificationDnsRecords);
    }
    ;
    /**
     * Gets the serviceConfigurationRecords property value. DNS records the customer adds to the DNS zone file of the domain before the domain can be used by Microsoft Online services. Read-only, Nullable
     * @returns a domainDnsRecord
     */
    get serviceConfigurationRecords() {
        return this._serviceConfigurationRecords;
    }
    ;
    /**
     * Sets the serviceConfigurationRecords property value. DNS records the customer adds to the DNS zone file of the domain before the domain can be used by Microsoft Online services. Read-only, Nullable
     * @param value Value to set for the serviceConfigurationRecords property.
     */
    set serviceConfigurationRecords(value) {
        this._serviceConfigurationRecords = value;
    }
    ;
    /**
     * Gets the state property value. Status of asynchronous operations scheduled for the domain.
     * @returns a domainState
     */
    get state() {
        return this._state;
    }
    ;
    /**
     * Sets the state property value. Status of asynchronous operations scheduled for the domain.
     * @param value Value to set for the state property.
     */
    set state(value) {
        this._state = value;
    }
    ;
    /**
     * Gets the supportedServices property value. The capabilities assigned to the domain. Can include 0, 1 or more of following values: Email, Sharepoint, EmailInternalRelayOnly, OfficeCommunicationsOnline, SharePointDefaultDomain, FullRedelegation, SharePointPublic, OrgIdAuthentication, Yammer, Intune. The values which you can add/remove using Graph API include: Email, OfficeCommunicationsOnline, Yammer. Not nullable
     * @returns a string
     */
    get supportedServices() {
        return this._supportedServices;
    }
    ;
    /**
     * Sets the supportedServices property value. The capabilities assigned to the domain. Can include 0, 1 or more of following values: Email, Sharepoint, EmailInternalRelayOnly, OfficeCommunicationsOnline, SharePointDefaultDomain, FullRedelegation, SharePointPublic, OrgIdAuthentication, Yammer, Intune. The values which you can add/remove using Graph API include: Email, OfficeCommunicationsOnline, Yammer. Not nullable
     * @param value Value to set for the supportedServices property.
     */
    set supportedServices(value) {
        this._supportedServices = value;
    }
    ;
    /**
     * Gets the verificationDnsRecords property value. DNS records that the customer adds to the DNS zone file of the domain before the customer can complete domain ownership verification with Azure AD. Read-only, Nullable
     * @returns a domainDnsRecord
     */
    get verificationDnsRecords() {
        return this._verificationDnsRecords;
    }
    ;
    /**
     * Sets the verificationDnsRecords property value. DNS records that the customer adds to the DNS zone file of the domain before the customer can complete domain ownership verification with Azure AD. Read-only, Nullable
     * @param value Value to set for the verificationDnsRecords property.
     */
    set verificationDnsRecords(value) {
        this._verificationDnsRecords = value;
    }
    ;
}
exports.Domain = Domain;
