import { BaseItem, DriveItem, IdentitySet, List, Quota, SharepointIds, SystemFacet } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Drive extends BaseItem implements Parsable {
    /** Collection of [bundles][bundle] (albums and multi-select-shared sets of items). Only in personal OneDrive.  */
    private _bundles?;
    /** Describes the type of drive represented by this resource. OneDrive personal drives will return personal. OneDrive for Business will return business. SharePoint document libraries will return documentLibrary. Read-only.  */
    private _driveType?;
    /** The list of items the user is following. Only in OneDrive for Business.  */
    private _following?;
    /** All items contained in the drive. Read-only. Nullable.  */
    private _items?;
    /** For drives in SharePoint, the underlying document library list. Read-only. Nullable.  */
    private _list?;
    /** Optional. The user account that owns the drive. Read-only.  */
    private _owner?;
    /** Optional. Information about the drive's storage space quota. Read-only.  */
    private _quota?;
    /** The root folder of the drive. Read-only.  */
    private _root?;
    private _sharePointIds?;
    /** Collection of common folders available in OneDrive. Read-only. Nullable.  */
    private _special?;
    /** If present, indicates that this is a system-managed drive. Read-only.  */
    private _system?;
    /**
     * Gets the bundles property value. Collection of [bundles][bundle] (albums and multi-select-shared sets of items). Only in personal OneDrive.
     * @returns a driveItem
     */
    get bundles(): DriveItem[] | undefined;
    /**
     * Sets the bundles property value. Collection of [bundles][bundle] (albums and multi-select-shared sets of items). Only in personal OneDrive.
     * @param value Value to set for the bundles property.
     */
    set bundles(value: DriveItem[] | undefined);
    /**
     * Instantiates a new drive and sets the default values.
     */
    constructor();
    /**
     * Gets the driveType property value. Describes the type of drive represented by this resource. OneDrive personal drives will return personal. OneDrive for Business will return business. SharePoint document libraries will return documentLibrary. Read-only.
     * @returns a string
     */
    get driveType(): string | undefined;
    /**
     * Sets the driveType property value. Describes the type of drive represented by this resource. OneDrive personal drives will return personal. OneDrive for Business will return business. SharePoint document libraries will return documentLibrary. Read-only.
     * @param value Value to set for the driveType property.
     */
    set driveType(value: string | undefined);
    /**
     * Gets the following property value. The list of items the user is following. Only in OneDrive for Business.
     * @returns a driveItem
     */
    get following(): DriveItem[] | undefined;
    /**
     * Sets the following property value. The list of items the user is following. Only in OneDrive for Business.
     * @param value Value to set for the following property.
     */
    set following(value: DriveItem[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the items property value. All items contained in the drive. Read-only. Nullable.
     * @returns a driveItem
     */
    get items(): DriveItem[] | undefined;
    /**
     * Sets the items property value. All items contained in the drive. Read-only. Nullable.
     * @param value Value to set for the items property.
     */
    set items(value: DriveItem[] | undefined);
    /**
     * Gets the list property value. For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @returns a list
     */
    get list(): List | undefined;
    /**
     * Sets the list property value. For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @param value Value to set for the list property.
     */
    set list(value: List | undefined);
    /**
     * Gets the owner property value. Optional. The user account that owns the drive. Read-only.
     * @returns a identitySet
     */
    get owner(): IdentitySet | undefined;
    /**
     * Sets the owner property value. Optional. The user account that owns the drive. Read-only.
     * @param value Value to set for the owner property.
     */
    set owner(value: IdentitySet | undefined);
    /**
     * Gets the quota property value. Optional. Information about the drive's storage space quota. Read-only.
     * @returns a quota
     */
    get quota(): Quota | undefined;
    /**
     * Sets the quota property value. Optional. Information about the drive's storage space quota. Read-only.
     * @param value Value to set for the quota property.
     */
    set quota(value: Quota | undefined);
    /**
     * Gets the root property value. The root folder of the drive. Read-only.
     * @returns a driveItem
     */
    get root(): DriveItem | undefined;
    /**
     * Sets the root property value. The root folder of the drive. Read-only.
     * @param value Value to set for the root property.
     */
    set root(value: DriveItem | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the sharePointIds property value.
     * @returns a sharepointIds
     */
    get sharePointIds(): SharepointIds | undefined;
    /**
     * Sets the sharePointIds property value.
     * @param value Value to set for the sharePointIds property.
     */
    set sharePointIds(value: SharepointIds | undefined);
    /**
     * Gets the special property value. Collection of common folders available in OneDrive. Read-only. Nullable.
     * @returns a driveItem
     */
    get special(): DriveItem[] | undefined;
    /**
     * Sets the special property value. Collection of common folders available in OneDrive. Read-only. Nullable.
     * @param value Value to set for the special property.
     */
    set special(value: DriveItem[] | undefined);
    /**
     * Gets the system property value. If present, indicates that this is a system-managed drive. Read-only.
     * @returns a systemFacet
     */
    get system(): SystemFacet | undefined;
    /**
     * Sets the system property value. If present, indicates that this is a system-managed drive. Read-only.
     * @param value Value to set for the system property.
     */
    set system(value: SystemFacet | undefined);
}
