"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Drive = void 0;
const createDriveItemFromDiscriminatorValue_1 = require("./createDriveItemFromDiscriminatorValue");
const createIdentitySetFromDiscriminatorValue_1 = require("./createIdentitySetFromDiscriminatorValue");
const createListFromDiscriminatorValue_1 = require("./createListFromDiscriminatorValue");
const createQuotaFromDiscriminatorValue_1 = require("./createQuotaFromDiscriminatorValue");
const createSharepointIdsFromDiscriminatorValue_1 = require("./createSharepointIdsFromDiscriminatorValue");
const createSystemFacetFromDiscriminatorValue_1 = require("./createSystemFacetFromDiscriminatorValue");
const index_1 = require("./index");
class Drive extends index_1.BaseItem {
    /**
     * Instantiates a new drive and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the bundles property value. Collection of [bundles][bundle] (albums and multi-select-shared sets of items). Only in personal OneDrive.
     * @returns a driveItem
     */
    get bundles() {
        return this._bundles;
    }
    ;
    /**
     * Sets the bundles property value. Collection of [bundles][bundle] (albums and multi-select-shared sets of items). Only in personal OneDrive.
     * @param value Value to set for the bundles property.
     */
    set bundles(value) {
        this._bundles = value;
    }
    ;
    ;
    /**
     * Gets the driveType property value. Describes the type of drive represented by this resource. OneDrive personal drives will return personal. OneDrive for Business will return business. SharePoint document libraries will return documentLibrary. Read-only.
     * @returns a string
     */
    get driveType() {
        return this._driveType;
    }
    ;
    /**
     * Sets the driveType property value. Describes the type of drive represented by this resource. OneDrive personal drives will return personal. OneDrive for Business will return business. SharePoint document libraries will return documentLibrary. Read-only.
     * @param value Value to set for the driveType property.
     */
    set driveType(value) {
        this._driveType = value;
    }
    ;
    /**
     * Gets the following property value. The list of items the user is following. Only in OneDrive for Business.
     * @returns a driveItem
     */
    get following() {
        return this._following;
    }
    ;
    /**
     * Sets the following property value. The list of items the user is following. Only in OneDrive for Business.
     * @param value Value to set for the following property.
     */
    set following(value) {
        this._following = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "bundles": (o, n) => { o.bundles = n.getCollectionOfObjectValues(createDriveItemFromDiscriminatorValue_1.createDriveItemFromDiscriminatorValue); }, "driveType": (o, n) => { o.driveType = n.getStringValue(); }, "following": (o, n) => { o.following = n.getCollectionOfObjectValues(createDriveItemFromDiscriminatorValue_1.createDriveItemFromDiscriminatorValue); }, "items": (o, n) => { o.items = n.getCollectionOfObjectValues(createDriveItemFromDiscriminatorValue_1.createDriveItemFromDiscriminatorValue); }, "list": (o, n) => { o.list = n.getObjectValue(createListFromDiscriminatorValue_1.createListFromDiscriminatorValue); }, "owner": (o, n) => { o.owner = n.getObjectValue(createIdentitySetFromDiscriminatorValue_1.createIdentitySetFromDiscriminatorValue); }, "quota": (o, n) => { o.quota = n.getObjectValue(createQuotaFromDiscriminatorValue_1.createQuotaFromDiscriminatorValue); }, "root": (o, n) => { o.root = n.getObjectValue(createDriveItemFromDiscriminatorValue_1.createDriveItemFromDiscriminatorValue); }, "sharePointIds": (o, n) => { o.sharePointIds = n.getObjectValue(createSharepointIdsFromDiscriminatorValue_1.createSharepointIdsFromDiscriminatorValue); }, "special": (o, n) => { o.special = n.getCollectionOfObjectValues(createDriveItemFromDiscriminatorValue_1.createDriveItemFromDiscriminatorValue); }, "system": (o, n) => { o.system = n.getObjectValue(createSystemFacetFromDiscriminatorValue_1.createSystemFacetFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the items property value. All items contained in the drive. Read-only. Nullable.
     * @returns a driveItem
     */
    get items() {
        return this._items;
    }
    ;
    /**
     * Sets the items property value. All items contained in the drive. Read-only. Nullable.
     * @param value Value to set for the items property.
     */
    set items(value) {
        this._items = value;
    }
    ;
    /**
     * Gets the list property value. For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @returns a list
     */
    get list() {
        return this._list;
    }
    ;
    /**
     * Sets the list property value. For drives in SharePoint, the underlying document library list. Read-only. Nullable.
     * @param value Value to set for the list property.
     */
    set list(value) {
        this._list = value;
    }
    ;
    /**
     * Gets the owner property value. Optional. The user account that owns the drive. Read-only.
     * @returns a identitySet
     */
    get owner() {
        return this._owner;
    }
    ;
    /**
     * Sets the owner property value. Optional. The user account that owns the drive. Read-only.
     * @param value Value to set for the owner property.
     */
    set owner(value) {
        this._owner = value;
    }
    ;
    /**
     * Gets the quota property value. Optional. Information about the drive's storage space quota. Read-only.
     * @returns a quota
     */
    get quota() {
        return this._quota;
    }
    ;
    /**
     * Sets the quota property value. Optional. Information about the drive's storage space quota. Read-only.
     * @param value Value to set for the quota property.
     */
    set quota(value) {
        this._quota = value;
    }
    ;
    /**
     * Gets the root property value. The root folder of the drive. Read-only.
     * @returns a driveItem
     */
    get root() {
        return this._root;
    }
    ;
    /**
     * Sets the root property value. The root folder of the drive. Read-only.
     * @param value Value to set for the root property.
     */
    set root(value) {
        this._root = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeCollectionOfObjectValues("bundles", this.bundles);
        writer.writeStringValue("driveType", this.driveType);
        writer.writeCollectionOfObjectValues("following", this.following);
        writer.writeCollectionOfObjectValues("items", this.items);
        writer.writeObjectValue("list", this.list);
        writer.writeObjectValue("owner", this.owner);
        writer.writeObjectValue("quota", this.quota);
        writer.writeObjectValue("root", this.root);
        writer.writeObjectValue("sharePointIds", this.sharePointIds);
        writer.writeCollectionOfObjectValues("special", this.special);
        writer.writeObjectValue("system", this.system);
    }
    ;
    /**
     * Gets the sharePointIds property value.
     * @returns a sharepointIds
     */
    get sharePointIds() {
        return this._sharePointIds;
    }
    ;
    /**
     * Sets the sharePointIds property value.
     * @param value Value to set for the sharePointIds property.
     */
    set sharePointIds(value) {
        this._sharePointIds = value;
    }
    ;
    /**
     * Gets the special property value. Collection of common folders available in OneDrive. Read-only. Nullable.
     * @returns a driveItem
     */
    get special() {
        return this._special;
    }
    ;
    /**
     * Sets the special property value. Collection of common folders available in OneDrive. Read-only. Nullable.
     * @param value Value to set for the special property.
     */
    set special(value) {
        this._special = value;
    }
    ;
    /**
     * Gets the system property value. If present, indicates that this is a system-managed drive. Read-only.
     * @returns a systemFacet
     */
    get system() {
        return this._system;
    }
    ;
    /**
     * Sets the system property value. If present, indicates that this is a system-managed drive. Read-only.
     * @param value Value to set for the system property.
     */
    set system(value) {
        this._system = value;
    }
    ;
}
exports.Drive = Drive;
