import { EducationExternalSource } from './educationExternalSource';
import { EducationAssignment, EducationAssignmentDefaults, EducationAssignmentSettings, EducationCategory, EducationCourse, EducationSchool, EducationTerm, EducationUser, Entity, Group, IdentitySet } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class EducationClass extends Entity implements Parsable {
    private _assignmentCategories?;
    private _assignmentDefaults?;
    /** All assignments associated with this class. Nullable.  */
    private _assignments?;
    private _assignmentSettings?;
    /** Class code used by the school to identify the class.  */
    private _classCode?;
    /** Course information for the class.  */
    private _course?;
    /** Entity who created the class  */
    private _createdBy?;
    /** Description of the class.  */
    private _description?;
    /** Name of the class.  */
    private _displayName?;
    /** ID of the class from the syncing system.  */
    private _externalId?;
    /** Name of the class in the syncing system.  */
    private _externalName?;
    /** How this class was created. Possible values are: sis, manual.  */
    private _externalSource?;
    /** The name of the external source this resources was generated from.  */
    private _externalSourceDetail?;
    /** Grade level of the class.  */
    private _grade?;
    /** The underlying Microsoft 365 group object.  */
    private _group?;
    /** Mail name for sending email to all members, if this is enabled.  */
    private _mailNickname?;
    /** All users in the class. Nullable.  */
    private _members?;
    /** All schools that this class is associated with. Nullable.  */
    private _schools?;
    /** All teachers in the class. Nullable.  */
    private _teachers?;
    /** Term for this class.  */
    private _term?;
    /**
     * Gets the assignmentCategories property value.
     * @returns a educationCategory
     */
    get assignmentCategories(): EducationCategory[] | undefined;
    /**
     * Sets the assignmentCategories property value.
     * @param value Value to set for the assignmentCategories property.
     */
    set assignmentCategories(value: EducationCategory[] | undefined);
    /**
     * Gets the assignmentDefaults property value.
     * @returns a educationAssignmentDefaults
     */
    get assignmentDefaults(): EducationAssignmentDefaults | undefined;
    /**
     * Sets the assignmentDefaults property value.
     * @param value Value to set for the assignmentDefaults property.
     */
    set assignmentDefaults(value: EducationAssignmentDefaults | undefined);
    /**
     * Gets the assignments property value. All assignments associated with this class. Nullable.
     * @returns a educationAssignment
     */
    get assignments(): EducationAssignment[] | undefined;
    /**
     * Sets the assignments property value. All assignments associated with this class. Nullable.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: EducationAssignment[] | undefined);
    /**
     * Gets the assignmentSettings property value.
     * @returns a educationAssignmentSettings
     */
    get assignmentSettings(): EducationAssignmentSettings | undefined;
    /**
     * Sets the assignmentSettings property value.
     * @param value Value to set for the assignmentSettings property.
     */
    set assignmentSettings(value: EducationAssignmentSettings | undefined);
    /**
     * Gets the classCode property value. Class code used by the school to identify the class.
     * @returns a string
     */
    get classCode(): string | undefined;
    /**
     * Sets the classCode property value. Class code used by the school to identify the class.
     * @param value Value to set for the classCode property.
     */
    set classCode(value: string | undefined);
    /**
     * Instantiates a new educationClass and sets the default values.
     */
    constructor();
    /**
     * Gets the course property value. Course information for the class.
     * @returns a educationCourse
     */
    get course(): EducationCourse | undefined;
    /**
     * Sets the course property value. Course information for the class.
     * @param value Value to set for the course property.
     */
    set course(value: EducationCourse | undefined);
    /**
     * Gets the createdBy property value. Entity who created the class
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. Entity who created the class
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the description property value. Description of the class.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Description of the class.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. Name of the class.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Name of the class.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the externalId property value. ID of the class from the syncing system.
     * @returns a string
     */
    get externalId(): string | undefined;
    /**
     * Sets the externalId property value. ID of the class from the syncing system.
     * @param value Value to set for the externalId property.
     */
    set externalId(value: string | undefined);
    /**
     * Gets the externalName property value. Name of the class in the syncing system.
     * @returns a string
     */
    get externalName(): string | undefined;
    /**
     * Sets the externalName property value. Name of the class in the syncing system.
     * @param value Value to set for the externalName property.
     */
    set externalName(value: string | undefined);
    /**
     * Gets the externalSource property value. How this class was created. Possible values are: sis, manual.
     * @returns a educationExternalSource
     */
    get externalSource(): EducationExternalSource | undefined;
    /**
     * Sets the externalSource property value. How this class was created. Possible values are: sis, manual.
     * @param value Value to set for the externalSource property.
     */
    set externalSource(value: EducationExternalSource | undefined);
    /**
     * Gets the externalSourceDetail property value. The name of the external source this resources was generated from.
     * @returns a string
     */
    get externalSourceDetail(): string | undefined;
    /**
     * Sets the externalSourceDetail property value. The name of the external source this resources was generated from.
     * @param value Value to set for the externalSourceDetail property.
     */
    set externalSourceDetail(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the grade property value. Grade level of the class.
     * @returns a string
     */
    get grade(): string | undefined;
    /**
     * Sets the grade property value. Grade level of the class.
     * @param value Value to set for the grade property.
     */
    set grade(value: string | undefined);
    /**
     * Gets the group property value. The underlying Microsoft 365 group object.
     * @returns a group
     */
    get group(): Group | undefined;
    /**
     * Sets the group property value. The underlying Microsoft 365 group object.
     * @param value Value to set for the group property.
     */
    set group(value: Group | undefined);
    /**
     * Gets the mailNickname property value. Mail name for sending email to all members, if this is enabled.
     * @returns a string
     */
    get mailNickname(): string | undefined;
    /**
     * Sets the mailNickname property value. Mail name for sending email to all members, if this is enabled.
     * @param value Value to set for the mailNickname property.
     */
    set mailNickname(value: string | undefined);
    /**
     * Gets the members property value. All users in the class. Nullable.
     * @returns a educationUser
     */
    get members(): EducationUser[] | undefined;
    /**
     * Sets the members property value. All users in the class. Nullable.
     * @param value Value to set for the members property.
     */
    set members(value: EducationUser[] | undefined);
    /**
     * Gets the schools property value. All schools that this class is associated with. Nullable.
     * @returns a educationSchool
     */
    get schools(): EducationSchool[] | undefined;
    /**
     * Sets the schools property value. All schools that this class is associated with. Nullable.
     * @param value Value to set for the schools property.
     */
    set schools(value: EducationSchool[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the teachers property value. All teachers in the class. Nullable.
     * @returns a educationUser
     */
    get teachers(): EducationUser[] | undefined;
    /**
     * Sets the teachers property value. All teachers in the class. Nullable.
     * @param value Value to set for the teachers property.
     */
    set teachers(value: EducationUser[] | undefined);
    /**
     * Gets the term property value. Term for this class.
     * @returns a educationTerm
     */
    get term(): EducationTerm | undefined;
    /**
     * Sets the term property value. Term for this class.
     * @param value Value to set for the term property.
     */
    set term(value: EducationTerm | undefined);
}
