import { AdministrativeUnit, EducationClass, EducationOrganization, EducationUser, IdentitySet, PhysicalAddress } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class EducationSchool extends EducationOrganization implements Parsable {
    /** Address of the school.  */
    private _address?;
    /** The underlying administrativeUnit for this school.  */
    private _administrativeUnit?;
    /** Classes taught at the school. Nullable.  */
    private _classes?;
    /** Entity who created the school.  */
    private _createdBy?;
    /** ID of school in syncing system.  */
    private _externalId?;
    /** ID of principal in syncing system.  */
    private _externalPrincipalId?;
    private _fax?;
    /** Highest grade taught.  */
    private _highestGrade?;
    /** Lowest grade taught.  */
    private _lowestGrade?;
    /** Phone number of school.  */
    private _phone?;
    /** Email address of the principal.  */
    private _principalEmail?;
    /** Name of the principal.  */
    private _principalName?;
    /** School Number.  */
    private _schoolNumber?;
    /** Users in the school. Nullable.  */
    private _users?;
    /**
     * Gets the address property value. Address of the school.
     * @returns a physicalAddress
     */
    get address(): PhysicalAddress | undefined;
    /**
     * Sets the address property value. Address of the school.
     * @param value Value to set for the address property.
     */
    set address(value: PhysicalAddress | undefined);
    /**
     * Gets the administrativeUnit property value. The underlying administrativeUnit for this school.
     * @returns a administrativeUnit
     */
    get administrativeUnit(): AdministrativeUnit | undefined;
    /**
     * Sets the administrativeUnit property value. The underlying administrativeUnit for this school.
     * @param value Value to set for the administrativeUnit property.
     */
    set administrativeUnit(value: AdministrativeUnit | undefined);
    /**
     * Gets the classes property value. Classes taught at the school. Nullable.
     * @returns a educationClass
     */
    get classes(): EducationClass[] | undefined;
    /**
     * Sets the classes property value. Classes taught at the school. Nullable.
     * @param value Value to set for the classes property.
     */
    set classes(value: EducationClass[] | undefined);
    /**
     * Instantiates a new educationSchool and sets the default values.
     */
    constructor();
    /**
     * Gets the createdBy property value. Entity who created the school.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. Entity who created the school.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the externalId property value. ID of school in syncing system.
     * @returns a string
     */
    get externalId(): string | undefined;
    /**
     * Sets the externalId property value. ID of school in syncing system.
     * @param value Value to set for the externalId property.
     */
    set externalId(value: string | undefined);
    /**
     * Gets the externalPrincipalId property value. ID of principal in syncing system.
     * @returns a string
     */
    get externalPrincipalId(): string | undefined;
    /**
     * Sets the externalPrincipalId property value. ID of principal in syncing system.
     * @param value Value to set for the externalPrincipalId property.
     */
    set externalPrincipalId(value: string | undefined);
    /**
     * Gets the fax property value.
     * @returns a string
     */
    get fax(): string | undefined;
    /**
     * Sets the fax property value.
     * @param value Value to set for the fax property.
     */
    set fax(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the highestGrade property value. Highest grade taught.
     * @returns a string
     */
    get highestGrade(): string | undefined;
    /**
     * Sets the highestGrade property value. Highest grade taught.
     * @param value Value to set for the highestGrade property.
     */
    set highestGrade(value: string | undefined);
    /**
     * Gets the lowestGrade property value. Lowest grade taught.
     * @returns a string
     */
    get lowestGrade(): string | undefined;
    /**
     * Sets the lowestGrade property value. Lowest grade taught.
     * @param value Value to set for the lowestGrade property.
     */
    set lowestGrade(value: string | undefined);
    /**
     * Gets the phone property value. Phone number of school.
     * @returns a string
     */
    get phone(): string | undefined;
    /**
     * Sets the phone property value. Phone number of school.
     * @param value Value to set for the phone property.
     */
    set phone(value: string | undefined);
    /**
     * Gets the principalEmail property value. Email address of the principal.
     * @returns a string
     */
    get principalEmail(): string | undefined;
    /**
     * Sets the principalEmail property value. Email address of the principal.
     * @param value Value to set for the principalEmail property.
     */
    set principalEmail(value: string | undefined);
    /**
     * Gets the principalName property value. Name of the principal.
     * @returns a string
     */
    get principalName(): string | undefined;
    /**
     * Sets the principalName property value. Name of the principal.
     * @param value Value to set for the principalName property.
     */
    set principalName(value: string | undefined);
    /**
     * Gets the schoolNumber property value. School Number.
     * @returns a string
     */
    get schoolNumber(): string | undefined;
    /**
     * Sets the schoolNumber property value. School Number.
     * @param value Value to set for the schoolNumber property.
     */
    set schoolNumber(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the users property value. Users in the school. Nullable.
     * @returns a educationUser
     */
    get users(): EducationUser[] | undefined;
    /**
     * Sets the users property value. Users in the school. Nullable.
     * @param value Value to set for the users property.
     */
    set users(value: EducationUser[] | undefined);
}
