import { EducationSubmissionStatus } from './educationSubmissionStatus';
import { EducationOutcome, EducationSubmissionRecipient, EducationSubmissionResource, Entity, IdentitySet } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class EducationSubmission extends Entity implements Parsable {
    /** Read-Write. Nullable.  */
    private _outcomes?;
    /** User who moved the status of this submission to reassigned.  */
    private _reassignedBy?;
    /** Moment in time when the submission was reassigned. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z  */
    private _reassignedDateTime?;
    /** Who this submission is assigned to.  */
    private _recipient?;
    /** Nullable.  */
    private _resources?;
    /** Folder where all file resources for this submission need to be stored.  */
    private _resourcesFolderUrl?;
    /** User who moved the status of this submission to returned.  */
    private _returnedBy?;
    /** Moment in time when the submission was returned. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z  */
    private _returnedDateTime?;
    /** Read-only. Possible values are: working, submitted, released, returned, and reassigned. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value(s) in this evolvable enum: reassigned.  */
    private _status?;
    /** User who moved the resource into the submitted state.  */
    private _submittedBy?;
    /** Moment in time when the submission was moved into the submitted state. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z  */
    private _submittedDateTime?;
    /** Read-only. Nullable.  */
    private _submittedResources?;
    /** User who moved the resource from submitted into the working state.  */
    private _unsubmittedBy?;
    /** Moment in time when the submission was moved from submitted into the working state. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z  */
    private _unsubmittedDateTime?;
    /**
     * Instantiates a new educationSubmission and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the outcomes property value. Read-Write. Nullable.
     * @returns a educationOutcome
     */
    get outcomes(): EducationOutcome[] | undefined;
    /**
     * Sets the outcomes property value. Read-Write. Nullable.
     * @param value Value to set for the outcomes property.
     */
    set outcomes(value: EducationOutcome[] | undefined);
    /**
     * Gets the reassignedBy property value. User who moved the status of this submission to reassigned.
     * @returns a identitySet
     */
    get reassignedBy(): IdentitySet | undefined;
    /**
     * Sets the reassignedBy property value. User who moved the status of this submission to reassigned.
     * @param value Value to set for the reassignedBy property.
     */
    set reassignedBy(value: IdentitySet | undefined);
    /**
     * Gets the reassignedDateTime property value. Moment in time when the submission was reassigned. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get reassignedDateTime(): Date | undefined;
    /**
     * Sets the reassignedDateTime property value. Moment in time when the submission was reassigned. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the reassignedDateTime property.
     */
    set reassignedDateTime(value: Date | undefined);
    /**
     * Gets the recipient property value. Who this submission is assigned to.
     * @returns a educationSubmissionRecipient
     */
    get recipient(): EducationSubmissionRecipient | undefined;
    /**
     * Sets the recipient property value. Who this submission is assigned to.
     * @param value Value to set for the recipient property.
     */
    set recipient(value: EducationSubmissionRecipient | undefined);
    /**
     * Gets the resources property value. Nullable.
     * @returns a educationSubmissionResource
     */
    get resources(): EducationSubmissionResource[] | undefined;
    /**
     * Sets the resources property value. Nullable.
     * @param value Value to set for the resources property.
     */
    set resources(value: EducationSubmissionResource[] | undefined);
    /**
     * Gets the resourcesFolderUrl property value. Folder where all file resources for this submission need to be stored.
     * @returns a string
     */
    get resourcesFolderUrl(): string | undefined;
    /**
     * Sets the resourcesFolderUrl property value. Folder where all file resources for this submission need to be stored.
     * @param value Value to set for the resourcesFolderUrl property.
     */
    set resourcesFolderUrl(value: string | undefined);
    /**
     * Gets the returnedBy property value. User who moved the status of this submission to returned.
     * @returns a identitySet
     */
    get returnedBy(): IdentitySet | undefined;
    /**
     * Sets the returnedBy property value. User who moved the status of this submission to returned.
     * @param value Value to set for the returnedBy property.
     */
    set returnedBy(value: IdentitySet | undefined);
    /**
     * Gets the returnedDateTime property value. Moment in time when the submission was returned. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get returnedDateTime(): Date | undefined;
    /**
     * Sets the returnedDateTime property value. Moment in time when the submission was returned. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the returnedDateTime property.
     */
    set returnedDateTime(value: Date | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. Read-only. Possible values are: working, submitted, released, returned, and reassigned. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value(s) in this evolvable enum: reassigned.
     * @returns a educationSubmissionStatus
     */
    get status(): EducationSubmissionStatus | undefined;
    /**
     * Sets the status property value. Read-only. Possible values are: working, submitted, released, returned, and reassigned. Note that you must use the Prefer: include-unknown-enum-members request header to get the following value(s) in this evolvable enum: reassigned.
     * @param value Value to set for the status property.
     */
    set status(value: EducationSubmissionStatus | undefined);
    /**
     * Gets the submittedBy property value. User who moved the resource into the submitted state.
     * @returns a identitySet
     */
    get submittedBy(): IdentitySet | undefined;
    /**
     * Sets the submittedBy property value. User who moved the resource into the submitted state.
     * @param value Value to set for the submittedBy property.
     */
    set submittedBy(value: IdentitySet | undefined);
    /**
     * Gets the submittedDateTime property value. Moment in time when the submission was moved into the submitted state. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get submittedDateTime(): Date | undefined;
    /**
     * Sets the submittedDateTime property value. Moment in time when the submission was moved into the submitted state. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the submittedDateTime property.
     */
    set submittedDateTime(value: Date | undefined);
    /**
     * Gets the submittedResources property value. Read-only. Nullable.
     * @returns a educationSubmissionResource
     */
    get submittedResources(): EducationSubmissionResource[] | undefined;
    /**
     * Sets the submittedResources property value. Read-only. Nullable.
     * @param value Value to set for the submittedResources property.
     */
    set submittedResources(value: EducationSubmissionResource[] | undefined);
    /**
     * Gets the unsubmittedBy property value. User who moved the resource from submitted into the working state.
     * @returns a identitySet
     */
    get unsubmittedBy(): IdentitySet | undefined;
    /**
     * Sets the unsubmittedBy property value. User who moved the resource from submitted into the working state.
     * @param value Value to set for the unsubmittedBy property.
     */
    set unsubmittedBy(value: IdentitySet | undefined);
    /**
     * Gets the unsubmittedDateTime property value. Moment in time when the submission was moved from submitted into the working state. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get unsubmittedDateTime(): Date | undefined;
    /**
     * Sets the unsubmittedDateTime property value. Moment in time when the submission was moved from submitted into the working state. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the unsubmittedDateTime property.
     */
    set unsubmittedDateTime(value: Date | undefined);
}
