import { EventType } from './eventType';
import { FreeBusyStatus } from './freeBusyStatus';
import { Importance } from './importance';
import { Attachment, Attendee, Calendar, DateTimeTimeZone, Extension, ItemBody, Location, MultiValueLegacyExtendedProperty, OnlineMeetingInfo, OutlookItem, PatternedRecurrence, Recipient, ResponseStatus, SingleValueLegacyExtendedProperty } from './index';
import { OnlineMeetingProviderType } from './onlineMeetingProviderType';
import { Sensitivity } from './sensitivity';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Event extends OutlookItem implements Parsable {
    /** true if the meeting organizer allows invitees to propose a new time when responding; otherwise, false. Optional. Default is true.  */
    private _allowNewTimeProposals?;
    /** The collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.  */
    private _attachments?;
    /** The collection of attendees for the event.  */
    private _attendees?;
    /** The body of the message associated with the event. It can be in HTML or text format.  */
    private _body?;
    /** The preview of the message associated with the event. It is in text format.  */
    private _bodyPreview?;
    /** The calendar that contains the event. Navigation property. Read-only.  */
    private _calendar?;
    /** The date, time, and time zone that the event ends. By default, the end time is in UTC.  */
    private _end?;
    /** The collection of open extensions defined for the event. Nullable.  */
    private _extensions?;
    /** Set to true if the event has attachments.  */
    private _hasAttachments?;
    /** When set to true, each attendee only sees themselves in the meeting request and meeting Tracking list. Default is false.  */
    private _hideAttendees?;
    /** A unique identifier for an event across calendars. This ID is different for each occurrence in a recurring series. Read-only.  */
    private _iCalUId?;
    private _importance?;
    /** The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.  */
    private _instances?;
    private _isAllDay?;
    private _isCancelled?;
    private _isDraft?;
    private _isOnlineMeeting?;
    private _isOrganizer?;
    private _isReminderOn?;
    private _location?;
    private _locations?;
    /** The collection of multi-value extended properties defined for the event. Read-only. Nullable.  */
    private _multiValueExtendedProperties?;
    private _onlineMeeting?;
    private _onlineMeetingProvider?;
    private _onlineMeetingUrl?;
    private _organizer?;
    private _originalEndTimeZone?;
    private _originalStart?;
    private _originalStartTimeZone?;
    private _recurrence?;
    private _reminderMinutesBeforeStart?;
    private _responseRequested?;
    private _responseStatus?;
    private _sensitivity?;
    private _seriesMasterId?;
    private _showAs?;
    /** The collection of single-value extended properties defined for the event. Read-only. Nullable.  */
    private _singleValueExtendedProperties?;
    private _start?;
    private _subject?;
    private _transactionId?;
    private _type?;
    private _webLink?;
    /**
     * Gets the allowNewTimeProposals property value. true if the meeting organizer allows invitees to propose a new time when responding; otherwise, false. Optional. Default is true.
     * @returns a boolean
     */
    get allowNewTimeProposals(): boolean | undefined;
    /**
     * Sets the allowNewTimeProposals property value. true if the meeting organizer allows invitees to propose a new time when responding; otherwise, false. Optional. Default is true.
     * @param value Value to set for the allowNewTimeProposals property.
     */
    set allowNewTimeProposals(value: boolean | undefined);
    /**
     * Gets the attachments property value. The collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
     * @returns a attachment
     */
    get attachments(): Attachment[] | undefined;
    /**
     * Sets the attachments property value. The collection of FileAttachment, ItemAttachment, and referenceAttachment attachments for the event. Navigation property. Read-only. Nullable.
     * @param value Value to set for the attachments property.
     */
    set attachments(value: Attachment[] | undefined);
    /**
     * Gets the attendees property value. The collection of attendees for the event.
     * @returns a attendee
     */
    get attendees(): Attendee[] | undefined;
    /**
     * Sets the attendees property value. The collection of attendees for the event.
     * @param value Value to set for the attendees property.
     */
    set attendees(value: Attendee[] | undefined);
    /**
     * Gets the body property value. The body of the message associated with the event. It can be in HTML or text format.
     * @returns a itemBody
     */
    get body(): ItemBody | undefined;
    /**
     * Sets the body property value. The body of the message associated with the event. It can be in HTML or text format.
     * @param value Value to set for the body property.
     */
    set body(value: ItemBody | undefined);
    /**
     * Gets the bodyPreview property value. The preview of the message associated with the event. It is in text format.
     * @returns a string
     */
    get bodyPreview(): string | undefined;
    /**
     * Sets the bodyPreview property value. The preview of the message associated with the event. It is in text format.
     * @param value Value to set for the bodyPreview property.
     */
    set bodyPreview(value: string | undefined);
    /**
     * Gets the calendar property value. The calendar that contains the event. Navigation property. Read-only.
     * @returns a calendar
     */
    get calendar(): Calendar | undefined;
    /**
     * Sets the calendar property value. The calendar that contains the event. Navigation property. Read-only.
     * @param value Value to set for the calendar property.
     */
    set calendar(value: Calendar | undefined);
    /**
     * Instantiates a new event and sets the default values.
     */
    constructor();
    /**
     * Gets the end property value. The date, time, and time zone that the event ends. By default, the end time is in UTC.
     * @returns a dateTimeTimeZone
     */
    get end(): DateTimeTimeZone | undefined;
    /**
     * Sets the end property value. The date, time, and time zone that the event ends. By default, the end time is in UTC.
     * @param value Value to set for the end property.
     */
    set end(value: DateTimeTimeZone | undefined);
    /**
     * Gets the extensions property value. The collection of open extensions defined for the event. Nullable.
     * @returns a extension
     */
    get extensions(): Extension[] | undefined;
    /**
     * Sets the extensions property value. The collection of open extensions defined for the event. Nullable.
     * @param value Value to set for the extensions property.
     */
    set extensions(value: Extension[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hasAttachments property value. Set to true if the event has attachments.
     * @returns a boolean
     */
    get hasAttachments(): boolean | undefined;
    /**
     * Sets the hasAttachments property value. Set to true if the event has attachments.
     * @param value Value to set for the hasAttachments property.
     */
    set hasAttachments(value: boolean | undefined);
    /**
     * Gets the hideAttendees property value. When set to true, each attendee only sees themselves in the meeting request and meeting Tracking list. Default is false.
     * @returns a boolean
     */
    get hideAttendees(): boolean | undefined;
    /**
     * Sets the hideAttendees property value. When set to true, each attendee only sees themselves in the meeting request and meeting Tracking list. Default is false.
     * @param value Value to set for the hideAttendees property.
     */
    set hideAttendees(value: boolean | undefined);
    /**
     * Gets the iCalUId property value. A unique identifier for an event across calendars. This ID is different for each occurrence in a recurring series. Read-only.
     * @returns a string
     */
    get iCalUId(): string | undefined;
    /**
     * Sets the iCalUId property value. A unique identifier for an event across calendars. This ID is different for each occurrence in a recurring series. Read-only.
     * @param value Value to set for the iCalUId property.
     */
    set iCalUId(value: string | undefined);
    /**
     * Gets the importance property value.
     * @returns a importance
     */
    get importance(): Importance | undefined;
    /**
     * Sets the importance property value.
     * @param value Value to set for the importance property.
     */
    set importance(value: Importance | undefined);
    /**
     * Gets the instances property value. The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.
     * @returns a event
     */
    get instances(): Event[] | undefined;
    /**
     * Sets the instances property value. The occurrences of a recurring series, if the event is a series master. This property includes occurrences that are part of the recurrence pattern, and exceptions that have been modified, but does not include occurrences that have been cancelled from the series. Navigation property. Read-only. Nullable.
     * @param value Value to set for the instances property.
     */
    set instances(value: Event[] | undefined);
    /**
     * Gets the isAllDay property value.
     * @returns a boolean
     */
    get isAllDay(): boolean | undefined;
    /**
     * Sets the isAllDay property value.
     * @param value Value to set for the isAllDay property.
     */
    set isAllDay(value: boolean | undefined);
    /**
     * Gets the isCancelled property value.
     * @returns a boolean
     */
    get isCancelled(): boolean | undefined;
    /**
     * Sets the isCancelled property value.
     * @param value Value to set for the isCancelled property.
     */
    set isCancelled(value: boolean | undefined);
    /**
     * Gets the isDraft property value.
     * @returns a boolean
     */
    get isDraft(): boolean | undefined;
    /**
     * Sets the isDraft property value.
     * @param value Value to set for the isDraft property.
     */
    set isDraft(value: boolean | undefined);
    /**
     * Gets the isOnlineMeeting property value.
     * @returns a boolean
     */
    get isOnlineMeeting(): boolean | undefined;
    /**
     * Sets the isOnlineMeeting property value.
     * @param value Value to set for the isOnlineMeeting property.
     */
    set isOnlineMeeting(value: boolean | undefined);
    /**
     * Gets the isOrganizer property value.
     * @returns a boolean
     */
    get isOrganizer(): boolean | undefined;
    /**
     * Sets the isOrganizer property value.
     * @param value Value to set for the isOrganizer property.
     */
    set isOrganizer(value: boolean | undefined);
    /**
     * Gets the isReminderOn property value.
     * @returns a boolean
     */
    get isReminderOn(): boolean | undefined;
    /**
     * Sets the isReminderOn property value.
     * @param value Value to set for the isReminderOn property.
     */
    set isReminderOn(value: boolean | undefined);
    /**
     * Gets the location property value.
     * @returns a location
     */
    get location(): Location | undefined;
    /**
     * Sets the location property value.
     * @param value Value to set for the location property.
     */
    set location(value: Location | undefined);
    /**
     * Gets the locations property value.
     * @returns a location
     */
    get locations(): Location[] | undefined;
    /**
     * Sets the locations property value.
     * @param value Value to set for the locations property.
     */
    set locations(value: Location[] | undefined);
    /**
     * Gets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the event. Read-only. Nullable.
     * @returns a multiValueLegacyExtendedProperty
     */
    get multiValueExtendedProperties(): MultiValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the event. Read-only. Nullable.
     * @param value Value to set for the multiValueExtendedProperties property.
     */
    set multiValueExtendedProperties(value: MultiValueLegacyExtendedProperty[] | undefined);
    /**
     * Gets the onlineMeeting property value.
     * @returns a onlineMeetingInfo
     */
    get onlineMeeting(): OnlineMeetingInfo | undefined;
    /**
     * Sets the onlineMeeting property value.
     * @param value Value to set for the onlineMeeting property.
     */
    set onlineMeeting(value: OnlineMeetingInfo | undefined);
    /**
     * Gets the onlineMeetingProvider property value.
     * @returns a onlineMeetingProviderType
     */
    get onlineMeetingProvider(): OnlineMeetingProviderType | undefined;
    /**
     * Sets the onlineMeetingProvider property value.
     * @param value Value to set for the onlineMeetingProvider property.
     */
    set onlineMeetingProvider(value: OnlineMeetingProviderType | undefined);
    /**
     * Gets the onlineMeetingUrl property value.
     * @returns a string
     */
    get onlineMeetingUrl(): string | undefined;
    /**
     * Sets the onlineMeetingUrl property value.
     * @param value Value to set for the onlineMeetingUrl property.
     */
    set onlineMeetingUrl(value: string | undefined);
    /**
     * Gets the organizer property value.
     * @returns a recipient
     */
    get organizer(): Recipient | undefined;
    /**
     * Sets the organizer property value.
     * @param value Value to set for the organizer property.
     */
    set organizer(value: Recipient | undefined);
    /**
     * Gets the originalEndTimeZone property value.
     * @returns a string
     */
    get originalEndTimeZone(): string | undefined;
    /**
     * Sets the originalEndTimeZone property value.
     * @param value Value to set for the originalEndTimeZone property.
     */
    set originalEndTimeZone(value: string | undefined);
    /**
     * Gets the originalStart property value.
     * @returns a Date
     */
    get originalStart(): Date | undefined;
    /**
     * Sets the originalStart property value.
     * @param value Value to set for the originalStart property.
     */
    set originalStart(value: Date | undefined);
    /**
     * Gets the originalStartTimeZone property value.
     * @returns a string
     */
    get originalStartTimeZone(): string | undefined;
    /**
     * Sets the originalStartTimeZone property value.
     * @param value Value to set for the originalStartTimeZone property.
     */
    set originalStartTimeZone(value: string | undefined);
    /**
     * Gets the recurrence property value.
     * @returns a patternedRecurrence
     */
    get recurrence(): PatternedRecurrence | undefined;
    /**
     * Sets the recurrence property value.
     * @param value Value to set for the recurrence property.
     */
    set recurrence(value: PatternedRecurrence | undefined);
    /**
     * Gets the reminderMinutesBeforeStart property value.
     * @returns a integer
     */
    get reminderMinutesBeforeStart(): number | undefined;
    /**
     * Sets the reminderMinutesBeforeStart property value.
     * @param value Value to set for the reminderMinutesBeforeStart property.
     */
    set reminderMinutesBeforeStart(value: number | undefined);
    /**
     * Gets the responseRequested property value.
     * @returns a boolean
     */
    get responseRequested(): boolean | undefined;
    /**
     * Sets the responseRequested property value.
     * @param value Value to set for the responseRequested property.
     */
    set responseRequested(value: boolean | undefined);
    /**
     * Gets the responseStatus property value.
     * @returns a responseStatus
     */
    get responseStatus(): ResponseStatus | undefined;
    /**
     * Sets the responseStatus property value.
     * @param value Value to set for the responseStatus property.
     */
    set responseStatus(value: ResponseStatus | undefined);
    /**
     * Gets the sensitivity property value.
     * @returns a sensitivity
     */
    get sensitivity(): Sensitivity | undefined;
    /**
     * Sets the sensitivity property value.
     * @param value Value to set for the sensitivity property.
     */
    set sensitivity(value: Sensitivity | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the seriesMasterId property value.
     * @returns a string
     */
    get seriesMasterId(): string | undefined;
    /**
     * Sets the seriesMasterId property value.
     * @param value Value to set for the seriesMasterId property.
     */
    set seriesMasterId(value: string | undefined);
    /**
     * Gets the showAs property value.
     * @returns a freeBusyStatus
     */
    get showAs(): FreeBusyStatus | undefined;
    /**
     * Sets the showAs property value.
     * @param value Value to set for the showAs property.
     */
    set showAs(value: FreeBusyStatus | undefined);
    /**
     * Gets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the event. Read-only. Nullable.
     * @returns a singleValueLegacyExtendedProperty
     */
    get singleValueExtendedProperties(): SingleValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the event. Read-only. Nullable.
     * @param value Value to set for the singleValueExtendedProperties property.
     */
    set singleValueExtendedProperties(value: SingleValueLegacyExtendedProperty[] | undefined);
    /**
     * Gets the start property value.
     * @returns a dateTimeTimeZone
     */
    get start(): DateTimeTimeZone | undefined;
    /**
     * Sets the start property value.
     * @param value Value to set for the start property.
     */
    set start(value: DateTimeTimeZone | undefined);
    /**
     * Gets the subject property value.
     * @returns a string
     */
    get subject(): string | undefined;
    /**
     * Sets the subject property value.
     * @param value Value to set for the subject property.
     */
    set subject(value: string | undefined);
    /**
     * Gets the transactionId property value.
     * @returns a string
     */
    get transactionId(): string | undefined;
    /**
     * Sets the transactionId property value.
     * @param value Value to set for the transactionId property.
     */
    set transactionId(value: string | undefined);
    /**
     * Gets the type property value.
     * @returns a eventType
     */
    get type(): EventType | undefined;
    /**
     * Sets the type property value.
     * @param value Value to set for the type property.
     */
    set type(value: EventType | undefined);
    /**
     * Gets the webLink property value.
     * @returns a string
     */
    get webLink(): string | undefined;
    /**
     * Sets the webLink property value.
     * @param value Value to set for the webLink property.
     */
    set webLink(value: string | undefined);
}
