"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Fido2AuthenticationMethod = void 0;
const attestationLevel_1 = require("./attestationLevel");
const index_1 = require("./index");
class Fido2AuthenticationMethod extends index_1.AuthenticationMethod {
    /**
     * Instantiates a new fido2AuthenticationMethod and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the aaGuid property value. Authenticator Attestation GUID, an identifier that indicates the type (e.g. make and model) of the authenticator.
     * @returns a string
     */
    get aaGuid() {
        return this._aaGuid;
    }
    ;
    /**
     * Sets the aaGuid property value. Authenticator Attestation GUID, an identifier that indicates the type (e.g. make and model) of the authenticator.
     * @param value Value to set for the aaGuid property.
     */
    set aaGuid(value) {
        this._aaGuid = value;
    }
    ;
    /**
     * Gets the attestationCertificates property value. The attestation certificate(s) attached to this security key.
     * @returns a string
     */
    get attestationCertificates() {
        return this._attestationCertificates;
    }
    ;
    /**
     * Sets the attestationCertificates property value. The attestation certificate(s) attached to this security key.
     * @param value Value to set for the attestationCertificates property.
     */
    set attestationCertificates(value) {
        this._attestationCertificates = value;
    }
    ;
    /**
     * Gets the attestationLevel property value. The attestation level of this FIDO2 security key. Possible values are: attested, or notAttested.
     * @returns a attestationLevel
     */
    get attestationLevel() {
        return this._attestationLevel;
    }
    ;
    /**
     * Sets the attestationLevel property value. The attestation level of this FIDO2 security key. Possible values are: attested, or notAttested.
     * @param value Value to set for the attestationLevel property.
     */
    set attestationLevel(value) {
        this._attestationLevel = value;
    }
    ;
    ;
    /**
     * Gets the createdDateTime property value. The timestamp when this key was registered to the user.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. The timestamp when this key was registered to the user.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the displayName property value. The display name of the key as given by the user.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. The display name of the key as given by the user.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "aaGuid": (o, n) => { o.aaGuid = n.getStringValue(); }, "attestationCertificates": (o, n) => { o.attestationCertificates = n.getCollectionOfPrimitiveValues(); }, "attestationLevel": (o, n) => { o.attestationLevel = n.getEnumValue(attestationLevel_1.AttestationLevel); }, "createdDateTime": (o, n) => { o.createdDateTime = n.getDateValue(); }, "displayName": (o, n) => { o.displayName = n.getStringValue(); }, "model": (o, n) => { o.model = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the model property value. The manufacturer-assigned model of the FIDO2 security key.
     * @returns a string
     */
    get model() {
        return this._model;
    }
    ;
    /**
     * Sets the model property value. The manufacturer-assigned model of the FIDO2 security key.
     * @param value Value to set for the model property.
     */
    set model(value) {
        this._model = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("aaGuid", this.aaGuid);
        writer.writeCollectionOfPrimitiveValues("attestationCertificates", this.attestationCertificates);
        writer.writeEnumValue("attestationLevel", this.attestationLevel);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeStringValue("model", this.model);
    }
    ;
}
exports.Fido2AuthenticationMethod = Fido2AuthenticationMethod;
