import { Entity, InvitedUserMessageInfo, User } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Invitation extends Entity implements Parsable {
    /** The user created as part of the invitation creation. Read-Only  */
    private _invitedUser?;
    /** The display name of the user being invited.  */
    private _invitedUserDisplayName?;
    /** The email address of the user being invited. Required. The following special characters are not permitted in the email address:Tilde (~)Exclamation point (!)Number sign (#)Dollar sign ($)Percent (%)Circumflex (^)Ampersand (&)Asterisk (*)Parentheses (( ))Plus sign (+)Equal sign (=)Brackets ([ ])Braces ({ })Backslash (/)Slash mark (/)Pipe (/|)Semicolon (;)Colon (:)Quotation marks (')Angle brackets (< >)Question mark (?)Comma (,)However, the following exceptions apply:A period (.) or a hyphen (-) is permitted anywhere in the user name, except at the beginning or end of the name.An underscore (_) is permitted anywhere in the user name. This includes at the beginning or end of the name.  */
    private _invitedUserEmailAddress?;
    /** Additional configuration for the message being sent to the invited user, including customizing message text, language and cc recipient list.  */
    private _invitedUserMessageInfo?;
    /** The userType of the user being invited. By default, this is Guest. You can invite as Member if you are a company administrator.  */
    private _invitedUserType?;
    /** The URL the user can use to redeem their invitation. Read-only.  */
    private _inviteRedeemUrl?;
    /** The URL the user should be redirected to once the invitation is redeemed. Required.  */
    private _inviteRedirectUrl?;
    /** Indicates whether an email should be sent to the user being invited. The default is false.  */
    private _sendInvitationMessage?;
    /** The status of the invitation. Possible values are: PendingAcceptance, Completed, InProgress, and Error.  */
    private _status?;
    /**
     * Instantiates a new invitation and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the invitedUser property value. The user created as part of the invitation creation. Read-Only
     * @returns a user
     */
    get invitedUser(): User | undefined;
    /**
     * Sets the invitedUser property value. The user created as part of the invitation creation. Read-Only
     * @param value Value to set for the invitedUser property.
     */
    set invitedUser(value: User | undefined);
    /**
     * Gets the invitedUserDisplayName property value. The display name of the user being invited.
     * @returns a string
     */
    get invitedUserDisplayName(): string | undefined;
    /**
     * Sets the invitedUserDisplayName property value. The display name of the user being invited.
     * @param value Value to set for the invitedUserDisplayName property.
     */
    set invitedUserDisplayName(value: string | undefined);
    /**
     * Gets the invitedUserEmailAddress property value. The email address of the user being invited. Required. The following special characters are not permitted in the email address:Tilde (~)Exclamation point (!)Number sign (#)Dollar sign ($)Percent (%)Circumflex (^)Ampersand (&)Asterisk (*)Parentheses (( ))Plus sign (+)Equal sign (=)Brackets ([ ])Braces ({ })Backslash (/)Slash mark (/)Pipe (/|)Semicolon (;)Colon (:)Quotation marks (')Angle brackets (< >)Question mark (?)Comma (,)However, the following exceptions apply:A period (.) or a hyphen (-) is permitted anywhere in the user name, except at the beginning or end of the name.An underscore (_) is permitted anywhere in the user name. This includes at the beginning or end of the name.
     * @returns a string
     */
    get invitedUserEmailAddress(): string | undefined;
    /**
     * Sets the invitedUserEmailAddress property value. The email address of the user being invited. Required. The following special characters are not permitted in the email address:Tilde (~)Exclamation point (!)Number sign (#)Dollar sign ($)Percent (%)Circumflex (^)Ampersand (&)Asterisk (*)Parentheses (( ))Plus sign (+)Equal sign (=)Brackets ([ ])Braces ({ })Backslash (/)Slash mark (/)Pipe (/|)Semicolon (;)Colon (:)Quotation marks (')Angle brackets (< >)Question mark (?)Comma (,)However, the following exceptions apply:A period (.) or a hyphen (-) is permitted anywhere in the user name, except at the beginning or end of the name.An underscore (_) is permitted anywhere in the user name. This includes at the beginning or end of the name.
     * @param value Value to set for the invitedUserEmailAddress property.
     */
    set invitedUserEmailAddress(value: string | undefined);
    /**
     * Gets the invitedUserMessageInfo property value. Additional configuration for the message being sent to the invited user, including customizing message text, language and cc recipient list.
     * @returns a invitedUserMessageInfo
     */
    get invitedUserMessageInfo(): InvitedUserMessageInfo | undefined;
    /**
     * Sets the invitedUserMessageInfo property value. Additional configuration for the message being sent to the invited user, including customizing message text, language and cc recipient list.
     * @param value Value to set for the invitedUserMessageInfo property.
     */
    set invitedUserMessageInfo(value: InvitedUserMessageInfo | undefined);
    /**
     * Gets the invitedUserType property value. The userType of the user being invited. By default, this is Guest. You can invite as Member if you are a company administrator.
     * @returns a string
     */
    get invitedUserType(): string | undefined;
    /**
     * Sets the invitedUserType property value. The userType of the user being invited. By default, this is Guest. You can invite as Member if you are a company administrator.
     * @param value Value to set for the invitedUserType property.
     */
    set invitedUserType(value: string | undefined);
    /**
     * Gets the inviteRedeemUrl property value. The URL the user can use to redeem their invitation. Read-only.
     * @returns a string
     */
    get inviteRedeemUrl(): string | undefined;
    /**
     * Sets the inviteRedeemUrl property value. The URL the user can use to redeem their invitation. Read-only.
     * @param value Value to set for the inviteRedeemUrl property.
     */
    set inviteRedeemUrl(value: string | undefined);
    /**
     * Gets the inviteRedirectUrl property value. The URL the user should be redirected to once the invitation is redeemed. Required.
     * @returns a string
     */
    get inviteRedirectUrl(): string | undefined;
    /**
     * Sets the inviteRedirectUrl property value. The URL the user should be redirected to once the invitation is redeemed. Required.
     * @param value Value to set for the inviteRedirectUrl property.
     */
    set inviteRedirectUrl(value: string | undefined);
    /**
     * Gets the sendInvitationMessage property value. Indicates whether an email should be sent to the user being invited. The default is false.
     * @returns a boolean
     */
    get sendInvitationMessage(): boolean | undefined;
    /**
     * Sets the sendInvitationMessage property value. Indicates whether an email should be sent to the user being invited. The default is false.
     * @param value Value to set for the sendInvitationMessage property.
     */
    set sendInvitationMessage(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. The status of the invitation. Possible values are: PendingAcceptance, Completed, InProgress, and Error.
     * @returns a string
     */
    get status(): string | undefined;
    /**
     * Sets the status property value. The status of the invitation. Possible values are: PendingAcceptance, Completed, InProgress, and Error.
     * @param value Value to set for the status property.
     */
    set status(value: string | undefined);
}
