import { SharepointIds } from './index';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ItemReference implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.  */
    private _additionalData;
    /** Unique identifier of the drive instance that contains the item. Read-only.  */
    private _driveId?;
    /** Identifies the type of drive. See [drive][] resource for values.  */
    private _driveType?;
    /** Unique identifier of the item in the drive. Read-only.  */
    private _id?;
    /** The name of the item being referenced. Read-only.  */
    private _name?;
    /** Path that can be used to navigate to the item. Read-only.  */
    private _path?;
    /** A unique identifier for a shared resource that can be accessed via the [Shares][] API.  */
    private _shareId?;
    /** Returns identifiers useful for SharePoint REST compatibility. Read-only.  */
    private _sharepointIds?;
    /** For OneDrive for Business and SharePoint, this property represents the ID of the site that contains the parent document library of the driveItem resource. The value is the same as the id property of that [site][] resource. It is an opaque string that consists of three identifiers of the site. For OneDrive, this property is not populated.  */
    private _siteId?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Instantiates a new itemReference and sets the default values.
     */
    constructor();
    /**
     * Gets the driveId property value. Unique identifier of the drive instance that contains the item. Read-only.
     * @returns a string
     */
    get driveId(): string | undefined;
    /**
     * Sets the driveId property value. Unique identifier of the drive instance that contains the item. Read-only.
     * @param value Value to set for the driveId property.
     */
    set driveId(value: string | undefined);
    /**
     * Gets the driveType property value. Identifies the type of drive. See [drive][] resource for values.
     * @returns a string
     */
    get driveType(): string | undefined;
    /**
     * Sets the driveType property value. Identifies the type of drive. See [drive][] resource for values.
     * @param value Value to set for the driveType property.
     */
    set driveType(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the id property value. Unique identifier of the item in the drive. Read-only.
     * @returns a string
     */
    get id(): string | undefined;
    /**
     * Sets the id property value. Unique identifier of the item in the drive. Read-only.
     * @param value Value to set for the id property.
     */
    set id(value: string | undefined);
    /**
     * Gets the name property value. The name of the item being referenced. Read-only.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The name of the item being referenced. Read-only.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the path property value. Path that can be used to navigate to the item. Read-only.
     * @returns a string
     */
    get path(): string | undefined;
    /**
     * Sets the path property value. Path that can be used to navigate to the item. Read-only.
     * @param value Value to set for the path property.
     */
    set path(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the shareId property value. A unique identifier for a shared resource that can be accessed via the [Shares][] API.
     * @returns a string
     */
    get shareId(): string | undefined;
    /**
     * Sets the shareId property value. A unique identifier for a shared resource that can be accessed via the [Shares][] API.
     * @param value Value to set for the shareId property.
     */
    set shareId(value: string | undefined);
    /**
     * Gets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @returns a sharepointIds
     */
    get sharepointIds(): SharepointIds | undefined;
    /**
     * Sets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @param value Value to set for the sharepointIds property.
     */
    set sharepointIds(value: SharepointIds | undefined);
    /**
     * Gets the siteId property value. For OneDrive for Business and SharePoint, this property represents the ID of the site that contains the parent document library of the driveItem resource. The value is the same as the id property of that [site][] resource. It is an opaque string that consists of three identifiers of the site. For OneDrive, this property is not populated.
     * @returns a string
     */
    get siteId(): string | undefined;
    /**
     * Sets the siteId property value. For OneDrive for Business and SharePoint, this property represents the ID of the site that contains the parent document library of the driveItem resource. The value is the same as the id property of that [site][] resource. It is an opaque string that consists of three identifiers of the site. For OneDrive, this property is not populated.
     * @param value Value to set for the siteId property.
     */
    set siteId(value: string | undefined);
}
