"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.List = void 0;
const createColumnDefinitionFromDiscriminatorValue_1 = require("./createColumnDefinitionFromDiscriminatorValue");
const createContentTypeFromDiscriminatorValue_1 = require("./createContentTypeFromDiscriminatorValue");
const createDriveFromDiscriminatorValue_1 = require("./createDriveFromDiscriminatorValue");
const createListInfoFromDiscriminatorValue_1 = require("./createListInfoFromDiscriminatorValue");
const createListItemFromDiscriminatorValue_1 = require("./createListItemFromDiscriminatorValue");
const createSharepointIdsFromDiscriminatorValue_1 = require("./createSharepointIdsFromDiscriminatorValue");
const createSubscriptionFromDiscriminatorValue_1 = require("./createSubscriptionFromDiscriminatorValue");
const createSystemFacetFromDiscriminatorValue_1 = require("./createSystemFacetFromDiscriminatorValue");
const index_1 = require("./index");
class List extends index_1.BaseItem {
    /**
     * Instantiates a new list and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the columns property value. The collection of field definitions for this list.
     * @returns a columnDefinition
     */
    get columns() {
        return this._columns;
    }
    ;
    /**
     * Sets the columns property value. The collection of field definitions for this list.
     * @param value Value to set for the columns property.
     */
    set columns(value) {
        this._columns = value;
    }
    ;
    ;
    /**
     * Gets the contentTypes property value. The collection of content types present in this list.
     * @returns a contentType
     */
    get contentTypes() {
        return this._contentTypes;
    }
    ;
    /**
     * Sets the contentTypes property value. The collection of content types present in this list.
     * @param value Value to set for the contentTypes property.
     */
    set contentTypes(value) {
        this._contentTypes = value;
    }
    ;
    /**
     * Gets the displayName property value. The displayable title of the list.
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. The displayable title of the list.
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * Gets the drive property value. Only present on document libraries. Allows access to the list as a [drive][] resource with [driveItems][driveItem].
     * @returns a drive
     */
    get drive() {
        return this._drive;
    }
    ;
    /**
     * Sets the drive property value. Only present on document libraries. Allows access to the list as a [drive][] resource with [driveItems][driveItem].
     * @param value Value to set for the drive property.
     */
    set drive(value) {
        this._drive = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "columns": (o, n) => { o.columns = n.getCollectionOfObjectValues(createColumnDefinitionFromDiscriminatorValue_1.createColumnDefinitionFromDiscriminatorValue); }, "contentTypes": (o, n) => { o.contentTypes = n.getCollectionOfObjectValues(createContentTypeFromDiscriminatorValue_1.createContentTypeFromDiscriminatorValue); }, "displayName": (o, n) => { o.displayName = n.getStringValue(); }, "drive": (o, n) => { o.drive = n.getObjectValue(createDriveFromDiscriminatorValue_1.createDriveFromDiscriminatorValue); }, "items": (o, n) => { o.items = n.getCollectionOfObjectValues(createListItemFromDiscriminatorValue_1.createListItemFromDiscriminatorValue); }, "list": (o, n) => { o.list = n.getObjectValue(createListInfoFromDiscriminatorValue_1.createListInfoFromDiscriminatorValue); }, "sharepointIds": (o, n) => { o.sharepointIds = n.getObjectValue(createSharepointIdsFromDiscriminatorValue_1.createSharepointIdsFromDiscriminatorValue); }, "subscriptions": (o, n) => { o.subscriptions = n.getCollectionOfObjectValues(createSubscriptionFromDiscriminatorValue_1.createSubscriptionFromDiscriminatorValue); }, "system": (o, n) => { o.system = n.getObjectValue(createSystemFacetFromDiscriminatorValue_1.createSystemFacetFromDiscriminatorValue); } });
    }
    ;
    /**
     * Gets the items property value. All items contained in the list.
     * @returns a listItem
     */
    get items() {
        return this._items;
    }
    ;
    /**
     * Sets the items property value. All items contained in the list.
     * @param value Value to set for the items property.
     */
    set items(value) {
        this._items = value;
    }
    ;
    /**
     * Gets the list property value. Provides additional details about the list.
     * @returns a listInfo
     */
    get list() {
        return this._list;
    }
    ;
    /**
     * Sets the list property value. Provides additional details about the list.
     * @param value Value to set for the list property.
     */
    set list(value) {
        this._list = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeCollectionOfObjectValues("columns", this.columns);
        writer.writeCollectionOfObjectValues("contentTypes", this.contentTypes);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeObjectValue("drive", this.drive);
        writer.writeCollectionOfObjectValues("items", this.items);
        writer.writeObjectValue("list", this.list);
        writer.writeObjectValue("sharepointIds", this.sharepointIds);
        writer.writeCollectionOfObjectValues("subscriptions", this.subscriptions);
        writer.writeObjectValue("system", this.system);
    }
    ;
    /**
     * Gets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @returns a sharepointIds
     */
    get sharepointIds() {
        return this._sharepointIds;
    }
    ;
    /**
     * Sets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @param value Value to set for the sharepointIds property.
     */
    set sharepointIds(value) {
        this._sharepointIds = value;
    }
    ;
    /**
     * Gets the subscriptions property value. The set of subscriptions on the list.
     * @returns a subscription
     */
    get subscriptions() {
        return this._subscriptions;
    }
    ;
    /**
     * Sets the subscriptions property value. The set of subscriptions on the list.
     * @param value Value to set for the subscriptions property.
     */
    set subscriptions(value) {
        this._subscriptions = value;
    }
    ;
    /**
     * Gets the system property value. If present, indicates that this is a system-managed list. Read-only.
     * @returns a systemFacet
     */
    get system() {
        return this._system;
    }
    ;
    /**
     * Sets the system property value. If present, indicates that this is a system-managed list. Read-only.
     * @param value Value to set for the system property.
     */
    set system(value) {
        this._system = value;
    }
    ;
}
exports.List = List;
