import { BaseItem, ContentTypeInfo, DriveItem, FieldValueSet, ItemAnalytics, ListItemVersion, SharepointIds } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ListItem extends BaseItem implements Parsable {
    /** Analytics about the view activities that took place on this item.  */
    private _analytics?;
    /** The content type of this list item  */
    private _contentType?;
    /** For document libraries, the driveItem relationship exposes the listItem as a [driveItem][]  */
    private _driveItem?;
    /** The values of the columns set on this list item.  */
    private _fields?;
    /** Returns identifiers useful for SharePoint REST compatibility. Read-only.  */
    private _sharepointIds?;
    /** The list of previous versions of the list item.  */
    private _versions?;
    /**
     * Gets the analytics property value. Analytics about the view activities that took place on this item.
     * @returns a itemAnalytics
     */
    get analytics(): ItemAnalytics | undefined;
    /**
     * Sets the analytics property value. Analytics about the view activities that took place on this item.
     * @param value Value to set for the analytics property.
     */
    set analytics(value: ItemAnalytics | undefined);
    /**
     * Instantiates a new listItem and sets the default values.
     */
    constructor();
    /**
     * Gets the contentType property value. The content type of this list item
     * @returns a contentTypeInfo
     */
    get contentType(): ContentTypeInfo | undefined;
    /**
     * Sets the contentType property value. The content type of this list item
     * @param value Value to set for the contentType property.
     */
    set contentType(value: ContentTypeInfo | undefined);
    /**
     * Gets the driveItem property value. For document libraries, the driveItem relationship exposes the listItem as a [driveItem][]
     * @returns a driveItem
     */
    get driveItem(): DriveItem | undefined;
    /**
     * Sets the driveItem property value. For document libraries, the driveItem relationship exposes the listItem as a [driveItem][]
     * @param value Value to set for the driveItem property.
     */
    set driveItem(value: DriveItem | undefined);
    /**
     * Gets the fields property value. The values of the columns set on this list item.
     * @returns a fieldValueSet
     */
    get fields(): FieldValueSet | undefined;
    /**
     * Sets the fields property value. The values of the columns set on this list item.
     * @param value Value to set for the fields property.
     */
    set fields(value: FieldValueSet | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @returns a sharepointIds
     */
    get sharepointIds(): SharepointIds | undefined;
    /**
     * Sets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @param value Value to set for the sharepointIds property.
     */
    set sharepointIds(value: SharepointIds | undefined);
    /**
     * Gets the versions property value. The list of previous versions of the list item.
     * @returns a listItemVersion
     */
    get versions(): ListItemVersion[] | undefined;
    /**
     * Sets the versions property value. The list of previous versions of the list item.
     * @param value Value to set for the versions property.
     */
    set versions(value: ListItemVersion[] | undefined);
}
