import { AutomaticRepliesMailTips, EmailAddress, MailTipsError, Recipient } from './index';
import { RecipientScopeType } from './recipientScopeType';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class MailTips implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.  */
    private _additionalData;
    /** Mail tips for automatic reply if it has been set up by the recipient.  */
    private _automaticReplies?;
    /** A custom mail tip that can be set on the recipient's mailbox.  */
    private _customMailTip?;
    /** Whether the recipient's mailbox is restricted, for example, accepting messages from only a predefined list of senders, rejecting messages from a predefined list of senders, or accepting messages from only authenticated senders.  */
    private _deliveryRestricted?;
    /** The email address of the recipient to get mailtips for.  */
    private _emailAddress?;
    /** Errors that occur during the getMailTips action.  */
    private _error_escaped?;
    /** The number of external members if the recipient is a distribution list.  */
    private _externalMemberCount?;
    /** Whether sending messages to the recipient requires approval. For example, if the recipient is a large distribution list and a moderator has been set up to approve messages sent to that distribution list, or if sending messages to a recipient requires approval of the recipient's manager.  */
    private _isModerated?;
    /** The mailbox full status of the recipient.  */
    private _mailboxFull?;
    /** The maximum message size that has been configured for the recipient's organization or mailbox.  */
    private _maxMessageSize?;
    /** The scope of the recipient. Possible values are: none, internal, external, externalPartner, externalNonParther. For example, an administrator can set another organization to be its 'partner'. The scope is useful if an administrator wants certain mailtips to be accessible to certain scopes. It's also useful to senders to inform them that their message may leave the organization, helping them make the correct decisions about wording, tone and content.  */
    private _recipientScope?;
    /** Recipients suggested based on previous contexts where they appear in the same message.  */
    private _recipientSuggestions?;
    /** The number of members if the recipient is a distribution list.  */
    private _totalMemberCount?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the automaticReplies property value. Mail tips for automatic reply if it has been set up by the recipient.
     * @returns a automaticRepliesMailTips
     */
    get automaticReplies(): AutomaticRepliesMailTips | undefined;
    /**
     * Sets the automaticReplies property value. Mail tips for automatic reply if it has been set up by the recipient.
     * @param value Value to set for the automaticReplies property.
     */
    set automaticReplies(value: AutomaticRepliesMailTips | undefined);
    /**
     * Instantiates a new mailTips and sets the default values.
     */
    constructor();
    /**
     * Gets the customMailTip property value. A custom mail tip that can be set on the recipient's mailbox.
     * @returns a string
     */
    get customMailTip(): string | undefined;
    /**
     * Sets the customMailTip property value. A custom mail tip that can be set on the recipient's mailbox.
     * @param value Value to set for the customMailTip property.
     */
    set customMailTip(value: string | undefined);
    /**
     * Gets the deliveryRestricted property value. Whether the recipient's mailbox is restricted, for example, accepting messages from only a predefined list of senders, rejecting messages from a predefined list of senders, or accepting messages from only authenticated senders.
     * @returns a boolean
     */
    get deliveryRestricted(): boolean | undefined;
    /**
     * Sets the deliveryRestricted property value. Whether the recipient's mailbox is restricted, for example, accepting messages from only a predefined list of senders, rejecting messages from a predefined list of senders, or accepting messages from only authenticated senders.
     * @param value Value to set for the deliveryRestricted property.
     */
    set deliveryRestricted(value: boolean | undefined);
    /**
     * Gets the emailAddress property value. The email address of the recipient to get mailtips for.
     * @returns a emailAddress
     */
    get emailAddress(): EmailAddress | undefined;
    /**
     * Sets the emailAddress property value. The email address of the recipient to get mailtips for.
     * @param value Value to set for the emailAddress property.
     */
    set emailAddress(value: EmailAddress | undefined);
    /**
     * Gets the error property value. Errors that occur during the getMailTips action.
     * @returns a mailTipsError
     */
    get error_escaped(): MailTipsError | undefined;
    /**
     * Sets the error property value. Errors that occur during the getMailTips action.
     * @param value Value to set for the error_escaped property.
     */
    set error_escaped(value: MailTipsError | undefined);
    /**
     * Gets the externalMemberCount property value. The number of external members if the recipient is a distribution list.
     * @returns a integer
     */
    get externalMemberCount(): number | undefined;
    /**
     * Sets the externalMemberCount property value. The number of external members if the recipient is a distribution list.
     * @param value Value to set for the externalMemberCount property.
     */
    set externalMemberCount(value: number | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isModerated property value. Whether sending messages to the recipient requires approval. For example, if the recipient is a large distribution list and a moderator has been set up to approve messages sent to that distribution list, or if sending messages to a recipient requires approval of the recipient's manager.
     * @returns a boolean
     */
    get isModerated(): boolean | undefined;
    /**
     * Sets the isModerated property value. Whether sending messages to the recipient requires approval. For example, if the recipient is a large distribution list and a moderator has been set up to approve messages sent to that distribution list, or if sending messages to a recipient requires approval of the recipient's manager.
     * @param value Value to set for the isModerated property.
     */
    set isModerated(value: boolean | undefined);
    /**
     * Gets the mailboxFull property value. The mailbox full status of the recipient.
     * @returns a boolean
     */
    get mailboxFull(): boolean | undefined;
    /**
     * Sets the mailboxFull property value. The mailbox full status of the recipient.
     * @param value Value to set for the mailboxFull property.
     */
    set mailboxFull(value: boolean | undefined);
    /**
     * Gets the maxMessageSize property value. The maximum message size that has been configured for the recipient's organization or mailbox.
     * @returns a integer
     */
    get maxMessageSize(): number | undefined;
    /**
     * Sets the maxMessageSize property value. The maximum message size that has been configured for the recipient's organization or mailbox.
     * @param value Value to set for the maxMessageSize property.
     */
    set maxMessageSize(value: number | undefined);
    /**
     * Gets the recipientScope property value. The scope of the recipient. Possible values are: none, internal, external, externalPartner, externalNonParther. For example, an administrator can set another organization to be its 'partner'. The scope is useful if an administrator wants certain mailtips to be accessible to certain scopes. It's also useful to senders to inform them that their message may leave the organization, helping them make the correct decisions about wording, tone and content.
     * @returns a recipientScopeType
     */
    get recipientScope(): RecipientScopeType | undefined;
    /**
     * Sets the recipientScope property value. The scope of the recipient. Possible values are: none, internal, external, externalPartner, externalNonParther. For example, an administrator can set another organization to be its 'partner'. The scope is useful if an administrator wants certain mailtips to be accessible to certain scopes. It's also useful to senders to inform them that their message may leave the organization, helping them make the correct decisions about wording, tone and content.
     * @param value Value to set for the recipientScope property.
     */
    set recipientScope(value: RecipientScopeType | undefined);
    /**
     * Gets the recipientSuggestions property value. Recipients suggested based on previous contexts where they appear in the same message.
     * @returns a recipient
     */
    get recipientSuggestions(): Recipient[] | undefined;
    /**
     * Sets the recipientSuggestions property value. Recipients suggested based on previous contexts where they appear in the same message.
     * @param value Value to set for the recipientSuggestions property.
     */
    set recipientSuggestions(value: Recipient[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the totalMemberCount property value. The number of members if the recipient is a distribution list.
     * @returns a integer
     */
    get totalMemberCount(): number | undefined;
    /**
     * Sets the totalMemberCount property value. The number of members if the recipient is a distribution list.
     * @param value Value to set for the totalMemberCount property.
     */
    set totalMemberCount(value: number | undefined);
}
