import { DelegateMeetingMessageDeliveryOptions } from './delegateMeetingMessageDeliveryOptions';
import { AutomaticRepliesSetting, LocaleInfo, WorkingHours } from './index';
import { UserPurpose } from './userPurpose';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class MailboxSettings implements AdditionalDataHolder, Parsable {
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.  */
    private _additionalData;
    /** Folder ID of an archive folder for the user.  */
    private _archiveFolder?;
    /** Configuration settings to automatically notify the sender of an incoming email with a message from the signed-in user.  */
    private _automaticRepliesSetting?;
    /** The date format for the user's mailbox.  */
    private _dateFormat?;
    /** If the user has a calendar delegate, this specifies whether the delegate, mailbox owner, or both receive meeting messages and meeting responses. Possible values are: sendToDelegateAndInformationToPrincipal, sendToDelegateAndPrincipal, sendToDelegateOnly.  */
    private _delegateMeetingMessageDeliveryOptions?;
    /** The locale information for the user, including the preferred language and country/region.  */
    private _language?;
    /** The time format for the user's mailbox.  */
    private _timeFormat?;
    /** The default time zone for the user's mailbox.  */
    private _timeZone?;
    /** The purpose of the mailbox. Used to differentiate a mailbox for a single user from a shared mailbox and equipment mailbox in Exchange Online. Read only.  */
    private _userPurpose?;
    /** The days of the week and hours in a specific time zone that the user works.  */
    private _workingHours?;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the archiveFolder property value. Folder ID of an archive folder for the user.
     * @returns a string
     */
    get archiveFolder(): string | undefined;
    /**
     * Sets the archiveFolder property value. Folder ID of an archive folder for the user.
     * @param value Value to set for the archiveFolder property.
     */
    set archiveFolder(value: string | undefined);
    /**
     * Gets the automaticRepliesSetting property value. Configuration settings to automatically notify the sender of an incoming email with a message from the signed-in user.
     * @returns a automaticRepliesSetting
     */
    get automaticRepliesSetting(): AutomaticRepliesSetting | undefined;
    /**
     * Sets the automaticRepliesSetting property value. Configuration settings to automatically notify the sender of an incoming email with a message from the signed-in user.
     * @param value Value to set for the automaticRepliesSetting property.
     */
    set automaticRepliesSetting(value: AutomaticRepliesSetting | undefined);
    /**
     * Instantiates a new mailboxSettings and sets the default values.
     */
    constructor();
    /**
     * Gets the dateFormat property value. The date format for the user's mailbox.
     * @returns a string
     */
    get dateFormat(): string | undefined;
    /**
     * Sets the dateFormat property value. The date format for the user's mailbox.
     * @param value Value to set for the dateFormat property.
     */
    set dateFormat(value: string | undefined);
    /**
     * Gets the delegateMeetingMessageDeliveryOptions property value. If the user has a calendar delegate, this specifies whether the delegate, mailbox owner, or both receive meeting messages and meeting responses. Possible values are: sendToDelegateAndInformationToPrincipal, sendToDelegateAndPrincipal, sendToDelegateOnly.
     * @returns a delegateMeetingMessageDeliveryOptions
     */
    get delegateMeetingMessageDeliveryOptions(): DelegateMeetingMessageDeliveryOptions | undefined;
    /**
     * Sets the delegateMeetingMessageDeliveryOptions property value. If the user has a calendar delegate, this specifies whether the delegate, mailbox owner, or both receive meeting messages and meeting responses. Possible values are: sendToDelegateAndInformationToPrincipal, sendToDelegateAndPrincipal, sendToDelegateOnly.
     * @param value Value to set for the delegateMeetingMessageDeliveryOptions property.
     */
    set delegateMeetingMessageDeliveryOptions(value: DelegateMeetingMessageDeliveryOptions | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the language property value. The locale information for the user, including the preferred language and country/region.
     * @returns a localeInfo
     */
    get language(): LocaleInfo | undefined;
    /**
     * Sets the language property value. The locale information for the user, including the preferred language and country/region.
     * @param value Value to set for the language property.
     */
    set language(value: LocaleInfo | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the timeFormat property value. The time format for the user's mailbox.
     * @returns a string
     */
    get timeFormat(): string | undefined;
    /**
     * Sets the timeFormat property value. The time format for the user's mailbox.
     * @param value Value to set for the timeFormat property.
     */
    set timeFormat(value: string | undefined);
    /**
     * Gets the timeZone property value. The default time zone for the user's mailbox.
     * @returns a string
     */
    get timeZone(): string | undefined;
    /**
     * Sets the timeZone property value. The default time zone for the user's mailbox.
     * @param value Value to set for the timeZone property.
     */
    set timeZone(value: string | undefined);
    /**
     * Gets the userPurpose property value. The purpose of the mailbox. Used to differentiate a mailbox for a single user from a shared mailbox and equipment mailbox in Exchange Online. Read only.
     * @returns a userPurpose
     */
    get userPurpose(): UserPurpose | undefined;
    /**
     * Sets the userPurpose property value. The purpose of the mailbox. Used to differentiate a mailbox for a single user from a shared mailbox and equipment mailbox in Exchange Online. Read only.
     * @param value Value to set for the userPurpose property.
     */
    set userPurpose(value: UserPurpose | undefined);
    /**
     * Gets the workingHours property value. The days of the week and hours in a specific time zone that the user works.
     * @returns a workingHours
     */
    get workingHours(): WorkingHours | undefined;
    /**
     * Sets the workingHours property value. The days of the week and hours in a specific time zone that the user works.
     * @param value Value to set for the workingHours property.
     */
    set workingHours(value: WorkingHours | undefined);
}
