import { ManagedAppPolicy } from './index';
import { ManagedAppClipboardSharingLevel } from './managedAppClipboardSharingLevel';
import { ManagedAppDataStorageLocation } from './managedAppDataStorageLocation';
import { ManagedAppDataTransferLevel } from './managedAppDataTransferLevel';
import { ManagedAppPinCharacterSet } from './managedAppPinCharacterSet';
import { ManagedBrowserType } from './managedBrowserType';
import { Duration, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ManagedAppProtection extends ManagedAppPolicy implements Parsable {
    /** Data storage locations where a user may store managed data.  */
    private _allowedDataStorageLocations?;
    /** Sources from which data is allowed to be transferred. Possible values are: allApps, managedApps, none.  */
    private _allowedInboundDataTransferSources?;
    /** The level to which the clipboard may be shared between apps on the managed device. Possible values are: allApps, managedAppsWithPasteIn, managedApps, blocked.  */
    private _allowedOutboundClipboardSharingLevel?;
    /** Destinations to which data is allowed to be transferred. Possible values are: allApps, managedApps, none.  */
    private _allowedOutboundDataTransferDestinations?;
    /** Indicates whether contacts can be synced to the user's device.  */
    private _contactSyncBlocked?;
    /** Indicates whether the backup of a managed app's data is blocked.  */
    private _dataBackupBlocked?;
    /** Indicates whether device compliance is required.  */
    private _deviceComplianceRequired?;
    /** Indicates whether use of the app pin is required if the device pin is set.  */
    private _disableAppPinIfDevicePinIsSet?;
    /** Indicates whether use of the fingerprint reader is allowed in place of a pin if PinRequired is set to True.  */
    private _fingerprintBlocked?;
    /** Indicates in which managed browser(s) that internet links should be opened. When this property is configured, ManagedBrowserToOpenLinksRequired should be true. Possible values are: notConfigured, microsoftEdge.  */
    private _managedBrowser?;
    /** Indicates whether internet links should be opened in the managed browser app, or any custom browser specified by CustomBrowserProtocol (for iOS) or CustomBrowserPackageId/CustomBrowserDisplayName (for Android)  */
    private _managedBrowserToOpenLinksRequired?;
    /** Maximum number of incorrect pin retry attempts before the managed app is either blocked or wiped.  */
    private _maximumPinRetries?;
    /** Minimum pin length required for an app-level pin if PinRequired is set to True  */
    private _minimumPinLength?;
    /** Versions less than the specified version will block the managed app from accessing company data.  */
    private _minimumRequiredAppVersion?;
    /** Versions less than the specified version will block the managed app from accessing company data.  */
    private _minimumRequiredOsVersion?;
    /** Versions less than the specified version will result in warning message on the managed app.  */
    private _minimumWarningAppVersion?;
    /** Versions less than the specified version will result in warning message on the managed app from accessing company data.  */
    private _minimumWarningOsVersion?;
    /** Indicates whether organizational credentials are required for app use.  */
    private _organizationalCredentialsRequired?;
    /** TimePeriod before the all-level pin must be reset if PinRequired is set to True.  */
    private _periodBeforePinReset?;
    /** The period after which access is checked when the device is not connected to the internet.  */
    private _periodOfflineBeforeAccessCheck?;
    /** The amount of time an app is allowed to remain disconnected from the internet before all managed data it is wiped.  */
    private _periodOfflineBeforeWipeIsEnforced?;
    /** The period after which access is checked when the device is connected to the internet.  */
    private _periodOnlineBeforeAccessCheck?;
    /** Character set which may be used for an app-level pin if PinRequired is set to True. Possible values are: numeric, alphanumericAndSymbol.  */
    private _pinCharacterSet?;
    /** Indicates whether an app-level pin is required.  */
    private _pinRequired?;
    /** Indicates whether printing is allowed from managed apps.  */
    private _printBlocked?;
    /** Indicates whether users may use the 'Save As' menu item to save a copy of protected files.  */
    private _saveAsBlocked?;
    /** Indicates whether simplePin is blocked.  */
    private _simplePinBlocked?;
    /**
     * Gets the allowedDataStorageLocations property value. Data storage locations where a user may store managed data.
     * @returns a managedAppDataStorageLocation
     */
    get allowedDataStorageLocations(): ManagedAppDataStorageLocation[] | undefined;
    /**
     * Sets the allowedDataStorageLocations property value. Data storage locations where a user may store managed data.
     * @param value Value to set for the allowedDataStorageLocations property.
     */
    set allowedDataStorageLocations(value: ManagedAppDataStorageLocation[] | undefined);
    /**
     * Gets the allowedInboundDataTransferSources property value. Sources from which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @returns a managedAppDataTransferLevel
     */
    get allowedInboundDataTransferSources(): ManagedAppDataTransferLevel | undefined;
    /**
     * Sets the allowedInboundDataTransferSources property value. Sources from which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @param value Value to set for the allowedInboundDataTransferSources property.
     */
    set allowedInboundDataTransferSources(value: ManagedAppDataTransferLevel | undefined);
    /**
     * Gets the allowedOutboundClipboardSharingLevel property value. The level to which the clipboard may be shared between apps on the managed device. Possible values are: allApps, managedAppsWithPasteIn, managedApps, blocked.
     * @returns a managedAppClipboardSharingLevel
     */
    get allowedOutboundClipboardSharingLevel(): ManagedAppClipboardSharingLevel | undefined;
    /**
     * Sets the allowedOutboundClipboardSharingLevel property value. The level to which the clipboard may be shared between apps on the managed device. Possible values are: allApps, managedAppsWithPasteIn, managedApps, blocked.
     * @param value Value to set for the allowedOutboundClipboardSharingLevel property.
     */
    set allowedOutboundClipboardSharingLevel(value: ManagedAppClipboardSharingLevel | undefined);
    /**
     * Gets the allowedOutboundDataTransferDestinations property value. Destinations to which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @returns a managedAppDataTransferLevel
     */
    get allowedOutboundDataTransferDestinations(): ManagedAppDataTransferLevel | undefined;
    /**
     * Sets the allowedOutboundDataTransferDestinations property value. Destinations to which data is allowed to be transferred. Possible values are: allApps, managedApps, none.
     * @param value Value to set for the allowedOutboundDataTransferDestinations property.
     */
    set allowedOutboundDataTransferDestinations(value: ManagedAppDataTransferLevel | undefined);
    /**
     * Instantiates a new managedAppProtection and sets the default values.
     */
    constructor();
    /**
     * Gets the contactSyncBlocked property value. Indicates whether contacts can be synced to the user's device.
     * @returns a boolean
     */
    get contactSyncBlocked(): boolean | undefined;
    /**
     * Sets the contactSyncBlocked property value. Indicates whether contacts can be synced to the user's device.
     * @param value Value to set for the contactSyncBlocked property.
     */
    set contactSyncBlocked(value: boolean | undefined);
    /**
     * Gets the dataBackupBlocked property value. Indicates whether the backup of a managed app's data is blocked.
     * @returns a boolean
     */
    get dataBackupBlocked(): boolean | undefined;
    /**
     * Sets the dataBackupBlocked property value. Indicates whether the backup of a managed app's data is blocked.
     * @param value Value to set for the dataBackupBlocked property.
     */
    set dataBackupBlocked(value: boolean | undefined);
    /**
     * Gets the deviceComplianceRequired property value. Indicates whether device compliance is required.
     * @returns a boolean
     */
    get deviceComplianceRequired(): boolean | undefined;
    /**
     * Sets the deviceComplianceRequired property value. Indicates whether device compliance is required.
     * @param value Value to set for the deviceComplianceRequired property.
     */
    set deviceComplianceRequired(value: boolean | undefined);
    /**
     * Gets the disableAppPinIfDevicePinIsSet property value. Indicates whether use of the app pin is required if the device pin is set.
     * @returns a boolean
     */
    get disableAppPinIfDevicePinIsSet(): boolean | undefined;
    /**
     * Sets the disableAppPinIfDevicePinIsSet property value. Indicates whether use of the app pin is required if the device pin is set.
     * @param value Value to set for the disableAppPinIfDevicePinIsSet property.
     */
    set disableAppPinIfDevicePinIsSet(value: boolean | undefined);
    /**
     * Gets the fingerprintBlocked property value. Indicates whether use of the fingerprint reader is allowed in place of a pin if PinRequired is set to True.
     * @returns a boolean
     */
    get fingerprintBlocked(): boolean | undefined;
    /**
     * Sets the fingerprintBlocked property value. Indicates whether use of the fingerprint reader is allowed in place of a pin if PinRequired is set to True.
     * @param value Value to set for the fingerprintBlocked property.
     */
    set fingerprintBlocked(value: boolean | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the managedBrowser property value. Indicates in which managed browser(s) that internet links should be opened. When this property is configured, ManagedBrowserToOpenLinksRequired should be true. Possible values are: notConfigured, microsoftEdge.
     * @returns a managedBrowserType
     */
    get managedBrowser(): ManagedBrowserType | undefined;
    /**
     * Sets the managedBrowser property value. Indicates in which managed browser(s) that internet links should be opened. When this property is configured, ManagedBrowserToOpenLinksRequired should be true. Possible values are: notConfigured, microsoftEdge.
     * @param value Value to set for the managedBrowser property.
     */
    set managedBrowser(value: ManagedBrowserType | undefined);
    /**
     * Gets the managedBrowserToOpenLinksRequired property value. Indicates whether internet links should be opened in the managed browser app, or any custom browser specified by CustomBrowserProtocol (for iOS) or CustomBrowserPackageId/CustomBrowserDisplayName (for Android)
     * @returns a boolean
     */
    get managedBrowserToOpenLinksRequired(): boolean | undefined;
    /**
     * Sets the managedBrowserToOpenLinksRequired property value. Indicates whether internet links should be opened in the managed browser app, or any custom browser specified by CustomBrowserProtocol (for iOS) or CustomBrowserPackageId/CustomBrowserDisplayName (for Android)
     * @param value Value to set for the managedBrowserToOpenLinksRequired property.
     */
    set managedBrowserToOpenLinksRequired(value: boolean | undefined);
    /**
     * Gets the maximumPinRetries property value. Maximum number of incorrect pin retry attempts before the managed app is either blocked or wiped.
     * @returns a integer
     */
    get maximumPinRetries(): number | undefined;
    /**
     * Sets the maximumPinRetries property value. Maximum number of incorrect pin retry attempts before the managed app is either blocked or wiped.
     * @param value Value to set for the maximumPinRetries property.
     */
    set maximumPinRetries(value: number | undefined);
    /**
     * Gets the minimumPinLength property value. Minimum pin length required for an app-level pin if PinRequired is set to True
     * @returns a integer
     */
    get minimumPinLength(): number | undefined;
    /**
     * Sets the minimumPinLength property value. Minimum pin length required for an app-level pin if PinRequired is set to True
     * @param value Value to set for the minimumPinLength property.
     */
    set minimumPinLength(value: number | undefined);
    /**
     * Gets the minimumRequiredAppVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @returns a string
     */
    get minimumRequiredAppVersion(): string | undefined;
    /**
     * Sets the minimumRequiredAppVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @param value Value to set for the minimumRequiredAppVersion property.
     */
    set minimumRequiredAppVersion(value: string | undefined);
    /**
     * Gets the minimumRequiredOsVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @returns a string
     */
    get minimumRequiredOsVersion(): string | undefined;
    /**
     * Sets the minimumRequiredOsVersion property value. Versions less than the specified version will block the managed app from accessing company data.
     * @param value Value to set for the minimumRequiredOsVersion property.
     */
    set minimumRequiredOsVersion(value: string | undefined);
    /**
     * Gets the minimumWarningAppVersion property value. Versions less than the specified version will result in warning message on the managed app.
     * @returns a string
     */
    get minimumWarningAppVersion(): string | undefined;
    /**
     * Sets the minimumWarningAppVersion property value. Versions less than the specified version will result in warning message on the managed app.
     * @param value Value to set for the minimumWarningAppVersion property.
     */
    set minimumWarningAppVersion(value: string | undefined);
    /**
     * Gets the minimumWarningOsVersion property value. Versions less than the specified version will result in warning message on the managed app from accessing company data.
     * @returns a string
     */
    get minimumWarningOsVersion(): string | undefined;
    /**
     * Sets the minimumWarningOsVersion property value. Versions less than the specified version will result in warning message on the managed app from accessing company data.
     * @param value Value to set for the minimumWarningOsVersion property.
     */
    set minimumWarningOsVersion(value: string | undefined);
    /**
     * Gets the organizationalCredentialsRequired property value. Indicates whether organizational credentials are required for app use.
     * @returns a boolean
     */
    get organizationalCredentialsRequired(): boolean | undefined;
    /**
     * Sets the organizationalCredentialsRequired property value. Indicates whether organizational credentials are required for app use.
     * @param value Value to set for the organizationalCredentialsRequired property.
     */
    set organizationalCredentialsRequired(value: boolean | undefined);
    /**
     * Gets the periodBeforePinReset property value. TimePeriod before the all-level pin must be reset if PinRequired is set to True.
     * @returns a Duration
     */
    get periodBeforePinReset(): Duration | undefined;
    /**
     * Sets the periodBeforePinReset property value. TimePeriod before the all-level pin must be reset if PinRequired is set to True.
     * @param value Value to set for the periodBeforePinReset property.
     */
    set periodBeforePinReset(value: Duration | undefined);
    /**
     * Gets the periodOfflineBeforeAccessCheck property value. The period after which access is checked when the device is not connected to the internet.
     * @returns a Duration
     */
    get periodOfflineBeforeAccessCheck(): Duration | undefined;
    /**
     * Sets the periodOfflineBeforeAccessCheck property value. The period after which access is checked when the device is not connected to the internet.
     * @param value Value to set for the periodOfflineBeforeAccessCheck property.
     */
    set periodOfflineBeforeAccessCheck(value: Duration | undefined);
    /**
     * Gets the periodOfflineBeforeWipeIsEnforced property value. The amount of time an app is allowed to remain disconnected from the internet before all managed data it is wiped.
     * @returns a Duration
     */
    get periodOfflineBeforeWipeIsEnforced(): Duration | undefined;
    /**
     * Sets the periodOfflineBeforeWipeIsEnforced property value. The amount of time an app is allowed to remain disconnected from the internet before all managed data it is wiped.
     * @param value Value to set for the periodOfflineBeforeWipeIsEnforced property.
     */
    set periodOfflineBeforeWipeIsEnforced(value: Duration | undefined);
    /**
     * Gets the periodOnlineBeforeAccessCheck property value. The period after which access is checked when the device is connected to the internet.
     * @returns a Duration
     */
    get periodOnlineBeforeAccessCheck(): Duration | undefined;
    /**
     * Sets the periodOnlineBeforeAccessCheck property value. The period after which access is checked when the device is connected to the internet.
     * @param value Value to set for the periodOnlineBeforeAccessCheck property.
     */
    set periodOnlineBeforeAccessCheck(value: Duration | undefined);
    /**
     * Gets the pinCharacterSet property value. Character set which may be used for an app-level pin if PinRequired is set to True. Possible values are: numeric, alphanumericAndSymbol.
     * @returns a managedAppPinCharacterSet
     */
    get pinCharacterSet(): ManagedAppPinCharacterSet | undefined;
    /**
     * Sets the pinCharacterSet property value. Character set which may be used for an app-level pin if PinRequired is set to True. Possible values are: numeric, alphanumericAndSymbol.
     * @param value Value to set for the pinCharacterSet property.
     */
    set pinCharacterSet(value: ManagedAppPinCharacterSet | undefined);
    /**
     * Gets the pinRequired property value. Indicates whether an app-level pin is required.
     * @returns a boolean
     */
    get pinRequired(): boolean | undefined;
    /**
     * Sets the pinRequired property value. Indicates whether an app-level pin is required.
     * @param value Value to set for the pinRequired property.
     */
    set pinRequired(value: boolean | undefined);
    /**
     * Gets the printBlocked property value. Indicates whether printing is allowed from managed apps.
     * @returns a boolean
     */
    get printBlocked(): boolean | undefined;
    /**
     * Sets the printBlocked property value. Indicates whether printing is allowed from managed apps.
     * @param value Value to set for the printBlocked property.
     */
    set printBlocked(value: boolean | undefined);
    /**
     * Gets the saveAsBlocked property value. Indicates whether users may use the 'Save As' menu item to save a copy of protected files.
     * @returns a boolean
     */
    get saveAsBlocked(): boolean | undefined;
    /**
     * Sets the saveAsBlocked property value. Indicates whether users may use the 'Save As' menu item to save a copy of protected files.
     * @param value Value to set for the saveAsBlocked property.
     */
    set saveAsBlocked(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the simplePinBlocked property value. Indicates whether simplePin is blocked.
     * @returns a boolean
     */
    get simplePinBlocked(): boolean | undefined;
    /**
     * Sets the simplePinBlocked property value. Indicates whether simplePin is blocked.
     * @param value Value to set for the simplePinBlocked property.
     */
    set simplePinBlocked(value: boolean | undefined);
}
