import { Entity, MessageRuleActions, MessageRulePredicates } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class MessageRule extends Entity implements Parsable {
    /** Actions to be taken on a message when the corresponding conditions are fulfilled.  */
    private _actions?;
    /** Conditions that when fulfilled, will trigger the corresponding actions for that rule.  */
    private _conditions?;
    /** The display name of the rule.  */
    private _displayName?;
    /** Exception conditions for the rule.  */
    private _exceptions?;
    /** Indicates whether the rule is in an error condition. Read-only.  */
    private _hasError?;
    /** Indicates whether the rule is enabled to be applied to messages.  */
    private _isEnabled?;
    /** Indicates if the rule is read-only and cannot be modified or deleted by the rules REST API.  */
    private _isReadOnly?;
    /** Indicates the order in which the rule is executed, among other rules.  */
    private _sequence?;
    /**
     * Gets the actions property value. Actions to be taken on a message when the corresponding conditions are fulfilled.
     * @returns a messageRuleActions
     */
    get actions(): MessageRuleActions | undefined;
    /**
     * Sets the actions property value. Actions to be taken on a message when the corresponding conditions are fulfilled.
     * @param value Value to set for the actions property.
     */
    set actions(value: MessageRuleActions | undefined);
    /**
     * Gets the conditions property value. Conditions that when fulfilled, will trigger the corresponding actions for that rule.
     * @returns a messageRulePredicates
     */
    get conditions(): MessageRulePredicates | undefined;
    /**
     * Sets the conditions property value. Conditions that when fulfilled, will trigger the corresponding actions for that rule.
     * @param value Value to set for the conditions property.
     */
    set conditions(value: MessageRulePredicates | undefined);
    /**
     * Instantiates a new messageRule and sets the default values.
     */
    constructor();
    /**
     * Gets the displayName property value. The display name of the rule.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The display name of the rule.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the exceptions property value. Exception conditions for the rule.
     * @returns a messageRulePredicates
     */
    get exceptions(): MessageRulePredicates | undefined;
    /**
     * Sets the exceptions property value. Exception conditions for the rule.
     * @param value Value to set for the exceptions property.
     */
    set exceptions(value: MessageRulePredicates | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hasError property value. Indicates whether the rule is in an error condition. Read-only.
     * @returns a boolean
     */
    get hasError(): boolean | undefined;
    /**
     * Sets the hasError property value. Indicates whether the rule is in an error condition. Read-only.
     * @param value Value to set for the hasError property.
     */
    set hasError(value: boolean | undefined);
    /**
     * Gets the isEnabled property value. Indicates whether the rule is enabled to be applied to messages.
     * @returns a boolean
     */
    get isEnabled(): boolean | undefined;
    /**
     * Sets the isEnabled property value. Indicates whether the rule is enabled to be applied to messages.
     * @param value Value to set for the isEnabled property.
     */
    set isEnabled(value: boolean | undefined);
    /**
     * Gets the isReadOnly property value. Indicates if the rule is read-only and cannot be modified or deleted by the rules REST API.
     * @returns a boolean
     */
    get isReadOnly(): boolean | undefined;
    /**
     * Sets the isReadOnly property value. Indicates if the rule is read-only and cannot be modified or deleted by the rules REST API.
     * @param value Value to set for the isReadOnly property.
     */
    set isReadOnly(value: boolean | undefined);
    /**
     * Gets the sequence property value. Indicates the order in which the rule is executed, among other rules.
     * @returns a integer
     */
    get sequence(): number | undefined;
    /**
     * Sets the sequence property value. Indicates the order in which the rule is executed, among other rules.
     * @param value Value to set for the sequence property.
     */
    set sequence(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
