import { Entity, MimeContent, MobileAppAssignment, MobileAppCategory } from './index';
import { MobileAppPublishingState } from './mobileAppPublishingState';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class MobileApp extends Entity implements Parsable {
    /** The list of group assignments for this mobile app.  */
    private _assignments?;
    /** The list of categories for this app.  */
    private _categories?;
    /** The date and time the app was created.  */
    private _createdDateTime?;
    /** The description of the app.  */
    private _description?;
    /** The developer of the app.  */
    private _developer?;
    /** The admin provided or imported title of the app.  */
    private _displayName?;
    /** The more information Url.  */
    private _informationUrl?;
    /** The value indicating whether the app is marked as featured by the admin.  */
    private _isFeatured?;
    /** The large icon, to be displayed in the app details and used for upload of the icon.  */
    private _largeIcon?;
    /** The date and time the app was last modified.  */
    private _lastModifiedDateTime?;
    /** Notes for the app.  */
    private _notes?;
    /** The owner of the app.  */
    private _owner?;
    /** The privacy statement Url.  */
    private _privacyInformationUrl?;
    /** The publisher of the app.  */
    private _publisher?;
    /** The publishing state for the app. The app cannot be assigned unless the app is published. Possible values are: notPublished, processing, published.  */
    private _publishingState?;
    /**
     * Gets the assignments property value. The list of group assignments for this mobile app.
     * @returns a mobileAppAssignment
     */
    get assignments(): MobileAppAssignment[] | undefined;
    /**
     * Sets the assignments property value. The list of group assignments for this mobile app.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: MobileAppAssignment[] | undefined);
    /**
     * Gets the categories property value. The list of categories for this app.
     * @returns a mobileAppCategory
     */
    get categories(): MobileAppCategory[] | undefined;
    /**
     * Sets the categories property value. The list of categories for this app.
     * @param value Value to set for the categories property.
     */
    set categories(value: MobileAppCategory[] | undefined);
    /**
     * Instantiates a new mobileApp and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. The date and time the app was created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The date and time the app was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the description property value. The description of the app.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. The description of the app.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the developer property value. The developer of the app.
     * @returns a string
     */
    get developer(): string | undefined;
    /**
     * Sets the developer property value. The developer of the app.
     * @param value Value to set for the developer property.
     */
    set developer(value: string | undefined);
    /**
     * Gets the displayName property value. The admin provided or imported title of the app.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The admin provided or imported title of the app.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the informationUrl property value. The more information Url.
     * @returns a string
     */
    get informationUrl(): string | undefined;
    /**
     * Sets the informationUrl property value. The more information Url.
     * @param value Value to set for the informationUrl property.
     */
    set informationUrl(value: string | undefined);
    /**
     * Gets the isFeatured property value. The value indicating whether the app is marked as featured by the admin.
     * @returns a boolean
     */
    get isFeatured(): boolean | undefined;
    /**
     * Sets the isFeatured property value. The value indicating whether the app is marked as featured by the admin.
     * @param value Value to set for the isFeatured property.
     */
    set isFeatured(value: boolean | undefined);
    /**
     * Gets the largeIcon property value. The large icon, to be displayed in the app details and used for upload of the icon.
     * @returns a mimeContent
     */
    get largeIcon(): MimeContent | undefined;
    /**
     * Sets the largeIcon property value. The large icon, to be displayed in the app details and used for upload of the icon.
     * @param value Value to set for the largeIcon property.
     */
    set largeIcon(value: MimeContent | undefined);
    /**
     * Gets the lastModifiedDateTime property value. The date and time the app was last modified.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. The date and time the app was last modified.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the notes property value. Notes for the app.
     * @returns a string
     */
    get notes(): string | undefined;
    /**
     * Sets the notes property value. Notes for the app.
     * @param value Value to set for the notes property.
     */
    set notes(value: string | undefined);
    /**
     * Gets the owner property value. The owner of the app.
     * @returns a string
     */
    get owner(): string | undefined;
    /**
     * Sets the owner property value. The owner of the app.
     * @param value Value to set for the owner property.
     */
    set owner(value: string | undefined);
    /**
     * Gets the privacyInformationUrl property value. The privacy statement Url.
     * @returns a string
     */
    get privacyInformationUrl(): string | undefined;
    /**
     * Sets the privacyInformationUrl property value. The privacy statement Url.
     * @param value Value to set for the privacyInformationUrl property.
     */
    set privacyInformationUrl(value: string | undefined);
    /**
     * Gets the publisher property value. The publisher of the app.
     * @returns a string
     */
    get publisher(): string | undefined;
    /**
     * Sets the publisher property value. The publisher of the app.
     * @param value Value to set for the publisher property.
     */
    set publisher(value: string | undefined);
    /**
     * Gets the publishingState property value. The publishing state for the app. The app cannot be assigned unless the app is published. Possible values are: notPublished, processing, published.
     * @returns a mobileAppPublishingState
     */
    get publishingState(): MobileAppPublishingState | undefined;
    /**
     * Sets the publishingState property value. The publishing state for the app. The app cannot be assigned unless the app is published. Possible values are: notPublished, processing, published.
     * @param value Value to set for the publishingState property.
     */
    set publishingState(value: MobileAppPublishingState | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
