import { Notebook, OnenoteEntitySchemaObjectModel, OnenoteSection, PageLinks } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class OnenotePage extends OnenoteEntitySchemaObjectModel implements Parsable {
    /** The page's HTML content.  */
    private _content?;
    /** The URL for the page's HTML content.  Read-only.  */
    private _contentUrl?;
    /** The unique identifier of the application that created the page. Read-only.  */
    private _createdByAppId?;
    /** The date and time when the page was last modified. The timestamp represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  */
    private _lastModifiedDateTime?;
    /** The indentation level of the page. Read-only.  */
    private _level?;
    /** Links for opening the page. The oneNoteClientURL link opens the page in the OneNote native client if it 's installed. The oneNoteWebUrl link opens the page in OneNote on the web. Read-only.  */
    private _links?;
    /** The order of the page within its parent section. Read-only.  */
    private _order?;
    /** The notebook that contains the page.  Read-only.  */
    private _parentNotebook?;
    /** The section that contains the page. Read-only.  */
    private _parentSection?;
    /** The title of the page.  */
    private _title?;
    private _userTags?;
    /**
     * Instantiates a new onenotePage and sets the default values.
     */
    constructor();
    /**
     * Gets the content property value. The page's HTML content.
     * @returns a binary
     */
    get content(): string | undefined;
    /**
     * Sets the content property value. The page's HTML content.
     * @param value Value to set for the content property.
     */
    set content(value: string | undefined);
    /**
     * Gets the contentUrl property value. The URL for the page's HTML content.  Read-only.
     * @returns a string
     */
    get contentUrl(): string | undefined;
    /**
     * Sets the contentUrl property value. The URL for the page's HTML content.  Read-only.
     * @param value Value to set for the contentUrl property.
     */
    set contentUrl(value: string | undefined);
    /**
     * Gets the createdByAppId property value. The unique identifier of the application that created the page. Read-only.
     * @returns a string
     */
    get createdByAppId(): string | undefined;
    /**
     * Sets the createdByAppId property value. The unique identifier of the application that created the page. Read-only.
     * @param value Value to set for the createdByAppId property.
     */
    set createdByAppId(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the lastModifiedDateTime property value. The date and time when the page was last modified. The timestamp represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. The date and time when the page was last modified. The timestamp represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the level property value. The indentation level of the page. Read-only.
     * @returns a integer
     */
    get level(): number | undefined;
    /**
     * Sets the level property value. The indentation level of the page. Read-only.
     * @param value Value to set for the level property.
     */
    set level(value: number | undefined);
    /**
     * Gets the links property value. Links for opening the page. The oneNoteClientURL link opens the page in the OneNote native client if it 's installed. The oneNoteWebUrl link opens the page in OneNote on the web. Read-only.
     * @returns a pageLinks
     */
    get links(): PageLinks | undefined;
    /**
     * Sets the links property value. Links for opening the page. The oneNoteClientURL link opens the page in the OneNote native client if it 's installed. The oneNoteWebUrl link opens the page in OneNote on the web. Read-only.
     * @param value Value to set for the links property.
     */
    set links(value: PageLinks | undefined);
    /**
     * Gets the order property value. The order of the page within its parent section. Read-only.
     * @returns a integer
     */
    get order(): number | undefined;
    /**
     * Sets the order property value. The order of the page within its parent section. Read-only.
     * @param value Value to set for the order property.
     */
    set order(value: number | undefined);
    /**
     * Gets the parentNotebook property value. The notebook that contains the page.  Read-only.
     * @returns a notebook
     */
    get parentNotebook(): Notebook | undefined;
    /**
     * Sets the parentNotebook property value. The notebook that contains the page.  Read-only.
     * @param value Value to set for the parentNotebook property.
     */
    set parentNotebook(value: Notebook | undefined);
    /**
     * Gets the parentSection property value. The section that contains the page. Read-only.
     * @returns a onenoteSection
     */
    get parentSection(): OnenoteSection | undefined;
    /**
     * Sets the parentSection property value. The section that contains the page. Read-only.
     * @param value Value to set for the parentSection property.
     */
    set parentSection(value: OnenoteSection | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the title property value. The title of the page.
     * @returns a string
     */
    get title(): string | undefined;
    /**
     * Sets the title property value. The title of the page.
     * @param value Value to set for the title property.
     */
    set title(value: string | undefined);
    /**
     * Gets the userTags property value.
     * @returns a string
     */
    get userTags(): string[] | undefined;
    /**
     * Sets the userTags property value.
     * @param value Value to set for the userTags property.
     */
    set userTags(value: string[] | undefined);
}
