import { AudioConferencing, BroadcastMeetingSettings, ChatInfo, Entity, ItemBody, LobbyBypassSettings, MeetingAttendanceReport, MeetingParticipants } from './index';
import { MeetingChatMode } from './meetingChatMode';
import { OnlineMeetingPresenters } from './onlineMeetingPresenters';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class OnlineMeeting extends Entity implements Parsable {
    /** Indicates whether attendees can turn on their camera.  */
    private _allowAttendeeToEnableCamera?;
    /** Indicates whether attendees can turn on their microphone.  */
    private _allowAttendeeToEnableMic?;
    /** Specifies who can be a presenter in a meeting. Possible values are listed in the following table.  */
    private _allowedPresenters?;
    /** Specifies the mode of meeting chat.  */
    private _allowMeetingChat?;
    /** Indicates whether Teams reactions are enabled for the meeting.  */
    private _allowTeamworkReactions?;
    /** The attendance reports of an online meeting. Read-only.  */
    private _attendanceReports?;
    /** The content stream of the attendee report of a Microsoft Teams live event. Read-only.  */
    private _attendeeReport?;
    /** The phone access (dial-in) information for an online meeting. Read-only.  */
    private _audioConferencing?;
    /** Settings related to a live event.  */
    private _broadcastSettings?;
    /** The chat information associated with this online meeting.  */
    private _chatInfo?;
    /** The meeting creation time in UTC. Read-only.  */
    private _creationDateTime?;
    /** The meeting end time in UTC.  */
    private _endDateTime?;
    /** The external ID. A custom ID. Optional.  */
    private _externalId?;
    /** Indicates if this is a Teams live event.  */
    private _isBroadcast?;
    /** Indicates whether to announce when callers join or leave.  */
    private _isEntryExitAnnounced?;
    /** The join information in the language and locale variant specified in the Accept-Language request HTTP header. Read-only.  */
    private _joinInformation?;
    /** The join URL of the online meeting. Read-only.  */
    private _joinWebUrl?;
    /** Specifies which participants can bypass the meeting   lobby.  */
    private _lobbyBypassSettings?;
    /** The participants associated with the online meeting.  This includes the organizer and the attendees.  */
    private _participants?;
    /** Indicates whether to record the meeting automatically.  */
    private _recordAutomatically?;
    /** The meeting start time in UTC.  */
    private _startDateTime?;
    /** The subject of the online meeting.  */
    private _subject?;
    /** The video teleconferencing ID. Read-only.  */
    private _videoTeleconferenceId?;
    /**
     * Gets the allowAttendeeToEnableCamera property value. Indicates whether attendees can turn on their camera.
     * @returns a boolean
     */
    get allowAttendeeToEnableCamera(): boolean | undefined;
    /**
     * Sets the allowAttendeeToEnableCamera property value. Indicates whether attendees can turn on their camera.
     * @param value Value to set for the allowAttendeeToEnableCamera property.
     */
    set allowAttendeeToEnableCamera(value: boolean | undefined);
    /**
     * Gets the allowAttendeeToEnableMic property value. Indicates whether attendees can turn on their microphone.
     * @returns a boolean
     */
    get allowAttendeeToEnableMic(): boolean | undefined;
    /**
     * Sets the allowAttendeeToEnableMic property value. Indicates whether attendees can turn on their microphone.
     * @param value Value to set for the allowAttendeeToEnableMic property.
     */
    set allowAttendeeToEnableMic(value: boolean | undefined);
    /**
     * Gets the allowedPresenters property value. Specifies who can be a presenter in a meeting. Possible values are listed in the following table.
     * @returns a onlineMeetingPresenters
     */
    get allowedPresenters(): OnlineMeetingPresenters | undefined;
    /**
     * Sets the allowedPresenters property value. Specifies who can be a presenter in a meeting. Possible values are listed in the following table.
     * @param value Value to set for the allowedPresenters property.
     */
    set allowedPresenters(value: OnlineMeetingPresenters | undefined);
    /**
     * Gets the allowMeetingChat property value. Specifies the mode of meeting chat.
     * @returns a meetingChatMode
     */
    get allowMeetingChat(): MeetingChatMode | undefined;
    /**
     * Sets the allowMeetingChat property value. Specifies the mode of meeting chat.
     * @param value Value to set for the allowMeetingChat property.
     */
    set allowMeetingChat(value: MeetingChatMode | undefined);
    /**
     * Gets the allowTeamworkReactions property value. Indicates whether Teams reactions are enabled for the meeting.
     * @returns a boolean
     */
    get allowTeamworkReactions(): boolean | undefined;
    /**
     * Sets the allowTeamworkReactions property value. Indicates whether Teams reactions are enabled for the meeting.
     * @param value Value to set for the allowTeamworkReactions property.
     */
    set allowTeamworkReactions(value: boolean | undefined);
    /**
     * Gets the attendanceReports property value. The attendance reports of an online meeting. Read-only.
     * @returns a meetingAttendanceReport
     */
    get attendanceReports(): MeetingAttendanceReport[] | undefined;
    /**
     * Sets the attendanceReports property value. The attendance reports of an online meeting. Read-only.
     * @param value Value to set for the attendanceReports property.
     */
    set attendanceReports(value: MeetingAttendanceReport[] | undefined);
    /**
     * Gets the attendeeReport property value. The content stream of the attendee report of a Microsoft Teams live event. Read-only.
     * @returns a binary
     */
    get attendeeReport(): string | undefined;
    /**
     * Sets the attendeeReport property value. The content stream of the attendee report of a Microsoft Teams live event. Read-only.
     * @param value Value to set for the attendeeReport property.
     */
    set attendeeReport(value: string | undefined);
    /**
     * Gets the audioConferencing property value. The phone access (dial-in) information for an online meeting. Read-only.
     * @returns a audioConferencing
     */
    get audioConferencing(): AudioConferencing | undefined;
    /**
     * Sets the audioConferencing property value. The phone access (dial-in) information for an online meeting. Read-only.
     * @param value Value to set for the audioConferencing property.
     */
    set audioConferencing(value: AudioConferencing | undefined);
    /**
     * Gets the broadcastSettings property value. Settings related to a live event.
     * @returns a broadcastMeetingSettings
     */
    get broadcastSettings(): BroadcastMeetingSettings | undefined;
    /**
     * Sets the broadcastSettings property value. Settings related to a live event.
     * @param value Value to set for the broadcastSettings property.
     */
    set broadcastSettings(value: BroadcastMeetingSettings | undefined);
    /**
     * Gets the chatInfo property value. The chat information associated with this online meeting.
     * @returns a chatInfo
     */
    get chatInfo(): ChatInfo | undefined;
    /**
     * Sets the chatInfo property value. The chat information associated with this online meeting.
     * @param value Value to set for the chatInfo property.
     */
    set chatInfo(value: ChatInfo | undefined);
    /**
     * Instantiates a new onlineMeeting and sets the default values.
     */
    constructor();
    /**
     * Gets the creationDateTime property value. The meeting creation time in UTC. Read-only.
     * @returns a Date
     */
    get creationDateTime(): Date | undefined;
    /**
     * Sets the creationDateTime property value. The meeting creation time in UTC. Read-only.
     * @param value Value to set for the creationDateTime property.
     */
    set creationDateTime(value: Date | undefined);
    /**
     * Gets the endDateTime property value. The meeting end time in UTC.
     * @returns a Date
     */
    get endDateTime(): Date | undefined;
    /**
     * Sets the endDateTime property value. The meeting end time in UTC.
     * @param value Value to set for the endDateTime property.
     */
    set endDateTime(value: Date | undefined);
    /**
     * Gets the externalId property value. The external ID. A custom ID. Optional.
     * @returns a string
     */
    get externalId(): string | undefined;
    /**
     * Sets the externalId property value. The external ID. A custom ID. Optional.
     * @param value Value to set for the externalId property.
     */
    set externalId(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isBroadcast property value. Indicates if this is a Teams live event.
     * @returns a boolean
     */
    get isBroadcast(): boolean | undefined;
    /**
     * Sets the isBroadcast property value. Indicates if this is a Teams live event.
     * @param value Value to set for the isBroadcast property.
     */
    set isBroadcast(value: boolean | undefined);
    /**
     * Gets the isEntryExitAnnounced property value. Indicates whether to announce when callers join or leave.
     * @returns a boolean
     */
    get isEntryExitAnnounced(): boolean | undefined;
    /**
     * Sets the isEntryExitAnnounced property value. Indicates whether to announce when callers join or leave.
     * @param value Value to set for the isEntryExitAnnounced property.
     */
    set isEntryExitAnnounced(value: boolean | undefined);
    /**
     * Gets the joinInformation property value. The join information in the language and locale variant specified in the Accept-Language request HTTP header. Read-only.
     * @returns a itemBody
     */
    get joinInformation(): ItemBody | undefined;
    /**
     * Sets the joinInformation property value. The join information in the language and locale variant specified in the Accept-Language request HTTP header. Read-only.
     * @param value Value to set for the joinInformation property.
     */
    set joinInformation(value: ItemBody | undefined);
    /**
     * Gets the joinWebUrl property value. The join URL of the online meeting. Read-only.
     * @returns a string
     */
    get joinWebUrl(): string | undefined;
    /**
     * Sets the joinWebUrl property value. The join URL of the online meeting. Read-only.
     * @param value Value to set for the joinWebUrl property.
     */
    set joinWebUrl(value: string | undefined);
    /**
     * Gets the lobbyBypassSettings property value. Specifies which participants can bypass the meeting   lobby.
     * @returns a lobbyBypassSettings
     */
    get lobbyBypassSettings(): LobbyBypassSettings | undefined;
    /**
     * Sets the lobbyBypassSettings property value. Specifies which participants can bypass the meeting   lobby.
     * @param value Value to set for the lobbyBypassSettings property.
     */
    set lobbyBypassSettings(value: LobbyBypassSettings | undefined);
    /**
     * Gets the participants property value. The participants associated with the online meeting.  This includes the organizer and the attendees.
     * @returns a meetingParticipants
     */
    get participants(): MeetingParticipants | undefined;
    /**
     * Sets the participants property value. The participants associated with the online meeting.  This includes the organizer and the attendees.
     * @param value Value to set for the participants property.
     */
    set participants(value: MeetingParticipants | undefined);
    /**
     * Gets the recordAutomatically property value. Indicates whether to record the meeting automatically.
     * @returns a boolean
     */
    get recordAutomatically(): boolean | undefined;
    /**
     * Sets the recordAutomatically property value. Indicates whether to record the meeting automatically.
     * @param value Value to set for the recordAutomatically property.
     */
    set recordAutomatically(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the startDateTime property value. The meeting start time in UTC.
     * @returns a Date
     */
    get startDateTime(): Date | undefined;
    /**
     * Sets the startDateTime property value. The meeting start time in UTC.
     * @param value Value to set for the startDateTime property.
     */
    set startDateTime(value: Date | undefined);
    /**
     * Gets the subject property value. The subject of the online meeting.
     * @returns a string
     */
    get subject(): string | undefined;
    /**
     * Sets the subject property value. The subject of the online meeting.
     * @param value Value to set for the subject property.
     */
    set subject(value: string | undefined);
    /**
     * Gets the videoTeleconferenceId property value. The video teleconferencing ID. Read-only.
     * @returns a string
     */
    get videoTeleconferenceId(): string | undefined;
    /**
     * Sets the videoTeleconferenceId property value. The video teleconferencing ID. Read-only.
     * @param value Value to set for the videoTeleconferenceId property.
     */
    set videoTeleconferenceId(value: string | undefined);
}
