import { AssignedPlan, CertificateBasedAuthConfiguration, DirectoryObject, Extension, OrganizationalBranding, PrivacyProfile, ProvisionedPlan, VerifiedDomain } from './index';
import { MdmAuthority } from './mdmAuthority';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Organization extends DirectoryObject implements Parsable {
    /** The collection of service plans associated with the tenant. Not nullable.  */
    private _assignedPlans?;
    private _branding?;
    /** Telephone number for the organization. Although this is a string collection, only one number can be set for this property.  */
    private _businessPhones?;
    /** Navigation property to manage certificate-based authentication configuration. Only a single instance of certificateBasedAuthConfiguration can be created in the collection.  */
    private _certificateBasedAuthConfiguration?;
    /** City name of the address for the organization.  */
    private _city?;
    /** Country/region name of the address for the organization.  */
    private _country?;
    /** Country or region abbreviation for the organization in ISO 3166-2 format.  */
    private _countryLetterCode?;
    /** Timestamp of when the organization was created. The value cannot be modified and is automatically populated when the organization is created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  */
    private _createdDateTime?;
    /** The display name for the tenant.  */
    private _displayName?;
    /** The collection of open extensions defined for the organization. Read-only. Nullable.  */
    private _extensions?;
    /** Not nullable.  */
    private _marketingNotificationEmails?;
    /** Mobile device management authority. Possible values are: unknown, intune, sccm, office365.  */
    private _mobileDeviceManagementAuthority?;
    /** The time and date at which the tenant was last synced with the on-premises directory. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.  */
    private _onPremisesLastSyncDateTime?;
    /** true if this object is synced from an on-premises directory; false if this object was originally synced from an on-premises directory but is no longer synced. Nullable. null if this object has never been synced from an on-premises directory (default).  */
    private _onPremisesSyncEnabled?;
    /** Postal code of the address for the organization.  */
    private _postalCode?;
    /** The preferred language for the organization. Should follow ISO 639-1 Code; for example, en.  */
    private _preferredLanguage?;
    /** The privacy profile of an organization.  */
    private _privacyProfile?;
    /** Not nullable.  */
    private _provisionedPlans?;
    private _securityComplianceNotificationMails?;
    private _securityComplianceNotificationPhones?;
    /** State name of the address for the organization.  */
    private _state?;
    /** Street name of the address for organization.  */
    private _street?;
    /** Not nullable.  */
    private _technicalNotificationMails?;
    private _tenantType?;
    /** The collection of domains associated with this tenant. Not nullable.  */
    private _verifiedDomains?;
    /**
     * Gets the assignedPlans property value. The collection of service plans associated with the tenant. Not nullable.
     * @returns a assignedPlan
     */
    get assignedPlans(): AssignedPlan[] | undefined;
    /**
     * Sets the assignedPlans property value. The collection of service plans associated with the tenant. Not nullable.
     * @param value Value to set for the assignedPlans property.
     */
    set assignedPlans(value: AssignedPlan[] | undefined);
    /**
     * Gets the branding property value.
     * @returns a organizationalBranding
     */
    get branding(): OrganizationalBranding | undefined;
    /**
     * Sets the branding property value.
     * @param value Value to set for the branding property.
     */
    set branding(value: OrganizationalBranding | undefined);
    /**
     * Gets the businessPhones property value. Telephone number for the organization. Although this is a string collection, only one number can be set for this property.
     * @returns a string
     */
    get businessPhones(): string[] | undefined;
    /**
     * Sets the businessPhones property value. Telephone number for the organization. Although this is a string collection, only one number can be set for this property.
     * @param value Value to set for the businessPhones property.
     */
    set businessPhones(value: string[] | undefined);
    /**
     * Gets the certificateBasedAuthConfiguration property value. Navigation property to manage certificate-based authentication configuration. Only a single instance of certificateBasedAuthConfiguration can be created in the collection.
     * @returns a certificateBasedAuthConfiguration
     */
    get certificateBasedAuthConfiguration(): CertificateBasedAuthConfiguration[] | undefined;
    /**
     * Sets the certificateBasedAuthConfiguration property value. Navigation property to manage certificate-based authentication configuration. Only a single instance of certificateBasedAuthConfiguration can be created in the collection.
     * @param value Value to set for the certificateBasedAuthConfiguration property.
     */
    set certificateBasedAuthConfiguration(value: CertificateBasedAuthConfiguration[] | undefined);
    /**
     * Gets the city property value. City name of the address for the organization.
     * @returns a string
     */
    get city(): string | undefined;
    /**
     * Sets the city property value. City name of the address for the organization.
     * @param value Value to set for the city property.
     */
    set city(value: string | undefined);
    /**
     * Instantiates a new organization and sets the default values.
     */
    constructor();
    /**
     * Gets the country property value. Country/region name of the address for the organization.
     * @returns a string
     */
    get country(): string | undefined;
    /**
     * Sets the country property value. Country/region name of the address for the organization.
     * @param value Value to set for the country property.
     */
    set country(value: string | undefined);
    /**
     * Gets the countryLetterCode property value. Country or region abbreviation for the organization in ISO 3166-2 format.
     * @returns a string
     */
    get countryLetterCode(): string | undefined;
    /**
     * Sets the countryLetterCode property value. Country or region abbreviation for the organization in ISO 3166-2 format.
     * @param value Value to set for the countryLetterCode property.
     */
    set countryLetterCode(value: string | undefined);
    /**
     * Gets the createdDateTime property value. Timestamp of when the organization was created. The value cannot be modified and is automatically populated when the organization is created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Timestamp of when the organization was created. The value cannot be modified and is automatically populated when the organization is created. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the displayName property value. The display name for the tenant.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The display name for the tenant.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the extensions property value. The collection of open extensions defined for the organization. Read-only. Nullable.
     * @returns a extension
     */
    get extensions(): Extension[] | undefined;
    /**
     * Sets the extensions property value. The collection of open extensions defined for the organization. Read-only. Nullable.
     * @param value Value to set for the extensions property.
     */
    set extensions(value: Extension[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the marketingNotificationEmails property value. Not nullable.
     * @returns a string
     */
    get marketingNotificationEmails(): string[] | undefined;
    /**
     * Sets the marketingNotificationEmails property value. Not nullable.
     * @param value Value to set for the marketingNotificationEmails property.
     */
    set marketingNotificationEmails(value: string[] | undefined);
    /**
     * Gets the mobileDeviceManagementAuthority property value. Mobile device management authority. Possible values are: unknown, intune, sccm, office365.
     * @returns a mdmAuthority
     */
    get mobileDeviceManagementAuthority(): MdmAuthority | undefined;
    /**
     * Sets the mobileDeviceManagementAuthority property value. Mobile device management authority. Possible values are: unknown, intune, sccm, office365.
     * @param value Value to set for the mobileDeviceManagementAuthority property.
     */
    set mobileDeviceManagementAuthority(value: MdmAuthority | undefined);
    /**
     * Gets the onPremisesLastSyncDateTime property value. The time and date at which the tenant was last synced with the on-premises directory. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @returns a Date
     */
    get onPremisesLastSyncDateTime(): Date | undefined;
    /**
     * Sets the onPremisesLastSyncDateTime property value. The time and date at which the tenant was last synced with the on-premises directory. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z. Read-only.
     * @param value Value to set for the onPremisesLastSyncDateTime property.
     */
    set onPremisesLastSyncDateTime(value: Date | undefined);
    /**
     * Gets the onPremisesSyncEnabled property value. true if this object is synced from an on-premises directory; false if this object was originally synced from an on-premises directory but is no longer synced. Nullable. null if this object has never been synced from an on-premises directory (default).
     * @returns a boolean
     */
    get onPremisesSyncEnabled(): boolean | undefined;
    /**
     * Sets the onPremisesSyncEnabled property value. true if this object is synced from an on-premises directory; false if this object was originally synced from an on-premises directory but is no longer synced. Nullable. null if this object has never been synced from an on-premises directory (default).
     * @param value Value to set for the onPremisesSyncEnabled property.
     */
    set onPremisesSyncEnabled(value: boolean | undefined);
    /**
     * Gets the postalCode property value. Postal code of the address for the organization.
     * @returns a string
     */
    get postalCode(): string | undefined;
    /**
     * Sets the postalCode property value. Postal code of the address for the organization.
     * @param value Value to set for the postalCode property.
     */
    set postalCode(value: string | undefined);
    /**
     * Gets the preferredLanguage property value. The preferred language for the organization. Should follow ISO 639-1 Code; for example, en.
     * @returns a string
     */
    get preferredLanguage(): string | undefined;
    /**
     * Sets the preferredLanguage property value. The preferred language for the organization. Should follow ISO 639-1 Code; for example, en.
     * @param value Value to set for the preferredLanguage property.
     */
    set preferredLanguage(value: string | undefined);
    /**
     * Gets the privacyProfile property value. The privacy profile of an organization.
     * @returns a privacyProfile
     */
    get privacyProfile(): PrivacyProfile | undefined;
    /**
     * Sets the privacyProfile property value. The privacy profile of an organization.
     * @param value Value to set for the privacyProfile property.
     */
    set privacyProfile(value: PrivacyProfile | undefined);
    /**
     * Gets the provisionedPlans property value. Not nullable.
     * @returns a provisionedPlan
     */
    get provisionedPlans(): ProvisionedPlan[] | undefined;
    /**
     * Sets the provisionedPlans property value. Not nullable.
     * @param value Value to set for the provisionedPlans property.
     */
    set provisionedPlans(value: ProvisionedPlan[] | undefined);
    /**
     * Gets the securityComplianceNotificationMails property value.
     * @returns a string
     */
    get securityComplianceNotificationMails(): string[] | undefined;
    /**
     * Sets the securityComplianceNotificationMails property value.
     * @param value Value to set for the securityComplianceNotificationMails property.
     */
    set securityComplianceNotificationMails(value: string[] | undefined);
    /**
     * Gets the securityComplianceNotificationPhones property value.
     * @returns a string
     */
    get securityComplianceNotificationPhones(): string[] | undefined;
    /**
     * Sets the securityComplianceNotificationPhones property value.
     * @param value Value to set for the securityComplianceNotificationPhones property.
     */
    set securityComplianceNotificationPhones(value: string[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the state property value. State name of the address for the organization.
     * @returns a string
     */
    get state(): string | undefined;
    /**
     * Sets the state property value. State name of the address for the organization.
     * @param value Value to set for the state property.
     */
    set state(value: string | undefined);
    /**
     * Gets the street property value. Street name of the address for organization.
     * @returns a string
     */
    get street(): string | undefined;
    /**
     * Sets the street property value. Street name of the address for organization.
     * @param value Value to set for the street property.
     */
    set street(value: string | undefined);
    /**
     * Gets the technicalNotificationMails property value. Not nullable.
     * @returns a string
     */
    get technicalNotificationMails(): string[] | undefined;
    /**
     * Sets the technicalNotificationMails property value. Not nullable.
     * @param value Value to set for the technicalNotificationMails property.
     */
    set technicalNotificationMails(value: string[] | undefined);
    /**
     * Gets the tenantType property value.
     * @returns a string
     */
    get tenantType(): string | undefined;
    /**
     * Sets the tenantType property value.
     * @param value Value to set for the tenantType property.
     */
    set tenantType(value: string | undefined);
    /**
     * Gets the verifiedDomains property value. The collection of domains associated with this tenant. Not nullable.
     * @returns a verifiedDomain
     */
    get verifiedDomains(): VerifiedDomain[] | undefined;
    /**
     * Sets the verifiedDomains property value. The collection of domains associated with this tenant. Not nullable.
     * @param value Value to set for the verifiedDomains property.
     */
    set verifiedDomains(value: VerifiedDomain[] | undefined);
}
