import { Entity, Location, PersonType, Phone, ScoredEmailAddress, Website } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Person extends Entity implements Parsable {
    /** The person's birthday.  */
    private _birthday?;
    /** The name of the person's company.  */
    private _companyName?;
    /** The person's department.  */
    private _department?;
    /** The person's display name.  */
    private _displayName?;
    /** The person's given name.  */
    private _givenName?;
    /** The instant message voice over IP (VOIP) session initiation protocol (SIP) address for the user. Read-only.  */
    private _imAddress?;
    /** true if the user has flagged this person as a favorite.  */
    private _isFavorite?;
    /** The person's job title.  */
    private _jobTitle?;
    /** The location of the person's office.  */
    private _officeLocation?;
    /** Free-form notes that the user has taken about this person.  */
    private _personNotes?;
    /** The type of person.  */
    private _personType?;
    /** The person's phone numbers.  */
    private _phones?;
    /** The person's addresses.  */
    private _postalAddresses?;
    /** The person's profession.  */
    private _profession?;
    /** The person's email addresses.  */
    private _scoredEmailAddresses?;
    /** The person's surname.  */
    private _surname?;
    /** The user principal name (UPN) of the person. The UPN is an Internet-style login name for the person based on the Internet standard RFC 822. By convention, this should map to the person's email name. The general format is alias@domain.  */
    private _userPrincipalName?;
    /** The person's websites.  */
    private _websites?;
    /** The phonetic Japanese name of the person's company.  */
    private _yomiCompany?;
    /**
     * Gets the birthday property value. The person's birthday.
     * @returns a string
     */
    get birthday(): string | undefined;
    /**
     * Sets the birthday property value. The person's birthday.
     * @param value Value to set for the birthday property.
     */
    set birthday(value: string | undefined);
    /**
     * Gets the companyName property value. The name of the person's company.
     * @returns a string
     */
    get companyName(): string | undefined;
    /**
     * Sets the companyName property value. The name of the person's company.
     * @param value Value to set for the companyName property.
     */
    set companyName(value: string | undefined);
    /**
     * Instantiates a new person and sets the default values.
     */
    constructor();
    /**
     * Gets the department property value. The person's department.
     * @returns a string
     */
    get department(): string | undefined;
    /**
     * Sets the department property value. The person's department.
     * @param value Value to set for the department property.
     */
    set department(value: string | undefined);
    /**
     * Gets the displayName property value. The person's display name.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The person's display name.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the givenName property value. The person's given name.
     * @returns a string
     */
    get givenName(): string | undefined;
    /**
     * Sets the givenName property value. The person's given name.
     * @param value Value to set for the givenName property.
     */
    set givenName(value: string | undefined);
    /**
     * Gets the imAddress property value. The instant message voice over IP (VOIP) session initiation protocol (SIP) address for the user. Read-only.
     * @returns a string
     */
    get imAddress(): string | undefined;
    /**
     * Sets the imAddress property value. The instant message voice over IP (VOIP) session initiation protocol (SIP) address for the user. Read-only.
     * @param value Value to set for the imAddress property.
     */
    set imAddress(value: string | undefined);
    /**
     * Gets the isFavorite property value. true if the user has flagged this person as a favorite.
     * @returns a boolean
     */
    get isFavorite(): boolean | undefined;
    /**
     * Sets the isFavorite property value. true if the user has flagged this person as a favorite.
     * @param value Value to set for the isFavorite property.
     */
    set isFavorite(value: boolean | undefined);
    /**
     * Gets the jobTitle property value. The person's job title.
     * @returns a string
     */
    get jobTitle(): string | undefined;
    /**
     * Sets the jobTitle property value. The person's job title.
     * @param value Value to set for the jobTitle property.
     */
    set jobTitle(value: string | undefined);
    /**
     * Gets the officeLocation property value. The location of the person's office.
     * @returns a string
     */
    get officeLocation(): string | undefined;
    /**
     * Sets the officeLocation property value. The location of the person's office.
     * @param value Value to set for the officeLocation property.
     */
    set officeLocation(value: string | undefined);
    /**
     * Gets the personNotes property value. Free-form notes that the user has taken about this person.
     * @returns a string
     */
    get personNotes(): string | undefined;
    /**
     * Sets the personNotes property value. Free-form notes that the user has taken about this person.
     * @param value Value to set for the personNotes property.
     */
    set personNotes(value: string | undefined);
    /**
     * Gets the personType property value. The type of person.
     * @returns a personType
     */
    get personType(): PersonType | undefined;
    /**
     * Sets the personType property value. The type of person.
     * @param value Value to set for the personType property.
     */
    set personType(value: PersonType | undefined);
    /**
     * Gets the phones property value. The person's phone numbers.
     * @returns a phone
     */
    get phones(): Phone[] | undefined;
    /**
     * Sets the phones property value. The person's phone numbers.
     * @param value Value to set for the phones property.
     */
    set phones(value: Phone[] | undefined);
    /**
     * Gets the postalAddresses property value. The person's addresses.
     * @returns a location
     */
    get postalAddresses(): Location[] | undefined;
    /**
     * Sets the postalAddresses property value. The person's addresses.
     * @param value Value to set for the postalAddresses property.
     */
    set postalAddresses(value: Location[] | undefined);
    /**
     * Gets the profession property value. The person's profession.
     * @returns a string
     */
    get profession(): string | undefined;
    /**
     * Sets the profession property value. The person's profession.
     * @param value Value to set for the profession property.
     */
    set profession(value: string | undefined);
    /**
     * Gets the scoredEmailAddresses property value. The person's email addresses.
     * @returns a scoredEmailAddress
     */
    get scoredEmailAddresses(): ScoredEmailAddress[] | undefined;
    /**
     * Sets the scoredEmailAddresses property value. The person's email addresses.
     * @param value Value to set for the scoredEmailAddresses property.
     */
    set scoredEmailAddresses(value: ScoredEmailAddress[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the surname property value. The person's surname.
     * @returns a string
     */
    get surname(): string | undefined;
    /**
     * Sets the surname property value. The person's surname.
     * @param value Value to set for the surname property.
     */
    set surname(value: string | undefined);
    /**
     * Gets the userPrincipalName property value. The user principal name (UPN) of the person. The UPN is an Internet-style login name for the person based on the Internet standard RFC 822. By convention, this should map to the person's email name. The general format is alias@domain.
     * @returns a string
     */
    get userPrincipalName(): string | undefined;
    /**
     * Sets the userPrincipalName property value. The user principal name (UPN) of the person. The UPN is an Internet-style login name for the person based on the Internet standard RFC 822. By convention, this should map to the person's email name. The general format is alias@domain.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value: string | undefined);
    /**
     * Gets the websites property value. The person's websites.
     * @returns a website
     */
    get websites(): Website[] | undefined;
    /**
     * Sets the websites property value. The person's websites.
     * @param value Value to set for the websites property.
     */
    set websites(value: Website[] | undefined);
    /**
     * Gets the yomiCompany property value. The phonetic Japanese name of the person's company.
     * @returns a string
     */
    get yomiCompany(): string | undefined;
    /**
     * Sets the yomiCompany property value. The phonetic Japanese name of the person's company.
     * @param value Value to set for the yomiCompany property.
     */
    set yomiCompany(value: string | undefined);
}
