import { ActivityBasedTimeoutPolicy, AdminConsentRequestPolicy, AuthenticationFlowsPolicy, AuthenticationMethodsPolicy, AuthorizationPolicy, ClaimsMappingPolicy, ConditionalAccessPolicy, Entity, FeatureRolloutPolicy, HomeRealmDiscoveryPolicy, IdentitySecurityDefaultsEnforcementPolicy, PermissionGrantPolicy, TokenIssuancePolicy, TokenLifetimePolicy } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the policyRoot singleton.  */
export declare class PolicyRoot extends Entity implements Parsable {
    /** The policy that controls the idle time out for web sessions for applications.  */
    private _activityBasedTimeoutPolicies?;
    /** The policy by which consent requests are created and managed for the entire tenant.  */
    private _adminConsentRequestPolicy?;
    /** The policy configuration of the self-service sign-up experience of external users.  */
    private _authenticationFlowsPolicy?;
    /** The authentication methods and the users that are allowed to use them to sign in and perform multi-factor authentication (MFA) in Azure Active Directory (Azure AD).  */
    private _authenticationMethodsPolicy?;
    /** The policy that controls Azure AD authorization settings.  */
    private _authorizationPolicy?;
    /** The claim-mapping policies for WS-Fed, SAML, OAuth 2.0, and OpenID Connect protocols, for tokens issued to a specific application.  */
    private _claimsMappingPolicies?;
    /** The custom rules that define an access scenario.  */
    private _conditionalAccessPolicies?;
    /** The feature rollout policy associated with a directory object.  */
    private _featureRolloutPolicies?;
    /** The policy to control Azure AD authentication behavior for federated users.  */
    private _homeRealmDiscoveryPolicies?;
    /** The policy that represents the security defaults that protect against common attacks.  */
    private _identitySecurityDefaultsEnforcementPolicy?;
    /** The policy that specifies the conditions under which consent can be granted.  */
    private _permissionGrantPolicies?;
    /** The policy that specifies the characteristics of SAML tokens issued by Azure AD.  */
    private _tokenIssuancePolicies?;
    /** The policy that controls the lifetime of a JWT access token, an ID token, or a SAML 1.1/2.0 token issued by Azure AD.  */
    private _tokenLifetimePolicies?;
    /**
     * Gets the activityBasedTimeoutPolicies property value. The policy that controls the idle time out for web sessions for applications.
     * @returns a activityBasedTimeoutPolicy
     */
    get activityBasedTimeoutPolicies(): ActivityBasedTimeoutPolicy[] | undefined;
    /**
     * Sets the activityBasedTimeoutPolicies property value. The policy that controls the idle time out for web sessions for applications.
     * @param value Value to set for the activityBasedTimeoutPolicies property.
     */
    set activityBasedTimeoutPolicies(value: ActivityBasedTimeoutPolicy[] | undefined);
    /**
     * Gets the adminConsentRequestPolicy property value. The policy by which consent requests are created and managed for the entire tenant.
     * @returns a adminConsentRequestPolicy
     */
    get adminConsentRequestPolicy(): AdminConsentRequestPolicy | undefined;
    /**
     * Sets the adminConsentRequestPolicy property value. The policy by which consent requests are created and managed for the entire tenant.
     * @param value Value to set for the adminConsentRequestPolicy property.
     */
    set adminConsentRequestPolicy(value: AdminConsentRequestPolicy | undefined);
    /**
     * Gets the authenticationFlowsPolicy property value. The policy configuration of the self-service sign-up experience of external users.
     * @returns a authenticationFlowsPolicy
     */
    get authenticationFlowsPolicy(): AuthenticationFlowsPolicy | undefined;
    /**
     * Sets the authenticationFlowsPolicy property value. The policy configuration of the self-service sign-up experience of external users.
     * @param value Value to set for the authenticationFlowsPolicy property.
     */
    set authenticationFlowsPolicy(value: AuthenticationFlowsPolicy | undefined);
    /**
     * Gets the authenticationMethodsPolicy property value. The authentication methods and the users that are allowed to use them to sign in and perform multi-factor authentication (MFA) in Azure Active Directory (Azure AD).
     * @returns a authenticationMethodsPolicy
     */
    get authenticationMethodsPolicy(): AuthenticationMethodsPolicy | undefined;
    /**
     * Sets the authenticationMethodsPolicy property value. The authentication methods and the users that are allowed to use them to sign in and perform multi-factor authentication (MFA) in Azure Active Directory (Azure AD).
     * @param value Value to set for the authenticationMethodsPolicy property.
     */
    set authenticationMethodsPolicy(value: AuthenticationMethodsPolicy | undefined);
    /**
     * Gets the authorizationPolicy property value. The policy that controls Azure AD authorization settings.
     * @returns a authorizationPolicy
     */
    get authorizationPolicy(): AuthorizationPolicy | undefined;
    /**
     * Sets the authorizationPolicy property value. The policy that controls Azure AD authorization settings.
     * @param value Value to set for the authorizationPolicy property.
     */
    set authorizationPolicy(value: AuthorizationPolicy | undefined);
    /**
     * Gets the claimsMappingPolicies property value. The claim-mapping policies for WS-Fed, SAML, OAuth 2.0, and OpenID Connect protocols, for tokens issued to a specific application.
     * @returns a claimsMappingPolicy
     */
    get claimsMappingPolicies(): ClaimsMappingPolicy[] | undefined;
    /**
     * Sets the claimsMappingPolicies property value. The claim-mapping policies for WS-Fed, SAML, OAuth 2.0, and OpenID Connect protocols, for tokens issued to a specific application.
     * @param value Value to set for the claimsMappingPolicies property.
     */
    set claimsMappingPolicies(value: ClaimsMappingPolicy[] | undefined);
    /**
     * Gets the conditionalAccessPolicies property value. The custom rules that define an access scenario.
     * @returns a conditionalAccessPolicy
     */
    get conditionalAccessPolicies(): ConditionalAccessPolicy[] | undefined;
    /**
     * Sets the conditionalAccessPolicies property value. The custom rules that define an access scenario.
     * @param value Value to set for the conditionalAccessPolicies property.
     */
    set conditionalAccessPolicies(value: ConditionalAccessPolicy[] | undefined);
    /**
     * Instantiates a new policyRoot and sets the default values.
     */
    constructor();
    /**
     * Gets the featureRolloutPolicies property value. The feature rollout policy associated with a directory object.
     * @returns a featureRolloutPolicy
     */
    get featureRolloutPolicies(): FeatureRolloutPolicy[] | undefined;
    /**
     * Sets the featureRolloutPolicies property value. The feature rollout policy associated with a directory object.
     * @param value Value to set for the featureRolloutPolicies property.
     */
    set featureRolloutPolicies(value: FeatureRolloutPolicy[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the homeRealmDiscoveryPolicies property value. The policy to control Azure AD authentication behavior for federated users.
     * @returns a homeRealmDiscoveryPolicy
     */
    get homeRealmDiscoveryPolicies(): HomeRealmDiscoveryPolicy[] | undefined;
    /**
     * Sets the homeRealmDiscoveryPolicies property value. The policy to control Azure AD authentication behavior for federated users.
     * @param value Value to set for the homeRealmDiscoveryPolicies property.
     */
    set homeRealmDiscoveryPolicies(value: HomeRealmDiscoveryPolicy[] | undefined);
    /**
     * Gets the identitySecurityDefaultsEnforcementPolicy property value. The policy that represents the security defaults that protect against common attacks.
     * @returns a identitySecurityDefaultsEnforcementPolicy
     */
    get identitySecurityDefaultsEnforcementPolicy(): IdentitySecurityDefaultsEnforcementPolicy | undefined;
    /**
     * Sets the identitySecurityDefaultsEnforcementPolicy property value. The policy that represents the security defaults that protect against common attacks.
     * @param value Value to set for the identitySecurityDefaultsEnforcementPolicy property.
     */
    set identitySecurityDefaultsEnforcementPolicy(value: IdentitySecurityDefaultsEnforcementPolicy | undefined);
    /**
     * Gets the permissionGrantPolicies property value. The policy that specifies the conditions under which consent can be granted.
     * @returns a permissionGrantPolicy
     */
    get permissionGrantPolicies(): PermissionGrantPolicy[] | undefined;
    /**
     * Sets the permissionGrantPolicies property value. The policy that specifies the conditions under which consent can be granted.
     * @param value Value to set for the permissionGrantPolicies property.
     */
    set permissionGrantPolicies(value: PermissionGrantPolicy[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the tokenIssuancePolicies property value. The policy that specifies the characteristics of SAML tokens issued by Azure AD.
     * @returns a tokenIssuancePolicy
     */
    get tokenIssuancePolicies(): TokenIssuancePolicy[] | undefined;
    /**
     * Sets the tokenIssuancePolicies property value. The policy that specifies the characteristics of SAML tokens issued by Azure AD.
     * @param value Value to set for the tokenIssuancePolicies property.
     */
    set tokenIssuancePolicies(value: TokenIssuancePolicy[] | undefined);
    /**
     * Gets the tokenLifetimePolicies property value. The policy that controls the lifetime of a JWT access token, an ID token, or a SAML 1.1/2.0 token issued by Azure AD.
     * @returns a tokenLifetimePolicy
     */
    get tokenLifetimePolicies(): TokenLifetimePolicy[] | undefined;
    /**
     * Sets the tokenLifetimePolicies property value. The policy that controls the lifetime of a JWT access token, an ID token, or a SAML 1.1/2.0 token issued by Azure AD.
     * @param value Value to set for the tokenLifetimePolicies property.
     */
    set tokenLifetimePolicies(value: TokenLifetimePolicy[] | undefined);
}
