import { Attachment, Extension, ItemBody, MultiValueLegacyExtendedProperty, OutlookItem, Recipient, SingleValueLegacyExtendedProperty } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Post extends OutlookItem implements Parsable {
    /** Read-only. Nullable. Supports $expand.  */
    private _attachments?;
    /** The contents of the post. This is a default property. This property can be null.  */
    private _body?;
    /** Unique ID of the conversation. Read-only.  */
    private _conversationId?;
    /** Unique ID of the conversation thread. Read-only.  */
    private _conversationThreadId?;
    /** The collection of open extensions defined for the post. Read-only. Nullable. Supports $expand.  */
    private _extensions?;
    private _from?;
    /** Indicates whether the post has at least one attachment. This is a default property.  */
    private _hasAttachments?;
    /** Read-only. Supports $expand.  */
    private _inReplyTo?;
    /** The collection of multi-value extended properties defined for the post. Read-only. Nullable.  */
    private _multiValueExtendedProperties?;
    /** Conversation participants that were added to the thread as part of this post.  */
    private _newParticipants?;
    /** Specifies when the post was received. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z  */
    private _receivedDateTime?;
    /** Contains the address of the sender. The value of Sender is assumed to be the address of the authenticated user in the case when Sender is not specified. This is a default property.  */
    private _sender?;
    /** The collection of single-value extended properties defined for the post. Read-only. Nullable.  */
    private _singleValueExtendedProperties?;
    /**
     * Gets the attachments property value. Read-only. Nullable. Supports $expand.
     * @returns a attachment
     */
    get attachments(): Attachment[] | undefined;
    /**
     * Sets the attachments property value. Read-only. Nullable. Supports $expand.
     * @param value Value to set for the attachments property.
     */
    set attachments(value: Attachment[] | undefined);
    /**
     * Gets the body property value. The contents of the post. This is a default property. This property can be null.
     * @returns a itemBody
     */
    get body(): ItemBody | undefined;
    /**
     * Sets the body property value. The contents of the post. This is a default property. This property can be null.
     * @param value Value to set for the body property.
     */
    set body(value: ItemBody | undefined);
    /**
     * Instantiates a new post and sets the default values.
     */
    constructor();
    /**
     * Gets the conversationId property value. Unique ID of the conversation. Read-only.
     * @returns a string
     */
    get conversationId(): string | undefined;
    /**
     * Sets the conversationId property value. Unique ID of the conversation. Read-only.
     * @param value Value to set for the conversationId property.
     */
    set conversationId(value: string | undefined);
    /**
     * Gets the conversationThreadId property value. Unique ID of the conversation thread. Read-only.
     * @returns a string
     */
    get conversationThreadId(): string | undefined;
    /**
     * Sets the conversationThreadId property value. Unique ID of the conversation thread. Read-only.
     * @param value Value to set for the conversationThreadId property.
     */
    set conversationThreadId(value: string | undefined);
    /**
     * Gets the extensions property value. The collection of open extensions defined for the post. Read-only. Nullable. Supports $expand.
     * @returns a extension
     */
    get extensions(): Extension[] | undefined;
    /**
     * Sets the extensions property value. The collection of open extensions defined for the post. Read-only. Nullable. Supports $expand.
     * @param value Value to set for the extensions property.
     */
    set extensions(value: Extension[] | undefined);
    /**
     * Gets the from property value.
     * @returns a recipient
     */
    get from(): Recipient | undefined;
    /**
     * Sets the from property value.
     * @param value Value to set for the from property.
     */
    set from(value: Recipient | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hasAttachments property value. Indicates whether the post has at least one attachment. This is a default property.
     * @returns a boolean
     */
    get hasAttachments(): boolean | undefined;
    /**
     * Sets the hasAttachments property value. Indicates whether the post has at least one attachment. This is a default property.
     * @param value Value to set for the hasAttachments property.
     */
    set hasAttachments(value: boolean | undefined);
    /**
     * Gets the inReplyTo property value. Read-only. Supports $expand.
     * @returns a post
     */
    get inReplyTo(): Post | undefined;
    /**
     * Sets the inReplyTo property value. Read-only. Supports $expand.
     * @param value Value to set for the inReplyTo property.
     */
    set inReplyTo(value: Post | undefined);
    /**
     * Gets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the post. Read-only. Nullable.
     * @returns a multiValueLegacyExtendedProperty
     */
    get multiValueExtendedProperties(): MultiValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the multiValueExtendedProperties property value. The collection of multi-value extended properties defined for the post. Read-only. Nullable.
     * @param value Value to set for the multiValueExtendedProperties property.
     */
    set multiValueExtendedProperties(value: MultiValueLegacyExtendedProperty[] | undefined);
    /**
     * Gets the newParticipants property value. Conversation participants that were added to the thread as part of this post.
     * @returns a recipient
     */
    get newParticipants(): Recipient[] | undefined;
    /**
     * Sets the newParticipants property value. Conversation participants that were added to the thread as part of this post.
     * @param value Value to set for the newParticipants property.
     */
    set newParticipants(value: Recipient[] | undefined);
    /**
     * Gets the receivedDateTime property value. Specifies when the post was received. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get receivedDateTime(): Date | undefined;
    /**
     * Sets the receivedDateTime property value. Specifies when the post was received. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z
     * @param value Value to set for the receivedDateTime property.
     */
    set receivedDateTime(value: Date | undefined);
    /**
     * Gets the sender property value. Contains the address of the sender. The value of Sender is assumed to be the address of the authenticated user in the case when Sender is not specified. This is a default property.
     * @returns a recipient
     */
    get sender(): Recipient | undefined;
    /**
     * Sets the sender property value. Contains the address of the sender. The value of Sender is assumed to be the address of the authenticated user in the case when Sender is not specified. This is a default property.
     * @param value Value to set for the sender property.
     */
    set sender(value: Recipient | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the post. Read-only. Nullable.
     * @returns a singleValueLegacyExtendedProperty
     */
    get singleValueExtendedProperties(): SingleValueLegacyExtendedProperty[] | undefined;
    /**
     * Sets the singleValueExtendedProperties property value. The collection of single-value extended properties defined for the post. Read-only. Nullable.
     * @param value Value to set for the singleValueExtendedProperties property.
     */
    set singleValueExtendedProperties(value: SingleValueLegacyExtendedProperty[] | undefined);
}
