import { Entity, PrintDocument, PrintJobConfiguration, PrintJobStatus, PrintTask, UserIdentity } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class PrintJob extends Entity implements Parsable {
    private _configuration?;
    /** Read-only. Nullable.  */
    private _createdBy?;
    /** The DateTimeOffset when the job was created. Read-only.  */
    private _createdDateTime?;
    /** Read-only.  */
    private _documents?;
    /** If true, document can be fetched by printer.  */
    private _isFetchable?;
    /** Contains the source job URL, if the job has been redirected from another printer.  */
    private _redirectedFrom?;
    /** Contains the destination job URL, if the job has been redirected to another printer.  */
    private _redirectedTo?;
    private _status?;
    /** A list of printTasks that were triggered by this print job.  */
    private _tasks?;
    /**
     * Gets the configuration property value.
     * @returns a printJobConfiguration
     */
    get configuration(): PrintJobConfiguration | undefined;
    /**
     * Sets the configuration property value.
     * @param value Value to set for the configuration property.
     */
    set configuration(value: PrintJobConfiguration | undefined);
    /**
     * Instantiates a new printJob and sets the default values.
     */
    constructor();
    /**
     * Gets the createdBy property value. Read-only. Nullable.
     * @returns a userIdentity
     */
    get createdBy(): UserIdentity | undefined;
    /**
     * Sets the createdBy property value. Read-only. Nullable.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: UserIdentity | undefined);
    /**
     * Gets the createdDateTime property value. The DateTimeOffset when the job was created. Read-only.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The DateTimeOffset when the job was created. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the documents property value. Read-only.
     * @returns a printDocument
     */
    get documents(): PrintDocument[] | undefined;
    /**
     * Sets the documents property value. Read-only.
     * @param value Value to set for the documents property.
     */
    set documents(value: PrintDocument[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isFetchable property value. If true, document can be fetched by printer.
     * @returns a boolean
     */
    get isFetchable(): boolean | undefined;
    /**
     * Sets the isFetchable property value. If true, document can be fetched by printer.
     * @param value Value to set for the isFetchable property.
     */
    set isFetchable(value: boolean | undefined);
    /**
     * Gets the redirectedFrom property value. Contains the source job URL, if the job has been redirected from another printer.
     * @returns a string
     */
    get redirectedFrom(): string | undefined;
    /**
     * Sets the redirectedFrom property value. Contains the source job URL, if the job has been redirected from another printer.
     * @param value Value to set for the redirectedFrom property.
     */
    set redirectedFrom(value: string | undefined);
    /**
     * Gets the redirectedTo property value. Contains the destination job URL, if the job has been redirected to another printer.
     * @returns a string
     */
    get redirectedTo(): string | undefined;
    /**
     * Sets the redirectedTo property value. Contains the destination job URL, if the job has been redirected to another printer.
     * @param value Value to set for the redirectedTo property.
     */
    set redirectedTo(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value.
     * @returns a printJobStatus
     */
    get status(): PrintJobStatus | undefined;
    /**
     * Sets the status property value.
     * @param value Value to set for the status property.
     */
    set status(value: PrintJobStatus | undefined);
    /**
     * Gets the tasks property value. A list of printTasks that were triggered by this print job.
     * @returns a printTask
     */
    get tasks(): PrintTask[] | undefined;
    /**
     * Sets the tasks property value. A list of printTasks that were triggered by this print job.
     * @param value Value to set for the tasks property.
     */
    set tasks(value: PrintTask[] | undefined);
}
