import { PrintConnector, PrinterBase, PrinterShare, PrintTaskTrigger } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Printer extends PrinterBase implements Parsable {
    /** The connectors that are associated with the printer.  */
    private _connectors?;
    /** True if the printer has a physical device for printing. Read-only.  */
    private _hasPhysicalDevice?;
    /** True if the printer is shared; false otherwise. Read-only.  */
    private _isShared?;
    /** The most recent dateTimeOffset when a printer interacted with Universal Print. Read-only.  */
    private _lastSeenDateTime?;
    /** The DateTimeOffset when the printer was registered. Read-only.  */
    private _registeredDateTime?;
    /** The list of printerShares that are associated with the printer. Currently, only one printerShare can be associated with the printer. Read-only. Nullable.  */
    private _shares?;
    /** A list of task triggers that are associated with the printer.  */
    private _taskTriggers?;
    /**
     * Gets the connectors property value. The connectors that are associated with the printer.
     * @returns a printConnector
     */
    get connectors(): PrintConnector[] | undefined;
    /**
     * Sets the connectors property value. The connectors that are associated with the printer.
     * @param value Value to set for the connectors property.
     */
    set connectors(value: PrintConnector[] | undefined);
    /**
     * Instantiates a new printer and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hasPhysicalDevice property value. True if the printer has a physical device for printing. Read-only.
     * @returns a boolean
     */
    get hasPhysicalDevice(): boolean | undefined;
    /**
     * Sets the hasPhysicalDevice property value. True if the printer has a physical device for printing. Read-only.
     * @param value Value to set for the hasPhysicalDevice property.
     */
    set hasPhysicalDevice(value: boolean | undefined);
    /**
     * Gets the isShared property value. True if the printer is shared; false otherwise. Read-only.
     * @returns a boolean
     */
    get isShared(): boolean | undefined;
    /**
     * Sets the isShared property value. True if the printer is shared; false otherwise. Read-only.
     * @param value Value to set for the isShared property.
     */
    set isShared(value: boolean | undefined);
    /**
     * Gets the lastSeenDateTime property value. The most recent dateTimeOffset when a printer interacted with Universal Print. Read-only.
     * @returns a Date
     */
    get lastSeenDateTime(): Date | undefined;
    /**
     * Sets the lastSeenDateTime property value. The most recent dateTimeOffset when a printer interacted with Universal Print. Read-only.
     * @param value Value to set for the lastSeenDateTime property.
     */
    set lastSeenDateTime(value: Date | undefined);
    /**
     * Gets the registeredDateTime property value. The DateTimeOffset when the printer was registered. Read-only.
     * @returns a Date
     */
    get registeredDateTime(): Date | undefined;
    /**
     * Sets the registeredDateTime property value. The DateTimeOffset when the printer was registered. Read-only.
     * @param value Value to set for the registeredDateTime property.
     */
    set registeredDateTime(value: Date | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the shares property value. The list of printerShares that are associated with the printer. Currently, only one printerShare can be associated with the printer. Read-only. Nullable.
     * @returns a printerShare
     */
    get shares(): PrinterShare[] | undefined;
    /**
     * Sets the shares property value. The list of printerShares that are associated with the printer. Currently, only one printerShare can be associated with the printer. Read-only. Nullable.
     * @param value Value to set for the shares property.
     */
    set shares(value: PrinterShare[] | undefined);
    /**
     * Gets the taskTriggers property value. A list of task triggers that are associated with the printer.
     * @returns a printTaskTrigger
     */
    get taskTriggers(): PrintTaskTrigger[] | undefined;
    /**
     * Sets the taskTriggers property value. A list of task triggers that are associated with the printer.
     * @param value Value to set for the taskTriggers property.
     */
    set taskTriggers(value: PrintTaskTrigger[] | undefined);
}
