"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PrinterCapabilities = void 0;
const createIntegerRangeFromDiscriminatorValue_1 = require("./createIntegerRangeFromDiscriminatorValue");
const printColorMode_1 = require("./printColorMode");
const printDuplexMode_1 = require("./printDuplexMode");
const printerFeedOrientation_1 = require("./printerFeedOrientation");
const printFinishing_1 = require("./printFinishing");
const printMultipageLayout_1 = require("./printMultipageLayout");
const printOrientation_1 = require("./printOrientation");
const printQuality_1 = require("./printQuality");
const printScaling_1 = require("./printScaling");
class PrinterCapabilities {
    /**
     * Instantiates a new printerCapabilities and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    /**
     * Gets the bottomMargins property value. A list of supported bottom margins(in microns) for the printer.
     * @returns a integer
     */
    get bottomMargins() {
        return this._bottomMargins;
    }
    ;
    /**
     * Sets the bottomMargins property value. A list of supported bottom margins(in microns) for the printer.
     * @param value Value to set for the bottomMargins property.
     */
    set bottomMargins(value) {
        this._bottomMargins = value;
    }
    ;
    /**
     * Gets the collation property value. True if the printer supports collating when printing muliple copies of a multi-page document; false otherwise.
     * @returns a boolean
     */
    get collation() {
        return this._collation;
    }
    ;
    /**
     * Sets the collation property value. True if the printer supports collating when printing muliple copies of a multi-page document; false otherwise.
     * @param value Value to set for the collation property.
     */
    set collation(value) {
        this._collation = value;
    }
    ;
    /**
     * Gets the colorModes property value. The color modes supported by the printer. Valid values are described in the following table.
     * @returns a printColorMode
     */
    get colorModes() {
        return this._colorModes;
    }
    ;
    /**
     * Sets the colorModes property value. The color modes supported by the printer. Valid values are described in the following table.
     * @param value Value to set for the colorModes property.
     */
    set colorModes(value) {
        this._colorModes = value;
    }
    ;
    ;
    /**
     * Gets the contentTypes property value. A list of supported content (MIME) types that the printer supports. It is not guaranteed that the Universal Print service supports printing all of these MIME types.
     * @returns a string
     */
    get contentTypes() {
        return this._contentTypes;
    }
    ;
    /**
     * Sets the contentTypes property value. A list of supported content (MIME) types that the printer supports. It is not guaranteed that the Universal Print service supports printing all of these MIME types.
     * @param value Value to set for the contentTypes property.
     */
    set contentTypes(value) {
        this._contentTypes = value;
    }
    ;
    /**
     * Gets the copiesPerJob property value. The range of copies per job supported by the printer.
     * @returns a integerRange
     */
    get copiesPerJob() {
        return this._copiesPerJob;
    }
    ;
    /**
     * Sets the copiesPerJob property value. The range of copies per job supported by the printer.
     * @param value Value to set for the copiesPerJob property.
     */
    set copiesPerJob(value) {
        this._copiesPerJob = value;
    }
    ;
    /**
     * Gets the dpis property value. The list of print resolutions in DPI that are supported by the printer.
     * @returns a integer
     */
    get dpis() {
        return this._dpis;
    }
    ;
    /**
     * Sets the dpis property value. The list of print resolutions in DPI that are supported by the printer.
     * @param value Value to set for the dpis property.
     */
    set dpis(value) {
        this._dpis = value;
    }
    ;
    /**
     * Gets the duplexModes property value. The list of duplex modes that are supported by the printer. Valid values are described in the following table.
     * @returns a printDuplexMode
     */
    get duplexModes() {
        return this._duplexModes;
    }
    ;
    /**
     * Sets the duplexModes property value. The list of duplex modes that are supported by the printer. Valid values are described in the following table.
     * @param value Value to set for the duplexModes property.
     */
    set duplexModes(value) {
        this._duplexModes = value;
    }
    ;
    /**
     * Gets the feedOrientations property value. The list of feed orientations that are supported by the printer.
     * @returns a printerFeedOrientation
     */
    get feedOrientations() {
        return this._feedOrientations;
    }
    ;
    /**
     * Sets the feedOrientations property value. The list of feed orientations that are supported by the printer.
     * @param value Value to set for the feedOrientations property.
     */
    set feedOrientations(value) {
        this._feedOrientations = value;
    }
    ;
    /**
     * Gets the finishings property value. Finishing processes the printer supports for a printed document.
     * @returns a printFinishing
     */
    get finishings() {
        return this._finishings;
    }
    ;
    /**
     * Sets the finishings property value. Finishing processes the printer supports for a printed document.
     * @param value Value to set for the finishings property.
     */
    set finishings(value) {
        this._finishings = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "bottomMargins": (o, n) => { o.bottomMargins = n.getCollectionOfPrimitiveValues(); },
            "collation": (o, n) => { o.collation = n.getBooleanValue(); },
            "colorModes": (o, n) => { o.colorModes = n.getEnumValues(printColorMode_1.PrintColorMode); },
            "contentTypes": (o, n) => { o.contentTypes = n.getCollectionOfPrimitiveValues(); },
            "copiesPerJob": (o, n) => { o.copiesPerJob = n.getObjectValue(createIntegerRangeFromDiscriminatorValue_1.createIntegerRangeFromDiscriminatorValue); },
            "dpis": (o, n) => { o.dpis = n.getCollectionOfPrimitiveValues(); },
            "duplexModes": (o, n) => { o.duplexModes = n.getEnumValues(printDuplexMode_1.PrintDuplexMode); },
            "feedOrientations": (o, n) => { o.feedOrientations = n.getEnumValues(printerFeedOrientation_1.PrinterFeedOrientation); },
            "finishings": (o, n) => { o.finishings = n.getEnumValues(printFinishing_1.PrintFinishing); },
            "inputBins": (o, n) => { o.inputBins = n.getCollectionOfPrimitiveValues(); },
            "isColorPrintingSupported": (o, n) => { o.isColorPrintingSupported = n.getBooleanValue(); },
            "isPageRangeSupported": (o, n) => { o.isPageRangeSupported = n.getBooleanValue(); },
            "leftMargins": (o, n) => { o.leftMargins = n.getCollectionOfPrimitiveValues(); },
            "mediaColors": (o, n) => { o.mediaColors = n.getCollectionOfPrimitiveValues(); },
            "mediaSizes": (o, n) => { o.mediaSizes = n.getCollectionOfPrimitiveValues(); },
            "mediaTypes": (o, n) => { o.mediaTypes = n.getCollectionOfPrimitiveValues(); },
            "multipageLayouts": (o, n) => { o.multipageLayouts = n.getEnumValues(printMultipageLayout_1.PrintMultipageLayout); },
            "orientations": (o, n) => { o.orientations = n.getEnumValues(printOrientation_1.PrintOrientation); },
            "outputBins": (o, n) => { o.outputBins = n.getCollectionOfPrimitiveValues(); },
            "pagesPerSheet": (o, n) => { o.pagesPerSheet = n.getCollectionOfPrimitiveValues(); },
            "qualities": (o, n) => { o.qualities = n.getEnumValues(printQuality_1.PrintQuality); },
            "rightMargins": (o, n) => { o.rightMargins = n.getCollectionOfPrimitiveValues(); },
            "scalings": (o, n) => { o.scalings = n.getEnumValues(printScaling_1.PrintScaling); },
            "supportsFitPdfToPage": (o, n) => { o.supportsFitPdfToPage = n.getBooleanValue(); },
            "topMargins": (o, n) => { o.topMargins = n.getCollectionOfPrimitiveValues(); },
        };
    }
    ;
    /**
     * Gets the inputBins property value. Supported input bins for the printer.
     * @returns a string
     */
    get inputBins() {
        return this._inputBins;
    }
    ;
    /**
     * Sets the inputBins property value. Supported input bins for the printer.
     * @param value Value to set for the inputBins property.
     */
    set inputBins(value) {
        this._inputBins = value;
    }
    ;
    /**
     * Gets the isColorPrintingSupported property value. True if color printing is supported by the printer; false otherwise. Read-only.
     * @returns a boolean
     */
    get isColorPrintingSupported() {
        return this._isColorPrintingSupported;
    }
    ;
    /**
     * Sets the isColorPrintingSupported property value. True if color printing is supported by the printer; false otherwise. Read-only.
     * @param value Value to set for the isColorPrintingSupported property.
     */
    set isColorPrintingSupported(value) {
        this._isColorPrintingSupported = value;
    }
    ;
    /**
     * Gets the isPageRangeSupported property value. True if the printer supports printing by page ranges; false otherwise.
     * @returns a boolean
     */
    get isPageRangeSupported() {
        return this._isPageRangeSupported;
    }
    ;
    /**
     * Sets the isPageRangeSupported property value. True if the printer supports printing by page ranges; false otherwise.
     * @param value Value to set for the isPageRangeSupported property.
     */
    set isPageRangeSupported(value) {
        this._isPageRangeSupported = value;
    }
    ;
    /**
     * Gets the leftMargins property value. A list of supported left margins(in microns) for the printer.
     * @returns a integer
     */
    get leftMargins() {
        return this._leftMargins;
    }
    ;
    /**
     * Sets the leftMargins property value. A list of supported left margins(in microns) for the printer.
     * @param value Value to set for the leftMargins property.
     */
    set leftMargins(value) {
        this._leftMargins = value;
    }
    ;
    /**
     * Gets the mediaColors property value. The media (i.e., paper) colors supported by the printer.
     * @returns a string
     */
    get mediaColors() {
        return this._mediaColors;
    }
    ;
    /**
     * Sets the mediaColors property value. The media (i.e., paper) colors supported by the printer.
     * @param value Value to set for the mediaColors property.
     */
    set mediaColors(value) {
        this._mediaColors = value;
    }
    ;
    /**
     * Gets the mediaSizes property value. The media sizes supported by the printer. Supports standard size names for ISO and ANSI media sizes. Valid values are in the following table.
     * @returns a string
     */
    get mediaSizes() {
        return this._mediaSizes;
    }
    ;
    /**
     * Sets the mediaSizes property value. The media sizes supported by the printer. Supports standard size names for ISO and ANSI media sizes. Valid values are in the following table.
     * @param value Value to set for the mediaSizes property.
     */
    set mediaSizes(value) {
        this._mediaSizes = value;
    }
    ;
    /**
     * Gets the mediaTypes property value. The media types supported by the printer.
     * @returns a string
     */
    get mediaTypes() {
        return this._mediaTypes;
    }
    ;
    /**
     * Sets the mediaTypes property value. The media types supported by the printer.
     * @param value Value to set for the mediaTypes property.
     */
    set mediaTypes(value) {
        this._mediaTypes = value;
    }
    ;
    /**
     * Gets the multipageLayouts property value. The presentation directions supported by the printer. Supported values are described in the following table.
     * @returns a printMultipageLayout
     */
    get multipageLayouts() {
        return this._multipageLayouts;
    }
    ;
    /**
     * Sets the multipageLayouts property value. The presentation directions supported by the printer. Supported values are described in the following table.
     * @param value Value to set for the multipageLayouts property.
     */
    set multipageLayouts(value) {
        this._multipageLayouts = value;
    }
    ;
    /**
     * Gets the orientations property value. The print orientations supported by the printer. Valid values are described in the following table.
     * @returns a printOrientation
     */
    get orientations() {
        return this._orientations;
    }
    ;
    /**
     * Sets the orientations property value. The print orientations supported by the printer. Valid values are described in the following table.
     * @param value Value to set for the orientations property.
     */
    set orientations(value) {
        this._orientations = value;
    }
    ;
    /**
     * Gets the outputBins property value. The printer's supported output bins (trays).
     * @returns a string
     */
    get outputBins() {
        return this._outputBins;
    }
    ;
    /**
     * Sets the outputBins property value. The printer's supported output bins (trays).
     * @param value Value to set for the outputBins property.
     */
    set outputBins(value) {
        this._outputBins = value;
    }
    ;
    /**
     * Gets the pagesPerSheet property value. Supported number of Input Pages to impose upon a single Impression.
     * @returns a integer
     */
    get pagesPerSheet() {
        return this._pagesPerSheet;
    }
    ;
    /**
     * Sets the pagesPerSheet property value. Supported number of Input Pages to impose upon a single Impression.
     * @param value Value to set for the pagesPerSheet property.
     */
    set pagesPerSheet(value) {
        this._pagesPerSheet = value;
    }
    ;
    /**
     * Gets the qualities property value. The print qualities supported by the printer.
     * @returns a printQuality
     */
    get qualities() {
        return this._qualities;
    }
    ;
    /**
     * Sets the qualities property value. The print qualities supported by the printer.
     * @param value Value to set for the qualities property.
     */
    set qualities(value) {
        this._qualities = value;
    }
    ;
    /**
     * Gets the rightMargins property value. A list of supported right margins(in microns) for the printer.
     * @returns a integer
     */
    get rightMargins() {
        return this._rightMargins;
    }
    ;
    /**
     * Sets the rightMargins property value. A list of supported right margins(in microns) for the printer.
     * @param value Value to set for the rightMargins property.
     */
    set rightMargins(value) {
        this._rightMargins = value;
    }
    ;
    /**
     * Gets the scalings property value. Supported print scalings.
     * @returns a printScaling
     */
    get scalings() {
        return this._scalings;
    }
    ;
    /**
     * Sets the scalings property value. Supported print scalings.
     * @param value Value to set for the scalings property.
     */
    set scalings(value) {
        this._scalings = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeCollectionOfPrimitiveValues("bottomMargins", this.bottomMargins);
        writer.writeBooleanValue("collation", this.collation);
        this.colorModes && writer.writeEnumValue("colorModes", ...this.colorModes);
        writer.writeCollectionOfPrimitiveValues("contentTypes", this.contentTypes);
        writer.writeObjectValue("copiesPerJob", this.copiesPerJob);
        writer.writeCollectionOfPrimitiveValues("dpis", this.dpis);
        this.duplexModes && writer.writeEnumValue("duplexModes", ...this.duplexModes);
        this.feedOrientations && writer.writeEnumValue("feedOrientations", ...this.feedOrientations);
        this.finishings && writer.writeEnumValue("finishings", ...this.finishings);
        writer.writeCollectionOfPrimitiveValues("inputBins", this.inputBins);
        writer.writeBooleanValue("isColorPrintingSupported", this.isColorPrintingSupported);
        writer.writeBooleanValue("isPageRangeSupported", this.isPageRangeSupported);
        writer.writeCollectionOfPrimitiveValues("leftMargins", this.leftMargins);
        writer.writeCollectionOfPrimitiveValues("mediaColors", this.mediaColors);
        writer.writeCollectionOfPrimitiveValues("mediaSizes", this.mediaSizes);
        writer.writeCollectionOfPrimitiveValues("mediaTypes", this.mediaTypes);
        this.multipageLayouts && writer.writeEnumValue("multipageLayouts", ...this.multipageLayouts);
        this.orientations && writer.writeEnumValue("orientations", ...this.orientations);
        writer.writeCollectionOfPrimitiveValues("outputBins", this.outputBins);
        writer.writeCollectionOfPrimitiveValues("pagesPerSheet", this.pagesPerSheet);
        this.qualities && writer.writeEnumValue("qualities", ...this.qualities);
        writer.writeCollectionOfPrimitiveValues("rightMargins", this.rightMargins);
        this.scalings && writer.writeEnumValue("scalings", ...this.scalings);
        writer.writeBooleanValue("supportsFitPdfToPage", this.supportsFitPdfToPage);
        writer.writeCollectionOfPrimitiveValues("topMargins", this.topMargins);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
    /**
     * Gets the supportsFitPdfToPage property value. True if the printer supports scaling PDF pages to match the print media size; false otherwise.
     * @returns a boolean
     */
    get supportsFitPdfToPage() {
        return this._supportsFitPdfToPage;
    }
    ;
    /**
     * Sets the supportsFitPdfToPage property value. True if the printer supports scaling PDF pages to match the print media size; false otherwise.
     * @param value Value to set for the supportsFitPdfToPage property.
     */
    set supportsFitPdfToPage(value) {
        this._supportsFitPdfToPage = value;
    }
    ;
    /**
     * Gets the topMargins property value. A list of supported top margins(in microns) for the printer.
     * @returns a integer
     */
    get topMargins() {
        return this._topMargins;
    }
    ;
    /**
     * Sets the topMargins property value. A list of supported top margins(in microns) for the printer.
     * @param value Value to set for the topMargins property.
     */
    set topMargins(value) {
        this._topMargins = value;
    }
    ;
}
exports.PrinterCapabilities = PrinterCapabilities;
