import { Group, Printer, PrinterBase, User } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class PrinterShare extends PrinterBase implements Parsable {
    /** If true, all users and groups will be granted access to this printer share. This supersedes the allow lists defined by the allowedUsers and allowedGroups navigation properties.  */
    private _allowAllUsers?;
    /** The groups whose users have access to print using the printer.  */
    private _allowedGroups?;
    /** The users who have access to print using the printer.  */
    private _allowedUsers?;
    /** The DateTimeOffset when the printer share was created. Read-only.  */
    private _createdDateTime?;
    /** The printer that this printer share is related to.  */
    private _printer?;
    /**
     * Gets the allowAllUsers property value. If true, all users and groups will be granted access to this printer share. This supersedes the allow lists defined by the allowedUsers and allowedGroups navigation properties.
     * @returns a boolean
     */
    get allowAllUsers(): boolean | undefined;
    /**
     * Sets the allowAllUsers property value. If true, all users and groups will be granted access to this printer share. This supersedes the allow lists defined by the allowedUsers and allowedGroups navigation properties.
     * @param value Value to set for the allowAllUsers property.
     */
    set allowAllUsers(value: boolean | undefined);
    /**
     * Gets the allowedGroups property value. The groups whose users have access to print using the printer.
     * @returns a group
     */
    get allowedGroups(): Group[] | undefined;
    /**
     * Sets the allowedGroups property value. The groups whose users have access to print using the printer.
     * @param value Value to set for the allowedGroups property.
     */
    set allowedGroups(value: Group[] | undefined);
    /**
     * Gets the allowedUsers property value. The users who have access to print using the printer.
     * @returns a user
     */
    get allowedUsers(): User[] | undefined;
    /**
     * Sets the allowedUsers property value. The users who have access to print using the printer.
     * @param value Value to set for the allowedUsers property.
     */
    set allowedUsers(value: User[] | undefined);
    /**
     * Instantiates a new printerShare and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. The DateTimeOffset when the printer share was created. Read-only.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The DateTimeOffset when the printer share was created. Read-only.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the printer property value. The printer that this printer share is related to.
     * @returns a printer
     */
    get printer(): Printer | undefined;
    /**
     * Sets the printer property value. The printer that this printer share is related to.
     * @param value Value to set for the printer property.
     */
    set printer(value: Printer | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
