import { FileHash } from './index';
import { ProcessIntegrityLevel } from './processIntegrityLevel';
import { AdditionalDataHolder, Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Process implements AdditionalDataHolder, Parsable {
    /** User account identifier (user account context the process ran under) for example, AccountName, SID, and so on.  */
    private _accountName?;
    /** Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.  */
    private _additionalData;
    /** The full process invocation commandline including all parameters.  */
    private _commandLine?;
    /** Time at which the process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.  */
    private _createdDateTime?;
    /** Complex type containing file hashes (cryptographic and location-sensitive).  */
    private _fileHash?;
    /** The integrity level of the process. Possible values are: unknown, untrusted, low, medium, high, system.  */
    private _integrityLevel?;
    /** True if the process is elevated.  */
    private _isElevated?;
    /** The name of the process' Image file.  */
    private _name?;
    /** DateTime at which the parent process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.  */
    private _parentProcessCreatedDateTime?;
    /** The Process ID (PID) of the parent process.  */
    private _parentProcessId?;
    /** The name of the image file of the parent process.  */
    private _parentProcessName?;
    /** Full path, including filename.  */
    private _path?;
    /** The Process ID (PID) of the process.  */
    private _processId?;
    /**
     * Gets the accountName property value. User account identifier (user account context the process ran under) for example, AccountName, SID, and so on.
     * @returns a string
     */
    get accountName(): string | undefined;
    /**
     * Sets the accountName property value. User account identifier (user account context the process ran under) for example, AccountName, SID, and so on.
     * @param value Value to set for the accountName property.
     */
    set accountName(value: string | undefined);
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData(): Record<string, unknown>;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value: Record<string, unknown>);
    /**
     * Gets the commandLine property value. The full process invocation commandline including all parameters.
     * @returns a string
     */
    get commandLine(): string | undefined;
    /**
     * Sets the commandLine property value. The full process invocation commandline including all parameters.
     * @param value Value to set for the commandLine property.
     */
    set commandLine(value: string | undefined);
    /**
     * Instantiates a new process and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. Time at which the process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. Time at which the process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the fileHash property value. Complex type containing file hashes (cryptographic and location-sensitive).
     * @returns a fileHash
     */
    get fileHash(): FileHash | undefined;
    /**
     * Sets the fileHash property value. Complex type containing file hashes (cryptographic and location-sensitive).
     * @param value Value to set for the fileHash property.
     */
    set fileHash(value: FileHash | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the integrityLevel property value. The integrity level of the process. Possible values are: unknown, untrusted, low, medium, high, system.
     * @returns a processIntegrityLevel
     */
    get integrityLevel(): ProcessIntegrityLevel | undefined;
    /**
     * Sets the integrityLevel property value. The integrity level of the process. Possible values are: unknown, untrusted, low, medium, high, system.
     * @param value Value to set for the integrityLevel property.
     */
    set integrityLevel(value: ProcessIntegrityLevel | undefined);
    /**
     * Gets the isElevated property value. True if the process is elevated.
     * @returns a boolean
     */
    get isElevated(): boolean | undefined;
    /**
     * Sets the isElevated property value. True if the process is elevated.
     * @param value Value to set for the isElevated property.
     */
    set isElevated(value: boolean | undefined);
    /**
     * Gets the name property value. The name of the process' Image file.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The name of the process' Image file.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the parentProcessCreatedDateTime property value. DateTime at which the parent process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get parentProcessCreatedDateTime(): Date | undefined;
    /**
     * Sets the parentProcessCreatedDateTime property value. DateTime at which the parent process was started. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the parentProcessCreatedDateTime property.
     */
    set parentProcessCreatedDateTime(value: Date | undefined);
    /**
     * Gets the parentProcessId property value. The Process ID (PID) of the parent process.
     * @returns a integer
     */
    get parentProcessId(): number | undefined;
    /**
     * Sets the parentProcessId property value. The Process ID (PID) of the parent process.
     * @param value Value to set for the parentProcessId property.
     */
    set parentProcessId(value: number | undefined);
    /**
     * Gets the parentProcessName property value. The name of the image file of the parent process.
     * @returns a string
     */
    get parentProcessName(): string | undefined;
    /**
     * Sets the parentProcessName property value. The name of the image file of the parent process.
     * @param value Value to set for the parentProcessName property.
     */
    set parentProcessName(value: string | undefined);
    /**
     * Gets the path property value. Full path, including filename.
     * @returns a string
     */
    get path(): string | undefined;
    /**
     * Sets the path property value. Full path, including filename.
     * @param value Value to set for the path property.
     */
    set path(value: string | undefined);
    /**
     * Gets the processId property value. The Process ID (PID) of the process.
     * @returns a integer
     */
    get processId(): number | undefined;
    /**
     * Sets the processId property value. The Process ID (PID) of the process.
     * @param value Value to set for the processId property.
     */
    set processId(value: number | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
