"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RiskDetection = void 0;
const activityType_1 = require("./activityType");
const createSignInLocationFromDiscriminatorValue_1 = require("./createSignInLocationFromDiscriminatorValue");
const index_1 = require("./index");
const riskDetail_1 = require("./riskDetail");
const riskDetectionTimingType_1 = require("./riskDetectionTimingType");
const riskLevel_1 = require("./riskLevel");
const riskState_1 = require("./riskState");
const tokenIssuerType_1 = require("./tokenIssuerType");
class RiskDetection extends index_1.Entity {
    /**
     * Instantiates a new riskDetection and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the activity property value. Indicates the activity type the detected risk is linked to. Possible values are: signin, user, unknownFutureValue.
     * @returns a activityType
     */
    get activity() {
        return this._activity;
    }
    ;
    /**
     * Sets the activity property value. Indicates the activity type the detected risk is linked to. Possible values are: signin, user, unknownFutureValue.
     * @param value Value to set for the activity property.
     */
    set activity(value) {
        this._activity = value;
    }
    ;
    /**
     * Gets the activityDateTime property value. Date and time that the risky activity occurred. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is look like this: 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get activityDateTime() {
        return this._activityDateTime;
    }
    ;
    /**
     * Sets the activityDateTime property value. Date and time that the risky activity occurred. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is look like this: 2014-01-01T00:00:00Z
     * @param value Value to set for the activityDateTime property.
     */
    set activityDateTime(value) {
        this._activityDateTime = value;
    }
    ;
    /**
     * Gets the additionalInfo property value. Additional information associated with the risk detection in JSON format. For example, '[{/'Key/':/'userAgent/',/'Value/':/'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/68.0.3440.106 Safari/537.36/'}]'. Possible keys in the additionalInfo JSON string are: userAgent, alertUrl, relatedEventTimeInUtc, relatedUserAgent, deviceInformation, relatedLocation, requestId, correlationId, lastActivityTimeInUtc, malwareName, clientLocation, clientIp, riskReasons. For more information about riskReasons and possible values, see riskReasons values.
     * @returns a string
     */
    get additionalInfo() {
        return this._additionalInfo;
    }
    ;
    /**
     * Sets the additionalInfo property value. Additional information associated with the risk detection in JSON format. For example, '[{/'Key/':/'userAgent/',/'Value/':/'Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/68.0.3440.106 Safari/537.36/'}]'. Possible keys in the additionalInfo JSON string are: userAgent, alertUrl, relatedEventTimeInUtc, relatedUserAgent, deviceInformation, relatedLocation, requestId, correlationId, lastActivityTimeInUtc, malwareName, clientLocation, clientIp, riskReasons. For more information about riskReasons and possible values, see riskReasons values.
     * @param value Value to set for the additionalInfo property.
     */
    set additionalInfo(value) {
        this._additionalInfo = value;
    }
    ;
    ;
    /**
     * Gets the correlationId property value. Correlation ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @returns a string
     */
    get correlationId() {
        return this._correlationId;
    }
    ;
    /**
     * Sets the correlationId property value. Correlation ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @param value Value to set for the correlationId property.
     */
    set correlationId(value) {
        this._correlationId = value;
    }
    ;
    /**
     * Gets the detectedDateTime property value. Date and time that the risk was detected. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 looks like this: 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get detectedDateTime() {
        return this._detectedDateTime;
    }
    ;
    /**
     * Sets the detectedDateTime property value. Date and time that the risk was detected. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 looks like this: 2014-01-01T00:00:00Z
     * @param value Value to set for the detectedDateTime property.
     */
    set detectedDateTime(value) {
        this._detectedDateTime = value;
    }
    ;
    /**
     * Gets the detectionTimingType property value. Timing of the detected risk (real-time/offline). Possible values are: notDefined, realtime, nearRealtime, offline, unknownFutureValue.
     * @returns a riskDetectionTimingType
     */
    get detectionTimingType() {
        return this._detectionTimingType;
    }
    ;
    /**
     * Sets the detectionTimingType property value. Timing of the detected risk (real-time/offline). Possible values are: notDefined, realtime, nearRealtime, offline, unknownFutureValue.
     * @param value Value to set for the detectionTimingType property.
     */
    set detectionTimingType(value) {
        this._detectionTimingType = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "activity": (o, n) => { o.activity = n.getEnumValue(activityType_1.ActivityType); }, "activityDateTime": (o, n) => { o.activityDateTime = n.getDateValue(); }, "additionalInfo": (o, n) => { o.additionalInfo = n.getStringValue(); }, "correlationId": (o, n) => { o.correlationId = n.getStringValue(); }, "detectedDateTime": (o, n) => { o.detectedDateTime = n.getDateValue(); }, "detectionTimingType": (o, n) => { o.detectionTimingType = n.getEnumValue(riskDetectionTimingType_1.RiskDetectionTimingType); }, "ipAddress": (o, n) => { o.ipAddress = n.getStringValue(); }, "lastUpdatedDateTime": (o, n) => { o.lastUpdatedDateTime = n.getDateValue(); }, "location": (o, n) => { o.location = n.getObjectValue(createSignInLocationFromDiscriminatorValue_1.createSignInLocationFromDiscriminatorValue); }, "requestId": (o, n) => { o.requestId = n.getStringValue(); }, "riskDetail": (o, n) => { o.riskDetail = n.getEnumValue(riskDetail_1.RiskDetail); }, "riskEventType": (o, n) => { o.riskEventType = n.getStringValue(); }, "riskLevel": (o, n) => { o.riskLevel = n.getEnumValue(riskLevel_1.RiskLevel); }, "riskState": (o, n) => { o.riskState = n.getEnumValue(riskState_1.RiskState); }, "source": (o, n) => { o.source = n.getStringValue(); }, "tokenIssuerType": (o, n) => { o.tokenIssuerType = n.getEnumValue(tokenIssuerType_1.TokenIssuerType); }, "userDisplayName": (o, n) => { o.userDisplayName = n.getStringValue(); }, "userId": (o, n) => { o.userId = n.getStringValue(); }, "userPrincipalName": (o, n) => { o.userPrincipalName = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the ipAddress property value. Provides the IP address of the client from where the risk occurred.
     * @returns a string
     */
    get ipAddress() {
        return this._ipAddress;
    }
    ;
    /**
     * Sets the ipAddress property value. Provides the IP address of the client from where the risk occurred.
     * @param value Value to set for the ipAddress property.
     */
    set ipAddress(value) {
        this._ipAddress = value;
    }
    ;
    /**
     * Gets the lastUpdatedDateTime property value. Date and time that the risk detection was last updated. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is look like this: 2014-01-01T00:00:00Z
     * @returns a Date
     */
    get lastUpdatedDateTime() {
        return this._lastUpdatedDateTime;
    }
    ;
    /**
     * Sets the lastUpdatedDateTime property value. Date and time that the risk detection was last updated. The DateTimeOffset type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is look like this: 2014-01-01T00:00:00Z
     * @param value Value to set for the lastUpdatedDateTime property.
     */
    set lastUpdatedDateTime(value) {
        this._lastUpdatedDateTime = value;
    }
    ;
    /**
     * Gets the location property value. Location of the sign-in.
     * @returns a signInLocation
     */
    get location() {
        return this._location;
    }
    ;
    /**
     * Sets the location property value. Location of the sign-in.
     * @param value Value to set for the location property.
     */
    set location(value) {
        this._location = value;
    }
    ;
    /**
     * Gets the requestId property value. Request ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @returns a string
     */
    get requestId() {
        return this._requestId;
    }
    ;
    /**
     * Sets the requestId property value. Request ID of the sign-in associated with the risk detection. This property is null if the risk detection is not associated with a sign-in.
     * @param value Value to set for the requestId property.
     */
    set requestId(value) {
        this._requestId = value;
    }
    ;
    /**
     * Gets the riskDetail property value. Details of the detected risk. Possible values are: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, hidden, adminConfirmedUserCompromised, unknownFutureValue.
     * @returns a riskDetail
     */
    get riskDetail() {
        return this._riskDetail;
    }
    ;
    /**
     * Sets the riskDetail property value. Details of the detected risk. Possible values are: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, hidden, adminConfirmedUserCompromised, unknownFutureValue.
     * @param value Value to set for the riskDetail property.
     */
    set riskDetail(value) {
        this._riskDetail = value;
    }
    ;
    /**
     * Gets the riskEventType property value. The type of risk event detected. The possible values are unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic,adminConfirmedUserCompromised, passwordSpray, impossibleTravel, newCountry, anomalousToken, tokenIssuerAnomaly,suspiciousBrowser, riskyIPAddress, mcasSuspiciousInboxManipulationRules, suspiciousInboxForwarding, and unknownFutureValue. If the risk detection is a premium detection, will show generic. For more information about each value, see riskEventType values.
     * @returns a string
     */
    get riskEventType() {
        return this._riskEventType;
    }
    ;
    /**
     * Sets the riskEventType property value. The type of risk event detected. The possible values are unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence, generic,adminConfirmedUserCompromised, passwordSpray, impossibleTravel, newCountry, anomalousToken, tokenIssuerAnomaly,suspiciousBrowser, riskyIPAddress, mcasSuspiciousInboxManipulationRules, suspiciousInboxForwarding, and unknownFutureValue. If the risk detection is a premium detection, will show generic. For more information about each value, see riskEventType values.
     * @param value Value to set for the riskEventType property.
     */
    set riskEventType(value) {
        this._riskEventType = value;
    }
    ;
    /**
     * Gets the riskLevel property value. Level of the detected risk. Possible values are: low, medium, high, hidden, none, unknownFutureValue.
     * @returns a riskLevel
     */
    get riskLevel() {
        return this._riskLevel;
    }
    ;
    /**
     * Sets the riskLevel property value. Level of the detected risk. Possible values are: low, medium, high, hidden, none, unknownFutureValue.
     * @param value Value to set for the riskLevel property.
     */
    set riskLevel(value) {
        this._riskLevel = value;
    }
    ;
    /**
     * Gets the riskState property value. The state of a detected risky user or sign-in. Possible values are: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, unknownFutureValue.
     * @returns a riskState
     */
    get riskState() {
        return this._riskState;
    }
    ;
    /**
     * Sets the riskState property value. The state of a detected risky user or sign-in. Possible values are: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, unknownFutureValue.
     * @param value Value to set for the riskState property.
     */
    set riskState(value) {
        this._riskState = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeEnumValue("activity", this.activity);
        writer.writeDateValue("activityDateTime", this.activityDateTime);
        writer.writeStringValue("additionalInfo", this.additionalInfo);
        writer.writeStringValue("correlationId", this.correlationId);
        writer.writeDateValue("detectedDateTime", this.detectedDateTime);
        writer.writeEnumValue("detectionTimingType", this.detectionTimingType);
        writer.writeStringValue("ipAddress", this.ipAddress);
        writer.writeDateValue("lastUpdatedDateTime", this.lastUpdatedDateTime);
        writer.writeObjectValue("location", this.location);
        writer.writeStringValue("requestId", this.requestId);
        writer.writeEnumValue("riskDetail", this.riskDetail);
        writer.writeStringValue("riskEventType", this.riskEventType);
        writer.writeEnumValue("riskLevel", this.riskLevel);
        writer.writeEnumValue("riskState", this.riskState);
        writer.writeStringValue("source", this.source);
        writer.writeEnumValue("tokenIssuerType", this.tokenIssuerType);
        writer.writeStringValue("userDisplayName", this.userDisplayName);
        writer.writeStringValue("userId", this.userId);
        writer.writeStringValue("userPrincipalName", this.userPrincipalName);
    }
    ;
    /**
     * Gets the source property value. Source of the risk detection. For example, activeDirectory.
     * @returns a string
     */
    get source() {
        return this._source;
    }
    ;
    /**
     * Sets the source property value. Source of the risk detection. For example, activeDirectory.
     * @param value Value to set for the source property.
     */
    set source(value) {
        this._source = value;
    }
    ;
    /**
     * Gets the tokenIssuerType property value. Indicates the type of token issuer for the detected sign-in risk. Possible values are: AzureAD, ADFederationServices, UnknownFutureValue.
     * @returns a tokenIssuerType
     */
    get tokenIssuerType() {
        return this._tokenIssuerType;
    }
    ;
    /**
     * Sets the tokenIssuerType property value. Indicates the type of token issuer for the detected sign-in risk. Possible values are: AzureAD, ADFederationServices, UnknownFutureValue.
     * @param value Value to set for the tokenIssuerType property.
     */
    set tokenIssuerType(value) {
        this._tokenIssuerType = value;
    }
    ;
    /**
     * Gets the userDisplayName property value. The user principal name (UPN) of the user.
     * @returns a string
     */
    get userDisplayName() {
        return this._userDisplayName;
    }
    ;
    /**
     * Sets the userDisplayName property value. The user principal name (UPN) of the user.
     * @param value Value to set for the userDisplayName property.
     */
    set userDisplayName(value) {
        this._userDisplayName = value;
    }
    ;
    /**
     * Gets the userId property value. Unique ID of the user.
     * @returns a string
     */
    get userId() {
        return this._userId;
    }
    ;
    /**
     * Sets the userId property value. Unique ID of the user.
     * @param value Value to set for the userId property.
     */
    set userId(value) {
        this._userId = value;
    }
    ;
    /**
     * Gets the userPrincipalName property value. The user principal name (UPN) of the user.
     * @returns a string
     */
    get userPrincipalName() {
        return this._userPrincipalName;
    }
    ;
    /**
     * Sets the userPrincipalName property value. The user principal name (UPN) of the user.
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value) {
        this._userPrincipalName = value;
    }
    ;
}
exports.RiskDetection = RiskDetection;
