import { ItemBody, ServiceAnnouncementAttachment, ServiceAnnouncementBase, ServiceUpdateMessageViewpoint } from './index';
import { ServiceUpdateCategory } from './serviceUpdateCategory';
import { ServiceUpdateSeverity } from './serviceUpdateSeverity';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ServiceUpdateMessage extends ServiceAnnouncementBase implements Parsable {
    /** The expected deadline of the action for the message.  */
    private _actionRequiredByDateTime?;
    /** A collection of serviceAnnouncementAttachments.  */
    private _attachments?;
    /** The zip file that contains all attachments for a message.  */
    private _attachmentsArchive?;
    private _body?;
    /** The service message category. Possible values are: preventOrFixIssue, planForChange, stayInformed, unknownFutureValue.  */
    private _category?;
    /** Indicates whether the message has any attachment.  */
    private _hasAttachments?;
    /** Indicates whether the message describes a major update for the service.  */
    private _isMajorChange?;
    /** The affected services by the service message.  */
    private _services?;
    /** The severity of the service message. Possible values are: normal, high, critical, unknownFutureValue.  */
    private _severity?;
    /** A collection of tags for the service message. Tags are provided by the service team/support team who post the message to tell whether this message contains privacy data, or whether this message is for a service new feature update, and so on.  */
    private _tags?;
    /** Represents user viewpoints data of the service message. This data includes message status such as whether the user has archived, read, or marked the message as favorite. This property is null when accessed with application permissions.  */
    private _viewPoint?;
    /**
     * Gets the actionRequiredByDateTime property value. The expected deadline of the action for the message.
     * @returns a Date
     */
    get actionRequiredByDateTime(): Date | undefined;
    /**
     * Sets the actionRequiredByDateTime property value. The expected deadline of the action for the message.
     * @param value Value to set for the actionRequiredByDateTime property.
     */
    set actionRequiredByDateTime(value: Date | undefined);
    /**
     * Gets the attachments property value. A collection of serviceAnnouncementAttachments.
     * @returns a serviceAnnouncementAttachment
     */
    get attachments(): ServiceAnnouncementAttachment[] | undefined;
    /**
     * Sets the attachments property value. A collection of serviceAnnouncementAttachments.
     * @param value Value to set for the attachments property.
     */
    set attachments(value: ServiceAnnouncementAttachment[] | undefined);
    /**
     * Gets the attachmentsArchive property value. The zip file that contains all attachments for a message.
     * @returns a binary
     */
    get attachmentsArchive(): string | undefined;
    /**
     * Sets the attachmentsArchive property value. The zip file that contains all attachments for a message.
     * @param value Value to set for the attachmentsArchive property.
     */
    set attachmentsArchive(value: string | undefined);
    /**
     * Gets the body property value.
     * @returns a itemBody
     */
    get body(): ItemBody | undefined;
    /**
     * Sets the body property value.
     * @param value Value to set for the body property.
     */
    set body(value: ItemBody | undefined);
    /**
     * Gets the category property value. The service message category. Possible values are: preventOrFixIssue, planForChange, stayInformed, unknownFutureValue.
     * @returns a serviceUpdateCategory
     */
    get category(): ServiceUpdateCategory | undefined;
    /**
     * Sets the category property value. The service message category. Possible values are: preventOrFixIssue, planForChange, stayInformed, unknownFutureValue.
     * @param value Value to set for the category property.
     */
    set category(value: ServiceUpdateCategory | undefined);
    /**
     * Instantiates a new serviceUpdateMessage and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the hasAttachments property value. Indicates whether the message has any attachment.
     * @returns a boolean
     */
    get hasAttachments(): boolean | undefined;
    /**
     * Sets the hasAttachments property value. Indicates whether the message has any attachment.
     * @param value Value to set for the hasAttachments property.
     */
    set hasAttachments(value: boolean | undefined);
    /**
     * Gets the isMajorChange property value. Indicates whether the message describes a major update for the service.
     * @returns a boolean
     */
    get isMajorChange(): boolean | undefined;
    /**
     * Sets the isMajorChange property value. Indicates whether the message describes a major update for the service.
     * @param value Value to set for the isMajorChange property.
     */
    set isMajorChange(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the services property value. The affected services by the service message.
     * @returns a string
     */
    get services(): string[] | undefined;
    /**
     * Sets the services property value. The affected services by the service message.
     * @param value Value to set for the services property.
     */
    set services(value: string[] | undefined);
    /**
     * Gets the severity property value. The severity of the service message. Possible values are: normal, high, critical, unknownFutureValue.
     * @returns a serviceUpdateSeverity
     */
    get severity(): ServiceUpdateSeverity | undefined;
    /**
     * Sets the severity property value. The severity of the service message. Possible values are: normal, high, critical, unknownFutureValue.
     * @param value Value to set for the severity property.
     */
    set severity(value: ServiceUpdateSeverity | undefined);
    /**
     * Gets the tags property value. A collection of tags for the service message. Tags are provided by the service team/support team who post the message to tell whether this message contains privacy data, or whether this message is for a service new feature update, and so on.
     * @returns a string
     */
    get tags(): string[] | undefined;
    /**
     * Sets the tags property value. A collection of tags for the service message. Tags are provided by the service team/support team who post the message to tell whether this message contains privacy data, or whether this message is for a service new feature update, and so on.
     * @param value Value to set for the tags property.
     */
    set tags(value: string[] | undefined);
    /**
     * Gets the viewPoint property value. Represents user viewpoints data of the service message. This data includes message status such as whether the user has archived, read, or marked the message as favorite. This property is null when accessed with application permissions.
     * @returns a serviceUpdateMessageViewpoint
     */
    get viewPoint(): ServiceUpdateMessageViewpoint | undefined;
    /**
     * Sets the viewPoint property value. Represents user viewpoints data of the service message. This data includes message status such as whether the user has archived, read, or marked the message as favorite. This property is null when accessed with application permissions.
     * @param value Value to set for the viewPoint property.
     */
    set viewPoint(value: ServiceUpdateMessageViewpoint | undefined);
}
