import { Entity, ResourceReference, ResourceVisualization, SharingDetail } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class SharedInsight extends Entity implements Parsable {
    /** Details about the shared item. Read only.  */
    private _lastShared?;
    private _lastSharedMethod?;
    /** Used for navigating to the item that was shared. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.  */
    private _resource?;
    /** Reference properties of the shared document, such as the url and type of the document. Read-only  */
    private _resourceReference?;
    /** Properties that you can use to visualize the document in your experience. Read-only  */
    private _resourceVisualization?;
    private _sharingHistory?;
    /**
     * Instantiates a new sharedInsight and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the lastShared property value. Details about the shared item. Read only.
     * @returns a sharingDetail
     */
    get lastShared(): SharingDetail | undefined;
    /**
     * Sets the lastShared property value. Details about the shared item. Read only.
     * @param value Value to set for the lastShared property.
     */
    set lastShared(value: SharingDetail | undefined);
    /**
     * Gets the lastSharedMethod property value.
     * @returns a entity
     */
    get lastSharedMethod(): Entity | undefined;
    /**
     * Sets the lastSharedMethod property value.
     * @param value Value to set for the lastSharedMethod property.
     */
    set lastSharedMethod(value: Entity | undefined);
    /**
     * Gets the resource property value. Used for navigating to the item that was shared. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.
     * @returns a entity
     */
    get resource(): Entity | undefined;
    /**
     * Sets the resource property value. Used for navigating to the item that was shared. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.
     * @param value Value to set for the resource property.
     */
    set resource(value: Entity | undefined);
    /**
     * Gets the resourceReference property value. Reference properties of the shared document, such as the url and type of the document. Read-only
     * @returns a resourceReference
     */
    get resourceReference(): ResourceReference | undefined;
    /**
     * Sets the resourceReference property value. Reference properties of the shared document, such as the url and type of the document. Read-only
     * @param value Value to set for the resourceReference property.
     */
    set resourceReference(value: ResourceReference | undefined);
    /**
     * Gets the resourceVisualization property value. Properties that you can use to visualize the document in your experience. Read-only
     * @returns a resourceVisualization
     */
    get resourceVisualization(): ResourceVisualization | undefined;
    /**
     * Sets the resourceVisualization property value. Properties that you can use to visualize the document in your experience. Read-only
     * @param value Value to set for the resourceVisualization property.
     */
    set resourceVisualization(value: ResourceVisualization | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the sharingHistory property value.
     * @returns a sharingDetail
     */
    get sharingHistory(): SharingDetail[] | undefined;
    /**
     * Sets the sharingHistory property value.
     * @param value Value to set for the sharingHistory property.
     */
    set sharingHistory(value: SharingDetail[] | undefined);
}
