"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SignIn = void 0;
const conditionalAccessStatus_1 = require("./conditionalAccessStatus");
const createAppliedConditionalAccessPolicyFromDiscriminatorValue_1 = require("./createAppliedConditionalAccessPolicyFromDiscriminatorValue");
const createDeviceDetailFromDiscriminatorValue_1 = require("./createDeviceDetailFromDiscriminatorValue");
const createSignInLocationFromDiscriminatorValue_1 = require("./createSignInLocationFromDiscriminatorValue");
const createSignInStatusFromDiscriminatorValue_1 = require("./createSignInStatusFromDiscriminatorValue");
const index_1 = require("./index");
const riskDetail_1 = require("./riskDetail");
const riskEventType_1 = require("./riskEventType");
const riskLevel_1 = require("./riskLevel");
const riskState_1 = require("./riskState");
class SignIn extends index_1.Entity {
    /**
     * Instantiates a new signIn and sets the default values.
     */
    constructor() {
        super();
    }
    /**
     * Gets the appDisplayName property value. App name displayed in the Azure Portal. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get appDisplayName() {
        return this._appDisplayName;
    }
    ;
    /**
     * Sets the appDisplayName property value. App name displayed in the Azure Portal. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the appDisplayName property.
     */
    set appDisplayName(value) {
        this._appDisplayName = value;
    }
    ;
    /**
     * Gets the appId property value. Unique GUID representing the app ID in the Azure Active Directory. Supports $filter (eq operator only).
     * @returns a string
     */
    get appId() {
        return this._appId;
    }
    ;
    /**
     * Sets the appId property value. Unique GUID representing the app ID in the Azure Active Directory. Supports $filter (eq operator only).
     * @param value Value to set for the appId property.
     */
    set appId(value) {
        this._appId = value;
    }
    ;
    /**
     * Gets the appliedConditionalAccessPolicies property value. A list of conditional access policies that are triggered by the corresponding sign-in activity.
     * @returns a appliedConditionalAccessPolicy
     */
    get appliedConditionalAccessPolicies() {
        return this._appliedConditionalAccessPolicies;
    }
    ;
    /**
     * Sets the appliedConditionalAccessPolicies property value. A list of conditional access policies that are triggered by the corresponding sign-in activity.
     * @param value Value to set for the appliedConditionalAccessPolicies property.
     */
    set appliedConditionalAccessPolicies(value) {
        this._appliedConditionalAccessPolicies = value;
    }
    ;
    /**
     * Gets the clientAppUsed property value. Identifies the client used for the sign-in activity. Modern authentication clients include Browser and modern clients. Legacy authentication clients include Exchange ActiveSync, IMAP, MAPI, SMTP, POP, and other clients. Supports $filter (eq operator only).
     * @returns a string
     */
    get clientAppUsed() {
        return this._clientAppUsed;
    }
    ;
    /**
     * Sets the clientAppUsed property value. Identifies the client used for the sign-in activity. Modern authentication clients include Browser and modern clients. Legacy authentication clients include Exchange ActiveSync, IMAP, MAPI, SMTP, POP, and other clients. Supports $filter (eq operator only).
     * @param value Value to set for the clientAppUsed property.
     */
    set clientAppUsed(value) {
        this._clientAppUsed = value;
    }
    ;
    /**
     * Gets the conditionalAccessStatus property value. Reports status of an activated conditional access policy. Possible values are: success, failure, notApplied, and unknownFutureValue. Supports $filter (eq operator only).
     * @returns a conditionalAccessStatus
     */
    get conditionalAccessStatus() {
        return this._conditionalAccessStatus;
    }
    ;
    /**
     * Sets the conditionalAccessStatus property value. Reports status of an activated conditional access policy. Possible values are: success, failure, notApplied, and unknownFutureValue. Supports $filter (eq operator only).
     * @param value Value to set for the conditionalAccessStatus property.
     */
    set conditionalAccessStatus(value) {
        this._conditionalAccessStatus = value;
    }
    ;
    ;
    /**
     * Gets the correlationId property value. The request ID sent from the client when the sign-in is initiated; used to troubleshoot sign-in activity. Supports $filter (eq operator only).
     * @returns a string
     */
    get correlationId() {
        return this._correlationId;
    }
    ;
    /**
     * Sets the correlationId property value. The request ID sent from the client when the sign-in is initiated; used to troubleshoot sign-in activity. Supports $filter (eq operator only).
     * @param value Value to set for the correlationId property.
     */
    set correlationId(value) {
        this._correlationId = value;
    }
    ;
    /**
     * Gets the createdDateTime property value. Date and time (UTC) the sign-in was initiated. Example: midnight on Jan 1, 2014 is reported as 2014-01-01T00:00:00Z. Supports $orderby and $filter (eq, le, and ge operators only).
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. Date and time (UTC) the sign-in was initiated. Example: midnight on Jan 1, 2014 is reported as 2014-01-01T00:00:00Z. Supports $orderby and $filter (eq, le, and ge operators only).
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the deviceDetail property value. Device information from where the sign-in occurred; includes device ID, operating system, and browser. Supports $filter (eq and startsWith operators only) on browser and operatingSytem properties.
     * @returns a deviceDetail
     */
    get deviceDetail() {
        return this._deviceDetail;
    }
    ;
    /**
     * Sets the deviceDetail property value. Device information from where the sign-in occurred; includes device ID, operating system, and browser. Supports $filter (eq and startsWith operators only) on browser and operatingSytem properties.
     * @param value Value to set for the deviceDetail property.
     */
    set deviceDetail(value) {
        this._deviceDetail = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "appDisplayName": (o, n) => { o.appDisplayName = n.getStringValue(); }, "appId": (o, n) => { o.appId = n.getStringValue(); }, "appliedConditionalAccessPolicies": (o, n) => { o.appliedConditionalAccessPolicies = n.getCollectionOfObjectValues(createAppliedConditionalAccessPolicyFromDiscriminatorValue_1.createAppliedConditionalAccessPolicyFromDiscriminatorValue); }, "clientAppUsed": (o, n) => { o.clientAppUsed = n.getStringValue(); }, "conditionalAccessStatus": (o, n) => { o.conditionalAccessStatus = n.getEnumValue(conditionalAccessStatus_1.ConditionalAccessStatus); }, "correlationId": (o, n) => { o.correlationId = n.getStringValue(); }, "createdDateTime": (o, n) => { o.createdDateTime = n.getDateValue(); }, "deviceDetail": (o, n) => { o.deviceDetail = n.getObjectValue(createDeviceDetailFromDiscriminatorValue_1.createDeviceDetailFromDiscriminatorValue); }, "ipAddress": (o, n) => { o.ipAddress = n.getStringValue(); }, "isInteractive": (o, n) => { o.isInteractive = n.getBooleanValue(); }, "location": (o, n) => { o.location = n.getObjectValue(createSignInLocationFromDiscriminatorValue_1.createSignInLocationFromDiscriminatorValue); }, "resourceDisplayName": (o, n) => { o.resourceDisplayName = n.getStringValue(); }, "resourceId": (o, n) => { o.resourceId = n.getStringValue(); }, "riskDetail": (o, n) => { o.riskDetail = n.getEnumValue(riskDetail_1.RiskDetail); }, "riskEventTypes": (o, n) => { o.riskEventTypes = n.getEnumValues(riskEventType_1.RiskEventType); }, "riskEventTypes_v2": (o, n) => { o.riskEventTypes_v2 = n.getCollectionOfPrimitiveValues(); }, "riskLevelAggregated": (o, n) => { o.riskLevelAggregated = n.getEnumValue(riskLevel_1.RiskLevel); }, "riskLevelDuringSignIn": (o, n) => { o.riskLevelDuringSignIn = n.getEnumValue(riskLevel_1.RiskLevel); }, "riskState": (o, n) => { o.riskState = n.getEnumValue(riskState_1.RiskState); }, "status": (o, n) => { o.status = n.getObjectValue(createSignInStatusFromDiscriminatorValue_1.createSignInStatusFromDiscriminatorValue); }, "userDisplayName": (o, n) => { o.userDisplayName = n.getStringValue(); }, "userId": (o, n) => { o.userId = n.getStringValue(); }, "userPrincipalName": (o, n) => { o.userPrincipalName = n.getStringValue(); } });
    }
    ;
    /**
     * Gets the ipAddress property value. IP address of the client used to sign in. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get ipAddress() {
        return this._ipAddress;
    }
    ;
    /**
     * Sets the ipAddress property value. IP address of the client used to sign in. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the ipAddress property.
     */
    set ipAddress(value) {
        this._ipAddress = value;
    }
    ;
    /**
     * Gets the isInteractive property value. Indicates if a sign-in is interactive or not.
     * @returns a boolean
     */
    get isInteractive() {
        return this._isInteractive;
    }
    ;
    /**
     * Sets the isInteractive property value. Indicates if a sign-in is interactive or not.
     * @param value Value to set for the isInteractive property.
     */
    set isInteractive(value) {
        this._isInteractive = value;
    }
    ;
    /**
     * Gets the location property value. Provides the city, state, and country code where the sign-in originated. Supports $filter (eq and startsWith operators only) on city, state, and countryOrRegion properties.
     * @returns a signInLocation
     */
    get location() {
        return this._location;
    }
    ;
    /**
     * Sets the location property value. Provides the city, state, and country code where the sign-in originated. Supports $filter (eq and startsWith operators only) on city, state, and countryOrRegion properties.
     * @param value Value to set for the location property.
     */
    set location(value) {
        this._location = value;
    }
    ;
    /**
     * Gets the resourceDisplayName property value. Name of the resource the user signed into. Supports $filter (eq operator only).
     * @returns a string
     */
    get resourceDisplayName() {
        return this._resourceDisplayName;
    }
    ;
    /**
     * Sets the resourceDisplayName property value. Name of the resource the user signed into. Supports $filter (eq operator only).
     * @param value Value to set for the resourceDisplayName property.
     */
    set resourceDisplayName(value) {
        this._resourceDisplayName = value;
    }
    ;
    /**
     * Gets the resourceId property value. ID of the resource that the user signed into. Supports $filter (eq operator only).
     * @returns a string
     */
    get resourceId() {
        return this._resourceId;
    }
    ;
    /**
     * Sets the resourceId property value. ID of the resource that the user signed into. Supports $filter (eq operator only).
     * @param value Value to set for the resourceId property.
     */
    set resourceId(value) {
        this._resourceId = value;
    }
    ;
    /**
     * Gets the riskDetail property value. Provides the 'reason' behind a specific state of a risky user, sign-in or a risk event. The possible values are: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, unknownFutureValue. The value none means that no action has been performed on the user or sign-in so far.  Supports $filter (eq operator only).Note: Details for this property require an Azure AD Premium P2 license. Other licenses return the value hidden.
     * @returns a riskDetail
     */
    get riskDetail() {
        return this._riskDetail;
    }
    ;
    /**
     * Sets the riskDetail property value. Provides the 'reason' behind a specific state of a risky user, sign-in or a risk event. The possible values are: none, adminGeneratedTemporaryPassword, userPerformedSecuredPasswordChange, userPerformedSecuredPasswordReset, adminConfirmedSigninSafe, aiConfirmedSigninSafe, userPassedMFADrivenByRiskBasedPolicy, adminDismissedAllRiskForUser, adminConfirmedSigninCompromised, unknownFutureValue. The value none means that no action has been performed on the user or sign-in so far.  Supports $filter (eq operator only).Note: Details for this property require an Azure AD Premium P2 license. Other licenses return the value hidden.
     * @param value Value to set for the riskDetail property.
     */
    set riskDetail(value) {
        this._riskDetail = value;
    }
    ;
    /**
     * Gets the riskEventTypes property value. Risk event types associated with the sign-in. The possible values are: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, and unknownFutureValue. Supports $filter (eq operator only).
     * @returns a riskEventType
     */
    get riskEventTypes() {
        return this._riskEventTypes;
    }
    ;
    /**
     * Sets the riskEventTypes property value. Risk event types associated with the sign-in. The possible values are: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, and unknownFutureValue. Supports $filter (eq operator only).
     * @param value Value to set for the riskEventTypes property.
     */
    set riskEventTypes(value) {
        this._riskEventTypes = value;
    }
    ;
    /**
     * Gets the riskEventTypes_v2 property value. The list of risk event types associated with the sign-in. Possible values: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, or unknownFutureValue. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get riskEventTypes_v2() {
        return this._riskEventTypes_v2;
    }
    ;
    /**
     * Sets the riskEventTypes_v2 property value. The list of risk event types associated with the sign-in. Possible values: unlikelyTravel, anonymizedIPAddress, maliciousIPAddress, unfamiliarFeatures, malwareInfectedIPAddress, suspiciousIPAddress, leakedCredentials, investigationsThreatIntelligence,  generic, or unknownFutureValue. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the riskEventTypes_v2 property.
     */
    set riskEventTypes_v2(value) {
        this._riskEventTypes_v2 = value;
    }
    ;
    /**
     * Gets the riskLevelAggregated property value. Aggregated risk level. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq operator only).  Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
     * @returns a riskLevel
     */
    get riskLevelAggregated() {
        return this._riskLevelAggregated;
    }
    ;
    /**
     * Sets the riskLevelAggregated property value. Aggregated risk level. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection. Supports $filter (eq operator only).  Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
     * @param value Value to set for the riskLevelAggregated property.
     */
    set riskLevelAggregated(value) {
        this._riskLevelAggregated = value;
    }
    ;
    /**
     * Gets the riskLevelDuringSignIn property value. Risk level during sign-in. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection.  Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
     * @returns a riskLevel
     */
    get riskLevelDuringSignIn() {
        return this._riskLevelDuringSignIn;
    }
    ;
    /**
     * Sets the riskLevelDuringSignIn property value. Risk level during sign-in. The possible values are: none, low, medium, high, hidden, and unknownFutureValue. The value hidden means the user or sign-in was not enabled for Azure AD Identity Protection.  Supports $filter (eq operator only). Note: Details for this property are only available for Azure AD Premium P2 customers. All other customers will be returned hidden.
     * @param value Value to set for the riskLevelDuringSignIn property.
     */
    set riskLevelDuringSignIn(value) {
        this._riskLevelDuringSignIn = value;
    }
    ;
    /**
     * Gets the riskState property value. Reports status of the risky user, sign-in, or a risk event. The possible values are: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, unknownFutureValue. Supports $filter (eq operator only).
     * @returns a riskState
     */
    get riskState() {
        return this._riskState;
    }
    ;
    /**
     * Sets the riskState property value. Reports status of the risky user, sign-in, or a risk event. The possible values are: none, confirmedSafe, remediated, dismissed, atRisk, confirmedCompromised, unknownFutureValue. Supports $filter (eq operator only).
     * @param value Value to set for the riskState property.
     */
    set riskState(value) {
        this._riskState = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeStringValue("appDisplayName", this.appDisplayName);
        writer.writeStringValue("appId", this.appId);
        writer.writeCollectionOfObjectValues("appliedConditionalAccessPolicies", this.appliedConditionalAccessPolicies);
        writer.writeStringValue("clientAppUsed", this.clientAppUsed);
        writer.writeEnumValue("conditionalAccessStatus", this.conditionalAccessStatus);
        writer.writeStringValue("correlationId", this.correlationId);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeObjectValue("deviceDetail", this.deviceDetail);
        writer.writeStringValue("ipAddress", this.ipAddress);
        writer.writeBooleanValue("isInteractive", this.isInteractive);
        writer.writeObjectValue("location", this.location);
        writer.writeStringValue("resourceDisplayName", this.resourceDisplayName);
        writer.writeStringValue("resourceId", this.resourceId);
        writer.writeEnumValue("riskDetail", this.riskDetail);
        this.riskEventTypes && writer.writeEnumValue("riskEventTypes", ...this.riskEventTypes);
        writer.writeCollectionOfPrimitiveValues("riskEventTypes_v2", this.riskEventTypes_v2);
        writer.writeEnumValue("riskLevelAggregated", this.riskLevelAggregated);
        writer.writeEnumValue("riskLevelDuringSignIn", this.riskLevelDuringSignIn);
        writer.writeEnumValue("riskState", this.riskState);
        writer.writeObjectValue("status", this.status);
        writer.writeStringValue("userDisplayName", this.userDisplayName);
        writer.writeStringValue("userId", this.userId);
        writer.writeStringValue("userPrincipalName", this.userPrincipalName);
    }
    ;
    /**
     * Gets the status property value. Sign-in status. Includes the error code and description of the error (in case of a sign-in failure). Supports $filter (eq operator only) on errorCode property.
     * @returns a signInStatus
     */
    get status() {
        return this._status;
    }
    ;
    /**
     * Sets the status property value. Sign-in status. Includes the error code and description of the error (in case of a sign-in failure). Supports $filter (eq operator only) on errorCode property.
     * @param value Value to set for the status property.
     */
    set status(value) {
        this._status = value;
    }
    ;
    /**
     * Gets the userDisplayName property value. Display name of the user that initiated the sign-in. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get userDisplayName() {
        return this._userDisplayName;
    }
    ;
    /**
     * Sets the userDisplayName property value. Display name of the user that initiated the sign-in. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the userDisplayName property.
     */
    set userDisplayName(value) {
        this._userDisplayName = value;
    }
    ;
    /**
     * Gets the userId property value. ID of the user that initiated the sign-in. Supports $filter (eq operator only).
     * @returns a string
     */
    get userId() {
        return this._userId;
    }
    ;
    /**
     * Sets the userId property value. ID of the user that initiated the sign-in. Supports $filter (eq operator only).
     * @param value Value to set for the userId property.
     */
    set userId(value) {
        this._userId = value;
    }
    ;
    /**
     * Gets the userPrincipalName property value. User principal name of the user that initiated the sign-in. Supports $filter (eq and startsWith operators only).
     * @returns a string
     */
    get userPrincipalName() {
        return this._userPrincipalName;
    }
    ;
    /**
     * Sets the userPrincipalName property value. User principal name of the user that initiated the sign-in. Supports $filter (eq and startsWith operators only).
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value) {
        this._userPrincipalName = value;
    }
    ;
}
exports.SignIn = SignIn;
