import { BaseItem, ColumnDefinition, ContentType, Drive, ItemAnalytics, List, Onenote, Permission, PublicError, Root, SharepointIds, SiteCollection } from './index';
import { Store } from './termStore/';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class Site extends BaseItem implements Parsable {
    /** Analytics about the view activities that took place in this site.  */
    private _analytics?;
    /** The collection of column definitions reusable across lists under this site.  */
    private _columns?;
    /** The collection of content types defined for this site.  */
    private _contentTypes?;
    /** The full title for the site. Read-only.  */
    private _displayName?;
    /** The default drive (document library) for this site.  */
    private _drive?;
    /** The collection of drives (document libraries) under this site.  */
    private _drives?;
    private _error_escaped?;
    /** The collection of column definitions available in the site that are referenced from the sites in the parent hierarchy of the current site.  */
    private _externalColumns?;
    /** Used to address any item contained in this site. This collection can't be enumerated.  */
    private _items?;
    /** The collection of lists under this site.  */
    private _lists?;
    /** Calls the OneNote service for notebook related operations.  */
    private _onenote?;
    /** The permissions associated with the site. Nullable.  */
    private _permissions?;
    /** If present, indicates that this is the root site in the site collection. Read-only.  */
    private _root?;
    /** Returns identifiers useful for SharePoint REST compatibility. Read-only.  */
    private _sharepointIds?;
    /** Provides details about the site's site collection. Available only on the root site. Read-only.  */
    private _siteCollection?;
    /** The collection of the sub-sites under this site.  */
    private _sites?;
    /** The default termStore under this site.  */
    private _termStore?;
    /** The collection of termStores under this site.  */
    private _termStores?;
    /**
     * Gets the analytics property value. Analytics about the view activities that took place in this site.
     * @returns a itemAnalytics
     */
    get analytics(): ItemAnalytics | undefined;
    /**
     * Sets the analytics property value. Analytics about the view activities that took place in this site.
     * @param value Value to set for the analytics property.
     */
    set analytics(value: ItemAnalytics | undefined);
    /**
     * Gets the columns property value. The collection of column definitions reusable across lists under this site.
     * @returns a columnDefinition
     */
    get columns(): ColumnDefinition[] | undefined;
    /**
     * Sets the columns property value. The collection of column definitions reusable across lists under this site.
     * @param value Value to set for the columns property.
     */
    set columns(value: ColumnDefinition[] | undefined);
    /**
     * Instantiates a new site and sets the default values.
     */
    constructor();
    /**
     * Gets the contentTypes property value. The collection of content types defined for this site.
     * @returns a contentType
     */
    get contentTypes(): ContentType[] | undefined;
    /**
     * Sets the contentTypes property value. The collection of content types defined for this site.
     * @param value Value to set for the contentTypes property.
     */
    set contentTypes(value: ContentType[] | undefined);
    /**
     * Gets the displayName property value. The full title for the site. Read-only.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The full title for the site. Read-only.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the drive property value. The default drive (document library) for this site.
     * @returns a drive
     */
    get drive(): Drive | undefined;
    /**
     * Sets the drive property value. The default drive (document library) for this site.
     * @param value Value to set for the drive property.
     */
    set drive(value: Drive | undefined);
    /**
     * Gets the drives property value. The collection of drives (document libraries) under this site.
     * @returns a drive
     */
    get drives(): Drive[] | undefined;
    /**
     * Sets the drives property value. The collection of drives (document libraries) under this site.
     * @param value Value to set for the drives property.
     */
    set drives(value: Drive[] | undefined);
    /**
     * Gets the error property value.
     * @returns a publicError
     */
    get error_escaped(): PublicError | undefined;
    /**
     * Sets the error property value.
     * @param value Value to set for the error_escaped property.
     */
    set error_escaped(value: PublicError | undefined);
    /**
     * Gets the externalColumns property value. The collection of column definitions available in the site that are referenced from the sites in the parent hierarchy of the current site.
     * @returns a columnDefinition
     */
    get externalColumns(): ColumnDefinition[] | undefined;
    /**
     * Sets the externalColumns property value. The collection of column definitions available in the site that are referenced from the sites in the parent hierarchy of the current site.
     * @param value Value to set for the externalColumns property.
     */
    set externalColumns(value: ColumnDefinition[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the items property value. Used to address any item contained in this site. This collection can't be enumerated.
     * @returns a baseItem
     */
    get items(): BaseItem[] | undefined;
    /**
     * Sets the items property value. Used to address any item contained in this site. This collection can't be enumerated.
     * @param value Value to set for the items property.
     */
    set items(value: BaseItem[] | undefined);
    /**
     * Gets the lists property value. The collection of lists under this site.
     * @returns a list
     */
    get lists(): List[] | undefined;
    /**
     * Sets the lists property value. The collection of lists under this site.
     * @param value Value to set for the lists property.
     */
    set lists(value: List[] | undefined);
    /**
     * Gets the onenote property value. Calls the OneNote service for notebook related operations.
     * @returns a onenote
     */
    get onenote(): Onenote | undefined;
    /**
     * Sets the onenote property value. Calls the OneNote service for notebook related operations.
     * @param value Value to set for the onenote property.
     */
    set onenote(value: Onenote | undefined);
    /**
     * Gets the permissions property value. The permissions associated with the site. Nullable.
     * @returns a permission
     */
    get permissions(): Permission[] | undefined;
    /**
     * Sets the permissions property value. The permissions associated with the site. Nullable.
     * @param value Value to set for the permissions property.
     */
    set permissions(value: Permission[] | undefined);
    /**
     * Gets the root property value. If present, indicates that this is the root site in the site collection. Read-only.
     * @returns a root
     */
    get root(): Root | undefined;
    /**
     * Sets the root property value. If present, indicates that this is the root site in the site collection. Read-only.
     * @param value Value to set for the root property.
     */
    set root(value: Root | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @returns a sharepointIds
     */
    get sharepointIds(): SharepointIds | undefined;
    /**
     * Sets the sharepointIds property value. Returns identifiers useful for SharePoint REST compatibility. Read-only.
     * @param value Value to set for the sharepointIds property.
     */
    set sharepointIds(value: SharepointIds | undefined);
    /**
     * Gets the siteCollection property value. Provides details about the site's site collection. Available only on the root site. Read-only.
     * @returns a siteCollection
     */
    get siteCollection(): SiteCollection | undefined;
    /**
     * Sets the siteCollection property value. Provides details about the site's site collection. Available only on the root site. Read-only.
     * @param value Value to set for the siteCollection property.
     */
    set siteCollection(value: SiteCollection | undefined);
    /**
     * Gets the sites property value. The collection of the sub-sites under this site.
     * @returns a site
     */
    get sites(): Site[] | undefined;
    /**
     * Sets the sites property value. The collection of the sub-sites under this site.
     * @param value Value to set for the sites property.
     */
    set sites(value: Site[] | undefined);
    /**
     * Gets the termStore property value. The default termStore under this site.
     * @returns a store
     */
    get termStore(): Store | undefined;
    /**
     * Sets the termStore property value. The default termStore under this site.
     * @param value Value to set for the termStore property.
     */
    set termStore(value: Store | undefined);
    /**
     * Gets the termStores property value. The collection of termStores under this site.
     * @returns a store
     */
    get termStores(): Store[] | undefined;
    /**
     * Sets the termStores property value. The collection of termStores under this site.
     * @param value Value to set for the termStores property.
     */
    set termStores(value: Store[] | undefined);
}
