import { ManagedAppConfiguration, ManagedAppPolicyDeploymentSummary, ManagedMobileApp, TargetedManagedAppPolicyAssignment } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class TargetedManagedAppConfiguration extends ManagedAppConfiguration implements Parsable {
    /** List of apps to which the policy is deployed.  */
    private _apps?;
    /** Navigation property to list of inclusion and exclusion groups to which the policy is deployed.  */
    private _assignments?;
    /** Count of apps to which the current policy is deployed.  */
    private _deployedAppCount?;
    /** Navigation property to deployment summary of the configuration.  */
    private _deploymentSummary?;
    /** Indicates if the policy is deployed to any inclusion groups or not.  */
    private _isAssigned?;
    /**
     * Gets the apps property value. List of apps to which the policy is deployed.
     * @returns a managedMobileApp
     */
    get apps(): ManagedMobileApp[] | undefined;
    /**
     * Sets the apps property value. List of apps to which the policy is deployed.
     * @param value Value to set for the apps property.
     */
    set apps(value: ManagedMobileApp[] | undefined);
    /**
     * Gets the assignments property value. Navigation property to list of inclusion and exclusion groups to which the policy is deployed.
     * @returns a targetedManagedAppPolicyAssignment
     */
    get assignments(): TargetedManagedAppPolicyAssignment[] | undefined;
    /**
     * Sets the assignments property value. Navigation property to list of inclusion and exclusion groups to which the policy is deployed.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: TargetedManagedAppPolicyAssignment[] | undefined);
    /**
     * Instantiates a new targetedManagedAppConfiguration and sets the default values.
     */
    constructor();
    /**
     * Gets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @returns a integer
     */
    get deployedAppCount(): number | undefined;
    /**
     * Sets the deployedAppCount property value. Count of apps to which the current policy is deployed.
     * @param value Value to set for the deployedAppCount property.
     */
    set deployedAppCount(value: number | undefined);
    /**
     * Gets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @returns a managedAppPolicyDeploymentSummary
     */
    get deploymentSummary(): ManagedAppPolicyDeploymentSummary | undefined;
    /**
     * Sets the deploymentSummary property value. Navigation property to deployment summary of the configuration.
     * @param value Value to set for the deploymentSummary property.
     */
    set deploymentSummary(value: ManagedAppPolicyDeploymentSummary | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isAssigned property value. Indicates if the policy is deployed to any inclusion groups or not.
     * @returns a boolean
     */
    get isAssigned(): boolean | undefined;
    /**
     * Sets the isAssigned property value. Indicates if the policy is deployed to any inclusion groups or not.
     * @param value Value to set for the isAssigned property.
     */
    set isAssigned(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
