import { Entity, IdentitySet, TeamworkBot } from './index';
import { TeamsAppPublishingState } from './teamsAppPublishingState';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class TeamsAppDefinition extends Entity implements Parsable {
    /** The details of the bot specified in the Teams app manifest.  */
    private _bot?;
    private _createdBy?;
    /** Verbose description of the application.  */
    private _description?;
    /** The name of the app provided by the app developer.  */
    private _displayName?;
    private _lastModifiedDateTime?;
    /** The published status of a specific version of a Teams app. Possible values are:submitted — The specific version of the Teams app has been submitted and is under review. published  — The request to publish the specific version of the Teams app has been approved by the admin and the app is published.  rejected — The request to publish the specific version of the Teams app was rejected by the admin.  */
    private _publishingState?;
    /** Short description of the application.  */
    private _shortDescription?;
    /** The ID from the Teams app manifest.  */
    private _teamsAppId?;
    /** The version number of the application.  */
    private _version?;
    /**
     * Gets the bot property value. The details of the bot specified in the Teams app manifest.
     * @returns a teamworkBot
     */
    get bot(): TeamworkBot | undefined;
    /**
     * Sets the bot property value. The details of the bot specified in the Teams app manifest.
     * @param value Value to set for the bot property.
     */
    set bot(value: TeamworkBot | undefined);
    /**
     * Instantiates a new teamsAppDefinition and sets the default values.
     */
    constructor();
    /**
     * Gets the createdBy property value.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the description property value. Verbose description of the application.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Verbose description of the application.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. The name of the app provided by the app developer.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name of the app provided by the app developer.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the lastModifiedDateTime property value.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the publishingState property value. The published status of a specific version of a Teams app. Possible values are:submitted — The specific version of the Teams app has been submitted and is under review. published  — The request to publish the specific version of the Teams app has been approved by the admin and the app is published.  rejected — The request to publish the specific version of the Teams app was rejected by the admin.
     * @returns a teamsAppPublishingState
     */
    get publishingState(): TeamsAppPublishingState | undefined;
    /**
     * Sets the publishingState property value. The published status of a specific version of a Teams app. Possible values are:submitted — The specific version of the Teams app has been submitted and is under review. published  — The request to publish the specific version of the Teams app has been approved by the admin and the app is published.  rejected — The request to publish the specific version of the Teams app was rejected by the admin.
     * @param value Value to set for the publishingState property.
     */
    set publishingState(value: TeamsAppPublishingState | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the shortDescription property value. Short description of the application.
     * @returns a string
     */
    get shortDescription(): string | undefined;
    /**
     * Sets the shortDescription property value. Short description of the application.
     * @param value Value to set for the shortDescription property.
     */
    set shortDescription(value: string | undefined);
    /**
     * Gets the teamsAppId property value. The ID from the Teams app manifest.
     * @returns a string
     */
    get teamsAppId(): string | undefined;
    /**
     * Sets the teamsAppId property value. The ID from the Teams app manifest.
     * @param value Value to set for the teamsAppId property.
     */
    set teamsAppId(value: string | undefined);
    /**
     * Gets the version property value. The version number of the application.
     * @returns a string
     */
    get version(): string | undefined;
    /**
     * Sets the version property value. The version number of the application.
     * @param value Value to set for the version property.
     */
    set version(value: string | undefined);
}
