import { Entity, TermsAndConditionsAcceptanceStatus, TermsAndConditionsAssignment } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class TermsAndConditions extends Entity implements Parsable {
    /** Administrator-supplied explanation of the terms and conditions, typically describing what it means to accept the terms and conditions set out in the T&C policy. This is shown to the user on prompts to accept the T&C policy.  */
    private _acceptanceStatement?;
    /** The list of acceptance statuses for this T&C policy.  */
    private _acceptanceStatuses?;
    /** The list of assignments for this T&C policy.  */
    private _assignments?;
    /** Administrator-supplied body text of the terms and conditions, typically the terms themselves. This is shown to the user on prompts to accept the T&C policy.  */
    private _bodyText?;
    /** DateTime the object was created.  */
    private _createdDateTime?;
    /** Administrator-supplied description of the T&C policy.  */
    private _description?;
    /** Administrator-supplied name for the T&C policy.  */
    private _displayName?;
    /** DateTime the object was last modified.  */
    private _lastModifiedDateTime?;
    /** Administrator-supplied title of the terms and conditions. This is shown to the user on prompts to accept the T&C policy.  */
    private _title?;
    /** Integer indicating the current version of the terms. Incremented when an administrator makes a change to the terms and wishes to require users to re-accept the modified T&C policy.  */
    private _version?;
    /**
     * Gets the acceptanceStatement property value. Administrator-supplied explanation of the terms and conditions, typically describing what it means to accept the terms and conditions set out in the T&C policy. This is shown to the user on prompts to accept the T&C policy.
     * @returns a string
     */
    get acceptanceStatement(): string | undefined;
    /**
     * Sets the acceptanceStatement property value. Administrator-supplied explanation of the terms and conditions, typically describing what it means to accept the terms and conditions set out in the T&C policy. This is shown to the user on prompts to accept the T&C policy.
     * @param value Value to set for the acceptanceStatement property.
     */
    set acceptanceStatement(value: string | undefined);
    /**
     * Gets the acceptanceStatuses property value. The list of acceptance statuses for this T&C policy.
     * @returns a termsAndConditionsAcceptanceStatus
     */
    get acceptanceStatuses(): TermsAndConditionsAcceptanceStatus[] | undefined;
    /**
     * Sets the acceptanceStatuses property value. The list of acceptance statuses for this T&C policy.
     * @param value Value to set for the acceptanceStatuses property.
     */
    set acceptanceStatuses(value: TermsAndConditionsAcceptanceStatus[] | undefined);
    /**
     * Gets the assignments property value. The list of assignments for this T&C policy.
     * @returns a termsAndConditionsAssignment
     */
    get assignments(): TermsAndConditionsAssignment[] | undefined;
    /**
     * Sets the assignments property value. The list of assignments for this T&C policy.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: TermsAndConditionsAssignment[] | undefined);
    /**
     * Gets the bodyText property value. Administrator-supplied body text of the terms and conditions, typically the terms themselves. This is shown to the user on prompts to accept the T&C policy.
     * @returns a string
     */
    get bodyText(): string | undefined;
    /**
     * Sets the bodyText property value. Administrator-supplied body text of the terms and conditions, typically the terms themselves. This is shown to the user on prompts to accept the T&C policy.
     * @param value Value to set for the bodyText property.
     */
    set bodyText(value: string | undefined);
    /**
     * Instantiates a new termsAndConditions and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. DateTime the object was created.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. DateTime the object was created.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the description property value. Administrator-supplied description of the T&C policy.
     * @returns a string
     */
    get description(): string | undefined;
    /**
     * Sets the description property value. Administrator-supplied description of the T&C policy.
     * @param value Value to set for the description property.
     */
    set description(value: string | undefined);
    /**
     * Gets the displayName property value. Administrator-supplied name for the T&C policy.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Administrator-supplied name for the T&C policy.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. DateTime the object was last modified.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the title property value. Administrator-supplied title of the terms and conditions. This is shown to the user on prompts to accept the T&C policy.
     * @returns a string
     */
    get title(): string | undefined;
    /**
     * Sets the title property value. Administrator-supplied title of the terms and conditions. This is shown to the user on prompts to accept the T&C policy.
     * @param value Value to set for the title property.
     */
    set title(value: string | undefined);
    /**
     * Gets the version property value. Integer indicating the current version of the terms. Incremented when an administrator makes a change to the terms and wishes to require users to re-accept the modified T&C policy.
     * @returns a integer
     */
    get version(): number | undefined;
    /**
     * Sets the version property value. Integer indicating the current version of the terms. Incremented when an administrator makes a change to the terms and wishes to require users to re-accept the modified T&C policy.
     * @param value Value to set for the version property.
     */
    set version(value: number | undefined);
}
