import { Entity, IdentitySet, ThreatAssessmentResult } from './index';
import { ThreatAssessmentContentType } from './threatAssessmentContentType';
import { ThreatAssessmentRequestSource } from './threatAssessmentRequestSource';
import { ThreatAssessmentStatus } from './threatAssessmentStatus';
import { ThreatCategory } from './threatCategory';
import { ThreatExpectedAssessment } from './threatExpectedAssessment';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class ThreatAssessmentRequest extends Entity implements Parsable {
    /** The threat category. Possible values are: spam, phishing, malware.  */
    private _category?;
    /** The content type of threat assessment. Possible values are: mail, url, file.  */
    private _contentType?;
    /** The threat assessment request creator.  */
    private _createdBy?;
    /** The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.  */
    private _createdDateTime?;
    /** The expected assessment from submitter. Possible values are: block, unblock.  */
    private _expectedAssessment?;
    /** The source of the threat assessment request. Possible values are: administrator.  */
    private _requestSource?;
    /** A collection of threat assessment results. Read-only. By default, a GET /threatAssessmentRequests/{id} does not return this property unless you apply $expand on it.  */
    private _results?;
    /** The assessment process status. Possible values are: pending, completed.  */
    private _status?;
    /**
     * Gets the category property value. The threat category. Possible values are: spam, phishing, malware.
     * @returns a threatCategory
     */
    get category(): ThreatCategory | undefined;
    /**
     * Sets the category property value. The threat category. Possible values are: spam, phishing, malware.
     * @param value Value to set for the category property.
     */
    set category(value: ThreatCategory | undefined);
    /**
     * Instantiates a new threatAssessmentRequest and sets the default values.
     */
    constructor();
    /**
     * Gets the contentType property value. The content type of threat assessment. Possible values are: mail, url, file.
     * @returns a threatAssessmentContentType
     */
    get contentType(): ThreatAssessmentContentType | undefined;
    /**
     * Sets the contentType property value. The content type of threat assessment. Possible values are: mail, url, file.
     * @param value Value to set for the contentType property.
     */
    set contentType(value: ThreatAssessmentContentType | undefined);
    /**
     * Gets the createdBy property value. The threat assessment request creator.
     * @returns a identitySet
     */
    get createdBy(): IdentitySet | undefined;
    /**
     * Sets the createdBy property value. The threat assessment request creator.
     * @param value Value to set for the createdBy property.
     */
    set createdBy(value: IdentitySet | undefined);
    /**
     * Gets the createdDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the expectedAssessment property value. The expected assessment from submitter. Possible values are: block, unblock.
     * @returns a threatExpectedAssessment
     */
    get expectedAssessment(): ThreatExpectedAssessment | undefined;
    /**
     * Sets the expectedAssessment property value. The expected assessment from submitter. Possible values are: block, unblock.
     * @param value Value to set for the expectedAssessment property.
     */
    set expectedAssessment(value: ThreatExpectedAssessment | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the requestSource property value. The source of the threat assessment request. Possible values are: administrator.
     * @returns a threatAssessmentRequestSource
     */
    get requestSource(): ThreatAssessmentRequestSource | undefined;
    /**
     * Sets the requestSource property value. The source of the threat assessment request. Possible values are: administrator.
     * @param value Value to set for the requestSource property.
     */
    set requestSource(value: ThreatAssessmentRequestSource | undefined);
    /**
     * Gets the results property value. A collection of threat assessment results. Read-only. By default, a GET /threatAssessmentRequests/{id} does not return this property unless you apply $expand on it.
     * @returns a threatAssessmentResult
     */
    get results(): ThreatAssessmentResult[] | undefined;
    /**
     * Sets the results property value. A collection of threat assessment results. Read-only. By default, a GET /threatAssessmentRequests/{id} does not return this property unless you apply $expand on it.
     * @param value Value to set for the results property.
     */
    set results(value: ThreatAssessmentResult[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. The assessment process status. Possible values are: pending, completed.
     * @returns a threatAssessmentStatus
     */
    get status(): ThreatAssessmentStatus | undefined;
    /**
     * Sets the status property value. The assessment process status. Possible values are: pending, completed.
     * @param value Value to set for the status property.
     */
    set status(value: ThreatAssessmentStatus | undefined);
}
