import { Importance } from './importance';
import { DateTimeTimeZone, Entity, Extension, ItemBody, LinkedResource, PatternedRecurrence } from './index';
import { TaskStatus } from './taskStatus';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class TodoTask extends Entity implements Parsable {
    /** The task body that typically contains information about the task.  */
    private _body?;
    /** The date and time when the task was last modified. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.  */
    private _bodyLastModifiedDateTime?;
    /** The date in the specified time zone that the task was finished.  */
    private _completedDateTime?;
    /** The date and time when the task was created. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.  */
    private _createdDateTime?;
    /** The date in the specified time zone that the task is to be finished.  */
    private _dueDateTime?;
    /** The collection of open extensions defined for the task. Nullable.  */
    private _extensions?;
    /** The importance of the task. Possible values are: low, normal, high.  */
    private _importance?;
    /** Set to true if an alert is set to remind the user of the task.  */
    private _isReminderOn?;
    /** The date and time when the task was last modified. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.  */
    private _lastModifiedDateTime?;
    /** A collection of resources linked to the task.  */
    private _linkedResources?;
    /** The recurrence pattern for the task.  */
    private _recurrence?;
    /** The date and time for a reminder alert of the task to occur.  */
    private _reminderDateTime?;
    /** Indicates the state or progress of the task. Possible values are: notStarted, inProgress, completed, waitingOnOthers, deferred.  */
    private _status?;
    /** A brief description of the task.  */
    private _title?;
    /**
     * Gets the body property value. The task body that typically contains information about the task.
     * @returns a itemBody
     */
    get body(): ItemBody | undefined;
    /**
     * Sets the body property value. The task body that typically contains information about the task.
     * @param value Value to set for the body property.
     */
    set body(value: ItemBody | undefined);
    /**
     * Gets the bodyLastModifiedDateTime property value. The date and time when the task was last modified. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.
     * @returns a Date
     */
    get bodyLastModifiedDateTime(): Date | undefined;
    /**
     * Sets the bodyLastModifiedDateTime property value. The date and time when the task was last modified. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.
     * @param value Value to set for the bodyLastModifiedDateTime property.
     */
    set bodyLastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the completedDateTime property value. The date in the specified time zone that the task was finished.
     * @returns a dateTimeTimeZone
     */
    get completedDateTime(): DateTimeTimeZone | undefined;
    /**
     * Sets the completedDateTime property value. The date in the specified time zone that the task was finished.
     * @param value Value to set for the completedDateTime property.
     */
    set completedDateTime(value: DateTimeTimeZone | undefined);
    /**
     * Instantiates a new todoTask and sets the default values.
     */
    constructor();
    /**
     * Gets the createdDateTime property value. The date and time when the task was created. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.
     * @returns a Date
     */
    get createdDateTime(): Date | undefined;
    /**
     * Sets the createdDateTime property value. The date and time when the task was created. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value: Date | undefined);
    /**
     * Gets the dueDateTime property value. The date in the specified time zone that the task is to be finished.
     * @returns a dateTimeTimeZone
     */
    get dueDateTime(): DateTimeTimeZone | undefined;
    /**
     * Sets the dueDateTime property value. The date in the specified time zone that the task is to be finished.
     * @param value Value to set for the dueDateTime property.
     */
    set dueDateTime(value: DateTimeTimeZone | undefined);
    /**
     * Gets the extensions property value. The collection of open extensions defined for the task. Nullable.
     * @returns a extension
     */
    get extensions(): Extension[] | undefined;
    /**
     * Sets the extensions property value. The collection of open extensions defined for the task. Nullable.
     * @param value Value to set for the extensions property.
     */
    set extensions(value: Extension[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the importance property value. The importance of the task. Possible values are: low, normal, high.
     * @returns a importance
     */
    get importance(): Importance | undefined;
    /**
     * Sets the importance property value. The importance of the task. Possible values are: low, normal, high.
     * @param value Value to set for the importance property.
     */
    set importance(value: Importance | undefined);
    /**
     * Gets the isReminderOn property value. Set to true if an alert is set to remind the user of the task.
     * @returns a boolean
     */
    get isReminderOn(): boolean | undefined;
    /**
     * Sets the isReminderOn property value. Set to true if an alert is set to remind the user of the task.
     * @param value Value to set for the isReminderOn property.
     */
    set isReminderOn(value: boolean | undefined);
    /**
     * Gets the lastModifiedDateTime property value. The date and time when the task was last modified. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.
     * @returns a Date
     */
    get lastModifiedDateTime(): Date | undefined;
    /**
     * Sets the lastModifiedDateTime property value. The date and time when the task was last modified. By default, it is in UTC. You can provide a custom time zone in the request header. The property value uses ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2020 would look like this: '2020-01-01T00:00:00Z'.
     * @param value Value to set for the lastModifiedDateTime property.
     */
    set lastModifiedDateTime(value: Date | undefined);
    /**
     * Gets the linkedResources property value. A collection of resources linked to the task.
     * @returns a linkedResource
     */
    get linkedResources(): LinkedResource[] | undefined;
    /**
     * Sets the linkedResources property value. A collection of resources linked to the task.
     * @param value Value to set for the linkedResources property.
     */
    set linkedResources(value: LinkedResource[] | undefined);
    /**
     * Gets the recurrence property value. The recurrence pattern for the task.
     * @returns a patternedRecurrence
     */
    get recurrence(): PatternedRecurrence | undefined;
    /**
     * Sets the recurrence property value. The recurrence pattern for the task.
     * @param value Value to set for the recurrence property.
     */
    set recurrence(value: PatternedRecurrence | undefined);
    /**
     * Gets the reminderDateTime property value. The date and time for a reminder alert of the task to occur.
     * @returns a dateTimeTimeZone
     */
    get reminderDateTime(): DateTimeTimeZone | undefined;
    /**
     * Sets the reminderDateTime property value. The date and time for a reminder alert of the task to occur.
     * @param value Value to set for the reminderDateTime property.
     */
    set reminderDateTime(value: DateTimeTimeZone | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the status property value. Indicates the state or progress of the task. Possible values are: notStarted, inProgress, completed, waitingOnOthers, deferred.
     * @returns a taskStatus
     */
    get status(): TaskStatus | undefined;
    /**
     * Sets the status property value. Indicates the state or progress of the task. Possible values are: notStarted, inProgress, completed, waitingOnOthers, deferred.
     * @param value Value to set for the status property.
     */
    set status(value: TaskStatus | undefined);
    /**
     * Gets the title property value. A brief description of the task.
     * @returns a string
     */
    get title(): string | undefined;
    /**
     * Sets the title property value. A brief description of the task.
     * @param value Value to set for the title property.
     */
    set title(value: string | undefined);
}
