import { Entity, Extension, TodoTask } from './index';
import { WellknownListName } from './wellknownListName';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class TodoTaskList extends Entity implements Parsable {
    /** The name of the task list.  */
    private _displayName?;
    /** The collection of open extensions defined for the task list. Nullable.  */
    private _extensions?;
    /** True if the user is owner of the given task list.  */
    private _isOwner?;
    /** True if the task list is shared with other users  */
    private _isShared?;
    /** The tasks in this task list. Read-only. Nullable.  */
    private _tasks?;
    /** Property indicating the list name if the given list is a well-known list. Possible values are: none, defaultList, flaggedEmails, unknownFutureValue.  */
    private _wellknownListName?;
    /**
     * Instantiates a new todoTaskList and sets the default values.
     */
    constructor();
    /**
     * Gets the displayName property value. The name of the task list.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. The name of the task list.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the extensions property value. The collection of open extensions defined for the task list. Nullable.
     * @returns a extension
     */
    get extensions(): Extension[] | undefined;
    /**
     * Sets the extensions property value. The collection of open extensions defined for the task list. Nullable.
     * @param value Value to set for the extensions property.
     */
    set extensions(value: Extension[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isOwner property value. True if the user is owner of the given task list.
     * @returns a boolean
     */
    get isOwner(): boolean | undefined;
    /**
     * Sets the isOwner property value. True if the user is owner of the given task list.
     * @param value Value to set for the isOwner property.
     */
    set isOwner(value: boolean | undefined);
    /**
     * Gets the isShared property value. True if the task list is shared with other users
     * @returns a boolean
     */
    get isShared(): boolean | undefined;
    /**
     * Sets the isShared property value. True if the task list is shared with other users
     * @param value Value to set for the isShared property.
     */
    set isShared(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the tasks property value. The tasks in this task list. Read-only. Nullable.
     * @returns a todoTask
     */
    get tasks(): TodoTask[] | undefined;
    /**
     * Sets the tasks property value. The tasks in this task list. Read-only. Nullable.
     * @param value Value to set for the tasks property.
     */
    set tasks(value: TodoTask[] | undefined);
    /**
     * Gets the wellknownListName property value. Property indicating the list name if the given list is a well-known list. Possible values are: none, defaultList, flaggedEmails, unknownFutureValue.
     * @returns a wellknownListName
     */
    get wellknownListName(): WellknownListName | undefined;
    /**
     * Sets the wellknownListName property value. Property indicating the list name if the given list is a well-known list. Possible values are: none, defaultList, flaggedEmails, unknownFutureValue.
     * @param value Value to set for the wellknownListName property.
     */
    set wellknownListName(value: WellknownListName | undefined);
}
