import { AppScope, DirectoryObject, Entity, UnifiedRoleDefinition } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class UnifiedRoleAssignment extends Entity implements Parsable {
    /** Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity. Supports $expand.  */
    private _appScope?;
    /** Identifier of the app-specific scope when the assignment scope is app-specific.  Either this property or directoryScopeId is required. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units. Supports $filter (eq, in).  */
    private _appScopeId?;
    private _condition?;
    /** The directory object that is the scope of the assignment. Read-only. Supports $expand.  */
    private _directoryScope?;
    /** Identifier of the directory object representing the scope of the assignment.  Either this property or appScopeId is required. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only. Supports $filter (eq, in).  */
    private _directoryScopeId?;
    /** Referencing the assigned principal. Read-only. Supports $expand.  */
    private _principal?;
    /** Identifier of the principal to which the assignment is granted. Supports $filter (eq, in).  */
    private _principalId?;
    /** The roleDefinition the assignment is for.  Supports $expand. roleDefinition.Id will be auto expanded.  */
    private _roleDefinition?;
    /** Identifier of the role definition the assignment is for. Read only. Supports $filter (eq, in).  */
    private _roleDefinitionId?;
    /**
     * Gets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity. Supports $expand.
     * @returns a appScope
     */
    get appScope(): AppScope | undefined;
    /**
     * Sets the appScope property value. Read-only property with details of the app specific scope when the assignment scope is app specific. Containment entity. Supports $expand.
     * @param value Value to set for the appScope property.
     */
    set appScope(value: AppScope | undefined);
    /**
     * Gets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific.  Either this property or directoryScopeId is required. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units. Supports $filter (eq, in).
     * @returns a string
     */
    get appScopeId(): string | undefined;
    /**
     * Sets the appScopeId property value. Identifier of the app-specific scope when the assignment scope is app-specific.  Either this property or directoryScopeId is required. App scopes are scopes that are defined and understood by this application only. Use / for tenant-wide app scopes. Use directoryScopeId to limit the scope to particular directory objects, for example, administrative units. Supports $filter (eq, in).
     * @param value Value to set for the appScopeId property.
     */
    set appScopeId(value: string | undefined);
    /**
     * Gets the condition property value.
     * @returns a string
     */
    get condition(): string | undefined;
    /**
     * Sets the condition property value.
     * @param value Value to set for the condition property.
     */
    set condition(value: string | undefined);
    /**
     * Instantiates a new unifiedRoleAssignment and sets the default values.
     */
    constructor();
    /**
     * Gets the directoryScope property value. The directory object that is the scope of the assignment. Read-only. Supports $expand.
     * @returns a directoryObject
     */
    get directoryScope(): DirectoryObject | undefined;
    /**
     * Sets the directoryScope property value. The directory object that is the scope of the assignment. Read-only. Supports $expand.
     * @param value Value to set for the directoryScope property.
     */
    set directoryScope(value: DirectoryObject | undefined);
    /**
     * Gets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment.  Either this property or appScopeId is required. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only. Supports $filter (eq, in).
     * @returns a string
     */
    get directoryScopeId(): string | undefined;
    /**
     * Sets the directoryScopeId property value. Identifier of the directory object representing the scope of the assignment.  Either this property or appScopeId is required. The scope of an assignment determines the set of resources for which the principal has been granted access. Directory scopes are shared scopes stored in the directory that are understood by multiple applications. Use / for tenant-wide scope. Use appScopeId to limit the scope to an application only. Supports $filter (eq, in).
     * @param value Value to set for the directoryScopeId property.
     */
    set directoryScopeId(value: string | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the principal property value. Referencing the assigned principal. Read-only. Supports $expand.
     * @returns a directoryObject
     */
    get principal(): DirectoryObject | undefined;
    /**
     * Sets the principal property value. Referencing the assigned principal. Read-only. Supports $expand.
     * @param value Value to set for the principal property.
     */
    set principal(value: DirectoryObject | undefined);
    /**
     * Gets the principalId property value. Identifier of the principal to which the assignment is granted. Supports $filter (eq, in).
     * @returns a string
     */
    get principalId(): string | undefined;
    /**
     * Sets the principalId property value. Identifier of the principal to which the assignment is granted. Supports $filter (eq, in).
     * @param value Value to set for the principalId property.
     */
    set principalId(value: string | undefined);
    /**
     * Gets the roleDefinition property value. The roleDefinition the assignment is for.  Supports $expand. roleDefinition.Id will be auto expanded.
     * @returns a unifiedRoleDefinition
     */
    get roleDefinition(): UnifiedRoleDefinition | undefined;
    /**
     * Sets the roleDefinition property value. The roleDefinition the assignment is for.  Supports $expand. roleDefinition.Id will be auto expanded.
     * @param value Value to set for the roleDefinition property.
     */
    set roleDefinition(value: UnifiedRoleDefinition | undefined);
    /**
     * Gets the roleDefinitionId property value. Identifier of the role definition the assignment is for. Read only. Supports $filter (eq, in).
     * @returns a string
     */
    get roleDefinitionId(): string | undefined;
    /**
     * Sets the roleDefinitionId property value. Identifier of the role definition the assignment is for. Read only. Supports $filter (eq, in).
     * @param value Value to set for the roleDefinitionId property.
     */
    set roleDefinitionId(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
