import { Entity, ResourceReference, ResourceVisualization, UsageDetails } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class UsedInsight extends Entity implements Parsable {
    /** Information about when the item was last viewed or modified by the user. Read only.  */
    private _lastUsed?;
    /** Used for navigating to the item that was used. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.  */
    private _resource?;
    /** Reference properties of the used document, such as the url and type of the document. Read-only  */
    private _resourceReference?;
    /** Properties that you can use to visualize the document in your experience. Read-only  */
    private _resourceVisualization?;
    /**
     * Instantiates a new usedInsight and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the lastUsed property value. Information about when the item was last viewed or modified by the user. Read only.
     * @returns a usageDetails
     */
    get lastUsed(): UsageDetails | undefined;
    /**
     * Sets the lastUsed property value. Information about when the item was last viewed or modified by the user. Read only.
     * @param value Value to set for the lastUsed property.
     */
    set lastUsed(value: UsageDetails | undefined);
    /**
     * Gets the resource property value. Used for navigating to the item that was used. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.
     * @returns a entity
     */
    get resource(): Entity | undefined;
    /**
     * Sets the resource property value. Used for navigating to the item that was used. For file attachments, the type is fileAttachment. For linked attachments, the type is driveItem.
     * @param value Value to set for the resource property.
     */
    set resource(value: Entity | undefined);
    /**
     * Gets the resourceReference property value. Reference properties of the used document, such as the url and type of the document. Read-only
     * @returns a resourceReference
     */
    get resourceReference(): ResourceReference | undefined;
    /**
     * Sets the resourceReference property value. Reference properties of the used document, such as the url and type of the document. Read-only
     * @param value Value to set for the resourceReference property.
     */
    set resourceReference(value: ResourceReference | undefined);
    /**
     * Gets the resourceVisualization property value. Properties that you can use to visualize the document in your experience. Read-only
     * @returns a resourceVisualization
     */
    get resourceVisualization(): ResourceVisualization | undefined;
    /**
     * Sets the resourceVisualization property value. Properties that you can use to visualize the document in your experience. Read-only
     * @param value Value to set for the resourceVisualization property.
     */
    set resourceVisualization(value: ResourceVisualization | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
}
