"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UserSecurityState = void 0;
const emailRole_1 = require("./emailRole");
const logonType_1 = require("./logonType");
const userAccountSecurityType_1 = require("./userAccountSecurityType");
class UserSecurityState {
    /**
     * Instantiates a new userSecurityState and sets the default values.
     */
    constructor() {
        this._additionalData = {};
    }
    /**
     * Gets the aadUserId property value. AAD User object identifier (GUID) - represents the physical/multi-account user entity.
     * @returns a string
     */
    get aadUserId() {
        return this._aadUserId;
    }
    ;
    /**
     * Sets the aadUserId property value. AAD User object identifier (GUID) - represents the physical/multi-account user entity.
     * @param value Value to set for the aadUserId property.
     */
    set aadUserId(value) {
        this._aadUserId = value;
    }
    ;
    /**
     * Gets the accountName property value. Account name of user account (without Active Directory domain or DNS domain) - (also called mailNickName).
     * @returns a string
     */
    get accountName() {
        return this._accountName;
    }
    ;
    /**
     * Sets the accountName property value. Account name of user account (without Active Directory domain or DNS domain) - (also called mailNickName).
     * @param value Value to set for the accountName property.
     */
    set accountName(value) {
        this._accountName = value;
    }
    ;
    /**
     * Gets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @returns a Record<string, unknown>
     */
    get additionalData() {
        return this._additionalData;
    }
    ;
    /**
     * Sets the additionalData property value. Stores additional data not described in the OpenAPI description found when deserializing. Can be used for serialization as well.
     * @param value Value to set for the AdditionalData property.
     */
    set additionalData(value) {
        this._additionalData = value;
    }
    ;
    ;
    /**
     * Gets the domainName property value. NetBIOS/Active Directory domain of user account (that is, domain/account format).
     * @returns a string
     */
    get domainName() {
        return this._domainName;
    }
    ;
    /**
     * Sets the domainName property value. NetBIOS/Active Directory domain of user account (that is, domain/account format).
     * @param value Value to set for the domainName property.
     */
    set domainName(value) {
        this._domainName = value;
    }
    ;
    /**
     * Gets the emailRole property value. For email-related alerts - user account's email 'role'. Possible values are: unknown, sender, recipient.
     * @returns a emailRole
     */
    get emailRole() {
        return this._emailRole;
    }
    ;
    /**
     * Sets the emailRole property value. For email-related alerts - user account's email 'role'. Possible values are: unknown, sender, recipient.
     * @param value Value to set for the emailRole property.
     */
    set emailRole(value) {
        this._emailRole = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return {
            "aadUserId": (o, n) => { o.aadUserId = n.getStringValue(); },
            "accountName": (o, n) => { o.accountName = n.getStringValue(); },
            "domainName": (o, n) => { o.domainName = n.getStringValue(); },
            "emailRole": (o, n) => { o.emailRole = n.getEnumValue(emailRole_1.EmailRole); },
            "isVpn": (o, n) => { o.isVpn = n.getBooleanValue(); },
            "logonDateTime": (o, n) => { o.logonDateTime = n.getDateValue(); },
            "logonId": (o, n) => { o.logonId = n.getStringValue(); },
            "logonIp": (o, n) => { o.logonIp = n.getStringValue(); },
            "logonLocation": (o, n) => { o.logonLocation = n.getStringValue(); },
            "logonType": (o, n) => { o.logonType = n.getEnumValue(logonType_1.LogonType); },
            "onPremisesSecurityIdentifier": (o, n) => { o.onPremisesSecurityIdentifier = n.getStringValue(); },
            "riskScore": (o, n) => { o.riskScore = n.getStringValue(); },
            "userAccountType": (o, n) => { o.userAccountType = n.getEnumValue(userAccountSecurityType_1.UserAccountSecurityType); },
            "userPrincipalName": (o, n) => { o.userPrincipalName = n.getStringValue(); },
        };
    }
    ;
    /**
     * Gets the isVpn property value. Indicates whether the user logged on through a VPN.
     * @returns a boolean
     */
    get isVpn() {
        return this._isVpn;
    }
    ;
    /**
     * Sets the isVpn property value. Indicates whether the user logged on through a VPN.
     * @param value Value to set for the isVpn property.
     */
    set isVpn(value) {
        this._isVpn = value;
    }
    ;
    /**
     * Gets the logonDateTime property value. Time at which the sign-in occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @returns a Date
     */
    get logonDateTime() {
        return this._logonDateTime;
    }
    ;
    /**
     * Sets the logonDateTime property value. Time at which the sign-in occurred. The Timestamp type represents date and time information using ISO 8601 format and is always in UTC time. For example, midnight UTC on Jan 1, 2014 is 2014-01-01T00:00:00Z.
     * @param value Value to set for the logonDateTime property.
     */
    set logonDateTime(value) {
        this._logonDateTime = value;
    }
    ;
    /**
     * Gets the logonId property value. User sign-in ID.
     * @returns a string
     */
    get logonId() {
        return this._logonId;
    }
    ;
    /**
     * Sets the logonId property value. User sign-in ID.
     * @param value Value to set for the logonId property.
     */
    set logonId(value) {
        this._logonId = value;
    }
    ;
    /**
     * Gets the logonIp property value. IP Address the sign-in request originated from.
     * @returns a string
     */
    get logonIp() {
        return this._logonIp;
    }
    ;
    /**
     * Sets the logonIp property value. IP Address the sign-in request originated from.
     * @param value Value to set for the logonIp property.
     */
    set logonIp(value) {
        this._logonIp = value;
    }
    ;
    /**
     * Gets the logonLocation property value. Location (by IP address mapping) associated with a user sign-in event by this user.
     * @returns a string
     */
    get logonLocation() {
        return this._logonLocation;
    }
    ;
    /**
     * Sets the logonLocation property value. Location (by IP address mapping) associated with a user sign-in event by this user.
     * @param value Value to set for the logonLocation property.
     */
    set logonLocation(value) {
        this._logonLocation = value;
    }
    ;
    /**
     * Gets the logonType property value. Method of user sign in. Possible values are: unknown, interactive, remoteInteractive, network, batch, service.
     * @returns a logonType
     */
    get logonType() {
        return this._logonType;
    }
    ;
    /**
     * Sets the logonType property value. Method of user sign in. Possible values are: unknown, interactive, remoteInteractive, network, batch, service.
     * @param value Value to set for the logonType property.
     */
    set logonType(value) {
        this._logonType = value;
    }
    ;
    /**
     * Gets the onPremisesSecurityIdentifier property value. Active Directory (on-premises) Security Identifier (SID) of the user.
     * @returns a string
     */
    get onPremisesSecurityIdentifier() {
        return this._onPremisesSecurityIdentifier;
    }
    ;
    /**
     * Sets the onPremisesSecurityIdentifier property value. Active Directory (on-premises) Security Identifier (SID) of the user.
     * @param value Value to set for the onPremisesSecurityIdentifier property.
     */
    set onPremisesSecurityIdentifier(value) {
        this._onPremisesSecurityIdentifier = value;
    }
    ;
    /**
     * Gets the riskScore property value. Provider-generated/calculated risk score of the user account. Recommended value range of 0-1, which equates to a percentage.
     * @returns a string
     */
    get riskScore() {
        return this._riskScore;
    }
    ;
    /**
     * Sets the riskScore property value. Provider-generated/calculated risk score of the user account. Recommended value range of 0-1, which equates to a percentage.
     * @param value Value to set for the riskScore property.
     */
    set riskScore(value) {
        this._riskScore = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        writer.writeStringValue("aadUserId", this.aadUserId);
        writer.writeStringValue("accountName", this.accountName);
        writer.writeStringValue("domainName", this.domainName);
        writer.writeEnumValue("emailRole", this.emailRole);
        writer.writeBooleanValue("isVpn", this.isVpn);
        writer.writeDateValue("logonDateTime", this.logonDateTime);
        writer.writeStringValue("logonId", this.logonId);
        writer.writeStringValue("logonIp", this.logonIp);
        writer.writeStringValue("logonLocation", this.logonLocation);
        writer.writeEnumValue("logonType", this.logonType);
        writer.writeStringValue("onPremisesSecurityIdentifier", this.onPremisesSecurityIdentifier);
        writer.writeStringValue("riskScore", this.riskScore);
        writer.writeEnumValue("userAccountType", this.userAccountType);
        writer.writeStringValue("userPrincipalName", this.userPrincipalName);
        writer.writeAdditionalData(this.additionalData);
    }
    ;
    /**
     * Gets the userAccountType property value. User account type (group membership), per Windows definition. Possible values are: unknown, standard, power, administrator.
     * @returns a userAccountSecurityType
     */
    get userAccountType() {
        return this._userAccountType;
    }
    ;
    /**
     * Sets the userAccountType property value. User account type (group membership), per Windows definition. Possible values are: unknown, standard, power, administrator.
     * @param value Value to set for the userAccountType property.
     */
    set userAccountType(value) {
        this._userAccountType = value;
    }
    ;
    /**
     * Gets the userPrincipalName property value. User sign-in name - internet format: (user account name)@(user account DNS domain name).
     * @returns a string
     */
    get userPrincipalName() {
        return this._userPrincipalName;
    }
    ;
    /**
     * Sets the userPrincipalName property value. User sign-in name - internet format: (user account name)@(user account DNS domain name).
     * @param value Value to set for the userPrincipalName property.
     */
    set userPrincipalName(value) {
        this._userPrincipalName = value;
    }
    ;
}
exports.UserSecurityState = UserSecurityState;
