"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WindowsHelloForBusinessAuthenticationMethod = void 0;
const authenticationMethodKeyStrength_1 = require("./authenticationMethodKeyStrength");
const createDeviceFromDiscriminatorValue_1 = require("./createDeviceFromDiscriminatorValue");
const index_1 = require("./index");
class WindowsHelloForBusinessAuthenticationMethod extends index_1.AuthenticationMethod {
    /**
     * Instantiates a new windowsHelloForBusinessAuthenticationMethod and sets the default values.
     */
    constructor() {
        super();
    }
    ;
    /**
     * Gets the createdDateTime property value. The date and time that this Windows Hello for Business key was registered.
     * @returns a Date
     */
    get createdDateTime() {
        return this._createdDateTime;
    }
    ;
    /**
     * Sets the createdDateTime property value. The date and time that this Windows Hello for Business key was registered.
     * @param value Value to set for the createdDateTime property.
     */
    set createdDateTime(value) {
        this._createdDateTime = value;
    }
    ;
    /**
     * Gets the device property value. The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/admin@contoso.com/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.
     * @returns a device
     */
    get device() {
        return this._device;
    }
    ;
    /**
     * Sets the device property value. The registered device on which this Windows Hello for Business key resides. Supports $expand. When you get a user's Windows Hello for Business registration information, this property is returned only on a single GET and when you specify ?$expand. For example, GET /users/admin@contoso.com/authentication/windowsHelloForBusinessMethods/_jpuR-TGZtk6aQCLF3BQjA2?$expand=device.
     * @param value Value to set for the device property.
     */
    set device(value) {
        this._device = value;
    }
    ;
    /**
     * Gets the displayName property value. The name of the device on which Windows Hello for Business is registered
     * @returns a string
     */
    get displayName() {
        return this._displayName;
    }
    ;
    /**
     * Sets the displayName property value. The name of the device on which Windows Hello for Business is registered
     * @param value Value to set for the displayName property.
     */
    set displayName(value) {
        this._displayName = value;
    }
    ;
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers() {
        return Object.assign(Object.assign({}, super.getFieldDeserializers()), { "createdDateTime": (o, n) => { o.createdDateTime = n.getDateValue(); }, "device": (o, n) => { o.device = n.getObjectValue(createDeviceFromDiscriminatorValue_1.createDeviceFromDiscriminatorValue); }, "displayName": (o, n) => { o.displayName = n.getStringValue(); }, "keyStrength": (o, n) => { o.keyStrength = n.getEnumValue(authenticationMethodKeyStrength_1.AuthenticationMethodKeyStrength); } });
    }
    ;
    /**
     * Gets the keyStrength property value. Key strength of this Windows Hello for Business key. Possible values are: normal, weak, unknown.
     * @returns a authenticationMethodKeyStrength
     */
    get keyStrength() {
        return this._keyStrength;
    }
    ;
    /**
     * Sets the keyStrength property value. Key strength of this Windows Hello for Business key. Possible values are: normal, weak, unknown.
     * @param value Value to set for the keyStrength property.
     */
    set keyStrength(value) {
        this._keyStrength = value;
    }
    ;
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer) {
        if (!writer)
            throw new Error("writer cannot be undefined");
        super.serialize(writer);
        writer.writeDateValue("createdDateTime", this.createdDateTime);
        writer.writeObjectValue("device", this.device);
        writer.writeStringValue("displayName", this.displayName);
        writer.writeEnumValue("keyStrength", this.keyStrength);
    }
    ;
}
exports.WindowsHelloForBusinessAuthenticationMethod = WindowsHelloForBusinessAuthenticationMethod;
