import { ManagedAppPolicy, TargetedManagedAppPolicyAssignment, WindowsInformationProtectionApp, WindowsInformationProtectionAppLockerFile, WindowsInformationProtectionDataRecoveryCertificate, WindowsInformationProtectionIPRangeCollection, WindowsInformationProtectionProxiedDomainCollection, WindowsInformationProtectionResourceCollection } from './index';
import { WindowsInformationProtectionEnforcementLevel } from './windowsInformationProtectionEnforcementLevel';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class WindowsInformationProtection extends ManagedAppPolicy implements Parsable {
    /** Navigation property to list of security groups targeted for policy.  */
    private _assignments?;
    /** Specifies whether to allow Azure RMS encryption for WIP  */
    private _azureRightsManagementServicesAllowed?;
    /** Specifies a recovery certificate that can be used for data recovery of encrypted files. This is the same as the data recovery agent(DRA) certificate for encrypting file system(EFS)  */
    private _dataRecoveryCertificate?;
    /** WIP enforcement level.See the Enum definition for supported values. Possible values are: noProtection, encryptAndAuditOnly, encryptAuditAndPrompt, encryptAuditAndBlock.  */
    private _enforcementLevel?;
    /** Primary enterprise domain  */
    private _enterpriseDomain?;
    /** This is the comma-separated list of internal proxy servers. For example, '157.54.14.28, 157.54.11.118, 10.202.14.167, 157.53.14.163, 157.69.210.59'. These proxies have been configured by the admin to connect to specific resources on the Internet. They are considered to be enterprise network locations. The proxies are only leveraged in configuring the EnterpriseProxiedDomains policy to force traffic to the matched domains through these proxies  */
    private _enterpriseInternalProxyServers?;
    /** Sets the enterprise IP ranges that define the computers in the enterprise network. Data that comes from those computers will be considered part of the enterprise and protected. These locations will be considered a safe destination for enterprise data to be shared to  */
    private _enterpriseIPRanges?;
    /** Boolean value that tells the client to accept the configured list and not to use heuristics to attempt to find other subnets. Default is false  */
    private _enterpriseIPRangesAreAuthoritative?;
    /** This is the list of domains that comprise the boundaries of the enterprise. Data from one of these domains that is sent to a device will be considered enterprise data and protected These locations will be considered a safe destination for enterprise data to be shared to  */
    private _enterpriseNetworkDomainNames?;
    /** List of enterprise domains to be protected  */
    private _enterpriseProtectedDomainNames?;
    /** Contains a list of Enterprise resource domains hosted in the cloud that need to be protected. Connections to these resources are considered enterprise data. If a proxy is paired with a cloud resource, traffic to the cloud resource will be routed through the enterprise network via the denoted proxy server (on Port 80). A proxy server used for this purpose must also be configured using the EnterpriseInternalProxyServers policy  */
    private _enterpriseProxiedDomains?;
    /** This is a list of proxy servers. Any server not on this list is considered non-enterprise  */
    private _enterpriseProxyServers?;
    /** Boolean value that tells the client to accept the configured list of proxies and not try to detect other work proxies. Default is false  */
    private _enterpriseProxyServersAreAuthoritative?;
    /** Another way to input exempt apps through xml files  */
    private _exemptAppLockerFiles?;
    /** Exempt applications can also access enterprise data, but the data handled by those applications are not protected. This is because some critical enterprise applications may have compatibility problems with encrypted data.  */
    private _exemptApps?;
    /** Determines whether overlays are added to icons for WIP protected files in Explorer and enterprise only app tiles in the Start menu. Starting in Windows 10, version 1703 this setting also configures the visibility of the WIP icon in the title bar of a WIP-protected app  */
    private _iconsVisible?;
    /** This switch is for the Windows Search Indexer, to allow or disallow indexing of items  */
    private _indexingEncryptedStoresOrItemsBlocked?;
    /** Indicates if the policy is deployed to any inclusion groups or not.  */
    private _isAssigned?;
    /** List of domain names that can used for work or personal resource  */
    private _neutralDomainResources?;
    /** Another way to input protected apps through xml files  */
    private _protectedAppLockerFiles?;
    /** Protected applications can access enterprise data and the data handled by those applications are protected with encryption  */
    private _protectedApps?;
    /** Specifies whether the protection under lock feature (also known as encrypt under pin) should be configured  */
    private _protectionUnderLockConfigRequired?;
    /** This policy controls whether to revoke the WIP keys when a device unenrolls from the management service. If set to 1 (Don't revoke keys), the keys will not be revoked and the user will continue to have access to protected files after unenrollment. If the keys are not revoked, there will be no revoked file cleanup subsequently.  */
    private _revokeOnUnenrollDisabled?;
    /** TemplateID GUID to use for RMS encryption. The RMS template allows the IT admin to configure the details about who has access to RMS-protected file and how long they have access  */
    private _rightsManagementServicesTemplateId?;
    /** Specifies a list of file extensions, so that files with these extensions are encrypted when copying from an SMB share within the corporate boundary  */
    private _smbAutoEncryptedFileExtensions?;
    /**
     * Gets the assignments property value. Navigation property to list of security groups targeted for policy.
     * @returns a targetedManagedAppPolicyAssignment
     */
    get assignments(): TargetedManagedAppPolicyAssignment[] | undefined;
    /**
     * Sets the assignments property value. Navigation property to list of security groups targeted for policy.
     * @param value Value to set for the assignments property.
     */
    set assignments(value: TargetedManagedAppPolicyAssignment[] | undefined);
    /**
     * Gets the azureRightsManagementServicesAllowed property value. Specifies whether to allow Azure RMS encryption for WIP
     * @returns a boolean
     */
    get azureRightsManagementServicesAllowed(): boolean | undefined;
    /**
     * Sets the azureRightsManagementServicesAllowed property value. Specifies whether to allow Azure RMS encryption for WIP
     * @param value Value to set for the azureRightsManagementServicesAllowed property.
     */
    set azureRightsManagementServicesAllowed(value: boolean | undefined);
    /**
     * Instantiates a new windowsInformationProtection and sets the default values.
     */
    constructor();
    /**
     * Gets the dataRecoveryCertificate property value. Specifies a recovery certificate that can be used for data recovery of encrypted files. This is the same as the data recovery agent(DRA) certificate for encrypting file system(EFS)
     * @returns a windowsInformationProtectionDataRecoveryCertificate
     */
    get dataRecoveryCertificate(): WindowsInformationProtectionDataRecoveryCertificate | undefined;
    /**
     * Sets the dataRecoveryCertificate property value. Specifies a recovery certificate that can be used for data recovery of encrypted files. This is the same as the data recovery agent(DRA) certificate for encrypting file system(EFS)
     * @param value Value to set for the dataRecoveryCertificate property.
     */
    set dataRecoveryCertificate(value: WindowsInformationProtectionDataRecoveryCertificate | undefined);
    /**
     * Gets the enforcementLevel property value. WIP enforcement level.See the Enum definition for supported values. Possible values are: noProtection, encryptAndAuditOnly, encryptAuditAndPrompt, encryptAuditAndBlock.
     * @returns a windowsInformationProtectionEnforcementLevel
     */
    get enforcementLevel(): WindowsInformationProtectionEnforcementLevel | undefined;
    /**
     * Sets the enforcementLevel property value. WIP enforcement level.See the Enum definition for supported values. Possible values are: noProtection, encryptAndAuditOnly, encryptAuditAndPrompt, encryptAuditAndBlock.
     * @param value Value to set for the enforcementLevel property.
     */
    set enforcementLevel(value: WindowsInformationProtectionEnforcementLevel | undefined);
    /**
     * Gets the enterpriseDomain property value. Primary enterprise domain
     * @returns a string
     */
    get enterpriseDomain(): string | undefined;
    /**
     * Sets the enterpriseDomain property value. Primary enterprise domain
     * @param value Value to set for the enterpriseDomain property.
     */
    set enterpriseDomain(value: string | undefined);
    /**
     * Gets the enterpriseInternalProxyServers property value. This is the comma-separated list of internal proxy servers. For example, '157.54.14.28, 157.54.11.118, 10.202.14.167, 157.53.14.163, 157.69.210.59'. These proxies have been configured by the admin to connect to specific resources on the Internet. They are considered to be enterprise network locations. The proxies are only leveraged in configuring the EnterpriseProxiedDomains policy to force traffic to the matched domains through these proxies
     * @returns a windowsInformationProtectionResourceCollection
     */
    get enterpriseInternalProxyServers(): WindowsInformationProtectionResourceCollection[] | undefined;
    /**
     * Sets the enterpriseInternalProxyServers property value. This is the comma-separated list of internal proxy servers. For example, '157.54.14.28, 157.54.11.118, 10.202.14.167, 157.53.14.163, 157.69.210.59'. These proxies have been configured by the admin to connect to specific resources on the Internet. They are considered to be enterprise network locations. The proxies are only leveraged in configuring the EnterpriseProxiedDomains policy to force traffic to the matched domains through these proxies
     * @param value Value to set for the enterpriseInternalProxyServers property.
     */
    set enterpriseInternalProxyServers(value: WindowsInformationProtectionResourceCollection[] | undefined);
    /**
     * Gets the enterpriseIPRanges property value. Sets the enterprise IP ranges that define the computers in the enterprise network. Data that comes from those computers will be considered part of the enterprise and protected. These locations will be considered a safe destination for enterprise data to be shared to
     * @returns a windowsInformationProtectionIPRangeCollection
     */
    get enterpriseIPRanges(): WindowsInformationProtectionIPRangeCollection[] | undefined;
    /**
     * Sets the enterpriseIPRanges property value. Sets the enterprise IP ranges that define the computers in the enterprise network. Data that comes from those computers will be considered part of the enterprise and protected. These locations will be considered a safe destination for enterprise data to be shared to
     * @param value Value to set for the enterpriseIPRanges property.
     */
    set enterpriseIPRanges(value: WindowsInformationProtectionIPRangeCollection[] | undefined);
    /**
     * Gets the enterpriseIPRangesAreAuthoritative property value. Boolean value that tells the client to accept the configured list and not to use heuristics to attempt to find other subnets. Default is false
     * @returns a boolean
     */
    get enterpriseIPRangesAreAuthoritative(): boolean | undefined;
    /**
     * Sets the enterpriseIPRangesAreAuthoritative property value. Boolean value that tells the client to accept the configured list and not to use heuristics to attempt to find other subnets. Default is false
     * @param value Value to set for the enterpriseIPRangesAreAuthoritative property.
     */
    set enterpriseIPRangesAreAuthoritative(value: boolean | undefined);
    /**
     * Gets the enterpriseNetworkDomainNames property value. This is the list of domains that comprise the boundaries of the enterprise. Data from one of these domains that is sent to a device will be considered enterprise data and protected These locations will be considered a safe destination for enterprise data to be shared to
     * @returns a windowsInformationProtectionResourceCollection
     */
    get enterpriseNetworkDomainNames(): WindowsInformationProtectionResourceCollection[] | undefined;
    /**
     * Sets the enterpriseNetworkDomainNames property value. This is the list of domains that comprise the boundaries of the enterprise. Data from one of these domains that is sent to a device will be considered enterprise data and protected These locations will be considered a safe destination for enterprise data to be shared to
     * @param value Value to set for the enterpriseNetworkDomainNames property.
     */
    set enterpriseNetworkDomainNames(value: WindowsInformationProtectionResourceCollection[] | undefined);
    /**
     * Gets the enterpriseProtectedDomainNames property value. List of enterprise domains to be protected
     * @returns a windowsInformationProtectionResourceCollection
     */
    get enterpriseProtectedDomainNames(): WindowsInformationProtectionResourceCollection[] | undefined;
    /**
     * Sets the enterpriseProtectedDomainNames property value. List of enterprise domains to be protected
     * @param value Value to set for the enterpriseProtectedDomainNames property.
     */
    set enterpriseProtectedDomainNames(value: WindowsInformationProtectionResourceCollection[] | undefined);
    /**
     * Gets the enterpriseProxiedDomains property value. Contains a list of Enterprise resource domains hosted in the cloud that need to be protected. Connections to these resources are considered enterprise data. If a proxy is paired with a cloud resource, traffic to the cloud resource will be routed through the enterprise network via the denoted proxy server (on Port 80). A proxy server used for this purpose must also be configured using the EnterpriseInternalProxyServers policy
     * @returns a windowsInformationProtectionProxiedDomainCollection
     */
    get enterpriseProxiedDomains(): WindowsInformationProtectionProxiedDomainCollection[] | undefined;
    /**
     * Sets the enterpriseProxiedDomains property value. Contains a list of Enterprise resource domains hosted in the cloud that need to be protected. Connections to these resources are considered enterprise data. If a proxy is paired with a cloud resource, traffic to the cloud resource will be routed through the enterprise network via the denoted proxy server (on Port 80). A proxy server used for this purpose must also be configured using the EnterpriseInternalProxyServers policy
     * @param value Value to set for the enterpriseProxiedDomains property.
     */
    set enterpriseProxiedDomains(value: WindowsInformationProtectionProxiedDomainCollection[] | undefined);
    /**
     * Gets the enterpriseProxyServers property value. This is a list of proxy servers. Any server not on this list is considered non-enterprise
     * @returns a windowsInformationProtectionResourceCollection
     */
    get enterpriseProxyServers(): WindowsInformationProtectionResourceCollection[] | undefined;
    /**
     * Sets the enterpriseProxyServers property value. This is a list of proxy servers. Any server not on this list is considered non-enterprise
     * @param value Value to set for the enterpriseProxyServers property.
     */
    set enterpriseProxyServers(value: WindowsInformationProtectionResourceCollection[] | undefined);
    /**
     * Gets the enterpriseProxyServersAreAuthoritative property value. Boolean value that tells the client to accept the configured list of proxies and not try to detect other work proxies. Default is false
     * @returns a boolean
     */
    get enterpriseProxyServersAreAuthoritative(): boolean | undefined;
    /**
     * Sets the enterpriseProxyServersAreAuthoritative property value. Boolean value that tells the client to accept the configured list of proxies and not try to detect other work proxies. Default is false
     * @param value Value to set for the enterpriseProxyServersAreAuthoritative property.
     */
    set enterpriseProxyServersAreAuthoritative(value: boolean | undefined);
    /**
     * Gets the exemptAppLockerFiles property value. Another way to input exempt apps through xml files
     * @returns a windowsInformationProtectionAppLockerFile
     */
    get exemptAppLockerFiles(): WindowsInformationProtectionAppLockerFile[] | undefined;
    /**
     * Sets the exemptAppLockerFiles property value. Another way to input exempt apps through xml files
     * @param value Value to set for the exemptAppLockerFiles property.
     */
    set exemptAppLockerFiles(value: WindowsInformationProtectionAppLockerFile[] | undefined);
    /**
     * Gets the exemptApps property value. Exempt applications can also access enterprise data, but the data handled by those applications are not protected. This is because some critical enterprise applications may have compatibility problems with encrypted data.
     * @returns a windowsInformationProtectionApp
     */
    get exemptApps(): WindowsInformationProtectionApp[] | undefined;
    /**
     * Sets the exemptApps property value. Exempt applications can also access enterprise data, but the data handled by those applications are not protected. This is because some critical enterprise applications may have compatibility problems with encrypted data.
     * @param value Value to set for the exemptApps property.
     */
    set exemptApps(value: WindowsInformationProtectionApp[] | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the iconsVisible property value. Determines whether overlays are added to icons for WIP protected files in Explorer and enterprise only app tiles in the Start menu. Starting in Windows 10, version 1703 this setting also configures the visibility of the WIP icon in the title bar of a WIP-protected app
     * @returns a boolean
     */
    get iconsVisible(): boolean | undefined;
    /**
     * Sets the iconsVisible property value. Determines whether overlays are added to icons for WIP protected files in Explorer and enterprise only app tiles in the Start menu. Starting in Windows 10, version 1703 this setting also configures the visibility of the WIP icon in the title bar of a WIP-protected app
     * @param value Value to set for the iconsVisible property.
     */
    set iconsVisible(value: boolean | undefined);
    /**
     * Gets the indexingEncryptedStoresOrItemsBlocked property value. This switch is for the Windows Search Indexer, to allow or disallow indexing of items
     * @returns a boolean
     */
    get indexingEncryptedStoresOrItemsBlocked(): boolean | undefined;
    /**
     * Sets the indexingEncryptedStoresOrItemsBlocked property value. This switch is for the Windows Search Indexer, to allow or disallow indexing of items
     * @param value Value to set for the indexingEncryptedStoresOrItemsBlocked property.
     */
    set indexingEncryptedStoresOrItemsBlocked(value: boolean | undefined);
    /**
     * Gets the isAssigned property value. Indicates if the policy is deployed to any inclusion groups or not.
     * @returns a boolean
     */
    get isAssigned(): boolean | undefined;
    /**
     * Sets the isAssigned property value. Indicates if the policy is deployed to any inclusion groups or not.
     * @param value Value to set for the isAssigned property.
     */
    set isAssigned(value: boolean | undefined);
    /**
     * Gets the neutralDomainResources property value. List of domain names that can used for work or personal resource
     * @returns a windowsInformationProtectionResourceCollection
     */
    get neutralDomainResources(): WindowsInformationProtectionResourceCollection[] | undefined;
    /**
     * Sets the neutralDomainResources property value. List of domain names that can used for work or personal resource
     * @param value Value to set for the neutralDomainResources property.
     */
    set neutralDomainResources(value: WindowsInformationProtectionResourceCollection[] | undefined);
    /**
     * Gets the protectedAppLockerFiles property value. Another way to input protected apps through xml files
     * @returns a windowsInformationProtectionAppLockerFile
     */
    get protectedAppLockerFiles(): WindowsInformationProtectionAppLockerFile[] | undefined;
    /**
     * Sets the protectedAppLockerFiles property value. Another way to input protected apps through xml files
     * @param value Value to set for the protectedAppLockerFiles property.
     */
    set protectedAppLockerFiles(value: WindowsInformationProtectionAppLockerFile[] | undefined);
    /**
     * Gets the protectedApps property value. Protected applications can access enterprise data and the data handled by those applications are protected with encryption
     * @returns a windowsInformationProtectionApp
     */
    get protectedApps(): WindowsInformationProtectionApp[] | undefined;
    /**
     * Sets the protectedApps property value. Protected applications can access enterprise data and the data handled by those applications are protected with encryption
     * @param value Value to set for the protectedApps property.
     */
    set protectedApps(value: WindowsInformationProtectionApp[] | undefined);
    /**
     * Gets the protectionUnderLockConfigRequired property value. Specifies whether the protection under lock feature (also known as encrypt under pin) should be configured
     * @returns a boolean
     */
    get protectionUnderLockConfigRequired(): boolean | undefined;
    /**
     * Sets the protectionUnderLockConfigRequired property value. Specifies whether the protection under lock feature (also known as encrypt under pin) should be configured
     * @param value Value to set for the protectionUnderLockConfigRequired property.
     */
    set protectionUnderLockConfigRequired(value: boolean | undefined);
    /**
     * Gets the revokeOnUnenrollDisabled property value. This policy controls whether to revoke the WIP keys when a device unenrolls from the management service. If set to 1 (Don't revoke keys), the keys will not be revoked and the user will continue to have access to protected files after unenrollment. If the keys are not revoked, there will be no revoked file cleanup subsequently.
     * @returns a boolean
     */
    get revokeOnUnenrollDisabled(): boolean | undefined;
    /**
     * Sets the revokeOnUnenrollDisabled property value. This policy controls whether to revoke the WIP keys when a device unenrolls from the management service. If set to 1 (Don't revoke keys), the keys will not be revoked and the user will continue to have access to protected files after unenrollment. If the keys are not revoked, there will be no revoked file cleanup subsequently.
     * @param value Value to set for the revokeOnUnenrollDisabled property.
     */
    set revokeOnUnenrollDisabled(value: boolean | undefined);
    /**
     * Gets the rightsManagementServicesTemplateId property value. TemplateID GUID to use for RMS encryption. The RMS template allows the IT admin to configure the details about who has access to RMS-protected file and how long they have access
     * @returns a string
     */
    get rightsManagementServicesTemplateId(): string | undefined;
    /**
     * Sets the rightsManagementServicesTemplateId property value. TemplateID GUID to use for RMS encryption. The RMS template allows the IT admin to configure the details about who has access to RMS-protected file and how long they have access
     * @param value Value to set for the rightsManagementServicesTemplateId property.
     */
    set rightsManagementServicesTemplateId(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the smbAutoEncryptedFileExtensions property value. Specifies a list of file extensions, so that files with these extensions are encrypted when copying from an SMB share within the corporate boundary
     * @returns a windowsInformationProtectionResourceCollection
     */
    get smbAutoEncryptedFileExtensions(): WindowsInformationProtectionResourceCollection[] | undefined;
    /**
     * Sets the smbAutoEncryptedFileExtensions property value. Specifies a list of file extensions, so that files with these extensions are encrypted when copying from an SMB share within the corporate boundary
     * @param value Value to set for the smbAutoEncryptedFileExtensions property.
     */
    set smbAutoEncryptedFileExtensions(value: WindowsInformationProtectionResourceCollection[] | undefined);
}
