import { Entity, WorkbookChartAreaFormat, WorkbookChartAxes, WorkbookChartDataLabels, WorkbookChartLegend, WorkbookChartSeries, WorkbookChartTitle, WorkbookWorksheet } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class WorkbookChart extends Entity implements Parsable {
    /** Represents chart axes. Read-only.  */
    private _axes?;
    /** Represents the datalabels on the chart. Read-only.  */
    private _dataLabels?;
    /** Encapsulates the format properties for the chart area. Read-only.  */
    private _format?;
    /** Represents the height, in points, of the chart object.  */
    private _height?;
    /** The distance, in points, from the left side of the chart to the worksheet origin.  */
    private _left?;
    /** Represents the legend for the chart. Read-only.  */
    private _legend?;
    /** Represents the name of a chart object.  */
    private _name?;
    /** Represents either a single series or collection of series in the chart. Read-only.  */
    private _series?;
    /** Represents the title of the specified chart, including the text, visibility, position and formating of the title. Read-only.  */
    private _title?;
    /** Represents the distance, in points, from the top edge of the object to the top of row 1 (on a worksheet) or the top of the chart area (on a chart).  */
    private _top?;
    /** Represents the width, in points, of the chart object.  */
    private _width?;
    /** The worksheet containing the current chart. Read-only.  */
    private _worksheet?;
    /**
     * Gets the axes property value. Represents chart axes. Read-only.
     * @returns a workbookChartAxes
     */
    get axes(): WorkbookChartAxes | undefined;
    /**
     * Sets the axes property value. Represents chart axes. Read-only.
     * @param value Value to set for the axes property.
     */
    set axes(value: WorkbookChartAxes | undefined);
    /**
     * Instantiates a new workbookChart and sets the default values.
     */
    constructor();
    /**
     * Gets the dataLabels property value. Represents the datalabels on the chart. Read-only.
     * @returns a workbookChartDataLabels
     */
    get dataLabels(): WorkbookChartDataLabels | undefined;
    /**
     * Sets the dataLabels property value. Represents the datalabels on the chart. Read-only.
     * @param value Value to set for the dataLabels property.
     */
    set dataLabels(value: WorkbookChartDataLabels | undefined);
    /**
     * Gets the format property value. Encapsulates the format properties for the chart area. Read-only.
     * @returns a workbookChartAreaFormat
     */
    get format(): WorkbookChartAreaFormat | undefined;
    /**
     * Sets the format property value. Encapsulates the format properties for the chart area. Read-only.
     * @param value Value to set for the format property.
     */
    set format(value: WorkbookChartAreaFormat | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the height property value. Represents the height, in points, of the chart object.
     * @returns a double
     */
    get height(): number | undefined;
    /**
     * Sets the height property value. Represents the height, in points, of the chart object.
     * @param value Value to set for the height property.
     */
    set height(value: number | undefined);
    /**
     * Gets the left property value. The distance, in points, from the left side of the chart to the worksheet origin.
     * @returns a double
     */
    get left(): number | undefined;
    /**
     * Sets the left property value. The distance, in points, from the left side of the chart to the worksheet origin.
     * @param value Value to set for the left property.
     */
    set left(value: number | undefined);
    /**
     * Gets the legend property value. Represents the legend for the chart. Read-only.
     * @returns a workbookChartLegend
     */
    get legend(): WorkbookChartLegend | undefined;
    /**
     * Sets the legend property value. Represents the legend for the chart. Read-only.
     * @param value Value to set for the legend property.
     */
    set legend(value: WorkbookChartLegend | undefined);
    /**
     * Gets the name property value. Represents the name of a chart object.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. Represents the name of a chart object.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the series property value. Represents either a single series or collection of series in the chart. Read-only.
     * @returns a workbookChartSeries
     */
    get series(): WorkbookChartSeries[] | undefined;
    /**
     * Sets the series property value. Represents either a single series or collection of series in the chart. Read-only.
     * @param value Value to set for the series property.
     */
    set series(value: WorkbookChartSeries[] | undefined);
    /**
     * Gets the title property value. Represents the title of the specified chart, including the text, visibility, position and formating of the title. Read-only.
     * @returns a workbookChartTitle
     */
    get title(): WorkbookChartTitle | undefined;
    /**
     * Sets the title property value. Represents the title of the specified chart, including the text, visibility, position and formating of the title. Read-only.
     * @param value Value to set for the title property.
     */
    set title(value: WorkbookChartTitle | undefined);
    /**
     * Gets the top property value. Represents the distance, in points, from the top edge of the object to the top of row 1 (on a worksheet) or the top of the chart area (on a chart).
     * @returns a double
     */
    get top(): number | undefined;
    /**
     * Sets the top property value. Represents the distance, in points, from the top edge of the object to the top of row 1 (on a worksheet) or the top of the chart area (on a chart).
     * @param value Value to set for the top property.
     */
    set top(value: number | undefined);
    /**
     * Gets the width property value. Represents the width, in points, of the chart object.
     * @returns a double
     */
    get width(): number | undefined;
    /**
     * Sets the width property value. Represents the width, in points, of the chart object.
     * @param value Value to set for the width property.
     */
    set width(value: number | undefined);
    /**
     * Gets the worksheet property value. The worksheet containing the current chart. Read-only.
     * @returns a workbookWorksheet
     */
    get worksheet(): WorkbookWorksheet | undefined;
    /**
     * Sets the worksheet property value. The worksheet containing the current chart. Read-only.
     * @param value Value to set for the worksheet property.
     */
    set worksheet(value: WorkbookWorksheet | undefined);
}
