import { Entity, Json, WorkbookWorksheet } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class WorkbookNamedItem extends Entity implements Parsable {
    /** Represents the comment associated with this name.  */
    private _comment?;
    /** The name of the object. Read-only.  */
    private _name?;
    /** Indicates whether the name is scoped to the workbook or to a specific worksheet. Read-only.  */
    private _scope?;
    /** Indicates what type of reference is associated with the name. The possible values are: String, Integer, Double, Boolean, Range. Read-only.  */
    private _type?;
    /** Represents the formula that the name is defined to refer to. E.g. =Sheet14!$B$2:$H$12, =4.75, etc. Read-only.  */
    private _value?;
    /** Specifies whether the object is visible or not.  */
    private _visible?;
    /** Returns the worksheet on which the named item is scoped to. Available only if the item is scoped to the worksheet. Read-only.  */
    private _worksheet?;
    /**
     * Gets the comment property value. Represents the comment associated with this name.
     * @returns a string
     */
    get comment(): string | undefined;
    /**
     * Sets the comment property value. Represents the comment associated with this name.
     * @param value Value to set for the comment property.
     */
    set comment(value: string | undefined);
    /**
     * Instantiates a new workbookNamedItem and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the name property value. The name of the object. Read-only.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The name of the object. Read-only.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the scope property value. Indicates whether the name is scoped to the workbook or to a specific worksheet. Read-only.
     * @returns a string
     */
    get scope(): string | undefined;
    /**
     * Sets the scope property value. Indicates whether the name is scoped to the workbook or to a specific worksheet. Read-only.
     * @param value Value to set for the scope property.
     */
    set scope(value: string | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the type property value. Indicates what type of reference is associated with the name. The possible values are: String, Integer, Double, Boolean, Range. Read-only.
     * @returns a string
     */
    get type(): string | undefined;
    /**
     * Sets the type property value. Indicates what type of reference is associated with the name. The possible values are: String, Integer, Double, Boolean, Range. Read-only.
     * @param value Value to set for the type property.
     */
    set type(value: string | undefined);
    /**
     * Gets the value property value. Represents the formula that the name is defined to refer to. E.g. =Sheet14!$B$2:$H$12, =4.75, etc. Read-only.
     * @returns a Json
     */
    get value(): Json | undefined;
    /**
     * Sets the value property value. Represents the formula that the name is defined to refer to. E.g. =Sheet14!$B$2:$H$12, =4.75, etc. Read-only.
     * @param value Value to set for the value property.
     */
    set value(value: Json | undefined);
    /**
     * Gets the visible property value. Specifies whether the object is visible or not.
     * @returns a boolean
     */
    get visible(): boolean | undefined;
    /**
     * Sets the visible property value. Specifies whether the object is visible or not.
     * @param value Value to set for the visible property.
     */
    set visible(value: boolean | undefined);
    /**
     * Gets the worksheet property value. Returns the worksheet on which the named item is scoped to. Available only if the item is scoped to the worksheet. Read-only.
     * @returns a workbookWorksheet
     */
    get worksheet(): WorkbookWorksheet | undefined;
    /**
     * Sets the worksheet property value. Returns the worksheet on which the named item is scoped to. Available only if the item is scoped to the worksheet. Read-only.
     * @param value Value to set for the worksheet property.
     */
    set worksheet(value: WorkbookWorksheet | undefined);
}
