import { Entity, WorkbookTableColumn, WorkbookTableRow, WorkbookTableSort, WorkbookWorksheet } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class WorkbookTable extends Entity implements Parsable {
    /** Represents a collection of all the columns in the table. Read-only.  */
    private _columns?;
    /** Indicates whether the first column contains special formatting.  */
    private _highlightFirstColumn?;
    /** Indicates whether the last column contains special formatting.  */
    private _highlightLastColumn?;
    /** Legacy Id used in older Excle clients. The value of the identifier remains the same even when the table is renamed. This property should be interpreted as an opaque string value and should not be parsed to any other type. Read-only.  */
    private _legacyId?;
    /** Name of the table.  */
    private _name?;
    /** Represents a collection of all the rows in the table. Read-only.  */
    private _rows?;
    /** Indicates whether the columns show banded formatting in which odd columns are highlighted differently from even ones to make reading the table easier.  */
    private _showBandedColumns?;
    /** Indicates whether the rows show banded formatting in which odd rows are highlighted differently from even ones to make reading the table easier.  */
    private _showBandedRows?;
    /** Indicates whether the filter buttons are visible at the top of each column header. Setting this is only allowed if the table contains a header row.  */
    private _showFilterButton?;
    /** Indicates whether the header row is visible or not. This value can be set to show or remove the header row.  */
    private _showHeaders?;
    /** Indicates whether the total row is visible or not. This value can be set to show or remove the total row.  */
    private _showTotals?;
    /** Represents the sorting for the table. Read-only.  */
    private _sort?;
    /** Constant value that represents the Table style. The possible values are: TableStyleLight1 thru TableStyleLight21, TableStyleMedium1 thru TableStyleMedium28, TableStyleStyleDark1 thru TableStyleStyleDark11. A custom user-defined style present in the workbook can also be specified.  */
    private _style?;
    /** The worksheet containing the current table. Read-only.  */
    private _worksheet?;
    /**
     * Gets the columns property value. Represents a collection of all the columns in the table. Read-only.
     * @returns a workbookTableColumn
     */
    get columns(): WorkbookTableColumn[] | undefined;
    /**
     * Sets the columns property value. Represents a collection of all the columns in the table. Read-only.
     * @param value Value to set for the columns property.
     */
    set columns(value: WorkbookTableColumn[] | undefined);
    /**
     * Instantiates a new workbookTable and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the highlightFirstColumn property value. Indicates whether the first column contains special formatting.
     * @returns a boolean
     */
    get highlightFirstColumn(): boolean | undefined;
    /**
     * Sets the highlightFirstColumn property value. Indicates whether the first column contains special formatting.
     * @param value Value to set for the highlightFirstColumn property.
     */
    set highlightFirstColumn(value: boolean | undefined);
    /**
     * Gets the highlightLastColumn property value. Indicates whether the last column contains special formatting.
     * @returns a boolean
     */
    get highlightLastColumn(): boolean | undefined;
    /**
     * Sets the highlightLastColumn property value. Indicates whether the last column contains special formatting.
     * @param value Value to set for the highlightLastColumn property.
     */
    set highlightLastColumn(value: boolean | undefined);
    /**
     * Gets the legacyId property value. Legacy Id used in older Excle clients. The value of the identifier remains the same even when the table is renamed. This property should be interpreted as an opaque string value and should not be parsed to any other type. Read-only.
     * @returns a string
     */
    get legacyId(): string | undefined;
    /**
     * Sets the legacyId property value. Legacy Id used in older Excle clients. The value of the identifier remains the same even when the table is renamed. This property should be interpreted as an opaque string value and should not be parsed to any other type. Read-only.
     * @param value Value to set for the legacyId property.
     */
    set legacyId(value: string | undefined);
    /**
     * Gets the name property value. Name of the table.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. Name of the table.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the rows property value. Represents a collection of all the rows in the table. Read-only.
     * @returns a workbookTableRow
     */
    get rows(): WorkbookTableRow[] | undefined;
    /**
     * Sets the rows property value. Represents a collection of all the rows in the table. Read-only.
     * @param value Value to set for the rows property.
     */
    set rows(value: WorkbookTableRow[] | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the showBandedColumns property value. Indicates whether the columns show banded formatting in which odd columns are highlighted differently from even ones to make reading the table easier.
     * @returns a boolean
     */
    get showBandedColumns(): boolean | undefined;
    /**
     * Sets the showBandedColumns property value. Indicates whether the columns show banded formatting in which odd columns are highlighted differently from even ones to make reading the table easier.
     * @param value Value to set for the showBandedColumns property.
     */
    set showBandedColumns(value: boolean | undefined);
    /**
     * Gets the showBandedRows property value. Indicates whether the rows show banded formatting in which odd rows are highlighted differently from even ones to make reading the table easier.
     * @returns a boolean
     */
    get showBandedRows(): boolean | undefined;
    /**
     * Sets the showBandedRows property value. Indicates whether the rows show banded formatting in which odd rows are highlighted differently from even ones to make reading the table easier.
     * @param value Value to set for the showBandedRows property.
     */
    set showBandedRows(value: boolean | undefined);
    /**
     * Gets the showFilterButton property value. Indicates whether the filter buttons are visible at the top of each column header. Setting this is only allowed if the table contains a header row.
     * @returns a boolean
     */
    get showFilterButton(): boolean | undefined;
    /**
     * Sets the showFilterButton property value. Indicates whether the filter buttons are visible at the top of each column header. Setting this is only allowed if the table contains a header row.
     * @param value Value to set for the showFilterButton property.
     */
    set showFilterButton(value: boolean | undefined);
    /**
     * Gets the showHeaders property value. Indicates whether the header row is visible or not. This value can be set to show or remove the header row.
     * @returns a boolean
     */
    get showHeaders(): boolean | undefined;
    /**
     * Sets the showHeaders property value. Indicates whether the header row is visible or not. This value can be set to show or remove the header row.
     * @param value Value to set for the showHeaders property.
     */
    set showHeaders(value: boolean | undefined);
    /**
     * Gets the showTotals property value. Indicates whether the total row is visible or not. This value can be set to show or remove the total row.
     * @returns a boolean
     */
    get showTotals(): boolean | undefined;
    /**
     * Sets the showTotals property value. Indicates whether the total row is visible or not. This value can be set to show or remove the total row.
     * @param value Value to set for the showTotals property.
     */
    set showTotals(value: boolean | undefined);
    /**
     * Gets the sort property value. Represents the sorting for the table. Read-only.
     * @returns a workbookTableSort
     */
    get sort(): WorkbookTableSort | undefined;
    /**
     * Sets the sort property value. Represents the sorting for the table. Read-only.
     * @param value Value to set for the sort property.
     */
    set sort(value: WorkbookTableSort | undefined);
    /**
     * Gets the style property value. Constant value that represents the Table style. The possible values are: TableStyleLight1 thru TableStyleLight21, TableStyleMedium1 thru TableStyleMedium28, TableStyleStyleDark1 thru TableStyleStyleDark11. A custom user-defined style present in the workbook can also be specified.
     * @returns a string
     */
    get style(): string | undefined;
    /**
     * Sets the style property value. Constant value that represents the Table style. The possible values are: TableStyleLight1 thru TableStyleLight21, TableStyleMedium1 thru TableStyleMedium28, TableStyleStyleDark1 thru TableStyleStyleDark11. A custom user-defined style present in the workbook can also be specified.
     * @param value Value to set for the style property.
     */
    set style(value: string | undefined);
    /**
     * Gets the worksheet property value. The worksheet containing the current table. Read-only.
     * @returns a workbookWorksheet
     */
    get worksheet(): WorkbookWorksheet | undefined;
    /**
     * Sets the worksheet property value. The worksheet containing the current table. Read-only.
     * @param value Value to set for the worksheet property.
     */
    set worksheet(value: WorkbookWorksheet | undefined);
}
