import { Entity, WorkbookChart, WorkbookNamedItem, WorkbookPivotTable, WorkbookTable, WorkbookWorksheetProtection } from './index';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class WorkbookWorksheet extends Entity implements Parsable {
    /** Returns collection of charts that are part of the worksheet. Read-only.  */
    private _charts?;
    /** The display name of the worksheet.  */
    private _name?;
    /** Returns collection of names that are associated with the worksheet. Read-only.  */
    private _names?;
    /** Collection of PivotTables that are part of the worksheet.  */
    private _pivotTables?;
    /** The zero-based position of the worksheet within the workbook.  */
    private _position?;
    /** Returns sheet protection object for a worksheet. Read-only.  */
    private _protection?;
    /** Collection of tables that are part of the worksheet. Read-only.  */
    private _tables?;
    /** The Visibility of the worksheet. The possible values are: Visible, Hidden, VeryHidden.  */
    private _visibility?;
    /**
     * Gets the charts property value. Returns collection of charts that are part of the worksheet. Read-only.
     * @returns a workbookChart
     */
    get charts(): WorkbookChart[] | undefined;
    /**
     * Sets the charts property value. Returns collection of charts that are part of the worksheet. Read-only.
     * @param value Value to set for the charts property.
     */
    set charts(value: WorkbookChart[] | undefined);
    /**
     * Instantiates a new workbookWorksheet and sets the default values.
     */
    constructor();
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the name property value. The display name of the worksheet.
     * @returns a string
     */
    get name(): string | undefined;
    /**
     * Sets the name property value. The display name of the worksheet.
     * @param value Value to set for the name property.
     */
    set name(value: string | undefined);
    /**
     * Gets the names property value. Returns collection of names that are associated with the worksheet. Read-only.
     * @returns a workbookNamedItem
     */
    get names(): WorkbookNamedItem[] | undefined;
    /**
     * Sets the names property value. Returns collection of names that are associated with the worksheet. Read-only.
     * @param value Value to set for the names property.
     */
    set names(value: WorkbookNamedItem[] | undefined);
    /**
     * Gets the pivotTables property value. Collection of PivotTables that are part of the worksheet.
     * @returns a workbookPivotTable
     */
    get pivotTables(): WorkbookPivotTable[] | undefined;
    /**
     * Sets the pivotTables property value. Collection of PivotTables that are part of the worksheet.
     * @param value Value to set for the pivotTables property.
     */
    set pivotTables(value: WorkbookPivotTable[] | undefined);
    /**
     * Gets the position property value. The zero-based position of the worksheet within the workbook.
     * @returns a integer
     */
    get position(): number | undefined;
    /**
     * Sets the position property value. The zero-based position of the worksheet within the workbook.
     * @param value Value to set for the position property.
     */
    set position(value: number | undefined);
    /**
     * Gets the protection property value. Returns sheet protection object for a worksheet. Read-only.
     * @returns a workbookWorksheetProtection
     */
    get protection(): WorkbookWorksheetProtection | undefined;
    /**
     * Sets the protection property value. Returns sheet protection object for a worksheet. Read-only.
     * @param value Value to set for the protection property.
     */
    set protection(value: WorkbookWorksheetProtection | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the tables property value. Collection of tables that are part of the worksheet. Read-only.
     * @returns a workbookTable
     */
    get tables(): WorkbookTable[] | undefined;
    /**
     * Sets the tables property value. Collection of tables that are part of the worksheet. Read-only.
     * @param value Value to set for the tables property.
     */
    set tables(value: WorkbookTable[] | undefined);
    /**
     * Gets the visibility property value. The Visibility of the worksheet. The possible values are: Visible, Hidden, VeryHidden.
     * @returns a string
     */
    get visibility(): string | undefined;
    /**
     * Sets the visibility property value. The Visibility of the worksheet. The possible values are: Visible, Hidden, VeryHidden.
     * @param value Value to set for the visibility property.
     */
    set visibility(value: string | undefined);
}
