import { ChangeTrackedEntity, WorkforceIntegrationEncryption } from './index';
import { WorkforceIntegrationSupportedEntities } from './workforceIntegrationSupportedEntities';
import { Parsable, ParseNode, SerializationWriter } from '@microsoft/kiota-abstractions';
export declare class WorkforceIntegration extends ChangeTrackedEntity implements Parsable {
    /** API version for the call back URL. Start with 1.  */
    private _apiVersion?;
    /** Name of the workforce integration.  */
    private _displayName?;
    /** The workforce integration encryption resource.  */
    private _encryption?;
    /** Indicates whether this workforce integration is currently active and available.  */
    private _isActive?;
    /** The Shifts entities supported for synchronous change notifications. Shifts will make a call back to the url provided on client changes on those entities added here. By default, no entities are supported for change notifications. Possible values are: none, shift, swapRequest, userShiftPreferences, openshift, openShiftRequest, offerShiftRequest, unknownFutureValue.  */
    private _supportedEntities?;
    /** Workforce Integration URL for callbacks from the Shifts service.  */
    private _url?;
    /**
     * Gets the apiVersion property value. API version for the call back URL. Start with 1.
     * @returns a integer
     */
    get apiVersion(): number | undefined;
    /**
     * Sets the apiVersion property value. API version for the call back URL. Start with 1.
     * @param value Value to set for the apiVersion property.
     */
    set apiVersion(value: number | undefined);
    /**
     * Instantiates a new workforceIntegration and sets the default values.
     */
    constructor();
    /**
     * Gets the displayName property value. Name of the workforce integration.
     * @returns a string
     */
    get displayName(): string | undefined;
    /**
     * Sets the displayName property value. Name of the workforce integration.
     * @param value Value to set for the displayName property.
     */
    set displayName(value: string | undefined);
    /**
     * Gets the encryption property value. The workforce integration encryption resource.
     * @returns a workforceIntegrationEncryption
     */
    get encryption(): WorkforceIntegrationEncryption | undefined;
    /**
     * Sets the encryption property value. The workforce integration encryption resource.
     * @param value Value to set for the encryption property.
     */
    set encryption(value: WorkforceIntegrationEncryption | undefined);
    /**
     * The deserialization information for the current model
     * @returns a Record<string, (item: T, node: ParseNode) => void>
     */
    getFieldDeserializers<T>(): Record<string, (item: T, node: ParseNode) => void>;
    /**
     * Gets the isActive property value. Indicates whether this workforce integration is currently active and available.
     * @returns a boolean
     */
    get isActive(): boolean | undefined;
    /**
     * Sets the isActive property value. Indicates whether this workforce integration is currently active and available.
     * @param value Value to set for the isActive property.
     */
    set isActive(value: boolean | undefined);
    /**
     * Serializes information the current object
     * @param writer Serialization writer to use to serialize this model
     */
    serialize(writer: SerializationWriter): void;
    /**
     * Gets the supportedEntities property value. The Shifts entities supported for synchronous change notifications. Shifts will make a call back to the url provided on client changes on those entities added here. By default, no entities are supported for change notifications. Possible values are: none, shift, swapRequest, userShiftPreferences, openshift, openShiftRequest, offerShiftRequest, unknownFutureValue.
     * @returns a workforceIntegrationSupportedEntities
     */
    get supportedEntities(): WorkforceIntegrationSupportedEntities | undefined;
    /**
     * Sets the supportedEntities property value. The Shifts entities supported for synchronous change notifications. Shifts will make a call back to the url provided on client changes on those entities added here. By default, no entities are supported for change notifications. Possible values are: none, shift, swapRequest, userShiftPreferences, openshift, openShiftRequest, offerShiftRequest, unknownFutureValue.
     * @param value Value to set for the supportedEntities property.
     */
    set supportedEntities(value: WorkforceIntegrationSupportedEntities | undefined);
    /**
     * Gets the url property value. Workforce Integration URL for callbacks from the Shifts service.
     * @returns a string
     */
    get url(): string | undefined;
    /**
     * Sets the url property value. Workforce Integration URL for callbacks from the Shifts service.
     * @param value Value to set for the url property.
     */
    set url(value: string | undefined);
}
