import { OrganizationalBranding } from '../../../models/microsoft/graph/';
import { BackgroundImageRequestBuilder } from './backgroundImage/backgroundImageRequestBuilder';
import { BannerLogoRequestBuilder } from './bannerLogo/bannerLogoRequestBuilder';
import { OrganizationalBrandingLocalizationItemRequestBuilder } from './localizations/item/organizationalBrandingLocalizationItemRequestBuilder';
import { LocalizationsRequestBuilder } from './localizations/localizationsRequestBuilder';
import { SquareLogoRequestBuilder } from './squareLogo/squareLogoRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the branding property of the microsoft.graph.organization entity.  */
export declare class BrandingRequestBuilder {
    get backgroundImage(): BackgroundImageRequestBuilder;
    get bannerLogo(): BannerLogoRequestBuilder;
    get localizations(): LocalizationsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get squareLogo(): SquareLogoRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new BrandingRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property branding for organization
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get branding from organization
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property branding in organization
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: OrganizationalBranding | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property branding for organization
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Get branding from organization
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of OrganizationalBranding
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<OrganizationalBranding | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.organization.item.branding.localizations.item collection
     * @param id Unique identifier of the item
     * @returns a organizationalBrandingLocalizationItemRequestBuilder
     */
    localizationsById(id: string): OrganizationalBrandingLocalizationItemRequestBuilder;
    /**
     * Update the navigation property branding in organization
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: OrganizationalBranding | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
