"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceSpecificPermissionGrantItemRequestBuilder = void 0;
const createResourceSpecificPermissionGrantFromDiscriminatorValue_1 = require("../../models/microsoft/graph/createResourceSpecificPermissionGrantFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const checkMemberGroupsRequestBuilder_1 = require("./checkMemberGroups/checkMemberGroupsRequestBuilder");
const checkMemberObjectsRequestBuilder_1 = require("./checkMemberObjects/checkMemberObjectsRequestBuilder");
const getMemberGroupsRequestBuilder_1 = require("./getMemberGroups/getMemberGroupsRequestBuilder");
const getMemberObjectsRequestBuilder_1 = require("./getMemberObjects/getMemberObjectsRequestBuilder");
const restoreRequestBuilder_1 = require("./restore/restoreRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the collection of resourceSpecificPermissionGrant entities.  */
class ResourceSpecificPermissionGrantItemRequestBuilder {
    /**
     * Instantiates a new ResourceSpecificPermissionGrantItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/permissionGrants/{resourceSpecificPermissionGrant_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get checkMemberGroups() {
        return new checkMemberGroupsRequestBuilder_1.CheckMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get checkMemberObjects() {
        return new checkMemberObjectsRequestBuilder_1.CheckMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get getMemberGroups() {
        return new getMemberGroupsRequestBuilder_1.GetMemberGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get getMemberObjects() {
        return new getMemberObjectsRequestBuilder_1.GetMemberObjectsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get restore() {
        return new restoreRequestBuilder_1.RestoreRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete entity from permissionGrants
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Get entity from permissionGrants by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update entity in permissionGrants
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete entity from permissionGrants
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Get entity from permissionGrants by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ResourceSpecificPermissionGrant
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createResourceSpecificPermissionGrantFromDiscriminatorValue_1.createResourceSpecificPermissionGrantFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update entity in permissionGrants
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.ResourceSpecificPermissionGrantItemRequestBuilder = ResourceSpecificPermissionGrantItemRequestBuilder;
