"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PlannerTaskItemRequestBuilder = void 0;
const createPlannerTaskFromDiscriminatorValue_1 = require("../../../../../../../models/microsoft/graph/createPlannerTaskFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const assignedToTaskBoardFormatRequestBuilder_1 = require("./assignedToTaskBoardFormat/assignedToTaskBoardFormatRequestBuilder");
const bucketTaskBoardFormatRequestBuilder_1 = require("./bucketTaskBoardFormat/bucketTaskBoardFormatRequestBuilder");
const detailsRequestBuilder_1 = require("./details/detailsRequestBuilder");
const progressTaskBoardFormatRequestBuilder_1 = require("./progressTaskBoardFormat/progressTaskBoardFormatRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the tasks property of the microsoft.graph.plannerBucket entity.  */
class PlannerTaskItemRequestBuilder {
    /**
     * Instantiates a new PlannerTaskItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/planner/plans/{plannerPlan_id}/buckets/{plannerBucket_id}/tasks/{plannerTask_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get assignedToTaskBoardFormat() {
        return new assignedToTaskBoardFormatRequestBuilder_1.AssignedToTaskBoardFormatRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get bucketTaskBoardFormat() {
        return new bucketTaskBoardFormatRequestBuilder_1.BucketTaskBoardFormatRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get details() {
        return new detailsRequestBuilder_1.DetailsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get progressTaskBoardFormat() {
        return new progressTaskBoardFormatRequestBuilder_1.ProgressTaskBoardFormatRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property tasks for planner
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Read-only. Nullable. The collection of tasks in the bucket.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property tasks in planner
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property tasks for planner
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Read-only. Nullable. The collection of tasks in the bucket.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of PlannerTask
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createPlannerTaskFromDiscriminatorValue_1.createPlannerTaskFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property tasks in planner
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.PlannerTaskItemRequestBuilder = PlannerTaskItemRequestBuilder;
