import { PolicyRoot } from '../models/microsoft/graph/';
import { ActivityBasedTimeoutPoliciesRequestBuilder } from './activityBasedTimeoutPolicies/activityBasedTimeoutPoliciesRequestBuilder';
import { ActivityBasedTimeoutPolicyItemRequestBuilder } from './activityBasedTimeoutPolicies/item/activityBasedTimeoutPolicyItemRequestBuilder';
import { AdminConsentRequestPolicyRequestBuilder } from './adminConsentRequestPolicy/adminConsentRequestPolicyRequestBuilder';
import { AuthenticationFlowsPolicyRequestBuilder } from './authenticationFlowsPolicy/authenticationFlowsPolicyRequestBuilder';
import { AuthenticationMethodsPolicyRequestBuilder } from './authenticationMethodsPolicy/authenticationMethodsPolicyRequestBuilder';
import { AuthorizationPolicyRequestBuilder } from './authorizationPolicy/authorizationPolicyRequestBuilder';
import { ClaimsMappingPoliciesRequestBuilder } from './claimsMappingPolicies/claimsMappingPoliciesRequestBuilder';
import { ClaimsMappingPolicyItemRequestBuilder } from './claimsMappingPolicies/item/claimsMappingPolicyItemRequestBuilder';
import { ConditionalAccessPoliciesRequestBuilder } from './conditionalAccessPolicies/conditionalAccessPoliciesRequestBuilder';
import { ConditionalAccessPolicyItemRequestBuilder } from './conditionalAccessPolicies/item/conditionalAccessPolicyItemRequestBuilder';
import { FeatureRolloutPoliciesRequestBuilder } from './featureRolloutPolicies/featureRolloutPoliciesRequestBuilder';
import { FeatureRolloutPolicyItemRequestBuilder } from './featureRolloutPolicies/item/featureRolloutPolicyItemRequestBuilder';
import { HomeRealmDiscoveryPoliciesRequestBuilder } from './homeRealmDiscoveryPolicies/homeRealmDiscoveryPoliciesRequestBuilder';
import { HomeRealmDiscoveryPolicyItemRequestBuilder } from './homeRealmDiscoveryPolicies/item/homeRealmDiscoveryPolicyItemRequestBuilder';
import { IdentitySecurityDefaultsEnforcementPolicyRequestBuilder } from './identitySecurityDefaultsEnforcementPolicy/identitySecurityDefaultsEnforcementPolicyRequestBuilder';
import { PermissionGrantPolicyItemRequestBuilder } from './permissionGrantPolicies/item/permissionGrantPolicyItemRequestBuilder';
import { PermissionGrantPoliciesRequestBuilder } from './permissionGrantPolicies/permissionGrantPoliciesRequestBuilder';
import { TokenIssuancePolicyItemRequestBuilder } from './tokenIssuancePolicies/item/tokenIssuancePolicyItemRequestBuilder';
import { TokenIssuancePoliciesRequestBuilder } from './tokenIssuancePolicies/tokenIssuancePoliciesRequestBuilder';
import { TokenLifetimePolicyItemRequestBuilder } from './tokenLifetimePolicies/item/tokenLifetimePolicyItemRequestBuilder';
import { TokenLifetimePoliciesRequestBuilder } from './tokenLifetimePolicies/tokenLifetimePoliciesRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the policyRoot singleton.  */
export declare class PoliciesRequestBuilder {
    get activityBasedTimeoutPolicies(): ActivityBasedTimeoutPoliciesRequestBuilder;
    get adminConsentRequestPolicy(): AdminConsentRequestPolicyRequestBuilder;
    get authenticationFlowsPolicy(): AuthenticationFlowsPolicyRequestBuilder;
    get authenticationMethodsPolicy(): AuthenticationMethodsPolicyRequestBuilder;
    get authorizationPolicy(): AuthorizationPolicyRequestBuilder;
    get claimsMappingPolicies(): ClaimsMappingPoliciesRequestBuilder;
    get conditionalAccessPolicies(): ConditionalAccessPoliciesRequestBuilder;
    get featureRolloutPolicies(): FeatureRolloutPoliciesRequestBuilder;
    get homeRealmDiscoveryPolicies(): HomeRealmDiscoveryPoliciesRequestBuilder;
    get identitySecurityDefaultsEnforcementPolicy(): IdentitySecurityDefaultsEnforcementPolicyRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get permissionGrantPolicies(): PermissionGrantPoliciesRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get tokenIssuancePolicies(): TokenIssuancePoliciesRequestBuilder;
    get tokenLifetimePolicies(): TokenLifetimePoliciesRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.activityBasedTimeoutPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a activityBasedTimeoutPolicyItemRequestBuilder
     */
    activityBasedTimeoutPoliciesById(id: string): ActivityBasedTimeoutPolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.claimsMappingPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a claimsMappingPolicyItemRequestBuilder
     */
    claimsMappingPoliciesById(id: string): ClaimsMappingPolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.conditionalAccessPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a conditionalAccessPolicyItemRequestBuilder
     */
    conditionalAccessPoliciesById(id: string): ConditionalAccessPolicyItemRequestBuilder;
    /**
     * Instantiates a new PoliciesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get policies
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update policies
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: PolicyRoot | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.featureRolloutPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a featureRolloutPolicyItemRequestBuilder
     */
    featureRolloutPoliciesById(id: string): FeatureRolloutPolicyItemRequestBuilder;
    /**
     * Get policies
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of PolicyRoot
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<PolicyRoot | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.homeRealmDiscoveryPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a homeRealmDiscoveryPolicyItemRequestBuilder
     */
    homeRealmDiscoveryPoliciesById(id: string): HomeRealmDiscoveryPolicyItemRequestBuilder;
    /**
     * Update policies
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: PolicyRoot | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.permissionGrantPolicies.item collection
     * @param id Unique identifier of the item
     * @returns a permissionGrantPolicyItemRequestBuilder
     */
    permissionGrantPoliciesById(id: string): PermissionGrantPolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.tokenIssuancePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenIssuancePolicyItemRequestBuilder
     */
    tokenIssuancePoliciesById(id: string): TokenIssuancePolicyItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.policies.tokenLifetimePolicies.item collection
     * @param id Unique identifier of the item
     * @returns a tokenLifetimePolicyItemRequestBuilder
     */
    tokenLifetimePoliciesById(id: string): TokenLifetimePolicyItemRequestBuilder;
}
