import { Print } from '../models/microsoft/graph/';
import { ConnectorsRequestBuilder } from './connectors/connectorsRequestBuilder';
import { PrintConnectorItemRequestBuilder } from './connectors/item/printConnectorItemRequestBuilder';
import { PrintOperationItemRequestBuilder } from './operations/item/printOperationItemRequestBuilder';
import { OperationsRequestBuilder } from './operations/operationsRequestBuilder';
import { PrinterItemRequestBuilder } from './printers/item/printerItemRequestBuilder';
import { PrintersRequestBuilder } from './printers/printersRequestBuilder';
import { PrintServiceItemRequestBuilder } from './services/item/printServiceItemRequestBuilder';
import { ServicesRequestBuilder } from './services/servicesRequestBuilder';
import { PrinterShareItemRequestBuilder } from './shares/item/printerShareItemRequestBuilder';
import { SharesRequestBuilder } from './shares/sharesRequestBuilder';
import { PrintTaskDefinitionItemRequestBuilder } from './taskDefinitions/item/printTaskDefinitionItemRequestBuilder';
import { TaskDefinitionsRequestBuilder } from './taskDefinitions/taskDefinitionsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the print singleton.  */
export declare class PrintRequestBuilder {
    get connectors(): ConnectorsRequestBuilder;
    get operations(): OperationsRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get printers(): PrintersRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get services(): ServicesRequestBuilder;
    get shares(): SharesRequestBuilder;
    get taskDefinitions(): TaskDefinitionsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.connectors.item collection
     * @param id Unique identifier of the item
     * @returns a printConnectorItemRequestBuilder
     */
    connectorsById(id: string): PrintConnectorItemRequestBuilder;
    /**
     * Instantiates a new PrintRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Get print
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update print
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Print | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get print
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Print
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Print | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.operations.item collection
     * @param id Unique identifier of the item
     * @returns a printOperationItemRequestBuilder
     */
    operationsById(id: string): PrintOperationItemRequestBuilder;
    /**
     * Update print
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Print | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.printers.item collection
     * @param id Unique identifier of the item
     * @returns a printerItemRequestBuilder
     */
    printersById(id: string): PrinterItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.services.item collection
     * @param id Unique identifier of the item
     * @returns a printServiceItemRequestBuilder
     */
    servicesById(id: string): PrintServiceItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.shares.item collection
     * @param id Unique identifier of the item
     * @returns a printerShareItemRequestBuilder
     */
    sharesById(id: string): PrinterShareItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.taskDefinitions.item collection
     * @param id Unique identifier of the item
     * @returns a printTaskDefinitionItemRequestBuilder
     */
    taskDefinitionsById(id: string): PrintTaskDefinitionItemRequestBuilder;
}
