import { PrinterShare } from '../../../models/microsoft/graph/';
import { AllowedGroupsRequestBuilder } from './allowedGroups/allowedGroupsRequestBuilder';
import { GroupItemRequestBuilder } from './allowedGroups/item/groupItemRequestBuilder';
import { AllowedUsersRequestBuilder } from './allowedUsers/allowedUsersRequestBuilder';
import { UserItemRequestBuilder } from './allowedUsers/item/userItemRequestBuilder';
import { PrinterRequestBuilder } from './printer/printerRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the shares property of the microsoft.graph.print entity.  */
export declare class PrinterShareItemRequestBuilder {
    get allowedGroups(): AllowedGroupsRequestBuilder;
    get allowedUsers(): AllowedUsersRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get printer(): PrinterRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.shares.item.allowedGroups.item collection
     * @param id Unique identifier of the item
     * @returns a groupItemRequestBuilder
     */
    allowedGroupsById(id: string): GroupItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.print.shares.item.allowedUsers.item collection
     * @param id Unique identifier of the item
     * @returns a userItemRequestBuilder
     */
    allowedUsersById(id: string): UserItemRequestBuilder;
    /**
     * Instantiates a new PrinterShareItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property shares for print
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The list of printer shares registered in the tenant.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property shares in print
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: PrinterShare | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property shares for print
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The list of printer shares registered in the tenant.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of PrinterShare
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<PrinterShare | undefined>;
    /**
     * Update the navigation property shares in print
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: PrinterShare | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
}
