"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SecurityRequestBuilder = void 0;
const createSecurityFromDiscriminatorValue_1 = require("../models/microsoft/graph/createSecurityFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const alertsRequestBuilder_1 = require("./alerts/alertsRequestBuilder");
const alertItemRequestBuilder_1 = require("./alerts/item/alertItemRequestBuilder");
const secureScoreControlProfileItemRequestBuilder_1 = require("./secureScoreControlProfiles/item/secureScoreControlProfileItemRequestBuilder");
const secureScoreControlProfilesRequestBuilder_1 = require("./secureScoreControlProfiles/secureScoreControlProfilesRequestBuilder");
const secureScoreItemRequestBuilder_1 = require("./secureScores/item/secureScoreItemRequestBuilder");
const secureScoresRequestBuilder_1 = require("./secureScores/secureScoresRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the security singleton.  */
class SecurityRequestBuilder {
    /**
     * Instantiates a new SecurityRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/security{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get alerts() {
        return new alertsRequestBuilder_1.AlertsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get secureScoreControlProfiles() {
        return new secureScoreControlProfilesRequestBuilder_1.SecureScoreControlProfilesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get secureScores() {
        return new secureScoresRequestBuilder_1.SecureScoresRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.alerts.item collection
     * @param id Unique identifier of the item
     * @returns a alertItemRequestBuilder
     */
    alertsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["alert_id"] = id;
        return new alertItemRequestBuilder_1.AlertItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Get security
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update security
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Get security
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Security
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createSecurityFromDiscriminatorValue_1.createSecurityFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update security
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.secureScoreControlProfiles.item collection
     * @param id Unique identifier of the item
     * @returns a secureScoreControlProfileItemRequestBuilder
     */
    secureScoreControlProfilesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["secureScoreControlProfile_id"] = id;
        return new secureScoreControlProfileItemRequestBuilder_1.SecureScoreControlProfileItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.security.secureScores.item collection
     * @param id Unique identifier of the item
     * @returns a secureScoreItemRequestBuilder
     */
    secureScoresById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["secureScore_id"] = id;
        return new secureScoreItemRequestBuilder_1.SecureScoreItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.SecurityRequestBuilder = SecurityRequestBuilder;
