"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContentTypeItemRequestBuilder = void 0;
const createContentTypeFromDiscriminatorValue_1 = require("../../../../../../models/microsoft/graph/createContentTypeFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const associateWithHubSitesRequestBuilder_1 = require("./associateWithHubSites/associateWithHubSitesRequestBuilder");
const baseRequestBuilder_1 = require("./base/baseRequestBuilder");
const baseTypesRequestBuilder_1 = require("./baseTypes/baseTypesRequestBuilder");
const contentTypeItemRequestBuilder_1 = require("./baseTypes/item/contentTypeItemRequestBuilder");
const columnLinksRequestBuilder_1 = require("./columnLinks/columnLinksRequestBuilder");
const columnLinkItemRequestBuilder_1 = require("./columnLinks/item/columnLinkItemRequestBuilder");
const columnPositionsRequestBuilder_1 = require("./columnPositions/columnPositionsRequestBuilder");
const columnDefinitionItemRequestBuilder_1 = require("./columnPositions/item/columnDefinitionItemRequestBuilder");
const columnsRequestBuilder_1 = require("./columns/columnsRequestBuilder");
const columnDefinitionItemRequestBuilder_2 = require("./columns/item/columnDefinitionItemRequestBuilder");
const copyToDefaultContentLocationRequestBuilder_1 = require("./copyToDefaultContentLocation/copyToDefaultContentLocationRequestBuilder");
const isPublishedRequestBuilder_1 = require("./isPublished/isPublishedRequestBuilder");
const publishRequestBuilder_1 = require("./publish/publishRequestBuilder");
const unpublishRequestBuilder_1 = require("./unpublish/unpublishRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the contentTypes property of the microsoft.graph.list entity.  */
class ContentTypeItemRequestBuilder {
    /**
     * Instantiates a new ContentTypeItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/sites/{site_id}/lists/{list_id}/contentTypes/{contentType_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get associateWithHubSites() {
        return new associateWithHubSitesRequestBuilder_1.AssociateWithHubSitesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get base() {
        return new baseRequestBuilder_1.BaseRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get baseTypes() {
        return new baseTypesRequestBuilder_1.BaseTypesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get columnLinks() {
        return new columnLinksRequestBuilder_1.ColumnLinksRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get columnPositions() {
        return new columnPositionsRequestBuilder_1.ColumnPositionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get columns() {
        return new columnsRequestBuilder_1.ColumnsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get copyToDefaultContentLocation() {
        return new copyToDefaultContentLocationRequestBuilder_1.CopyToDefaultContentLocationRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get publish() {
        return new publishRequestBuilder_1.PublishRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get unpublish() {
        return new unpublishRequestBuilder_1.UnpublishRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.lists.item.contentTypes.item.baseTypes.item collection
     * @param id Unique identifier of the item
     * @returns a contentTypeItemRequestBuilder
     */
    baseTypesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["contentType_id1"] = id;
        return new contentTypeItemRequestBuilder_1.ContentTypeItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.lists.item.contentTypes.item.columnLinks.item collection
     * @param id Unique identifier of the item
     * @returns a columnLinkItemRequestBuilder
     */
    columnLinksById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["columnLink_id"] = id;
        return new columnLinkItemRequestBuilder_1.ColumnLinkItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.lists.item.contentTypes.item.columnPositions.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnPositionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["columnDefinition_id"] = id;
        return new columnDefinitionItemRequestBuilder_1.ColumnDefinitionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.lists.item.contentTypes.item.columns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["columnDefinition_id"] = id;
        return new columnDefinitionItemRequestBuilder_2.ColumnDefinitionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property contentTypes for sites
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * The collection of content types present in this list.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property contentTypes in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property contentTypes for sites
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * The collection of content types present in this list.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ContentType
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createContentTypeFromDiscriminatorValue_1.createContentTypeFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Provides operations to call the isPublished method.
     * @returns a isPublishedRequestBuilder
     */
    isPublished() {
        return new isPublishedRequestBuilder_1.IsPublishedRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property contentTypes in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.ContentTypeItemRequestBuilder = ContentTypeItemRequestBuilder;
