"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OnenoteRequestBuilder = void 0;
const createOnenoteFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/createOnenoteFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const notebookItemRequestBuilder_1 = require("./notebooks/item/notebookItemRequestBuilder");
const notebooksRequestBuilder_1 = require("./notebooks/notebooksRequestBuilder");
const onenoteOperationItemRequestBuilder_1 = require("./operations/item/onenoteOperationItemRequestBuilder");
const operationsRequestBuilder_1 = require("./operations/operationsRequestBuilder");
const onenotePageItemRequestBuilder_1 = require("./pages/item/onenotePageItemRequestBuilder");
const pagesRequestBuilder_1 = require("./pages/pagesRequestBuilder");
const onenoteResourceItemRequestBuilder_1 = require("./resources/item/onenoteResourceItemRequestBuilder");
const resourcesRequestBuilder_1 = require("./resources/resourcesRequestBuilder");
const sectionGroupItemRequestBuilder_1 = require("./sectionGroups/item/sectionGroupItemRequestBuilder");
const sectionGroupsRequestBuilder_1 = require("./sectionGroups/sectionGroupsRequestBuilder");
const onenoteSectionItemRequestBuilder_1 = require("./sections/item/onenoteSectionItemRequestBuilder");
const sectionsRequestBuilder_1 = require("./sections/sectionsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the onenote property of the microsoft.graph.site entity.  */
class OnenoteRequestBuilder {
    /**
     * Instantiates a new OnenoteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/sites/{site_id}/onenote{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get notebooks() {
        return new notebooksRequestBuilder_1.NotebooksRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get operations() {
        return new operationsRequestBuilder_1.OperationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get pages() {
        return new pagesRequestBuilder_1.PagesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get resources() {
        return new resourcesRequestBuilder_1.ResourcesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get sectionGroups() {
        return new sectionGroupsRequestBuilder_1.SectionGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get sections() {
        return new sectionsRequestBuilder_1.SectionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property onenote for sites
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property onenote in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property onenote for sites
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Calls the OneNote service for notebook related operations.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Onenote
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createOnenoteFromDiscriminatorValue_1.createOnenoteFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.notebooks.item collection
     * @param id Unique identifier of the item
     * @returns a notebookItemRequestBuilder
     */
    notebooksById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["notebook_id"] = id;
        return new notebookItemRequestBuilder_1.NotebookItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.operations.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteOperationItemRequestBuilder
     */
    operationsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteOperation_id"] = id;
        return new onenoteOperationItemRequestBuilder_1.OnenoteOperationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.pages.item collection
     * @param id Unique identifier of the item
     * @returns a onenotePageItemRequestBuilder
     */
    pagesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenotePage_id"] = id;
        return new onenotePageItemRequestBuilder_1.OnenotePageItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property onenote in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.resources.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteResourceItemRequestBuilder
     */
    resourcesById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteResource_id"] = id;
        return new onenoteResourceItemRequestBuilder_1.OnenoteResourceItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.sectionGroups.item collection
     * @param id Unique identifier of the item
     * @returns a sectionGroupItemRequestBuilder
     */
    sectionGroupsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["sectionGroup_id"] = id;
        return new sectionGroupItemRequestBuilder_1.SectionGroupItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.sections.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteSectionItemRequestBuilder
     */
    sectionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteSection_id"] = id;
        return new onenoteSectionItemRequestBuilder_1.OnenoteSectionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.OnenoteRequestBuilder = OnenoteRequestBuilder;
