"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SectionGroupItemRequestBuilder = void 0;
const createSectionGroupFromDiscriminatorValue_1 = require("../../../../../models/microsoft/graph/createSectionGroupFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const parentNotebookRequestBuilder_1 = require("./parentNotebook/parentNotebookRequestBuilder");
const parentSectionGroupRequestBuilder_1 = require("./parentSectionGroup/parentSectionGroupRequestBuilder");
const sectionGroupItemRequestBuilder_1 = require("./sectionGroups/item/sectionGroupItemRequestBuilder");
const sectionGroupsRequestBuilder_1 = require("./sectionGroups/sectionGroupsRequestBuilder");
const onenoteSectionItemRequestBuilder_1 = require("./sections/item/onenoteSectionItemRequestBuilder");
const sectionsRequestBuilder_1 = require("./sections/sectionsRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the sectionGroups property of the microsoft.graph.onenote entity.  */
class SectionGroupItemRequestBuilder {
    /**
     * Instantiates a new SectionGroupItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/sites/{site_id}/onenote/sectionGroups/{sectionGroup_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get parentNotebook() {
        return new parentNotebookRequestBuilder_1.ParentNotebookRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get parentSectionGroup() {
        return new parentSectionGroupRequestBuilder_1.ParentSectionGroupRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get sectionGroups() {
        return new sectionGroupsRequestBuilder_1.SectionGroupsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get sections() {
        return new sectionsRequestBuilder_1.SectionsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    ;
    /**
     * Delete navigation property sectionGroups for sites
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * The section groups in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property sectionGroups in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property sectionGroups for sites
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * The section groups in all OneNote notebooks that are owned by the user or group.  Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of SectionGroup
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createSectionGroupFromDiscriminatorValue_1.createSectionGroupFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property sectionGroups in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.sectionGroups.item.sectionGroups.item collection
     * @param id Unique identifier of the item
     * @returns a sectionGroupItemRequestBuilder
     */
    sectionGroupsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["sectionGroup_id1"] = id;
        return new sectionGroupItemRequestBuilder_1.SectionGroupItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.onenote.sectionGroups.item.sections.item collection
     * @param id Unique identifier of the item
     * @returns a onenoteSectionItemRequestBuilder
     */
    sectionsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["onenoteSection_id"] = id;
        return new onenoteSectionItemRequestBuilder_1.OnenoteSectionItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
}
exports.SectionGroupItemRequestBuilder = SectionGroupItemRequestBuilder;
