import { Site } from '../../models/microsoft/graph/';
import { AnalyticsRequestBuilder } from './analytics/analyticsRequestBuilder';
import { ColumnsRequestBuilder } from './columns/columnsRequestBuilder';
import { ColumnDefinitionItemRequestBuilder as i0651dfe4698a70eee0ef5305cd747a2902cd5762eb79a6bc5dfdd41f40242fb4 } from './columns/item/columnDefinitionItemRequestBuilder';
import { ContentTypesRequestBuilder } from './contentTypes/contentTypesRequestBuilder';
import { ContentTypeItemRequestBuilder } from './contentTypes/item/contentTypeItemRequestBuilder';
import { DriveRequestBuilder } from './drive/driveRequestBuilder';
import { DrivesRequestBuilder } from './drives/drivesRequestBuilder';
import { DriveItemRequestBuilder } from './drives/item/driveItemRequestBuilder';
import { ExternalColumnsRequestBuilder } from './externalColumns/externalColumnsRequestBuilder';
import { ColumnDefinitionItemRequestBuilder as i69d9a20ea8706f655d5acd969cb4c0af2751247cd7b152f2ca687eb1181eca8f } from './externalColumns/item/columnDefinitionItemRequestBuilder';
import { GetActivitiesByIntervalRequestBuilder } from './getActivitiesByInterval/getActivitiesByIntervalRequestBuilder';
import { GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder } from './getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval/getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder';
import { GetApplicableContentTypesForListWithListIdRequestBuilder } from './getApplicableContentTypesForListWithListId/getApplicableContentTypesForListWithListIdRequestBuilder';
import { GetByPathWithPathRequestBuilder } from './getByPathWithPath/getByPathWithPathRequestBuilder';
import { BaseItemItemRequestBuilder } from './items/item/baseItemItemRequestBuilder';
import { ItemsRequestBuilder } from './items/itemsRequestBuilder';
import { ListItemRequestBuilder } from './lists/item/listItemRequestBuilder';
import { ListsRequestBuilder } from './lists/listsRequestBuilder';
import { OnenoteRequestBuilder } from './onenote/onenoteRequestBuilder';
import { PermissionItemRequestBuilder } from './permissions/item/permissionItemRequestBuilder';
import { PermissionsRequestBuilder } from './permissions/permissionsRequestBuilder';
import { SiteItemRequestBuilder as if9b6bcaec5c4a15417f50b4b2bb6037ae4fb788e8f7d060e671f01914a2b4f06 } from './sites/item/siteItemRequestBuilder';
import { SitesRequestBuilder } from './sites/sitesRequestBuilder';
import { TermStoreRequestBuilder } from './termStore/termStoreRequestBuilder';
import { StoreItemRequestBuilder } from './termStores/item/storeItemRequestBuilder';
import { TermStoresRequestBuilder } from './termStores/termStoresRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of site entities.  */
export declare class SiteItemRequestBuilder {
    get analytics(): AnalyticsRequestBuilder;
    get columns(): ColumnsRequestBuilder;
    get contentTypes(): ContentTypesRequestBuilder;
    get drive(): DriveRequestBuilder;
    get drives(): DrivesRequestBuilder;
    get externalColumns(): ExternalColumnsRequestBuilder;
    get items(): ItemsRequestBuilder;
    get lists(): ListsRequestBuilder;
    get onenote(): OnenoteRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get permissions(): PermissionsRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get sites(): SitesRequestBuilder;
    get termStore(): TermStoreRequestBuilder;
    get termStores(): TermStoresRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.columns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    columnsById(id: string): i0651dfe4698a70eee0ef5305cd747a2902cd5762eb79a6bc5dfdd41f40242fb4;
    /**
     * Instantiates a new SiteItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.contentTypes.item collection
     * @param id Unique identifier of the item
     * @returns a contentTypeItemRequestBuilder
     */
    contentTypesById(id: string): ContentTypeItemRequestBuilder;
    /**
     * Delete entity from sites
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entity from sites by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update entity in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Site | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete entity from sites
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.drives.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemRequestBuilder
     */
    drivesById(id: string): DriveItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.externalColumns.item collection
     * @param id Unique identifier of the item
     * @returns a columnDefinitionItemRequestBuilder
     */
    externalColumnsById(id: string): i69d9a20ea8706f655d5acd969cb4c0af2751247cd7b152f2ca687eb1181eca8f;
    /**
     * Get entity from sites by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Site
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Site | undefined>;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @returns a getActivitiesByIntervalRequestBuilder
     */
    getActivitiesByInterval(): GetActivitiesByIntervalRequestBuilder;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @param endDateTime Usage: endDateTime='{endDateTime}'
     * @param interval Usage: interval='{interval}'
     * @param startDateTime Usage: startDateTime='{startDateTime}'
     * @returns a getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder
     */
    getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime: string | undefined, interval: string | undefined, startDateTime: string | undefined): GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder;
    /**
     * Provides operations to call the getApplicableContentTypesForList method.
     * @param listId Usage: listId='{listId}'
     * @returns a getApplicableContentTypesForListWithListIdRequestBuilder
     */
    getApplicableContentTypesForListWithListId(listId: string | undefined): GetApplicableContentTypesForListWithListIdRequestBuilder;
    /**
     * Provides operations to call the getByPath method.
     * @param path Usage: path='{path}'
     * @returns a getByPathWithPathRequestBuilder
     */
    getByPathWithPath(path: string | undefined): GetByPathWithPathRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.items.item collection
     * @param id Unique identifier of the item
     * @returns a baseItemItemRequestBuilder
     */
    itemsById(id: string): BaseItemItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.lists.item collection
     * @param id Unique identifier of the item
     * @returns a listItemRequestBuilder
     */
    listsById(id: string): ListItemRequestBuilder;
    /**
     * Update entity in sites
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Site | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.permissions.item collection
     * @param id Unique identifier of the item
     * @returns a permissionItemRequestBuilder
     */
    permissionsById(id: string): PermissionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.sites.item collection
     * @param id Unique identifier of the item
     * @returns a siteItemRequestBuilder
     */
    sitesById(id: string): if9b6bcaec5c4a15417f50b4b2bb6037ae4fb788e8f7d060e671f01914a2b4f06;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.sites.item.termStores.item collection
     * @param id Unique identifier of the item
     * @returns a storeItemRequestBuilder
     */
    termStoresById(id: string): StoreItemRequestBuilder;
}
