import { ChatMessage, ChatMessageCollectionResponse } from '../../../../../../../models/microsoft/graph/';
import { CountRequestBuilder } from './count/countRequestBuilder';
import { DeltaRequestBuilder } from './delta/deltaRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the replies property of the microsoft.graph.chatMessage entity.  */
export declare class RepliesRequestBuilder {
    get count(): CountRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new RepliesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Replies for a specified message.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        count?: boolean;
        expand?: string[];
        filter?: string;
        orderby?: string[];
        search?: string;
        select?: string[];
        skip?: number;
        top?: number;
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Create new navigation property to replies for teams
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPostRequestInformation(body: ChatMessage | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Provides operations to call the delta method.
     * @returns a deltaRequestBuilder
     */
    delta(): DeltaRequestBuilder;
    /**
     * Replies for a specified message.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ChatMessageCollectionResponse
     */
    get(q?: {
        count?: boolean;
        expand?: string[];
        filter?: string;
        orderby?: string[];
        search?: string;
        select?: string[];
        skip?: number;
        top?: number;
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<ChatMessageCollectionResponse | undefined>;
    /**
     * Create new navigation property to replies for teams
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of ChatMessage
     */
    post(body: ChatMessage | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<ChatMessage | undefined>;
}
