import { Channel } from '../../../../../models/microsoft/graph/';
import { CompleteMigrationRequestBuilder } from './completeMigration/completeMigrationRequestBuilder';
import { FilesFolderRequestBuilder } from './filesFolder/filesFolderRequestBuilder';
import { ConversationMemberItemRequestBuilder } from './members/item/conversationMemberItemRequestBuilder';
import { MembersRequestBuilder } from './members/membersRequestBuilder';
import { ChatMessageItemRequestBuilder } from './messages/item/chatMessageItemRequestBuilder';
import { MessagesRequestBuilder } from './messages/messagesRequestBuilder';
import { ProvisionEmailRequestBuilder } from './provisionEmail/provisionEmailRequestBuilder';
import { RemoveEmailRequestBuilder } from './removeEmail/removeEmailRequestBuilder';
import { TeamsTabItemRequestBuilder } from './tabs/item/teamsTabItemRequestBuilder';
import { TabsRequestBuilder } from './tabs/tabsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the primaryChannel property of the microsoft.graph.team entity.  */
export declare class PrimaryChannelRequestBuilder {
    get completeMigration(): CompleteMigrationRequestBuilder;
    get filesFolder(): FilesFolderRequestBuilder;
    get members(): MembersRequestBuilder;
    get messages(): MessagesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get provisionEmail(): ProvisionEmailRequestBuilder;
    get removeEmail(): RemoveEmailRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get tabs(): TabsRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Instantiates a new PrimaryChannelRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property primaryChannel for users
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The general channel for the team.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property primaryChannel in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Channel | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property primaryChannel for users
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * The general channel for the team.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Channel
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Channel | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.joinedTeams.item.primaryChannel.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id: string): ConversationMemberItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.joinedTeams.item.primaryChannel.messages.item collection
     * @param id Unique identifier of the item
     * @returns a chatMessageItemRequestBuilder
     */
    messagesById(id: string): ChatMessageItemRequestBuilder;
    /**
     * Update the navigation property primaryChannel in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Channel | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.joinedTeams.item.primaryChannel.tabs.item collection
     * @param id Unique identifier of the item
     * @returns a teamsTabItemRequestBuilder
     */
    tabsById(id: string): TeamsTabItemRequestBuilder;
}
