"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TeamItemRequestBuilder = void 0;
const createTeamFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/createTeamFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const channelsRequestBuilder_1 = require("./channels/channelsRequestBuilder");
const channelItemRequestBuilder_1 = require("./channels/item/channelItemRequestBuilder");
const groupRequestBuilder_1 = require("./group/groupRequestBuilder");
const installedAppsRequestBuilder_1 = require("./installedApps/installedAppsRequestBuilder");
const teamsAppInstallationItemRequestBuilder_1 = require("./installedApps/item/teamsAppInstallationItemRequestBuilder");
const conversationMemberItemRequestBuilder_1 = require("./members/item/conversationMemberItemRequestBuilder");
const membersRequestBuilder_1 = require("./members/membersRequestBuilder");
const teamsAsyncOperationItemRequestBuilder_1 = require("./operations/item/teamsAsyncOperationItemRequestBuilder");
const operationsRequestBuilder_1 = require("./operations/operationsRequestBuilder");
const primaryChannelRequestBuilder_1 = require("./primaryChannel/primaryChannelRequestBuilder");
const scheduleRequestBuilder_1 = require("./schedule/scheduleRequestBuilder");
const templateRequestBuilder_1 = require("./template/templateRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the joinedTeams property of the microsoft.graph.user entity.  */
class TeamItemRequestBuilder {
    /**
     * Instantiates a new TeamItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/users/{user_id}/joinedTeams/{team_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get channels() {
        return new channelsRequestBuilder_1.ChannelsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get group() {
        return new groupRequestBuilder_1.GroupRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get installedApps() {
        return new installedAppsRequestBuilder_1.InstalledAppsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get members() {
        return new membersRequestBuilder_1.MembersRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get operations() {
        return new operationsRequestBuilder_1.OperationsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get primaryChannel() {
        return new primaryChannelRequestBuilder_1.PrimaryChannelRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get schedule() {
        return new scheduleRequestBuilder_1.ScheduleRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    get template() {
        return new templateRequestBuilder_1.TemplateRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.joinedTeams.item.channels.item collection
     * @param id Unique identifier of the item
     * @returns a channelItemRequestBuilder
     */
    channelsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["channel_id"] = id;
        return new channelItemRequestBuilder_1.ChannelItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property joinedTeams for users
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * The Microsoft Teams teams that the user is a member of. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property joinedTeams in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property joinedTeams for users
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * The Microsoft Teams teams that the user is a member of. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Team
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createTeamFromDiscriminatorValue_1.createTeamFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.joinedTeams.item.installedApps.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAppInstallationItemRequestBuilder
     */
    installedAppsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["teamsAppInstallation_id"] = id;
        return new teamsAppInstallationItemRequestBuilder_1.TeamsAppInstallationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.joinedTeams.item.members.item collection
     * @param id Unique identifier of the item
     * @returns a conversationMemberItemRequestBuilder
     */
    membersById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["conversationMember_id"] = id;
        return new conversationMemberItemRequestBuilder_1.ConversationMemberItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.joinedTeams.item.operations.item collection
     * @param id Unique identifier of the item
     * @returns a teamsAsyncOperationItemRequestBuilder
     */
    operationsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["teamsAsyncOperation_id"] = id;
        return new teamsAsyncOperationItemRequestBuilder_1.TeamsAsyncOperationItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Update the navigation property joinedTeams in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.TeamItemRequestBuilder = TeamItemRequestBuilder;
