import { Message } from '../../../../models/microsoft/graph/';
import { AttachmentsRequestBuilder } from './attachments/attachmentsRequestBuilder';
import { AttachmentItemRequestBuilder } from './attachments/item/attachmentItemRequestBuilder';
import { CalendarSharingMessageRequestBuilder } from './calendarSharingMessage/calendarSharingMessageRequestBuilder';
import { CopyRequestBuilder } from './copy/copyRequestBuilder';
import { CreateForwardRequestBuilder } from './createForward/createForwardRequestBuilder';
import { CreateReplyRequestBuilder } from './createReply/createReplyRequestBuilder';
import { CreateReplyAllRequestBuilder } from './createReplyAll/createReplyAllRequestBuilder';
import { ExtensionsRequestBuilder } from './extensions/extensionsRequestBuilder';
import { ExtensionItemRequestBuilder } from './extensions/item/extensionItemRequestBuilder';
import { ForwardRequestBuilder } from './forward/forwardRequestBuilder';
import { MoveRequestBuilder } from './move/moveRequestBuilder';
import { MultiValueLegacyExtendedPropertyItemRequestBuilder } from './multiValueExtendedProperties/item/multiValueLegacyExtendedPropertyItemRequestBuilder';
import { MultiValueExtendedPropertiesRequestBuilder } from './multiValueExtendedProperties/multiValueExtendedPropertiesRequestBuilder';
import { ReplyRequestBuilder } from './reply/replyRequestBuilder';
import { ReplyAllRequestBuilder } from './replyAll/replyAllRequestBuilder';
import { SendRequestBuilder } from './send/sendRequestBuilder';
import { SingleValueLegacyExtendedPropertyItemRequestBuilder } from './singleValueExtendedProperties/item/singleValueLegacyExtendedPropertyItemRequestBuilder';
import { SingleValueExtendedPropertiesRequestBuilder } from './singleValueExtendedProperties/singleValueExtendedPropertiesRequestBuilder';
import { ContentRequestBuilder } from './value/contentRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the messages property of the microsoft.graph.user entity.  */
export declare class MessageItemRequestBuilder {
    get attachments(): AttachmentsRequestBuilder;
    get calendarSharingMessage(): CalendarSharingMessageRequestBuilder;
    get content(): ContentRequestBuilder;
    get copy(): CopyRequestBuilder;
    get createForward(): CreateForwardRequestBuilder;
    get createReply(): CreateReplyRequestBuilder;
    get createReplyAll(): CreateReplyAllRequestBuilder;
    get extensions(): ExtensionsRequestBuilder;
    get forward(): ForwardRequestBuilder;
    get move(): MoveRequestBuilder;
    get multiValueExtendedProperties(): MultiValueExtendedPropertiesRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get reply(): ReplyRequestBuilder;
    get replyAll(): ReplyAllRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get send(): SendRequestBuilder;
    get singleValueExtendedProperties(): SingleValueExtendedPropertiesRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.attachments.item collection
     * @param id Unique identifier of the item
     * @returns a attachmentItemRequestBuilder
     */
    attachmentsById(id: string): AttachmentItemRequestBuilder;
    /**
     * Instantiates a new MessageItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete navigation property messages for users
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * The messages in a mailbox or folder. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update the navigation property messages in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: Message | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete navigation property messages for users
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.extensions.item collection
     * @param id Unique identifier of the item
     * @returns a extensionItemRequestBuilder
     */
    extensionsById(id: string): ExtensionItemRequestBuilder;
    /**
     * The messages in a mailbox or folder. Read-only. Nullable.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of Message
     */
    get(q?: {
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<Message | undefined>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.multiValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a multiValueLegacyExtendedPropertyItemRequestBuilder
     */
    multiValueExtendedPropertiesById(id: string): MultiValueLegacyExtendedPropertyItemRequestBuilder;
    /**
     * Update the navigation property messages in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: Message | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.messages.item.singleValueExtendedProperties.item collection
     * @param id Unique identifier of the item
     * @returns a singleValueLegacyExtendedPropertyItemRequestBuilder
     */
    singleValueExtendedPropertiesById(id: string): SingleValueLegacyExtendedPropertyItemRequestBuilder;
}
