"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MeetingAttendanceReportItemRequestBuilder = void 0;
const createMeetingAttendanceReportFromDiscriminatorValue_1 = require("../../../../../../models/microsoft/graph/createMeetingAttendanceReportFromDiscriminatorValue");
const createODataErrorFromDiscriminatorValue_1 = require("../../../../../../models/microsoft/graph/oDataErrors/createODataErrorFromDiscriminatorValue");
const attendanceRecordsRequestBuilder_1 = require("./attendanceRecords/attendanceRecordsRequestBuilder");
const attendanceRecordItemRequestBuilder_1 = require("./attendanceRecords/item/attendanceRecordItemRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/** Provides operations to manage the attendanceReports property of the microsoft.graph.onlineMeeting entity.  */
class MeetingAttendanceReportItemRequestBuilder {
    /**
     * Instantiates a new MeetingAttendanceReportItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        if (!pathParameters)
            throw new Error("pathParameters cannot be undefined");
        if (!requestAdapter)
            throw new Error("requestAdapter cannot be undefined");
        this.urlTemplate = "{+baseurl}/users/{user_id}/onlineMeetings/{onlineMeeting_id}/attendanceReports/{meetingAttendanceReport_id}{?select,expand}";
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(pathParameters);
        this.pathParameters = urlTplParams;
        this.requestAdapter = requestAdapter;
    }
    get attendanceRecords() {
        return new attendanceRecordsRequestBuilder_1.AttendanceRecordsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.users.item.onlineMeetings.item.attendanceReports.item.attendanceRecords.item collection
     * @param id Unique identifier of the item
     * @returns a attendanceRecordItemRequestBuilder
     */
    attendanceRecordsById(id) {
        if (!id)
            throw new Error("id cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["attendanceRecord_id"] = id;
        return new attendanceRecordItemRequestBuilder_1.AttendanceRecordItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    ;
    /**
     * Delete navigation property attendanceReports for users
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.DELETE;
        if (h)
            requestInfo.headers = h;
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * The attendance reports of an online meeting. Read-only.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q, h, o) {
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.GET;
        if (h)
            requestInfo.headers = h;
        q && requestInfo.setQueryStringParametersFromRawObject(q);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Update the navigation property attendanceReports in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body, h, o) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation();
        requestInfo.urlTemplate = this.urlTemplate;
        requestInfo.pathParameters = this.pathParameters;
        requestInfo.httpMethod = kiota_abstractions_1.HttpMethod.PATCH;
        if (h)
            requestInfo.headers = h;
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body);
        o && requestInfo.addRequestOptions(...o);
        return requestInfo;
    }
    ;
    /**
     * Delete navigation property attendanceReports for users
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createDeleteRequestInformation(h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * The attendance reports of an online meeting. Read-only.
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of MeetingAttendanceReport
     */
    get(q, h, o, responseHandler) {
        var _a, _b;
        const requestInfo = this.createGetRequestInformation(q, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendAsync(requestInfo, createMeetingAttendanceReportFromDiscriminatorValue_1.createMeetingAttendanceReportFromDiscriminatorValue, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
    /**
     * Update the navigation property attendanceReports in users
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body, h, o, responseHandler) {
        var _a, _b;
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = this.createPatchRequestInformation(body, h, o);
        const errorMapping = {
            "4XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
            "5XX": createODataErrorFromDiscriminatorValue_1.createODataErrorFromDiscriminatorValue,
        };
        return (_b = (_a = this.requestAdapter) === null || _a === void 0 ? void 0 : _a.sendNoResponseContentAsync(requestInfo, responseHandler, errorMapping)) !== null && _b !== void 0 ? _b : Promise.reject(new Error('http core is null'));
    }
    ;
}
exports.MeetingAttendanceReportItemRequestBuilder = MeetingAttendanceReportItemRequestBuilder;
