import { DriveItem } from '../../models/microsoft/graph/';
import { AnalyticsRequestBuilder } from './analytics/analyticsRequestBuilder';
import { CheckinRequestBuilder } from './checkin/checkinRequestBuilder';
import { CheckoutRequestBuilder } from './checkout/checkoutRequestBuilder';
import { ChildrenRequestBuilder } from './children/childrenRequestBuilder';
import { DriveItemItemRequestBuilder as i97c58a64396fcea6b321f90b37211f5423607f9cbe5067273f0854f0fd279683 } from './children/item/driveItemItemRequestBuilder';
import { ContentRequestBuilder } from './content/contentRequestBuilder';
import { CopyRequestBuilder } from './copy/copyRequestBuilder';
import { CreateLinkRequestBuilder } from './createLink/createLinkRequestBuilder';
import { CreateUploadSessionRequestBuilder } from './createUploadSession/createUploadSessionRequestBuilder';
import { DeltaRequestBuilder } from './delta/deltaRequestBuilder';
import { DeltaWithTokenRequestBuilder } from './deltaWithToken/deltaWithTokenRequestBuilder';
import { FollowRequestBuilder } from './follow/followRequestBuilder';
import { GetActivitiesByIntervalRequestBuilder } from './getActivitiesByInterval/getActivitiesByIntervalRequestBuilder';
import { GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder } from './getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval/getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder';
import { InviteRequestBuilder } from './invite/inviteRequestBuilder';
import { ListItemRequestBuilder } from './listItem/listItemRequestBuilder';
import { PermissionItemRequestBuilder } from './permissions/item/permissionItemRequestBuilder';
import { PermissionsRequestBuilder } from './permissions/permissionsRequestBuilder';
import { PreviewRequestBuilder } from './preview/previewRequestBuilder';
import { RestoreRequestBuilder } from './restore/restoreRequestBuilder';
import { SearchWithQRequestBuilder } from './searchWithQ/searchWithQRequestBuilder';
import { SubscriptionItemRequestBuilder } from './subscriptions/item/subscriptionItemRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { ThumbnailSetItemRequestBuilder } from './thumbnails/item/thumbnailSetItemRequestBuilder';
import { ThumbnailsRequestBuilder } from './thumbnails/thumbnailsRequestBuilder';
import { UnfollowRequestBuilder } from './unfollow/unfollowRequestBuilder';
import { ValidatePermissionRequestBuilder } from './validatePermission/validatePermissionRequestBuilder';
import { DriveItemVersionItemRequestBuilder } from './versions/item/driveItemVersionItemRequestBuilder';
import { VersionsRequestBuilder } from './versions/versionsRequestBuilder';
import { RequestAdapter, RequestInformation, RequestOption, ResponseHandler } from '@microsoft/kiota-abstractions';
/** Provides operations to manage the collection of driveItem entities.  */
export declare class DriveItemItemRequestBuilder {
    get analytics(): AnalyticsRequestBuilder;
    get checkin(): CheckinRequestBuilder;
    get checkout(): CheckoutRequestBuilder;
    get children(): ChildrenRequestBuilder;
    get content(): ContentRequestBuilder;
    get copy(): CopyRequestBuilder;
    get createLink(): CreateLinkRequestBuilder;
    get createUploadSession(): CreateUploadSessionRequestBuilder;
    get follow(): FollowRequestBuilder;
    get invite(): InviteRequestBuilder;
    get listItem(): ListItemRequestBuilder;
    /** Path parameters for the request  */
    private readonly pathParameters;
    get permissions(): PermissionsRequestBuilder;
    get preview(): PreviewRequestBuilder;
    /** The request adapter to use to execute the requests.  */
    private readonly requestAdapter;
    get restore(): RestoreRequestBuilder;
    get subscriptions(): SubscriptionsRequestBuilder;
    get thumbnails(): ThumbnailsRequestBuilder;
    get unfollow(): UnfollowRequestBuilder;
    /** Url template to use to build the URL for the current request builder  */
    private readonly urlTemplate;
    get validatePermission(): ValidatePermissionRequestBuilder;
    get versions(): VersionsRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.children.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemItemRequestBuilder
     */
    childrenById(id: string): i97c58a64396fcea6b321f90b37211f5423607f9cbe5067273f0854f0fd279683;
    /**
     * Instantiates a new DriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete entity from workbooks
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createDeleteRequestInformation(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Get entity from workbooks by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @returns a RequestInformation
     */
    createGetRequestInformation(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Update entity in workbooks
     * @param body
     * @param h Request headers
     * @param o Request options
     * @returns a RequestInformation
     */
    createPatchRequestInformation(body: DriveItem | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined): RequestInformation;
    /**
     * Delete entity from workbooks
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    delete(h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Provides operations to call the delta method.
     * @returns a deltaRequestBuilder
     */
    delta(): DeltaRequestBuilder;
    /**
     * Provides operations to call the delta method.
     * @param token Usage: token='{token}'
     * @returns a deltaWithTokenRequestBuilder
     */
    deltaWithToken(token: string | undefined): DeltaWithTokenRequestBuilder;
    /**
     * Get entity from workbooks by key
     * @param h Request headers
     * @param o Request options
     * @param q Request query parameters
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     * @returns a Promise of DriveItem
     */
    get(q?: {
        expand?: string[];
        select?: string[];
    } | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<DriveItem | undefined>;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @returns a getActivitiesByIntervalRequestBuilder
     */
    getActivitiesByInterval(): GetActivitiesByIntervalRequestBuilder;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @param endDateTime Usage: endDateTime='{endDateTime}'
     * @param interval Usage: interval='{interval}'
     * @param startDateTime Usage: startDateTime='{startDateTime}'
     * @returns a getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder
     */
    getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime: string | undefined, interval: string | undefined, startDateTime: string | undefined): GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder;
    /**
     * Update entity in workbooks
     * @param body
     * @param h Request headers
     * @param o Request options
     * @param responseHandler Response handler to use in place of the default response handling provided by the core service
     */
    patch(body: DriveItem | undefined, h?: Record<string, string> | undefined, o?: RequestOption[] | undefined, responseHandler?: ResponseHandler | undefined): Promise<void>;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.permissions.item collection
     * @param id Unique identifier of the item
     * @returns a permissionItemRequestBuilder
     */
    permissionsById(id: string): PermissionItemRequestBuilder;
    /**
     * Provides operations to call the search method.
     * @param q Usage: q='{q}'
     * @returns a searchWithQRequestBuilder
     */
    searchWithQ(q: string | undefined): SearchWithQRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.subscriptions.item collection
     * @param id Unique identifier of the item
     * @returns a subscriptionItemRequestBuilder
     */
    subscriptionsById(id: string): SubscriptionItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.thumbnails.item collection
     * @param id Unique identifier of the item
     * @returns a thumbnailSetItemRequestBuilder
     */
    thumbnailsById(id: string): ThumbnailSetItemRequestBuilder;
    /**
     * Gets an item from the github.com/microsoftgraph/msgraph-sdk-typescript/.workbooks.item.versions.item collection
     * @param id Unique identifier of the item
     * @returns a driveItemVersionItemRequestBuilder
     */
    versionsById(id: string): DriveItemVersionItemRequestBuilder;
}
